/*** This is gfx-2.6. ***/
#ifdef GFX_X11
#undef GFX_X11
#define GFX_X11 1
#endif
#ifdef GFX_FB
#undef GFX_FB
#define GFX_FB 1
#endif
#ifdef GFX_ANDROID
#undef GFX_ANDROID
#define GFX_ANDROID 1
#endif

#if (GFX_X11 + GFX_FB + GFX_ANDROID != 1)
#error "exactly one of GFX_X11, GFX_FB or GFX_ANDROID must be defined"
#endif
#ifdef GFX_X11
#include <stdarg.h>
#include <stdint.h>
#include <alloca.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <unistd.h>
#include <errno.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/ipc.h>
#include <sys/shm.h>
#include <sys/stat.h>
#include <dirent.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/extensions/XShm.h>
#include <X11/Xatom.h>
#include <X11/Xlocale.h>
#include <X11/Xos.h>
#include <X11/Xproto.h>
#define XK_MISCELLANY
#include <X11/keysymdef.h>

#endif
#ifdef GFX_FB
#include <stdarg.h>
#include <stdint.h>
#include <alloca.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <termios.h>
#include <unistd.h>
#include <errno.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <dirent.h>
#include <linux/input.h>
#include <linux/fb.h>
#include <sys/mman.h>
#include <sys/stat.h>
#include <fcntl.h>

#endif
#ifdef GFX_ANDROID
#include <jni.h>
#include <stdlib.h>
#include <alloca.h>
#include <stdio.h>
#include <math.h>
#include <stdint.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>
#include <errno.h>
#include <string.h>
#include <unistd.h>
#include <sys/resource.h>
#include <poll.h>
#include <pthread.h>
#include <sched.h>
#include <android/configuration.h>
#include <android/looper.h>
#include <android/native_activity.h>
#include <android/log.h>

#define quad_t int64_t
#define u_quad_t uint64_t

#endif
/** INCLUDE DIRECTIVE BEGIN **/
typedef struct
      {
  int   type;
  int   x, y;
  int   modifiers;
  int   button;
  int   key;
  char *string;
  void *usr;
  int wide;
  double flo0, flo1;
  unsigned long time;
      }
    gfx_event_t;

enum
{
  GFXEV_BUTTON_PRESS=1, GFXEV_BUTTON_RELEASE, GFXEV_DOUBLE_CLICK,
  GFXEV_KEY_PRESS,      GFXEV_KEY_RELEASE,
  GFXEV_POINTER_MOVE,   
  GFXEV_READY_READ, GFXEV_READY_WRITE, GFXEV_READY_EXCEPT,
  GFXEV_QUIT, GFXEV_LAST,
};

#define GFXEV(X,Y) (((X)<<8)|(GFXEV_##Y))

#define GFXRESERVED 24

/* The event routine returns an event from the queue. It waits a maximum
   of 'msecs' milliseconds for the event. If msecs is zero, it waits
   until an event is received.

   The return value is one if an event is returned. It's zero if the
   return was due to timeout.

   In case of an event, *msecs is updated to reflect the remaining
   wait time.  */

int gfx_event(unsigned int *msecs,gfx_event_t *Revent);

enum
{ 
   GFX_K_PRT=1, 
   GFX_K_BACKSPACE,     GFX_K_TAB,      GFX_K_RETURN, GFX_K_ESCAPE,
   GFX_K_INSERT,        GFX_K_DELETE,   GFX_K_HOME,   GFX_K_END,
   GFX_K_PAGEUP,        GFX_K_PAGEDOWN,
   GFX_K_LEFT,          GFX_K_RIGHT,    GFX_K_DOWN,   GFX_K_UP,
   GFX_K_CONTROL=0x100, GFX_K_SHIFT= 0x200 , GFX_K_ALT= 0x400,
};

int gfx_init(char *name, int width, int height, char *title);
void gfx_close();


void gfx_geometry(unsigned int *W, unsigned int *H);
void gfx_monitor_file(int fd, int ident, int R,int W,int X);
void gfx_stop_monitor_file(int fd,int ident);
void gfx_leave_screen();
void gfx_set_state(int wno, int state);
int  gfx_get_state(int wno);
int  gfx_get_selected(int wno);
void gfx_set_selected(int wno,int sel);
void gfx_set_text(int wno,char *str);
void gfx_set_fgbg(int wno, int fg, int bg);
void gfx_insert(int wno,int pos, char *text,void *user,unsigned int* icon);
void gfx_remove(int wno, int pos, void **Ruser);
char* gfx_get_text(int wno);
void gfx_clear(int wno);
void gfx_focus(int wno);
void gfx_text_data(int font, const char *str, 
                   int *Rw, int *Rh,int *Ra,unsigned char **Rd);
void gfx_scrollbar_set(int wno, double start, double end, double step);
void gfx_pixgrid_attribs(int pg, int *Rshown, unsigned int *Rw, unsigned int *Rh);
void gfx_pixgrid_put(int pg, int x,int y,
                     unsigned int *img, unsigned int iW,unsigned int iH,
                     int src_x, int src_y, 
                     int copy_w, int copy_h);
void gfx_pixgrid_putsimple(int pg, unsigned int *img);
 
int gfx_ask(char *title, char *butstr, char *fmt, ...);
char* gfx_select_file(int mode,char *init,char **types);
void gfx_canvas_setsize(int wno, int new_w, int new_h);
void gfx_canvas_draw_rectangle(int wno,int color, int x,int y,int w,int h);
void gfx_canvas_fill_rectangle(int wno,int color, int x,int y,int w,int h);
void gfx_canvas_recsel_begin(int wno, gfx_event_t *ev);
void gfx_canvas_recsel_end(int wno,int *Rx1, int *Ry1, int *Rx2, int *Ry2);
void gfx_canvas_print(int font, int color, int rot, int x, int y, char *str);
void gfx_canvas_put_graymap
       (int wno, unsigned int color, int dx,int dy, int w, int h,
        unsigned char *source, int sw, int sh, int sx, int sy);
void gfx_canvas_put
       (int wno, int dx,int dy, int w, int h,
        unsigned int *source, int sw, int sh, int sx, int sy);
void gfx_spinner_set_imin(int wno, int min);
void gfx_spinner_set_imax(int wno, int max);
void gfx_spinner_set_iquant(int wno, int qua);
void gfx_spinner_set_fmin(int wno, double min);
void gfx_spinner_set_fmax(int wno, double max);
void gfx_spinner_set_fquant(int wno, double qua);
void gfx_spinner_set_fvalue(int wno, double value);
void gfx_spinner_set_ivalue(int wno, int value);
int gfx_spinner_get_ivalue(int wno);
double gfx_spinner_get_fvalue(int wno);
void gfx_logview_printf(int wno, const char *fmt, ...);
void gfx_logview_write(int wno, const char *txt, size_t len);
void gfx_logview_clear(int wno);

#ifdef GFX_ANDROID
JavaVM *gfx_get_javavm();
#endif

enum { _XX_WIDGETS_START=GFXEV_LAST+GFXRESERVED,
  /* WIDGET NAMES BELOW */
  Wleft,
  Wfnleft,
  Wurlleft,
  Wsaveleft,
  Wloadleft,
  Wtitleleft,
  Wdelleft,
  Wupdateleft,
  Wputright,
  Wfnright,
  Wloadright,
  Wsaveright,
  Wright,
  Wurlright,
  Wtitleright,
  Wdelright,
  Wupdateright,
  Wputleft,
  Wparentleft,
  Wmkdirleft,
  Wupleft,
  Wdnleft,
  Wdnright,
  Wupright,
  Wmkdirright,
  Wparentright,
  WfolTITLE,
  WfolLAB0,
  WfolNAME,
  WfolOK,
  WfolCANCEL,

 _XX_WIDGETS_END };
void gfx_SCREEN_0();
void gfx_SCRmkfolder();
extern unsigned int GFXRES_directory[];
extern unsigned int res0[];
#define _MPRINTF_PROTO static
#ifndef _mprintf_h_included
#define _mprintf_h_included

#ifndef _MPRINTF_PROTO 
#define _MPRINTF_PROTO 
#endif

_MPRINTF_PROTO size_t
vgprintf    (void (*func)(void *,const char *, size_t), void *arg,
             char const *fmt, va_list ap);

_MPRINTF_PROTO size_t fdprintf(int fd, const char *fmt, ...);

_MPRINTF_PROTO char* mprintf(const char *fmt, ...);
_MPRINTF_PROTO char *vmprintf(const char *fmt, va_list ap);

#endif
/*-
 * Copyright (c) 1986, 1988, 1991, 1993
 *	The Regents of the University of California.  All rights reserved.
 * (c) UNIX System Laboratories, Inc.
 * All or some portions of this file are derived from material licensed
 * to the University of California by American Telephone and Telegraph
 * Co. or Unix System Laboratories, Inc. and are reproduced herein with
 * the permission of UNIX System Laboratories, Inc.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)subr_prf.c	8.3 (Berkeley) 1/21/94
 */
#define __USE_BSD 1
#include <sys/types.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <stdarg.h>
#include <ctype.h>
#include <errno.h>
#include <unistd.h>

#define NBBY    8               /* number of bits in a byte */
static char const hex2ascii_data[] = "0123456789abcdefghijklmnopqrstuvwxyz";
#define hex2ascii(hex)  (hex2ascii_data[hex])

/* Max number conversion buffer length: a u_quad_t in base 2, plus NUL byte. */
#define MAXNBUF	(sizeof(intmax_t) * NBBY + 1)

/*
 * Put a NUL-terminated ASCII number (base <= 36) in a buffer in reverse
 * order; return an optional length and a pointer to the last character
 * written in the buffer (i.e., the first character of the string).
 * The buffer pointed to by `nbuf' must have length >= MAXNBUF.
 */
static char *
ksprintn(char *nbuf, uintmax_t num, int base, int *lenp, int upper)
{
	char *p, c;

	p = nbuf;
	*p = '\0';
	do {
		c = hex2ascii(num % base);
		*++p = upper ? toupper(c) : c;
	} while (num /= base);
	if (lenp)
		*lenp = p - nbuf;
	return (p);
}

/*
 * Scaled down version of printf(3).
 *
 * Two additional formats:
 *
 * The format %b is supported to decode error registers.
 * Its usage is:
 *
 *	printf("reg=%b\n", regval, "*");
 *
 * where  is the output base expressed as a control character, e.g.
 * \10 gives octal; \20 gives hex.  Each arg is a sequence of characters,
 * the first of which gives the bit number to be inspected (origin 1), and
 * the next characters (up to a control character, i.e. a character <= 32),
 * give the name of the register.  Thus:
 *
 *	kvprintf("reg=%b\n", 3, "\10\2BITTWO\1BITONE\n");
 *
 * would produce output:
 *
 *	reg=3
 *
 * XXX:  %D  -- Hexdump, takes pointer and separator string:
 *		("%6D", ptr, ":")   -> XX:XX:XX:XX:XX:XX
 *		("%*D", len, ptr, " " -> XX XX XX XX ...
 */
_MPRINTF_PROTO size_t
vgprintf(void (*func)(void *,const char *, size_t), void *arg,
         char const *fmt, va_list ap)
{
#define PCHAR(c) do {char cc=(c); (*func)(arg,&cc,1); retval++;} while(0)
	char nbuf[MAXNBUF];
	const char *p, *percent, *q;
	u_char *up;
	int ch, n;
	uintmax_t num;
	int base, lflag, qflag, tmp, width, ladjust, sharpflag, neg, sign, dot;
	int cflag, hflag, jflag, tflag, zflag;
	int dwidth, upper;
	char padc;
	int stop = 0, retval = 0;
        int radix= 10;

	num = 0;

	if (fmt == NULL)
		fmt = "(fmt null)\n";

	if (radix < 2 || radix > 36)
		radix = 10;

	for (;;) {
		padc = ' ';
		width = 0;
		while ((ch = (u_char)*fmt++) != '%' || stop) {
			if (ch == '\0')
				return (retval);
			PCHAR(ch);
		}
		percent = fmt - 1;
		qflag = 0; lflag = 0; ladjust = 0; sharpflag = 0; neg = 0;
		sign = 0; dot = 0; dwidth = 0; upper = 0;
		cflag = 0; hflag = 0; jflag = 0; tflag = 0; zflag = 0;
reswitch:	switch (ch = (u_char)*fmt++) {
		case '.':
			dot = 1;
			goto reswitch;
		case '#':
			sharpflag = 1;
			goto reswitch;
		case '+':
			sign = 1;
			goto reswitch;
		case '-':
			ladjust = 1;
			goto reswitch;
		case '%':
			PCHAR(ch);
			break;
		case '*':
			if (!dot) {
				width = va_arg(ap, int);
				if (width < 0) {
					ladjust = !ladjust;
					width = -width;
				}
			} else {
				dwidth = va_arg(ap, int);
			}
			goto reswitch;
		case '0':
			if (!dot) {
				padc = '0';
				goto reswitch;
			}
		case '1': case '2': case '3': case '4':
		case '5': case '6': case '7': case '8': case '9':
				for (n = 0;; ++fmt) {
					n = n * 10 + ch - '0';
					ch = *fmt;
					if (ch < '0' || ch > '9')
						break;
				}
			if (dot)
				dwidth = n;
			else
				width = n;
			goto reswitch;
		case 'b':
			num = (u_int)va_arg(ap, int);
			p = va_arg(ap, char *);
			for (q = ksprintn(nbuf, num, *p++, NULL, 0); *q;)
				PCHAR(*q--);

			if (num == 0)
				break;

			for (tmp = 0; *p;) {
				n = *p++;
				if (num & (1 << (n - 1))) {
					PCHAR(tmp ? ',' : '<');
					for (; (n = *p) > ' '; ++p)
						PCHAR(n);
					tmp = 1;
				} else
					for (; *p > ' '; ++p)
						continue;
			}
			if (tmp)
				PCHAR('>');
			break;
		case 'c':
			PCHAR(va_arg(ap, int));
			break;
		case 'D':
			up = va_arg(ap, u_char *);
			p = va_arg(ap, char *);
			if (!width)
				width = 16;
			while(width--) {
				PCHAR(hex2ascii(*up >> 4));
				PCHAR(hex2ascii(*up & 0x0f));
				up++;
				if (width)
					for (q=p;*q;q++)
						PCHAR(*q);
			}
			break;
		case 'd':
		case 'i':
			base = 10;
			sign = 1;
			goto handle_sign;
		case 'h':
			if (hflag) {
				hflag = 0;
				cflag = 1;
			} else
				hflag = 1;
			goto reswitch;
		case 'j':
			jflag = 1;
			goto reswitch;
		case 'l':
			if (lflag) {
				lflag = 0;
				qflag = 1;
			} else
				lflag = 1;
			goto reswitch;
		case 'n':
			if (jflag)
				*(va_arg(ap, intmax_t *)) = retval;
			else if (qflag)
				*(va_arg(ap, quad_t *)) = retval;
			else if (lflag)
				*(va_arg(ap, long *)) = retval;
			else if (zflag)
				*(va_arg(ap, size_t *)) = retval;
			else if (hflag)
				*(va_arg(ap, short *)) = retval;
			else if (cflag)
				*(va_arg(ap, char *)) = retval;
			else
				*(va_arg(ap, int *)) = retval;
			break;
		case 'o':
			base = 8;
			goto handle_nosign;
		case 'p':
			base = 16;
			sharpflag = (width == 0);
			sign = 0;
			num = (uintptr_t)va_arg(ap, void *);
			goto number;
		case 'q':
			qflag = 1;
			goto reswitch;
		case 'r':
			base = radix;
			if (sign)
				goto handle_sign;
			goto handle_nosign;
		case 's':
			p = va_arg(ap, char *);
			if (p == NULL)
				p = "(null)";
			if (!dot)
				n = strlen (p);
			else
				for (n = 0; n < dwidth && p[n]; n++)
					continue;

			width -= n;

			if (!ladjust && width > 0)
				while (width--)
					PCHAR(padc);
			while (n--)
				PCHAR(*p++);
			if (ladjust && width > 0)
				while (width--)
					PCHAR(padc);
			break;
		case 't':
			tflag = 1;
			goto reswitch;
		case 'u':
			base = 10;
			goto handle_nosign;
		case 'X':
			upper = 1;
		case 'x':
			base = 16;
			goto handle_nosign;
		case 'y':
			base = 16;
			sign = 1;
			goto handle_sign;
		case 'z':
			zflag = 1;
			goto reswitch;
handle_nosign:
			sign = 0;
			if (jflag)
				num = va_arg(ap, uintmax_t);
			else if (qflag)
				num = va_arg(ap, u_quad_t);
			else if (tflag)
				num = va_arg(ap, ptrdiff_t);
			else if (lflag)
				num = va_arg(ap, u_long);
			else if (zflag)
				num = va_arg(ap, size_t);
			else if (hflag)
				num = (u_short)va_arg(ap, int);
			else if (cflag)
				num = (u_char)va_arg(ap, int);
			else
				num = va_arg(ap, u_int);
			goto number;
handle_sign:
			if (jflag)
				num = va_arg(ap, intmax_t);
			else if (qflag)
				num = va_arg(ap, quad_t);
			else if (tflag)
				num = va_arg(ap, ptrdiff_t);
			else if (lflag)
				num = va_arg(ap, long);
			else if (zflag)
				num = va_arg(ap, ssize_t);
			else if (hflag)
				num = (short)va_arg(ap, int);
			else if (cflag)
				num = (char)va_arg(ap, int);
			else
				num = va_arg(ap, int);
number:
			if (sign && (intmax_t)num < 0) {
				neg = 1;
				num = -(intmax_t)num;
			}
			p = ksprintn(nbuf, num, base, &tmp, upper);
			if (sharpflag && num != 0) {
				if (base == 8)
					tmp++;
				else if (base == 16)
					tmp += 2;
			}
			if (neg)
				tmp++;

			if (!ladjust && padc != '0' && width
			    && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);
			if (neg)
				PCHAR('-');
			if (sharpflag && num != 0) {
				if (base == 8) {
					PCHAR('0');
				} else if (base == 16) {
					PCHAR('0');
					PCHAR('x');
				}
			}
			if (!ladjust && width && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);

			while (*p)
				PCHAR(*p--);

			if (ladjust && width && (width -= tmp) > 0)
				while (width--)
					PCHAR(padc);

			break;
		default:
			while (percent < fmt)
				PCHAR(*percent++);
			/*
			 * Since we ignore an formatting argument it is no
			 * longer safe to obey the remaining formatting
			 * arguments as the arguments will no longer match
			 * the format specs.
			 */
			stop = 1;
			break;
		}
	}
#undef PCHAR
}

static void write_buf
     (char **x,const char *b,size_t len)
{
    memcpy(*x,b,len);
    *x += len;
}

static void ignore
     (void *arg, const char *b, size_t len)
{
}

_MPRINTF_PROTO char *vmprintf(const char *fmt, va_list ap)
{
    va_list ap2;
    size_t size;
    char *ret,*x;
    int eno;

    eno= errno;

    va_copy(ap2,ap);
    size= vgprintf((void*) ignore, NULL, fmt, ap2);
    va_end(ap2);

    x= ret= malloc(size+1);
    if (ret)
    {
        errno= eno;
        vgprintf((void*) write_buf, (void*) &x,fmt, ap);
    }
    ret[size]= 0;
    return ret;
}

_MPRINTF_PROTO char *mprintf(const char *fmt, ...)
{
    va_list ap;
    char *ret;
    va_start(ap,fmt);
    ret= vmprintf(fmt, ap);
    va_end(ap);
    return ret;
}

static void write_fd(void *arg, const char *buf, size_t len)
{
  write(*(int*)arg, buf,len);
}

_MPRINTF_PROTO size_t fdprintf
      (int fd, const char *fmt, ...)
{
    va_list ap;
    size_t ret;
    va_start(ap,fmt);
    ret= vgprintf(write_fd, &fd, fmt, ap);
    va_end(ap);
    return ret;
}

#ifdef GFX_ANDROID

#define LOGI(...) \
  ((void)__android_log_print(ANDROID_LOG_INFO, "threaded_app", __VA_ARGS__))
#define LOGE(...) \
  ((void)__android_log_print(ANDROID_LOG_ERROR, "threaded_app", __VA_ARGS__))

#ifndef NDEBUG
#  define LOGV(...) \
  ((void)__android_log_print(ANDROID_LOG_VERBOSE, "threaded_app", __VA_ARGS__))
#else
#  define LOGV(...)  ((void)0)
#endif


#define  PIPE_CMD    1
#define  PIPE_EVENT  2
#define  PIPE_SENSOR 3

  
enum
{
  CMD_APP_START,
  CMD_APP_STOP,
  CMD_APP_RESUME,
  CMD_APP_PAUSE,
  CMD_WINDOW_DESTROYED,
  CMD_WINDOW_CREATED,
  CMD_WINDOW_RESIZED,
  CMD_WINDOW_REDRAW,
  CMD_WINDOW_CONTENTRECT,
  CMD_SAVE_STATE,
  CMD_FOCUS_CHANGE,
  CMD_LOW_MEMORY,
  CMD_CONFIG_CHANGE,
  CMD_INPUTQ_DESTROYED,
  CMD_INPUTQ_CREATED,
  CMD_QUIT
};


#define x_red_mask    0x0000ff
#define x_green_mask  0x00ff00
#define x_blue_mask   0xff0000
#define x_red_shift   0
#define x_green_shift 8
#define x_blue_shift  16

#endif

#define GFX_UPDATE (1<<0)
#define GFX_ALPHA  (1<<1)
#define GFX_ORDER  (1<<0)    // order returned coordinates
#define GFX_BACKGND (1<<2)   // use background color instead of pixel buffer
#define GFX_FOCUS (1<<6)
#define GFX_HORIZONTAL (1<<7)
#define GFX_VERTICAL   (1<<8)
#define GFX_NOICON     (1<<9)
#define GFX_MULTISELECT (1<<3)

#define RES_COLOR(x,y,z) static uint32_t x= y
#define RES_INT RES_COLOR
#define RES_GRAYIMG(x,y) static const unsigned char x[]= {
#define RES_END };
#define RES_COLORIMG(x,y) unsigned int x[]= {
#define RES_STRING(x,y,z) static const char *x= y

/***********************************************************************
 *                                                                     *
 *                                TYPES                                *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11
/***********************************************************************
  Images can be shared on non-shared. They are represented by the
  following struct.
 ***********************************************************************/
typedef struct 
{
  uint32_t *data;
  unsigned int width,height, bpl;
  int shared;
  XShmSegmentInfo shminfo;
  XImage *x11image;
} ximage_t;


typedef struct xkeyb
{
  int method;
  Window window;
  XIC ic;
  char *buf;
  size_t sbuf;
  uint32_t *wbuf;
  size_t swbuf;
} x_keyboard_t;


#endif
#ifdef GFX_FB

typedef struct {
  int type;     // one of 'M'odifier 'C'ontrol 'P'rintable. 0 if unknown
  char *lo,*hi; // with and without shift
  int value;    // modifier value or control key value
  char ss[4];
} kbmap_t;

#endif
#ifdef GFX_ANDROID
typedef struct req request_t;
typedef struct app app_t;

/***********************************************************************
 *##B                                                                  *
 *                         Application Object                          *
 *                                                                     *
 ***********************************************************************
  The application object is called an 'instance' in the android documents.
  It contains the necessary data to properly handle and serialize events.
  Window handle etc. are also contained in this object.
 ***********************************************************************/

struct app {
      // command pipe. This is used for reporting system events such
      // as Pause, Resume, etc.
  int cmdpipe_r, cmdpipe_w;

      // The worker thread is actually the 'main' thread for our
      // application. It initializes the input system and then calls
      // android_main. When that function is done, it rips up the
      // input/output objects and quits.
  pthread_t worker_thread;

      // These two are used for signalling various conditions. 
  pthread_mutex_t mutex;
  pthread_cond_t cond;

      // This is one of the conditions. When this is set to 1, 
      // the thread which fired off the worker thread can continue
      // in its Java world.
  int running;

  void *init_state; size_t init_state_size;

  ANativeActivity *activity;
  ALooper *looper;
  AConfiguration *config;
  AInputQueue *inputq;
  ANativeWindow *window;

  request_t *quit_request;
  int last_pointer_id;
};


struct req {
  int type;
  int complete;
  union {
    ANativeWindow *window;
    AInputQueue   *inputq;
    struct {
       void* ptr;
       size_t size;
    }             buffer; 
    int           intv;
  } d;
};

#endif

typedef struct
{
  int ident;
  unsigned int value;
  int (*func)(void *,gfx_event_t *);
  void *arg;
} gui_timer_t;


typedef struct
{
  int fd;
  int ident;
  int events; // 1=read 2=write 4=except
} file_monitor_t;


typedef struct widget
{
  int x,y,w,h;
  int klass;
  int number;   // this is for accessing the array from the pointer

  char can_focus, has_focus;
  void (*focus)(void *,int);
  int  (*handle_key)(void *,gfx_event_t *);

  int shown;
  void (*show)(struct widget *);
  void (*hide)(struct widget *);
  void (*position)(struct widget *,int ,int ,int ,int ); // x y w h
  void (*destroy)(struct widget *);
} widget_t;

typedef struct
{
  int ident;
  int n_widgets,s_widgets;
  widget_t **widgets;
} radio_group_t;


enum {
  GFXCLASS_BUTTON,
  GFXCLASS_TOGGLE,

 GFXCLASS_LABEL,

  GFXCLASS_RADIO,
  GFXCLASS_CHECKBOX,

  GFXCLASS_SCROLLBAR,

 GFXCLASS_PANEL,

  GFXCLASS_DROPDOWN,

 GFXCLASS_LIST,

  GFXCLASS_TEXTENTRY,

  GFXCLASS_PIXGRID,

  GFXCLASS_CANVAS,

GFXCLASS_SPINNER,

  GFXCLASS_LOGVIEW,

};


typedef struct
{
  int  x,y,w,h;
  int  (*func)(void *,gfx_event_t*);
  void *arg;
  int  *enabled;
  int button;
} click_handler_t;

typedef struct screen
{
  int n_widgets;
  int *widgets;

  int n_click_handlers, s_click_handlers;
  click_handler_t *click_handlers;
  click_handler_t release_handler;
  click_handler_t motion_handler;
  click_handler_t grabber;

  widget_t *focus_widget;
  widget_t *focus_clicked;

  struct screen *next;
  uint32_t *backstore;
  uint32_t back_w, back_h;

  int x,y,w,h; 

  int n_rgroups, s_rgroups;
  radio_group_t *rgroups;

  int n_timers,s_timers;
  gui_timer_t *timers;
} screen_t;


typedef struct
{
  widget_t widget;
  char *text;
  uint32_t *icon;
  int iconpos; // 'T' 'B' 'L' 'R'
  int state;  //0 = normal, 1= depressed 
  int enabled; 
  int click_handler;

  int (*click_func)(void *,gfx_event_t *);
  int (*release_func)(void *,gfx_event_t *);
  void *click_arg;
} gui_button_t;

typedef struct 
{
  widget_t widget;
  int font, fg, bg;
  int just;
  char *text;
} gui_label_t;


typedef struct radio
{
  widget_t widget;
  int state; 
  int enabled;
  int click;
  int change;  
  int group;
  char *text;
} radio_t;


typedef struct checkbox
{
  widget_t widget;
  int state; 
  int enabled;
  int click;
  char *text;
} checkbox_t;


typedef struct
{
  widget_t widget;
  double start, end;          // start/end points for the sliding button
  double step;                // step amount for up/down left/right buttons
  int tro_c0, tro_c1, tro_dc; // start/end points for trough. can be X or 
                              // Y coordinates dc is the difference between
                              // them, but normalized to prevent divide by zero
  int but_c0, but_c1;         // start/end points for button

  int tro_x, tro_y, tro_w, tro_h; // used for updates
  int last_seen_c;

  int enabled;                // for enabling/disabling clicks

  int orient;

  int action;                 // action is used for reporting changes to user.
  void *reportarg;            // the following two are used for reporting
                              // to other widgets.
  void (*reportfunc)(void *, double, double);
  
  // stepper button position
  int SX[2], SY[2];
  // stepper button images, 0 = Up-normal 1= Up-pressed 2-Down-normal ..
  uint32_t *SD[4], SW[4], SH[4];

    // click handler entries
    // 0= up button 
    // 1= down button
    // 2= trough
  int ch0, ch1, ch2;
} scrollbar_t;


typedef struct
{
  int n_widgets;
  int *widgets;
} subscreen_t;

typedef struct
{
  widget_t widget;
  int enabled;
  int active;
  int n_subs;
  subscreen_t *subs;
} panel_t;


typedef struct { void* ptr; char *str; } TUPsp_t;

typedef struct
{
  widget_t widget;
  int shown;
  int n_items, s_items;
  TUPsp_t *items;
  int selected;

  int click_handler;
  int click_enabled;

  int list_active;

  // list stuff
  int list_x,list_y,list_w,list_h;
  int list_px, list_py, list_pw, list_ph; // port coords
  unsigned int *list_backup;
  int fh;
  scrollbar_t *scroll;
  int posy;
  int list_cont_h;  // content height

  int but1clicked;
  int selitem;
  int action;
} dropdown_t;


typedef struct
{
  char *str;
  const unsigned int *icon_data;
  unsigned int icon_width, icon_height;
  int selected;
  void *user;

  int y;
  int w,h;
  int icon_y,icon_x,text_y,text_x;
  int text_w, text_h;
} list_item_t;


typedef struct
{
  widget_t widget;
  int n_items, s_items;
  list_item_t *items;

  int posx, posy; // scrolled position

  int has_scrollv, has_scrollh;
  scrollbar_t *scrollv, *scrollh;

  int content_w, content_h;
  int port_w, port_h;
  int port_x, port_y;

  int max_icon_width;
  int uses_icons;
  int multiselect;

  int enabled;
  int ch0;    // ID of the click handler, we use this
              // to modify the click area when the
              // scrollbars appear/disappear
  int ch1,ch2; // mouse buttons 4 and 5
  int click_action; // not reported if 0

    // for double click
  unsigned long click_time;
  int click_index;
 
  int x,y,w,h;
} gui_list_t;


typedef struct { uint32_t chr; uint8_t  *d; uint32_t w; int x; } glyph_t;

typedef struct 
 { widget_t widget;
   int x,y,w,h; glyph_t *glyphs; int size, len;
   int fonth;
   uint32_t left; int cursor; 
   int (*key_filter)(void *,void *,gfx_event_t *);
   void *key_arg;
   } text_entry_t;


typedef struct
{
  widget_t widget;
  int enabled; 
  int click_handler;
} gui_pixgrid_t;


#define _BUFFER_PROTO static

typedef struct buffer buffer_t;
#ifndef _BUFFER_PROTO
#define _BUFFER_PROTO 
#endif


struct buffer_node { 
  struct buffer_node *next;
  size_t len,size,start;
  unsigned char data[1];
};

struct buffer {
  struct buffer_node *first, *last;
  size_t blksize;
};




typedef struct
{
  char *label;
  char *dir;
  int width;
} fsent_t;

typedef struct
{
  int n_dirs;
  fsent_t *dirs;
  int dir_start, dir_end;

  int nfiles, shown;
  char **files;

  char **types;
  char **ext;

  char *dir;
  int x,y,w,h;
  int button_h;
  int dirst_y;
} filesel_t;



typedef struct
{
  widget_t widget;
  int buffer_w, buffer_h;
  uint32_t *buffer;
  int enabled;

  int pos_x, pos_y,port_w,port_h;
  int have_scrollh, have_scrollv;
  scrollbar_t *scrollh, *scrollv;
  int too_small; // the display is too small for the
                 // scrollbars to fit.

  int click1, click3;

  int recsel;
  int rs_x0, rs_y0, rs_x1, rs_y1;
} gui_canvas_t;


typedef struct
{
  widget_t widget;
  int type; // 'F' = float 'I'= integer
  int frac; // fractional digits

  int intv, intq, intmin, intmax;
  double flov, floq, flomin, flomax;
  int limflags;

  int enabled;
  int timer, count;

  gui_button_t less,more;
  widget_t *label;
} gui_spinner_t;


#define SPINNER_MIN 1
#define SPINNER_MAX 2


typedef struct
{
  widget_t widget;
  int nlines,slines;
  char **lines;
  int last_line_incomplete;

  int fh;
  int cx, cy;
  int px, py, pw, ph;
} gui_logview_t;


// Reserved widget numbers
enum { 
     // confirmation dialog buttons
  GUIRaskB1=GFXEV_LAST, GUIRaskB2, GUIRaskB3, GUIRaskB4, GUIRaskB5,
  GUIRaskB6, GUIRaskB7, GUIRaskB8,
     // file selector widgets
  GUIRfilD1, GUIRfilD2, GUIRfilD3, GUIRfilD4, GUIRfilD5, GUIRfilD6,
  GUIRfilD7, GUIRfilD8, GUIRfilD9, GUIRfilD10, 
  GUIRfilHOME, GUIRfilREFRESH, GUIRfilOK, GUIRfilCANCEL, GUIRfilLIST,
  GUIRfilNAME,
     };



/***********************************************************************
 *                                                                     *
 *                             PROTOTYPES                              *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

 
static uint32_t trailing_zero_bits(uint32_t Y);
static int get_x_visual();
static Window create_window(char *title,int width, int height);
static void get_root_attribs();
int gfx_init(char *name, int width, int height, char *title);
 
static ximage_t *create_image(uint32_t width, uint32_t height);
static ximage_t *ximage_create_simple(uint32_t width,uint32_t height);
static void destroy_image(ximage_t *image);
 
static void put_image(Drawable draw, int dest_x, int dest_y,
               ximage_t *image, int src_x, int src_y,
               int width, int height);
 
static int can_use_shared_images();
static void gfx_update(int x,int y,int width,int height);
void gfx_close();
static void checker_pattern(ximage_t *img,int N);
static x_keyboard_t *x_keyboard_init(Window window);
static void x_keyboard_free(x_keyboard_t *xk);
static void get_xim();
static int x_keyboard_event
             (x_keyboard_t *xk, XEvent *ev, gfx_event_t *Revent);
static uint32_t keysym2ucs(KeySym keysym);
 
static int lookup_key(KeySym sym, unsigned int modifiers);
static void tv2msecs(struct timeval *tv, unsigned int* msecs);
static int event_noprocess(unsigned int *msecs,gfx_event_t *Revent);
#endif
#ifdef GFX_ANDROID

void ANativeActivity_onCreate
      (ANativeActivity* activity, void* state, size_t state_size);
   static void* worker_entry(void* arg);
static void make_request(app_t *A, request_t *R);
static int get_request(app_t *A,request_t **R);
static void complete_request(app_t *A, request_t *R);
static void simple_command(ANativeActivity *ac, int cmd);
static void onStart(ANativeActivity* activity);
static void onResume(ANativeActivity* activity);
static void onPause(ANativeActivity* activity);
static void onStop(ANativeActivity* activity);
static void onNativeWindowCreated
   (ANativeActivity* activity, ANativeWindow* window);
static void onNativeWindowDestroyed
   (ANativeActivity* activity, ANativeWindow* window);
static void onNativeWindowRedrawNeeded
              (ANativeActivity* activity, ANativeWindow* window);
static void onInputQueueCreated
   (ANativeActivity* activity, AInputQueue* queue);
static void onInputQueueDestroyed
   (ANativeActivity* activity, AInputQueue* queue);
static void* onSaveInstanceState
   (ANativeActivity* activity, size_t* outLen);
static void onWindowFocusChanged
   (ANativeActivity* activity, int focused);
static void onLowMemory(ANativeActivity* activity);
static void onConfigurationChanged(ANativeActivity* activity);
static int handle_command(app_t *A);
static int execute_commands(app_t *app);
static void graphics_window_destroyed(app_t *A, ANativeWindow *window);
static void graphics_window_created(app_t *A, ANativeWindow *window);
static void gfx_update(int x,int y,int w,int h);
static int handle_input(app_t *A, gfx_event_t *ev);
static int get_event(unsigned int *msecs, gfx_event_t *E);
int gfx_event (unsigned int *msecs, gfx_event_t *E);
static int event_noprocess(unsigned int *msecs,gfx_event_t *E);
JavaVM *gfx_get_javavm();
#endif
#ifdef GFX_FB

static uint32_t all_ones(uint32_t S,uint32_t L);
int gfx_init(char *DUMMYname, int DUMMYwidth, int DUMMYheight, char *DUMMYtitle);
static void destroy_image();
static void gfx_update(int x,int y,int width,int height);
void gfx_close();
static void checker_pattern(int N);
static void draw_cursor(int ux,int uy,int uw,int uh);
static void move_cursor(int cx,int cy);
static void prt_key(int key,char *lo,char *hi);
static void prt_keys(int SK,int EK, char *lo,char *hi);
static void prt_keys_upper(int SK,int EK,char *inp);
static void ctl_key(int raw,int gf);
static void mod_key(int raw,int gf);
static char *getenvd(char *name,char *def);
static void read_environ_vars();
static void rawinput_init();
static int event_noprocess(unsigned int *msecs, gfx_event_t *Revent);
#endif

static void gfx_update_all();
static uint32_t *get_server_pix(int src_x,int src_y,int w,int h);
static void put_server_pix(uint32_t *D,int dst_x,int dst_y,int w, int h);
static void populate_select_set
  (int *Rmaxfd, fd_set *rfd, fd_set *wfd, fd_set *xfd);
static int get_file_monitor_event
  (fd_set *rfd, fd_set *wfd, fd_set *xfd, gfx_event_t *Revent);
static int flag2(int a,int b);
static int range_test(int v, int s, int w) ;
static int imin2(int a,int b) ;
static int imax2(int a,int b) ;
static double dmin2(double a,double b) ;
static double dmax2(double a,double b) ;
static int utf8_encode_string
    (const uint32_t* wstr,size_t wlen, uint8_t *dst, size_t *dlen);
 
static int utf8_decode_string
  (const uint8_t *input, size_t ilen, uint32_t *output, size_t *olen);
static uint32_t utf8_decode_single_char(char *src);
static void utf8_encode_single_char(uint32_t wide, char *dst);
static void utf8_decode_alloc(char *str, uint32_t **Rwstr, uint32_t *Rwlen);
static int clip_for_rect(int *start, int *amount, int max);
static void freeNnull(void *A);
void *array_make1space(int pos,void **Rarray,int n, int *Rs, int eltsize);
static void enter_screen
   (int n_widgets, int *widgets,int *co);
static int install_click_handler
        (int x,int y,int w,int h,int *enabled,
         void *arg, int (*func)(void*,gfx_event_t*),int button);
static void install_release_handler
        (void *arg, int (*func)(void*,gfx_event_t*));
static void install_motion_handler(void *arg,int (*func)(void *,gfx_event_t*));
static void uninstall_motion_handler();
 
static int handle_grabbed_event(gfx_event_t *event);
static void grab_mouse(int (*func)(void*,gfx_event_t*), void *arg);
static void ungrab_mouse();
static int handle_click_event(gfx_event_t *event);
static void remove_click_handler(int H);
static int handle_release_event(gfx_event_t *event);
static int handle_motion_event(gfx_event_t *event);
static void widget_destroy(widget_t* W);
static void widget_move(widget_t *W,int x,int y,int w,int h);
static void widget_show(widget_t *W, int show);
static void widget_set_text(widget_t *W, char *str);
static char* widget_get_text(widget_t *W);
static widget_t *get_widget(int wno);
static void widget_set_state(widget_t *W, int state);
static int widget_get_state(widget_t *W);
static int widget_get_selected(widget_t *W);
static void widget_set_selected(widget_t *W,int sel);
static void widget_set_fgbg(widget_t *W,int fg,int bg);
static void widget_insert
  (widget_t *W,int pos, char *text, void *user, uint32_t *icon);
static void widget_remove(widget_t *W,int pos, void **Ruser);
static void widget_clear(widget_t *W);
static void set_focus(widget_t *N);
static int tabs_before(widget_t *A,widget_t *B);
static int focusable_event(gfx_event_t *event);
static void focus_lost();
static void set_click_handler(int click,int x,int y,int w,int h);
static int install_or_modify_click
  (int ch, int *enabled, int (*func)(void*,gfx_event_t*), void* arg,
   int x,int y,int w,int h,int button);
static void widgetpos(widget_t *W,int x,int y,int w,int h);
static uint32_t blend_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg);
static uint32_t blend_usr_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg);
static uint32_t blend_usr_svr(uint32_t alpha, uint32_t fg, uint32_t bg);
static void blend_graymap(int flags, int fg, int bg,
                          const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          int dst_x, int dst_y, int width, int height);
static uint32_t color_s(uint32_t uR, uint32_t uG, uint32_t uB);
static uint32_t u_red(uint32_t C) ;
static uint32_t u_green(uint32_t C) ;
static uint32_t u_blue(uint32_t C) ;
static uint32_t color_u_to_s(uint32_t U);
static unsigned int blend_chan(unsigned int F, double A, unsigned int B);
static unsigned int blend(uint32_t F, double A, uint32_t B);
static void grad_fill(int x,int y, int w, int h, uint32_t start, uint32_t end);
static void hline(int x1,int x2, int y,uint32_t color);
static void vline(int x,int y1, int y2,uint32_t color);
static void gfx_fill_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color);
void gfx_draw_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color);
static void blend_graymap_buffer
        (unsigned int fg, const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          unsigned int *dst, int dst_w, int dst_h,
                          int dst_x, int dst_y, int width, int height);
static void gfx_put(int flags,
             const unsigned int *buffer, int src_w, int src_h,
             int src_x, int src_y,
             int dst_x, int dst_y,
             int width, int height);
static unsigned int* convert_graymap_to_color
        (unsigned int fg, unsigned int bg, const unsigned char *src);
static void gfx_draw_3dbox(int x,int y,int w,int h, 
                        int light, int dark, int border,
                        int start, int end);
static void convert_images_to_server(uint32_t **images);
static void convert_image_to_server(uint32_t *IMG);
static void draw_icon_and_text
                 (int x,int y,int w,int h,
                  int iconpos, uint32_t *icon,
                  int space,
                  uint32_t text_fg, char *text);
static void draw_icon_centered(int x,int y,int w,int h, uint32_t *icon);
static void get_text_data(int font, const char *str, 
                          int *Rw, int *Rh,int *Ra,unsigned char **Rd);
static void gfx_text_size(int font, char *str, int *W, int *H);
void txt_print(int flags, int font, int fg, int bg, int x, int y, 
               char *str,int *Rw, int *Rh);
static int max_text_width(int font, ...);
static void txt_print_fit(const char *horz,const char *vert,
                   int x,int y, int w, int h,
                   int font, int alpha, int fg, int bg,
                   const char *str);
static void button_set_text(gui_button_t *B, char *text);
static void button_render(gui_button_t *B);
static gui_button_t *gui_button_new
  (const char *txt, int iconpos, uint32_t* icon, int klass);
static widget_t* gfx_button
     (const char *txt,int iconpos, uint32_t *icon,int klass);
static void button_set_state(gui_button_t *B, int state);
static int gui_button_click(void *arg, gfx_event_t *event);
static int gui_button_release(void *arg, gfx_event_t *event);
static void gui_button_destroy(gui_button_t *B);
static void button_set_position( gui_button_t *B, int x,int y,int w,int h);
static void gui_button_activate(widget_t *W, int x,int y,int w,int h);
static void gui_button_show(gui_button_t *B,int show);
static void gui_button_init
  (gui_button_t *B,const char *txt, int iconpos, uint32_t* icon, 
   int (*click_func)(void *,gfx_event_t*), 
   int (*release_func)(void *,gfx_event_t*), void *click_arg);
static void label_render(gui_label_t *G);
static widget_t* gfx_label(int font, int fg, int bg, int just, char *str);
static void gui_label_show(widget_t *W);
static void gui_label_set_position(gui_label_t *L,int x,int y,int w,int h);
static void gui_label_destroy(gui_label_t *G);
static void gui_label_set_text(gui_label_t *G,const char *str);
static void label_set_fgbg(gui_label_t *G, int fg,int bg);
static void init_radio_images();
static void radio_draw_button(radio_t *R,int state,int bg, int upd);
static void radio_show(radio_t *R, int show);
static void radio_set(radio_t *R);
static int radio_click(void *arg, gfx_event_t *event);
static int radio_release(void *arg, gfx_event_t *event);
static widget_t* radio_new(const char *text, int group);
static void radio_draw_text(radio_t *R);
static void radio_draw(radio_t *R);
static radio_group_t *get_rgroup(int ident);
static void rgroup_clear_except(int ident,widget_t *R);
static void register_radio_in_group(int ident, widget_t *W);
static void free_rgroups(screen_t *S);
static int radio_group_get_selected(int ident);
static void init_checkbox_images();
static void checkbox_draw_button(checkbox_t *R,int state,int bg, int upd);
static void checkbox_show(checkbox_t *R, int show);
static void checkbox_set(checkbox_t *R,int value);
static int checkbox_click(void *arg, gfx_event_t *event);
static int checkbox_release(void *arg, gfx_event_t *event);
static widget_t* checkbox_new(const char *text);
static void checkbox_draw_text(checkbox_t *R);
static void checkbox_draw(checkbox_t *R);
static void scrollbar_compute_trough(scrollbar_t *SB);
static void scrollbar_compute_button(scrollbar_t *SB);
static void fill_with_horizontal_gradient
             (int x0,int y0, int y1, unsigned int *gra);
static void three_part_assembly_vertical
    (int x0,int y0, int y1, 
     uint32_t *top, uint32_t *mid, uint32_t *bot);
static void fill_with_vertical_gradient
             (int x0, int x1, int y0, unsigned int *gra);
static void three_part_assembly_horizontal
    (int x0, int x1, int y0, 
     uint32_t *lef, uint32_t *mid, uint32_t *rig);
static void scrollbar_draw_trough(scrollbar_t *SB);
static void scrollbar_draw_stepper(scrollbar_t *SB, int sno, int state);
static void scrollbar_draw_all(scrollbar_t *SB);
static void scrollbar_init_buttons
   (scrollbar_t *SB);
static void scrollbar_position_buttons(scrollbar_t *SB,int x,int y,int w,int h);
static widget_t* scrollbar_new
    (int orient, double start, double end, double step,
     int action, void *reportarg, void *reportfunc);
static void scrollbar_position(scrollbar_t *SB,int x,int y,int w,int h);
static int scrollbar_click_up(void *A, gfx_event_t *E);
static int scrollbar_release_up(void *A, gfx_event_t *event);
static void scrollbar_update(scrollbar_t *SB);
static int scrollbar_set
    (scrollbar_t *SB,double S, double E, int report, gfx_event_t* event);
static int scrollbar_click_down(void *A, gfx_event_t *E);
static int scrollbar_release_down(void *A, gfx_event_t *event);
static int scrollbar_click_tro(void *A,gfx_event_t *event);
static int scrollbar_release_dummy(void *A, gfx_event_t *E);
static int scrollbar_move_pointer(void *A, gfx_event_t *event);
static int scrollbar_release_tro(void *A, gfx_event_t *E);
static void scrollbar_relayout
   (scrollbar_t *SB, int nx, int ny, int nw,int nh,
    double start, double end, double step);
static void scrollbar_destroy(scrollbar_t *SB);
static void scrollbar_show(scrollbar_t *SB,int show);
static panel_t *panel_new(int nsubs);
static void panel_show(panel_t *P,int show);
static void panel_show_widgets(panel_t *P,int sub, int show);
static void panel_activate(panel_t *P,int sel);
static void panel_position(panel_t *P,int nx,int ny,int nw,int nh);
static widget_t *dropdown_new(int action);
static void dropdown_show(dropdown_t *DD,int show);
static void dropdown_render_button(dropdown_t *DD, int p);
static int dropdown_click(void *arg, gfx_event_t* event);
static int dropdown_release(void *arg, gfx_event_t *event);
static void dropdown_show_list(dropdown_t *DD);
static void dropdown_draw_listbg(dropdown_t *DD);
static void dropdown_get_list_backup(dropdown_t *DD);
static void dropdown_put_list_backup(dropdown_t *DD);
static void dropdown_draw_contents(dropdown_t *DD);
static int dropdown_draw_item(dropdown_t *DD,int idx);
static void print_clipped(int Cx,int Cy,int Cw,int Ch,
                          int x, int y, int font, const char* str);
static int dropdown_item_pos(dropdown_t *DD,int item);
static void dropdown_draw_listframe(dropdown_t *DD,int which);
static void dropdown_scroll(dropdown_t *DD,double S,double E);
static int dropdown_mouse(dropdown_t *DD, gfx_event_t *event);
static int in_rect(int rx,int ry,int rw,int rh, int x,int y);
static void dropdown_hide_list(dropdown_t *DD);
static void dropdown_scroll_to(dropdown_t *DD,int pos,int report);
static int dropdown_item_at(dropdown_t *DD,int y);
static void dropdown_hilight_item(dropdown_t *DD, int item);
static void fill_clipped_rect
               (int Cx,int Cy,int Cw, int Ch, 
                int dx,int dy,int ow, int oh, unsigned int color);
static void dropdown_insert(dropdown_t *DD,
                            int pos, const char *str, void *usr);
static void dropdown_remove(dropdown_t *DD,int pos, void **Rusr);
static void gui_dropdown_clear(dropdown_t *DD);
static void gfx_dropdown_select(dropdown_t *DD, int pos);
static void dropdown_destroy(dropdown_t *DD);
static void dropdown_position(dropdown_t *DD,int x,int y,int w,int h);
static widget_t* gfx_list(int noicon,int multisel, int click_action);
static void gui_list_set_position(gui_list_t* LL,int x,int y,int w,int h);
static void gfx_list_show(gui_list_t *L, int show);
static void list_install_click_handlers(gui_list_t *LL);
static void compute_list_items
    (gui_list_t* LL, int start, int end);
static void compute_list_content_size(gui_list_t *LL,int *Rw, int *Rh);
static int list_max_icon_width(gui_list_t *LL);
static void compute_list_port
  (gui_list_t* LL, int *Rportw, int *Rporth, int *Rhs, int *Rvs);
static int list_render_item(gui_list_t *LL,int ino,int bg);
static void gui_list_scrollbar_click_horz(void *a, double S, double E);
static void gui_list_scrollbar_click_vert(void *a, double S, double E);
static void list_layout_items(gui_list_t *LL,int start);
static void list_draw_borders(gui_list_t *LL,int which);
static void list_draw_contents(gui_list_t *L);
static void list_compute_scroll
    (int pos,int win,int con, double *Rstart, double *Rend, double *Rstep);
static void list_arrange_scrollbars
   (gui_list_t *LL, int have_horz, int have_vert);
static int gui_list_click(void *a, gfx_event_t *ev);
  static int gui_list_click4(void *a, gfx_event_t *ev);
  static int gui_list_click5(void *a, gfx_event_t *ev);
static void list_relayout(int flags, gui_list_t *L);
static void gfx_list_insert(gui_list_t* L, int pos, char *str, void *usr
                          ,const unsigned int*icon) ;
static void gfx_list_delete(gui_list_t *L, int pos, void **Ruser);
static int gfx_list_selected(gui_list_t *L);
static void gfx_list_select(gui_list_t* L,int pos);
static void gfx_list_clear(gui_list_t *L);
static widget_t *text_entry_new(char *initstr);
static void textentry_position(text_entry_t *te,int x,int y,int w,int h);
static void make_cursor_visible(text_entry_t *te);
static void mk_glyph(glyph_t *G, uint32_t chr);
static int draw_glyph(text_entry_t  *te, int gn, int expose);
static void textentry_focus(void *va, int focus);
static int textentry_key(void* va, gfx_event_t *event) ;
static void text_entry_move_cursor(text_entry_t *te, int newcurs);
static void insert_char(text_entry_t *te, uint32_t chr);
static void delete_cursor_char(text_entry_t *te);
static char *textentry_get_text(text_entry_t *te);
static void textentry_free(text_entry_t *te);
static void text_entry_set(text_entry_t *te, char *str);
static int font1height();
static void gui_textentry_show(widget_t *arg);
static void gui_textentry_hide(widget_t *arg);
static widget_t* gfx_pixgrid();
static int gui_pixgrid_click(void *arg,gfx_event_t *event);
static int gui_pixgrid_release(void *arg,gfx_event_t *event);
static void gfxask_make_buttons
  (char *butstr,int *coor,int *Rnbut, int *Rbut_h,int *Rbut_total_w);
static void gfxask_show_buttons
    (int *coor_widgets, int nbuttons,int X,int Y);
static void gfxask_draw_border(int X,int Y,int W,int H);
static void split_string_bychar_d(char *str, int chr, char ***Ra,int *Rn);
static void format_multi_line_str(char *fmt, va_list ap, char ***Rl, int *Rn);
static void multi_line_str_dim
  (int font,char **lines, int nlines,int *Rw,int *Rh);
static char **parse_ext_list(char *inp);
static char **make_file_extension_list(char **inp);
static int file_matches_ext_set(char *fn,char **ext);
static char **list_files(char *dn);
static void file_types(char *dn, char **files);
_BUFFER_PROTO buffer_t *buffer_new(size_t blksize);
_BUFFER_PROTO void buffer_free(buffer_t *B, void **Rd, size_t *Rl);
_BUFFER_PROTO void buffer_collect(buffer_t *B, void **Rd, size_t *Rl);
_BUFFER_PROTO void buffer_write(buffer_t *B, void *d, size_t l);
_BUFFER_PROTO void buffer_append(buffer_t *dst, buffer_t *src_f);
_BUFFER_PROTO size_t buffer_read(buffer_t *B, void *d, size_t l);
static int filter_files_byext(int nfiles,char **files, char **suffixes);
static int filter_files_byhid(int nfiles,char **files,int showhid);
static int comparstr(const void *a,const void* b);
static void sort_files(int nfiles, char **files);
static char *sau_getcwd();
static char *sau_gethome();
static char* combine_path(char *dir,char *fn);
static void split_initial_fn(char *init, char **Rdir, char **Rfil);
static void filesel_make_screen(int *RX,int *RY,int *RW,int *RH,int title_w);
static void file_select_dialog
  (filesel_t *fs,int mode,char *ifil);
static void populate_file_list
        (filesel_t *fs);
static int filesel_tab_complete(void *arg,void *te,gfx_event_t *event);
static char **sepdir(char *name);
static void filesel_hide_buttons();
static void filesel_show_buttons(filesel_t *fs);
static void filesel_render_dirstack(filesel_t *fs);
static char* remove_trailing_slash(char *dn);
static void filesel_create_buttons(filesel_t *fs);
static void filesel_free_buttons(filesel_t *fs);
static void filesel_activate_button(filesel_t *fs,int idx);
static void filesel_render_buttons(filesel_t *fs);
static char *com3(char *x,char *y,char *z);
static char *com2(char *x,char *y);
static char *fs_combine(char *x,char *y);
static void filesel_activate_dir(filesel_t *fs, int idx);
static void filesel_setdir(filesel_t *fs,char *dir);
static widget_t *gui_canvas_new();
static void gui_canvas_update_click_handlers(gui_canvas_t *CC);
static void gui_canvas_position(gui_canvas_t *CC,int x,int y,int w,int h);
static int gui_canvas_setbuffer(gui_canvas_t *CC,int new_w,int new_h);
static void gui_canvas_arrange_scrollbars
   (gui_canvas_t *CC);
static void gui_canvas_paint_scrollbars(gui_canvas_t *CC);
static void gui_canvas_paint_buffer(gui_canvas_t *CC);
static void gui_canvas_draw_all(gui_canvas_t *CC);
static void gui_canvas_update(gui_canvas_t *CC,int x,int y,int w,int h);
static void gui_canvas_clipped_hline
   (gui_canvas_t *CC,int color,int x1,int x2,int y);
static void gui_canvas_clipped_vline
   (gui_canvas_t *CC,int color,int x,int y1,int y2);
static gui_canvas_t *gui_canvas_get(int wno);
static void gui_canvas_scrollv(gui_canvas_t *CC,double start,double end);
static void gui_canvas_scrollh(gui_canvas_t *CC,double start,double end);
static int gui_canvas_click(void *arg,gfx_event_t *ev);
static int gui_canvas_release(void *arg,gfx_event_t *ev);
static int gui_canvas_motion(void *arg, gfx_event_t *ev);
static void gui_canvas_draw_recsel(gui_canvas_t *CC);
static void gui_canvas_invert_hline(gui_canvas_t *CC, int x1, int x2, int y);
static void gui_canvas_invert_vline(gui_canvas_t *CC,int x,int y1, int y2);
static int gui_timer_schedule
  (unsigned int msecs, int (*f)(void*,gfx_event_t*), void *a);
      static int gui_timer_get(unsigned int *Rmsecs);
static int gui_timer_elapsed(unsigned int elap,gfx_event_t *event);
static void gui_timer_cancel(int ident);
static widget_t* gui_spinner(int type, int frac);
static void gui_spinner_destroy(gui_spinner_t *SS);
static void gui_spinner_set_position
   (gui_spinner_t* LL,int x,int y,int w,int h);
static void gui_spinner_show(gui_spinner_t *S, int show);
static void gui_spinner_render(gui_spinner_t *S);
static int gui_spinner_delta(gui_spinner_t *S, gfx_event_t *event, int dir);
static void spinner_apply_limits(gui_spinner_t* S);
static gui_spinner_t *get_spinner_widget(int wno);
static void gui_spinner_remove_timer
  (gui_spinner_t *SS);
static void gui_spinner_init_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*));
static void gui_spinner_reset_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*));
static int gui_spinner_less_release(void *arg,gfx_event_t *event);
static int gui_spinner_less_click(void *arg,gfx_event_t *event);
static int gui_spinner_less_timeout(void *arg,gfx_event_t *event);
static int gui_spinner_more_release(void *arg,gfx_event_t *event);
static int gui_spinner_more_click(void *arg,gfx_event_t *event);
static int gui_spinner_more_timeout(void *arg,gfx_event_t *event);
static widget_t *gui_logview();
static void gui_logview_destroy(widget_t *W);
static void logview_scroll_up(gui_logview_t *L, int yof);
static void logview_print_line
   (gui_logview_t *L,char *line, 
    int nonl,int *Ruys,int *Ruye);
static void logview_render(gui_logview_t *L);
static void gui_logview_show(widget_t *W);
static void gui_logview_hide(widget_t *W) ;
static void gui_logview_position(widget_t *W, int x,int y,int w,int h);
static void logview_write(gui_logview_t *L, const char *txt, size_t len);
static void logview_put_line
   (gui_logview_t *L, const char *txt, size_t len, int nonl);
/***********************************************************************
 *                                                                     *
 *                              VARIABLES                              *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

static Display *x_display;
static Window   x_root_window;
static int      x_screen_number;
static uint32_t x_root_width, x_root_height;
static int      x_depth;
static Visual  *x_visual;
static int      x_window;
static Pixmap   x_pixmap;
static  Atom    wm_protocols, wm_delete_window;
static ximage_t *x_image;

static XIM xim;
static int xim_tried;
static XIMStyle xim_style;

/*
 * http://www.unicode.org/mail-arch/unicode-ml/Archives-Old/UML015/0422.html
 *
 * This module converts X Window System keysym values into the
 * corresponding ISO 10646-1 (UCS, Unicode) values.
 *
 * The array keysymtab[] contains pairs of X11 keysym values for graphical
 * characters and the corresponding Unicode value. The function
 * keysym2ucs() maps a keysym onto a Unicode value using a binary search,
 * therefore keysymtab[] must remain SORTED by keysym value.
 *
 * The keysym -> UTF-8 conversion will hopefully one day be provided
 * by Xlib via XmbLookupString() and should ideally not have to be
 * done in X applications. But we are not there yet.
 *
 * NOTE: The comments in the table below contain the actual character
 * encoded in UTF-8, so for viewing and editing best use an editor in
 * UTF-8 mode.
 *
 * Author: Markus G. Kuhn <mkuhn@acm.org>, University of Cambridge, June 1999
 *
 * Special thanks to Richard Verhoeven <river@win.tue.nl> for preparing
 * an initial draft of the mapping table. Suggestions for improvement welcome!
 *
 * This software is in the public domain. Share and enjoy!
 */
/** BEGIN KEYSYMTAB **/

static const struct codepair {
  unsigned short keysym;
  unsigned short ucs;
} keysymtab[] = {
  { 0x01a1, 0x0104 }, /* Aogonek Ą LATIN CAPITAL LETTER A WITH OGONEK */
  { 0x01a2, 0x02d8 }, /* breve ˘ BREVE */
  { 0x01a3, 0x0141 }, /* Lstroke Ł LATIN CAPITAL LETTER L WITH STROKE */
  { 0x01a5, 0x013d }, /* Lcaron Ľ LATIN CAPITAL LETTER L WITH CARON */
  { 0x01a6, 0x015a }, /* Sacute Ś LATIN CAPITAL LETTER S WITH ACUTE */
  { 0x01a9, 0x0160 }, /* Scaron Š LATIN CAPITAL LETTER S WITH CARON */
  { 0x01aa, 0x015e }, /* Scedilla Ş LATIN CAPITAL LETTER S WITH CEDILLA */
  { 0x01ab, 0x0164 }, /* Tcaron Ť LATIN CAPITAL LETTER T WITH CARON */
  { 0x01ac, 0x0179 }, /* Zacute Ź LATIN CAPITAL LETTER Z WITH ACUTE */
  { 0x01ae, 0x017d }, /* Zcaron Ž LATIN CAPITAL LETTER Z WITH CARON */
  { 0x01af, 0x017b }, /* Zabovedot Ż LATIN CAPITAL LETTER Z WITH DOT ABOVE */
  { 0x01b1, 0x0105 }, /* aogonek ą LATIN SMALL LETTER A WITH OGONEK */
  { 0x01b2, 0x02db }, /* ogonek ˛ OGONEK */
  { 0x01b3, 0x0142 }, /* lstroke ł LATIN SMALL LETTER L WITH STROKE */
  { 0x01b5, 0x013e }, /* lcaron ľ LATIN SMALL LETTER L WITH CARON */
  { 0x01b6, 0x015b }, /* sacute ś LATIN SMALL LETTER S WITH ACUTE */
  { 0x01b7, 0x02c7 }, /* caron ˇ CARON */
  { 0x01b9, 0x0161 }, /* scaron š LATIN SMALL LETTER S WITH CARON */
  { 0x01ba, 0x015f }, /* scedilla ş LATIN SMALL LETTER S WITH CEDILLA */
  { 0x01bb, 0x0165 }, /* tcaron ť LATIN SMALL LETTER T WITH CARON */
  { 0x01bc, 0x017a }, /* zacute ź LATIN SMALL LETTER Z WITH ACUTE */
  { 0x01bd, 0x02dd }, /* doubleacute ˝ DOUBLE ACUTE ACCENT */
  { 0x01be, 0x017e }, /* zcaron ž LATIN SMALL LETTER Z WITH CARON */
  { 0x01bf, 0x017c }, /* zabovedot ż LATIN SMALL LETTER Z WITH DOT ABOVE */
  { 0x01c0, 0x0154 }, /* Racute Ŕ LATIN CAPITAL LETTER R WITH ACUTE */
  { 0x01c3, 0x0102 }, /* Abreve Ă LATIN CAPITAL LETTER A WITH BREVE */
  { 0x01c5, 0x0139 }, /* Lacute Ĺ LATIN CAPITAL LETTER L WITH ACUTE */
  { 0x01c6, 0x0106 }, /* Cacute Ć LATIN CAPITAL LETTER C WITH ACUTE */
  { 0x01c8, 0x010c }, /* Ccaron Č LATIN CAPITAL LETTER C WITH CARON */
  { 0x01ca, 0x0118 }, /* Eogonek Ę LATIN CAPITAL LETTER E WITH OGONEK */
  { 0x01cc, 0x011a }, /* Ecaron Ě LATIN CAPITAL LETTER E WITH CARON */
  { 0x01cf, 0x010e }, /* Dcaron Ď LATIN CAPITAL LETTER D WITH CARON */
  { 0x01d0, 0x0110 }, /* Dstroke Đ LATIN CAPITAL LETTER D WITH STROKE */
  { 0x01d1, 0x0143 }, /* Nacute Ń LATIN CAPITAL LETTER N WITH ACUTE */
  { 0x01d2, 0x0147 }, /* Ncaron Ň LATIN CAPITAL LETTER N WITH CARON */
  { 0x01d5, 0x0150 }, /* Odoubleacute Ő LATIN CAPITAL LETTER O WITH DOUBLE ACUTE */
  { 0x01d8, 0x0158 }, /* Rcaron Ř LATIN CAPITAL LETTER R WITH CARON */
  { 0x01d9, 0x016e }, /* Uring Ů LATIN CAPITAL LETTER U WITH RING ABOVE */
  { 0x01db, 0x0170 }, /* Udoubleacute Ű LATIN CAPITAL LETTER U WITH DOUBLE ACUTE */
  { 0x01de, 0x0162 }, /* Tcedilla Ţ LATIN CAPITAL LETTER T WITH CEDILLA */
  { 0x01e0, 0x0155 }, /* racute ŕ LATIN SMALL LETTER R WITH ACUTE */
  { 0x01e3, 0x0103 }, /* abreve ă LATIN SMALL LETTER A WITH BREVE */
  { 0x01e5, 0x013a }, /* lacute ĺ LATIN SMALL LETTER L WITH ACUTE */
  { 0x01e6, 0x0107 }, /* cacute ć LATIN SMALL LETTER C WITH ACUTE */
  { 0x01e8, 0x010d }, /* ccaron č LATIN SMALL LETTER C WITH CARON */
  { 0x01ea, 0x0119 }, /* eogonek ę LATIN SMALL LETTER E WITH OGONEK */
  { 0x01ec, 0x011b }, /* ecaron ě LATIN SMALL LETTER E WITH CARON */
  { 0x01ef, 0x010f }, /* dcaron ď LATIN SMALL LETTER D WITH CARON */
  { 0x01f0, 0x0111 }, /* dstroke đ LATIN SMALL LETTER D WITH STROKE */
  { 0x01f1, 0x0144 }, /* nacute ń LATIN SMALL LETTER N WITH ACUTE */
  { 0x01f2, 0x0148 }, /* ncaron ň LATIN SMALL LETTER N WITH CARON */
  { 0x01f5, 0x0151 }, /* odoubleacute ő LATIN SMALL LETTER O WITH DOUBLE ACUTE */
  { 0x01f8, 0x0159 }, /* rcaron ř LATIN SMALL LETTER R WITH CARON */
  { 0x01f9, 0x016f }, /* uring ů LATIN SMALL LETTER U WITH RING ABOVE */
  { 0x01fb, 0x0171 }, /* udoubleacute ű LATIN SMALL LETTER U WITH DOUBLE ACUTE */
  { 0x01fe, 0x0163 }, /* tcedilla ţ LATIN SMALL LETTER T WITH CEDILLA */
  { 0x01ff, 0x02d9 }, /* abovedot ˙ DOT ABOVE */
  { 0x02a1, 0x0126 }, /* Hstroke Ħ LATIN CAPITAL LETTER H WITH STROKE */
  { 0x02a6, 0x0124 }, /* Hcircumflex Ĥ LATIN CAPITAL LETTER H WITH CIRCUMFLEX */
  { 0x02a9, 0x0130 }, /* Iabovedot İ LATIN CAPITAL LETTER I WITH DOT ABOVE */
  { 0x02ab, 0x011e }, /* Gbreve Ğ LATIN CAPITAL LETTER G WITH BREVE */
  { 0x02ac, 0x0134 }, /* Jcircumflex Ĵ LATIN CAPITAL LETTER J WITH CIRCUMFLEX */
  { 0x02b1, 0x0127 }, /* hstroke ħ LATIN SMALL LETTER H WITH STROKE */
  { 0x02b6, 0x0125 }, /* hcircumflex ĥ LATIN SMALL LETTER H WITH CIRCUMFLEX */
  { 0x02b9, 0x0131 }, /* idotless ı LATIN SMALL LETTER DOTLESS I */
  { 0x02bb, 0x011f }, /* gbreve ğ LATIN SMALL LETTER G WITH BREVE */
  { 0x02bc, 0x0135 }, /* jcircumflex ĵ LATIN SMALL LETTER J WITH CIRCUMFLEX */
  { 0x02c5, 0x010a }, /* Cabovedot Ċ LATIN CAPITAL LETTER C WITH DOT ABOVE */
  { 0x02c6, 0x0108 }, /* Ccircumflex Ĉ LATIN CAPITAL LETTER C WITH CIRCUMFLEX */
  { 0x02d5, 0x0120 }, /* Gabovedot Ġ LATIN CAPITAL LETTER G WITH DOT ABOVE */
  { 0x02d8, 0x011c }, /* Gcircumflex Ĝ LATIN CAPITAL LETTER G WITH CIRCUMFLEX */
  { 0x02dd, 0x016c }, /* Ubreve Ŭ LATIN CAPITAL LETTER U WITH BREVE */
  { 0x02de, 0x015c }, /* Scircumflex Ŝ LATIN CAPITAL LETTER S WITH CIRCUMFLEX */
  { 0x02e5, 0x010b }, /* cabovedot ċ LATIN SMALL LETTER C WITH DOT ABOVE */
  { 0x02e6, 0x0109 }, /* ccircumflex ĉ LATIN SMALL LETTER C WITH CIRCUMFLEX */
  { 0x02f5, 0x0121 }, /* gabovedot ġ LATIN SMALL LETTER G WITH DOT ABOVE */
  { 0x02f8, 0x011d }, /* gcircumflex ĝ LATIN SMALL LETTER G WITH CIRCUMFLEX */
  { 0x02fd, 0x016d }, /* ubreve ŭ LATIN SMALL LETTER U WITH BREVE */
  { 0x02fe, 0x015d }, /* scircumflex ŝ LATIN SMALL LETTER S WITH CIRCUMFLEX */
  { 0x03a2, 0x0138 }, /* kra ĸ LATIN SMALL LETTER KRA */
  { 0x03a3, 0x0156 }, /* Rcedilla Ŗ LATIN CAPITAL LETTER R WITH CEDILLA */
  { 0x03a5, 0x0128 }, /* Itilde Ĩ LATIN CAPITAL LETTER I WITH TILDE */
  { 0x03a6, 0x013b }, /* Lcedilla Ļ LATIN CAPITAL LETTER L WITH CEDILLA */
  { 0x03aa, 0x0112 }, /* Emacron Ē LATIN CAPITAL LETTER E WITH MACRON */
  { 0x03ab, 0x0122 }, /* Gcedilla Ģ LATIN CAPITAL LETTER G WITH CEDILLA */
  { 0x03ac, 0x0166 }, /* Tslash Ŧ LATIN CAPITAL LETTER T WITH STROKE */
  { 0x03b3, 0x0157 }, /* rcedilla ŗ LATIN SMALL LETTER R WITH CEDILLA */
  { 0x03b5, 0x0129 }, /* itilde ĩ LATIN SMALL LETTER I WITH TILDE */
  { 0x03b6, 0x013c }, /* lcedilla ļ LATIN SMALL LETTER L WITH CEDILLA */
  { 0x03ba, 0x0113 }, /* emacron ē LATIN SMALL LETTER E WITH MACRON */
  { 0x03bb, 0x0123 }, /* gcedilla ģ LATIN SMALL LETTER G WITH CEDILLA */
  { 0x03bc, 0x0167 }, /* tslash ŧ LATIN SMALL LETTER T WITH STROKE */
  { 0x03bd, 0x014a }, /* ENG Ŋ LATIN CAPITAL LETTER ENG */
  { 0x03bf, 0x014b }, /* eng ŋ LATIN SMALL LETTER ENG */
  { 0x03c0, 0x0100 }, /* Amacron Ā LATIN CAPITAL LETTER A WITH MACRON */
  { 0x03c7, 0x012e }, /* Iogonek Į LATIN CAPITAL LETTER I WITH OGONEK */
  { 0x03cc, 0x0116 }, /* Eabovedot Ė LATIN CAPITAL LETTER E WITH DOT ABOVE */
  { 0x03cf, 0x012a }, /* Imacron Ī LATIN CAPITAL LETTER I WITH MACRON */
  { 0x03d1, 0x0145 }, /* Ncedilla Ņ LATIN CAPITAL LETTER N WITH CEDILLA */
  { 0x03d2, 0x014c }, /* Omacron Ō LATIN CAPITAL LETTER O WITH MACRON */
  { 0x03d3, 0x0136 }, /* Kcedilla Ķ LATIN CAPITAL LETTER K WITH CEDILLA */
  { 0x03d9, 0x0172 }, /* Uogonek Ų LATIN CAPITAL LETTER U WITH OGONEK */
  { 0x03dd, 0x0168 }, /* Utilde Ũ LATIN CAPITAL LETTER U WITH TILDE */
  { 0x03de, 0x016a }, /* Umacron Ū LATIN CAPITAL LETTER U WITH MACRON */
  { 0x03e0, 0x0101 }, /* amacron ā LATIN SMALL LETTER A WITH MACRON */
  { 0x03e7, 0x012f }, /* iogonek į LATIN SMALL LETTER I WITH OGONEK */
  { 0x03ec, 0x0117 }, /* eabovedot ė LATIN SMALL LETTER E WITH DOT ABOVE */
  { 0x03ef, 0x012b }, /* imacron ī LATIN SMALL LETTER I WITH MACRON */
  { 0x03f1, 0x0146 }, /* ncedilla ņ LATIN SMALL LETTER N WITH CEDILLA */
  { 0x03f2, 0x014d }, /* omacron ō LATIN SMALL LETTER O WITH MACRON */
  { 0x03f3, 0x0137 }, /* kcedilla ķ LATIN SMALL LETTER K WITH CEDILLA */
  { 0x03f9, 0x0173 }, /* uogonek ų LATIN SMALL LETTER U WITH OGONEK */
  { 0x03fd, 0x0169 }, /* utilde ũ LATIN SMALL LETTER U WITH TILDE */
  { 0x03fe, 0x016b }, /* umacron ū LATIN SMALL LETTER U WITH MACRON */
  { 0x047e, 0x203e }, /* overline ‾ OVERLINE */
  { 0x04a1, 0x3002 }, /* kana_fullstop 。 IDEOGRAPHIC FULL STOP */
  { 0x04a2, 0x300c }, /* kana_openingbracket 「 LEFT CORNER BRACKET */
  { 0x04a3, 0x300d }, /* kana_closingbracket 」 RIGHT CORNER BRACKET */
  { 0x04a4, 0x3001 }, /* kana_comma 、 IDEOGRAPHIC COMMA */
  { 0x04a5, 0x30fb }, /* kana_conjunctive ・ KATAKANA MIDDLE DOT */
  { 0x04a6, 0x30f2 }, /* kana_WO ヲ KATAKANA LETTER WO */
  { 0x04a7, 0x30a1 }, /* kana_a ァ KATAKANA LETTER SMALL A */
  { 0x04a8, 0x30a3 }, /* kana_i ィ KATAKANA LETTER SMALL I */
  { 0x04a9, 0x30a5 }, /* kana_u ゥ KATAKANA LETTER SMALL U */
  { 0x04aa, 0x30a7 }, /* kana_e ェ KATAKANA LETTER SMALL E */
  { 0x04ab, 0x30a9 }, /* kana_o ォ KATAKANA LETTER SMALL O */
  { 0x04ac, 0x30e3 }, /* kana_ya ャ KATAKANA LETTER SMALL YA */
  { 0x04ad, 0x30e5 }, /* kana_yu ュ KATAKANA LETTER SMALL YU */
  { 0x04ae, 0x30e7 }, /* kana_yo ョ KATAKANA LETTER SMALL YO */
  { 0x04af, 0x30c3 }, /* kana_tsu ッ KATAKANA LETTER SMALL TU */
  { 0x04b0, 0x30fc }, /* prolongedsound ー KATAKANA-HIRAGANA PROLONGED SOUND MARK */
  { 0x04b1, 0x30a2 }, /* kana_A ア KATAKANA LETTER A */
  { 0x04b2, 0x30a4 }, /* kana_I イ KATAKANA LETTER I */
  { 0x04b3, 0x30a6 }, /* kana_U ウ KATAKANA LETTER U */
  { 0x04b4, 0x30a8 }, /* kana_E エ KATAKANA LETTER E */
  { 0x04b5, 0x30aa }, /* kana_O オ KATAKANA LETTER O */
  { 0x04b6, 0x30ab }, /* kana_KA カ KATAKANA LETTER KA */
  { 0x04b7, 0x30ad }, /* kana_KI キ KATAKANA LETTER KI */
  { 0x04b8, 0x30af }, /* kana_KU ク KATAKANA LETTER KU */
  { 0x04b9, 0x30b1 }, /* kana_KE ケ KATAKANA LETTER KE */
  { 0x04ba, 0x30b3 }, /* kana_KO コ KATAKANA LETTER KO */
  { 0x04bb, 0x30b5 }, /* kana_SA サ KATAKANA LETTER SA */
  { 0x04bc, 0x30b7 }, /* kana_SHI シ KATAKANA LETTER SI */
  { 0x04bd, 0x30b9 }, /* kana_SU ス KATAKANA LETTER SU */
  { 0x04be, 0x30bb }, /* kana_SE セ KATAKANA LETTER SE */
  { 0x04bf, 0x30bd }, /* kana_SO ソ KATAKANA LETTER SO */
  { 0x04c0, 0x30bf }, /* kana_TA タ KATAKANA LETTER TA */
  { 0x04c1, 0x30c1 }, /* kana_CHI チ KATAKANA LETTER TI */
  { 0x04c2, 0x30c4 }, /* kana_TSU ツ KATAKANA LETTER TU */
  { 0x04c3, 0x30c6 }, /* kana_TE テ KATAKANA LETTER TE */
  { 0x04c4, 0x30c8 }, /* kana_TO ト KATAKANA LETTER TO */
  { 0x04c5, 0x30ca }, /* kana_NA ナ KATAKANA LETTER NA */
  { 0x04c6, 0x30cb }, /* kana_NI ニ KATAKANA LETTER NI */
  { 0x04c7, 0x30cc }, /* kana_NU ヌ KATAKANA LETTER NU */
  { 0x04c8, 0x30cd }, /* kana_NE ネ KATAKANA LETTER NE */
  { 0x04c9, 0x30ce }, /* kana_NO ノ KATAKANA LETTER NO */
  { 0x04ca, 0x30cf }, /* kana_HA ハ KATAKANA LETTER HA */
  { 0x04cb, 0x30d2 }, /* kana_HI ヒ KATAKANA LETTER HI */
  { 0x04cc, 0x30d5 }, /* kana_FU フ KATAKANA LETTER HU */
  { 0x04cd, 0x30d8 }, /* kana_HE ヘ KATAKANA LETTER HE */
  { 0x04ce, 0x30db }, /* kana_HO ホ KATAKANA LETTER HO */
  { 0x04cf, 0x30de }, /* kana_MA マ KATAKANA LETTER MA */
  { 0x04d0, 0x30df }, /* kana_MI ミ KATAKANA LETTER MI */
  { 0x04d1, 0x30e0 }, /* kana_MU ム KATAKANA LETTER MU */
  { 0x04d2, 0x30e1 }, /* kana_ME メ KATAKANA LETTER ME */
  { 0x04d3, 0x30e2 }, /* kana_MO モ KATAKANA LETTER MO */
  { 0x04d4, 0x30e4 }, /* kana_YA ヤ KATAKANA LETTER YA */
  { 0x04d5, 0x30e6 }, /* kana_YU ユ KATAKANA LETTER YU */
  { 0x04d6, 0x30e8 }, /* kana_YO ヨ KATAKANA LETTER YO */
  { 0x04d7, 0x30e9 }, /* kana_RA ラ KATAKANA LETTER RA */
  { 0x04d8, 0x30ea }, /* kana_RI リ KATAKANA LETTER RI */
  { 0x04d9, 0x30eb }, /* kana_RU ル KATAKANA LETTER RU */
  { 0x04da, 0x30ec }, /* kana_RE レ KATAKANA LETTER RE */
  { 0x04db, 0x30ed }, /* kana_RO ロ KATAKANA LETTER RO */
  { 0x04dc, 0x30ef }, /* kana_WA ワ KATAKANA LETTER WA */
  { 0x04dd, 0x30f3 }, /* kana_N ン KATAKANA LETTER N */
  { 0x04de, 0x309b }, /* voicedsound ゛ KATAKANA-HIRAGANA VOICED SOUND MARK */
  { 0x04df, 0x309c }, /* semivoicedsound ゜ KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK */
  { 0x05ac, 0x060c }, /* Arabic_comma ، ARABIC COMMA */
  { 0x05bb, 0x061b }, /* Arabic_semicolon ؛ ARABIC SEMICOLON */
  { 0x05bf, 0x061f }, /* Arabic_question_mark ؟ ARABIC QUESTION MARK */
  { 0x05c1, 0x0621 }, /* Arabic_hamza ء ARABIC LETTER HAMZA */
  { 0x05c2, 0x0622 }, /* Arabic_maddaonalef آ ARABIC LETTER ALEF WITH MADDA ABOVE */
  { 0x05c3, 0x0623 }, /* Arabic_hamzaonalef أ ARABIC LETTER ALEF WITH HAMZA ABOVE */
  { 0x05c4, 0x0624 }, /* Arabic_hamzaonwaw ؤ ARABIC LETTER WAW WITH HAMZA ABOVE */
  { 0x05c5, 0x0625 }, /* Arabic_hamzaunderalef إ ARABIC LETTER ALEF WITH HAMZA BELOW */
  { 0x05c6, 0x0626 }, /* Arabic_hamzaonyeh ئ ARABIC LETTER YEH WITH HAMZA ABOVE */
  { 0x05c7, 0x0627 }, /* Arabic_alef ا ARABIC LETTER ALEF */
  { 0x05c8, 0x0628 }, /* Arabic_beh ب ARABIC LETTER BEH */
  { 0x05c9, 0x0629 }, /* Arabic_tehmarbuta ة ARABIC LETTER TEH MARBUTA */
  { 0x05ca, 0x062a }, /* Arabic_teh ت ARABIC LETTER TEH */
  { 0x05cb, 0x062b }, /* Arabic_theh ث ARABIC LETTER THEH */
  { 0x05cc, 0x062c }, /* Arabic_jeem ج ARABIC LETTER JEEM */
  { 0x05cd, 0x062d }, /* Arabic_hah ح ARABIC LETTER HAH */
  { 0x05ce, 0x062e }, /* Arabic_khah خ ARABIC LETTER KHAH */
  { 0x05cf, 0x062f }, /* Arabic_dal د ARABIC LETTER DAL */
  { 0x05d0, 0x0630 }, /* Arabic_thal ذ ARABIC LETTER THAL */
  { 0x05d1, 0x0631 }, /* Arabic_ra ر ARABIC LETTER REH */
  { 0x05d2, 0x0632 }, /* Arabic_zain ز ARABIC LETTER ZAIN */
  { 0x05d3, 0x0633 }, /* Arabic_seen س ARABIC LETTER SEEN */
  { 0x05d4, 0x0634 }, /* Arabic_sheen ش ARABIC LETTER SHEEN */
  { 0x05d5, 0x0635 }, /* Arabic_sad ص ARABIC LETTER SAD */
  { 0x05d6, 0x0636 }, /* Arabic_dad ض ARABIC LETTER DAD */
  { 0x05d7, 0x0637 }, /* Arabic_tah ط ARABIC LETTER TAH */
  { 0x05d8, 0x0638 }, /* Arabic_zah ظ ARABIC LETTER ZAH */
  { 0x05d9, 0x0639 }, /* Arabic_ain ع ARABIC LETTER AIN */
  { 0x05da, 0x063a }, /* Arabic_ghain غ ARABIC LETTER GHAIN */
  { 0x05e0, 0x0640 }, /* Arabic_tatweel ـ ARABIC TATWEEL */
  { 0x05e1, 0x0641 }, /* Arabic_feh ف ARABIC LETTER FEH */
  { 0x05e2, 0x0642 }, /* Arabic_qaf ق ARABIC LETTER QAF */
  { 0x05e3, 0x0643 }, /* Arabic_kaf ك ARABIC LETTER KAF */
  { 0x05e4, 0x0644 }, /* Arabic_lam ل ARABIC LETTER LAM */
  { 0x05e5, 0x0645 }, /* Arabic_meem م ARABIC LETTER MEEM */
  { 0x05e6, 0x0646 }, /* Arabic_noon ن ARABIC LETTER NOON */
  { 0x05e7, 0x0647 }, /* Arabic_ha ه ARABIC LETTER HEH */
  { 0x05e8, 0x0648 }, /* Arabic_waw و ARABIC LETTER WAW */
  { 0x05e9, 0x0649 }, /* Arabic_alefmaksura ى ARABIC LETTER ALEF MAKSURA */
  { 0x05ea, 0x064a }, /* Arabic_yeh ي ARABIC LETTER YEH */
  { 0x05eb, 0x064b }, /* Arabic_fathatan ً ARABIC FATHATAN */
  { 0x05ec, 0x064c }, /* Arabic_dammatan ٌ ARABIC DAMMATAN */
  { 0x05ed, 0x064d }, /* Arabic_kasratan ٍ ARABIC KASRATAN */
  { 0x05ee, 0x064e }, /* Arabic_fatha َ ARABIC FATHA */
  { 0x05ef, 0x064f }, /* Arabic_damma ُ ARABIC DAMMA */
  { 0x05f0, 0x0650 }, /* Arabic_kasra ِ ARABIC KASRA */
  { 0x05f1, 0x0651 }, /* Arabic_shadda ّ ARABIC SHADDA */
  { 0x05f2, 0x0652 }, /* Arabic_sukun ْ ARABIC SUKUN */
  { 0x06a1, 0x0452 }, /* Serbian_dje ђ CYRILLIC SMALL LETTER DJE */
  { 0x06a2, 0x0453 }, /* Macedonia_gje ѓ CYRILLIC SMALL LETTER GJE */
  { 0x06a3, 0x0451 }, /* Cyrillic_io ё CYRILLIC SMALL LETTER IO */
  { 0x06a4, 0x0454 }, /* Ukrainian_ie є CYRILLIC SMALL LETTER UKRAINIAN IE */
  { 0x06a5, 0x0455 }, /* Macedonia_dse ѕ CYRILLIC SMALL LETTER DZE */
  { 0x06a6, 0x0456 }, /* Ukrainian_i і CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I */
  { 0x06a7, 0x0457 }, /* Ukrainian_yi ї CYRILLIC SMALL LETTER YI */
  { 0x06a8, 0x0458 }, /* Cyrillic_je ј CYRILLIC SMALL LETTER JE */
  { 0x06a9, 0x0459 }, /* Cyrillic_lje љ CYRILLIC SMALL LETTER LJE */
  { 0x06aa, 0x045a }, /* Cyrillic_nje њ CYRILLIC SMALL LETTER NJE */
  { 0x06ab, 0x045b }, /* Serbian_tshe ћ CYRILLIC SMALL LETTER TSHE */
  { 0x06ac, 0x045c }, /* Macedonia_kje ќ CYRILLIC SMALL LETTER KJE */
  { 0x06ae, 0x045e }, /* Byelorussian_shortu ў CYRILLIC SMALL LETTER SHORT U */
  { 0x06af, 0x045f }, /* Cyrillic_dzhe џ CYRILLIC SMALL LETTER DZHE */
  { 0x06b0, 0x2116 }, /* numerosign № NUMERO SIGN */
  { 0x06b1, 0x0402 }, /* Serbian_DJE Ђ CYRILLIC CAPITAL LETTER DJE */
  { 0x06b2, 0x0403 }, /* Macedonia_GJE Ѓ CYRILLIC CAPITAL LETTER GJE */
  { 0x06b3, 0x0401 }, /* Cyrillic_IO Ё CYRILLIC CAPITAL LETTER IO */
  { 0x06b4, 0x0404 }, /* Ukrainian_IE Є CYRILLIC CAPITAL LETTER UKRAINIAN IE */
  { 0x06b5, 0x0405 }, /* Macedonia_DSE Ѕ CYRILLIC CAPITAL LETTER DZE */
  { 0x06b6, 0x0406 }, /* Ukrainian_I І CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I */
  { 0x06b7, 0x0407 }, /* Ukrainian_YI Ї CYRILLIC CAPITAL LETTER YI */
  { 0x06b8, 0x0408 }, /* Cyrillic_JE Ј CYRILLIC CAPITAL LETTER JE */
  { 0x06b9, 0x0409 }, /* Cyrillic_LJE Љ CYRILLIC CAPITAL LETTER LJE */
  { 0x06ba, 0x040a }, /* Cyrillic_NJE Њ CYRILLIC CAPITAL LETTER NJE */
  { 0x06bb, 0x040b }, /* Serbian_TSHE Ћ CYRILLIC CAPITAL LETTER TSHE */
  { 0x06bc, 0x040c }, /* Macedonia_KJE Ќ CYRILLIC CAPITAL LETTER KJE */
  { 0x06be, 0x040e }, /* Byelorussian_SHORTU Ў CYRILLIC CAPITAL LETTER SHORT U */
  { 0x06bf, 0x040f }, /* Cyrillic_DZHE Џ CYRILLIC CAPITAL LETTER DZHE */
  { 0x06c0, 0x044e }, /* Cyrillic_yu ю CYRILLIC SMALL LETTER YU */
  { 0x06c1, 0x0430 }, /* Cyrillic_a а CYRILLIC SMALL LETTER A */
  { 0x06c2, 0x0431 }, /* Cyrillic_be б CYRILLIC SMALL LETTER BE */
  { 0x06c3, 0x0446 }, /* Cyrillic_tse ц CYRILLIC SMALL LETTER TSE */
  { 0x06c4, 0x0434 }, /* Cyrillic_de д CYRILLIC SMALL LETTER DE */
  { 0x06c5, 0x0435 }, /* Cyrillic_ie е CYRILLIC SMALL LETTER IE */
  { 0x06c6, 0x0444 }, /* Cyrillic_ef ф CYRILLIC SMALL LETTER EF */
  { 0x06c7, 0x0433 }, /* Cyrillic_ghe г CYRILLIC SMALL LETTER GHE */
  { 0x06c8, 0x0445 }, /* Cyrillic_ha х CYRILLIC SMALL LETTER HA */
  { 0x06c9, 0x0438 }, /* Cyrillic_i и CYRILLIC SMALL LETTER I */
  { 0x06ca, 0x0439 }, /* Cyrillic_shorti й CYRILLIC SMALL LETTER SHORT I */
  { 0x06cb, 0x043a }, /* Cyrillic_ka к CYRILLIC SMALL LETTER KA */
  { 0x06cc, 0x043b }, /* Cyrillic_el л CYRILLIC SMALL LETTER EL */
  { 0x06cd, 0x043c }, /* Cyrillic_em м CYRILLIC SMALL LETTER EM */
  { 0x06ce, 0x043d }, /* Cyrillic_en н CYRILLIC SMALL LETTER EN */
  { 0x06cf, 0x043e }, /* Cyrillic_o о CYRILLIC SMALL LETTER O */
  { 0x06d0, 0x043f }, /* Cyrillic_pe п CYRILLIC SMALL LETTER PE */
  { 0x06d1, 0x044f }, /* Cyrillic_ya я CYRILLIC SMALL LETTER YA */
  { 0x06d2, 0x0440 }, /* Cyrillic_er р CYRILLIC SMALL LETTER ER */
  { 0x06d3, 0x0441 }, /* Cyrillic_es с CYRILLIC SMALL LETTER ES */
  { 0x06d4, 0x0442 }, /* Cyrillic_te т CYRILLIC SMALL LETTER TE */
  { 0x06d5, 0x0443 }, /* Cyrillic_u у CYRILLIC SMALL LETTER U */
  { 0x06d6, 0x0436 }, /* Cyrillic_zhe ж CYRILLIC SMALL LETTER ZHE */
  { 0x06d7, 0x0432 }, /* Cyrillic_ve в CYRILLIC SMALL LETTER VE */
  { 0x06d8, 0x044c }, /* Cyrillic_softsign ь CYRILLIC SMALL LETTER SOFT SIGN */
  { 0x06d9, 0x044b }, /* Cyrillic_yeru ы CYRILLIC SMALL LETTER YERU */
  { 0x06da, 0x0437 }, /* Cyrillic_ze з CYRILLIC SMALL LETTER ZE */
  { 0x06db, 0x0448 }, /* Cyrillic_sha ш CYRILLIC SMALL LETTER SHA */
  { 0x06dc, 0x044d }, /* Cyrillic_e э CYRILLIC SMALL LETTER E */
  { 0x06dd, 0x0449 }, /* Cyrillic_shcha щ CYRILLIC SMALL LETTER SHCHA */
  { 0x06de, 0x0447 }, /* Cyrillic_che ч CYRILLIC SMALL LETTER CHE */
  { 0x06df, 0x044a }, /* Cyrillic_hardsign ъ CYRILLIC SMALL LETTER HARD SIGN */
  { 0x06e0, 0x042e }, /* Cyrillic_YU Ю CYRILLIC CAPITAL LETTER YU */
  { 0x06e1, 0x0410 }, /* Cyrillic_A А CYRILLIC CAPITAL LETTER A */
  { 0x06e2, 0x0411 }, /* Cyrillic_BE Б CYRILLIC CAPITAL LETTER BE */
  { 0x06e3, 0x0426 }, /* Cyrillic_TSE Ц CYRILLIC CAPITAL LETTER TSE */
  { 0x06e4, 0x0414 }, /* Cyrillic_DE Д CYRILLIC CAPITAL LETTER DE */
  { 0x06e5, 0x0415 }, /* Cyrillic_IE Е CYRILLIC CAPITAL LETTER IE */
  { 0x06e6, 0x0424 }, /* Cyrillic_EF Ф CYRILLIC CAPITAL LETTER EF */
  { 0x06e7, 0x0413 }, /* Cyrillic_GHE Г CYRILLIC CAPITAL LETTER GHE */
  { 0x06e8, 0x0425 }, /* Cyrillic_HA Х CYRILLIC CAPITAL LETTER HA */
  { 0x06e9, 0x0418 }, /* Cyrillic_I И CYRILLIC CAPITAL LETTER I */
  { 0x06ea, 0x0419 }, /* Cyrillic_SHORTI Й CYRILLIC CAPITAL LETTER SHORT I */
  { 0x06eb, 0x041a }, /* Cyrillic_KA К CYRILLIC CAPITAL LETTER KA */
  { 0x06ec, 0x041b }, /* Cyrillic_EL Л CYRILLIC CAPITAL LETTER EL */
  { 0x06ed, 0x041c }, /* Cyrillic_EM М CYRILLIC CAPITAL LETTER EM */
  { 0x06ee, 0x041d }, /* Cyrillic_EN Н CYRILLIC CAPITAL LETTER EN */
  { 0x06ef, 0x041e }, /* Cyrillic_O О CYRILLIC CAPITAL LETTER O */
  { 0x06f0, 0x041f }, /* Cyrillic_PE П CYRILLIC CAPITAL LETTER PE */
  { 0x06f1, 0x042f }, /* Cyrillic_YA Я CYRILLIC CAPITAL LETTER YA */
  { 0x06f2, 0x0420 }, /* Cyrillic_ER Р CYRILLIC CAPITAL LETTER ER */
  { 0x06f3, 0x0421 }, /* Cyrillic_ES С CYRILLIC CAPITAL LETTER ES */
  { 0x06f4, 0x0422 }, /* Cyrillic_TE Т CYRILLIC CAPITAL LETTER TE */
  { 0x06f5, 0x0423 }, /* Cyrillic_U У CYRILLIC CAPITAL LETTER U */
  { 0x06f6, 0x0416 }, /* Cyrillic_ZHE Ж CYRILLIC CAPITAL LETTER ZHE */
  { 0x06f7, 0x0412 }, /* Cyrillic_VE В CYRILLIC CAPITAL LETTER VE */
  { 0x06f8, 0x042c }, /* Cyrillic_SOFTSIGN Ь CYRILLIC CAPITAL LETTER SOFT SIGN */
  { 0x06f9, 0x042b }, /* Cyrillic_YERU Ы CYRILLIC CAPITAL LETTER YERU */
  { 0x06fa, 0x0417 }, /* Cyrillic_ZE З CYRILLIC CAPITAL LETTER ZE */
  { 0x06fb, 0x0428 }, /* Cyrillic_SHA Ш CYRILLIC CAPITAL LETTER SHA */
  { 0x06fc, 0x042d }, /* Cyrillic_E Э CYRILLIC CAPITAL LETTER E */
  { 0x06fd, 0x0429 }, /* Cyrillic_SHCHA Щ CYRILLIC CAPITAL LETTER SHCHA */
  { 0x06fe, 0x0427 }, /* Cyrillic_CHE Ч CYRILLIC CAPITAL LETTER CHE */
  { 0x06ff, 0x042a }, /* Cyrillic_HARDSIGN Ъ CYRILLIC CAPITAL LETTER HARD SIGN */
  { 0x07a1, 0x0386 }, /* Greek_ALPHAaccent Ά GREEK CAPITAL LETTER ALPHA WITH TONOS */
  { 0x07a2, 0x0388 }, /* Greek_EPSILONaccent Έ GREEK CAPITAL LETTER EPSILON WITH TONOS */
  { 0x07a3, 0x0389 }, /* Greek_ETAaccent Ή GREEK CAPITAL LETTER ETA WITH TONOS */
  { 0x07a4, 0x038a }, /* Greek_IOTAaccent Ί GREEK CAPITAL LETTER IOTA WITH TONOS */
  { 0x07a5, 0x03aa }, /* Greek_IOTAdiaeresis Ϊ GREEK CAPITAL LETTER IOTA WITH DIALYTIKA */
  { 0x07a7, 0x038c }, /* Greek_OMICRONaccent Ό GREEK CAPITAL LETTER OMICRON WITH TONOS */
  { 0x07a8, 0x038e }, /* Greek_UPSILONaccent Ύ GREEK CAPITAL LETTER UPSILON WITH TONOS */
  { 0x07a9, 0x03ab }, /* Greek_UPSILONdieresis Ϋ GREEK CAPITAL LETTER UPSILON WITH DIALYTIKA */
  { 0x07ab, 0x038f }, /* Greek_OMEGAaccent Ώ GREEK CAPITAL LETTER OMEGA WITH TONOS */
  { 0x07ae, 0x0385 }, /* Greek_accentdieresis ΅ GREEK DIALYTIKA TONOS */
  { 0x07af, 0x2015 }, /* Greek_horizbar ― HORIZONTAL BAR */
  { 0x07b1, 0x03ac }, /* Greek_alphaaccent ά GREEK SMALL LETTER ALPHA WITH TONOS */
  { 0x07b2, 0x03ad }, /* Greek_epsilonaccent έ GREEK SMALL LETTER EPSILON WITH TONOS */
  { 0x07b3, 0x03ae }, /* Greek_etaaccent ή GREEK SMALL LETTER ETA WITH TONOS */
  { 0x07b4, 0x03af }, /* Greek_iotaaccent ί GREEK SMALL LETTER IOTA WITH TONOS */
  { 0x07b5, 0x03ca }, /* Greek_iotadieresis ϊ GREEK SMALL LETTER IOTA WITH DIALYTIKA */
  { 0x07b6, 0x0390 }, /* Greek_iotaaccentdieresis ΐ GREEK SMALL LETTER IOTA WITH DIALYTIKA AND TONOS */
  { 0x07b7, 0x03cc }, /* Greek_omicronaccent ό GREEK SMALL LETTER OMICRON WITH TONOS */
  { 0x07b8, 0x03cd }, /* Greek_upsilonaccent ύ GREEK SMALL LETTER UPSILON WITH TONOS */
  { 0x07b9, 0x03cb }, /* Greek_upsilondieresis ϋ GREEK SMALL LETTER UPSILON WITH DIALYTIKA */
  { 0x07ba, 0x03b0 }, /* Greek_upsilonaccentdieresis ΰ GREEK SMALL LETTER UPSILON WITH DIALYTIKA AND TONOS */
  { 0x07bb, 0x03ce }, /* Greek_omegaaccent ώ GREEK SMALL LETTER OMEGA WITH TONOS */
  { 0x07c1, 0x0391 }, /* Greek_ALPHA Α GREEK CAPITAL LETTER ALPHA */
  { 0x07c2, 0x0392 }, /* Greek_BETA Β GREEK CAPITAL LETTER BETA */
  { 0x07c3, 0x0393 }, /* Greek_GAMMA Γ GREEK CAPITAL LETTER GAMMA */
  { 0x07c4, 0x0394 }, /* Greek_DELTA Δ GREEK CAPITAL LETTER DELTA */
  { 0x07c5, 0x0395 }, /* Greek_EPSILON Ε GREEK CAPITAL LETTER EPSILON */
  { 0x07c6, 0x0396 }, /* Greek_ZETA Ζ GREEK CAPITAL LETTER ZETA */
  { 0x07c7, 0x0397 }, /* Greek_ETA Η GREEK CAPITAL LETTER ETA */
  { 0x07c8, 0x0398 }, /* Greek_THETA Θ GREEK CAPITAL LETTER THETA */
  { 0x07c9, 0x0399 }, /* Greek_IOTA Ι GREEK CAPITAL LETTER IOTA */
  { 0x07ca, 0x039a }, /* Greek_KAPPA Κ GREEK CAPITAL LETTER KAPPA */
  { 0x07cb, 0x039b }, /* Greek_LAMBDA Λ GREEK CAPITAL LETTER LAMDA */
  { 0x07cc, 0x039c }, /* Greek_MU Μ GREEK CAPITAL LETTER MU */
  { 0x07cd, 0x039d }, /* Greek_NU Ν GREEK CAPITAL LETTER NU */
  { 0x07ce, 0x039e }, /* Greek_XI Ξ GREEK CAPITAL LETTER XI */
  { 0x07cf, 0x039f }, /* Greek_OMICRON Ο GREEK CAPITAL LETTER OMICRON */
  { 0x07d0, 0x03a0 }, /* Greek_PI Π GREEK CAPITAL LETTER PI */
  { 0x07d1, 0x03a1 }, /* Greek_RHO Ρ GREEK CAPITAL LETTER RHO */
  { 0x07d2, 0x03a3 }, /* Greek_SIGMA Σ GREEK CAPITAL LETTER SIGMA */
  { 0x07d4, 0x03a4 }, /* Greek_TAU Τ GREEK CAPITAL LETTER TAU */
  { 0x07d5, 0x03a5 }, /* Greek_UPSILON Υ GREEK CAPITAL LETTER UPSILON */
  { 0x07d6, 0x03a6 }, /* Greek_PHI Φ GREEK CAPITAL LETTER PHI */
  { 0x07d7, 0x03a7 }, /* Greek_CHI Χ GREEK CAPITAL LETTER CHI */
  { 0x07d8, 0x03a8 }, /* Greek_PSI Ψ GREEK CAPITAL LETTER PSI */
  { 0x07d9, 0x03a9 }, /* Greek_OMEGA Ω GREEK CAPITAL LETTER OMEGA */
  { 0x07e1, 0x03b1 }, /* Greek_alpha α GREEK SMALL LETTER ALPHA */
  { 0x07e2, 0x03b2 }, /* Greek_beta β GREEK SMALL LETTER BETA */
  { 0x07e3, 0x03b3 }, /* Greek_gamma γ GREEK SMALL LETTER GAMMA */
  { 0x07e4, 0x03b4 }, /* Greek_delta δ GREEK SMALL LETTER DELTA */
  { 0x07e5, 0x03b5 }, /* Greek_epsilon ε GREEK SMALL LETTER EPSILON */
  { 0x07e6, 0x03b6 }, /* Greek_zeta ζ GREEK SMALL LETTER ZETA */
  { 0x07e7, 0x03b7 }, /* Greek_eta η GREEK SMALL LETTER ETA */
  { 0x07e8, 0x03b8 }, /* Greek_theta θ GREEK SMALL LETTER THETA */
  { 0x07e9, 0x03b9 }, /* Greek_iota ι GREEK SMALL LETTER IOTA */
  { 0x07ea, 0x03ba }, /* Greek_kappa κ GREEK SMALL LETTER KAPPA */
  { 0x07eb, 0x03bb }, /* Greek_lambda λ GREEK SMALL LETTER LAMDA */
  { 0x07ec, 0x03bc }, /* Greek_mu μ GREEK SMALL LETTER MU */
  { 0x07ed, 0x03bd }, /* Greek_nu ν GREEK SMALL LETTER NU */
  { 0x07ee, 0x03be }, /* Greek_xi ξ GREEK SMALL LETTER XI */
  { 0x07ef, 0x03bf }, /* Greek_omicron ο GREEK SMALL LETTER OMICRON */
  { 0x07f0, 0x03c0 }, /* Greek_pi π GREEK SMALL LETTER PI */
  { 0x07f1, 0x03c1 }, /* Greek_rho ρ GREEK SMALL LETTER RHO */
  { 0x07f2, 0x03c3 }, /* Greek_sigma σ GREEK SMALL LETTER SIGMA */
  { 0x07f3, 0x03c2 }, /* Greek_finalsmallsigma ς GREEK SMALL LETTER FINAL SIGMA */
  { 0x07f4, 0x03c4 }, /* Greek_tau τ GREEK SMALL LETTER TAU */
  { 0x07f5, 0x03c5 }, /* Greek_upsilon υ GREEK SMALL LETTER UPSILON */
  { 0x07f6, 0x03c6 }, /* Greek_phi φ GREEK SMALL LETTER PHI */
  { 0x07f7, 0x03c7 }, /* Greek_chi χ GREEK SMALL LETTER CHI */
  { 0x07f8, 0x03c8 }, /* Greek_psi ψ GREEK SMALL LETTER PSI */
  { 0x07f9, 0x03c9 }, /* Greek_omega ω GREEK SMALL LETTER OMEGA */
/* 0x08a1 leftradical ? ??? */
/* 0x08a2 topleftradical ? ??? */
/* 0x08a3 horizconnector ? ??? */
  { 0x08a4, 0x2320 }, /* topintegral ⌠ TOP HALF INTEGRAL */
  { 0x08a5, 0x2321 }, /* botintegral ⌡ BOTTOM HALF INTEGRAL */
  { 0x08a6, 0x2502 }, /* vertconnector │ BOX DRAWINGS LIGHT VERTICAL */
/* 0x08a7 topleftsqbracket ? ??? */
/* 0x08a8 botleftsqbracket ? ??? */
/* 0x08a9 toprightsqbracket ? ??? */
/* 0x08aa botrightsqbracket ? ??? */
/* 0x08ab topleftparens ? ??? */
/* 0x08ac botleftparens ? ??? */
/* 0x08ad toprightparens ? ??? */
/* 0x08ae botrightparens ? ??? */
/* 0x08af leftmiddlecurlybrace ? ??? */
/* 0x08b0 rightmiddlecurlybrace ? ??? */
/* 0x08b1 topleftsummation ? ??? */
/* 0x08b2 botleftsummation ? ??? */
/* 0x08b3 topvertsummationconnector ? ??? */
/* 0x08b4 botvertsummationconnector ? ??? */
/* 0x08b5 toprightsummation ? ??? */
/* 0x08b6 botrightsummation ? ??? */
/* 0x08b7 rightmiddlesummation ? ??? */
  { 0x08bc, 0x2264 }, /* lessthanequal ≤ LESS-THAN OR EQUAL TO */
  { 0x08bd, 0x2260 }, /* notequal ≠ NOT EQUAL TO */
  { 0x08be, 0x2265 }, /* greaterthanequal ≥ GREATER-THAN OR EQUAL TO */
  { 0x08bf, 0x222b }, /* integral ∫ INTEGRAL */
  { 0x08c0, 0x2234 }, /* therefore ∴ THEREFORE */
  { 0x08c1, 0x221d }, /* variation ∝ PROPORTIONAL TO */
  { 0x08c2, 0x221e }, /* infinity ∞ INFINITY */
  { 0x08c5, 0x2207 }, /* nabla ∇ NABLA */
  { 0x08c8, 0x2245 }, /* approximate ≅ APPROXIMATELY EQUAL TO */
/* 0x08c9 similarequal ? ??? */
  { 0x08cd, 0x21d4 }, /* ifonlyif ⇔ LEFT RIGHT DOUBLE ARROW */
  { 0x08ce, 0x21d2 }, /* implies ⇒ RIGHTWARDS DOUBLE ARROW */
  { 0x08cf, 0x2261 }, /* identical ≡ IDENTICAL TO */
  { 0x08d6, 0x221a }, /* radical √ SQUARE ROOT */
  { 0x08da, 0x2282 }, /* includedin ⊂ SUBSET OF */
  { 0x08db, 0x2283 }, /* includes ⊃ SUPERSET OF */
  { 0x08dc, 0x2229 }, /* intersection ∩ INTERSECTION */
  { 0x08dd, 0x222a }, /* union ∪ UNION */
  { 0x08de, 0x2227 }, /* logicaland ∧ LOGICAL AND */
  { 0x08df, 0x2228 }, /* logicalor ∨ LOGICAL OR */
  { 0x08ef, 0x2202 }, /* partialderivative ∂ PARTIAL DIFFERENTIAL */
  { 0x08f6, 0x0192 }, /* function ƒ LATIN SMALL LETTER F WITH HOOK */
  { 0x08fb, 0x2190 }, /* leftarrow ← LEFTWARDS ARROW */
  { 0x08fc, 0x2191 }, /* uparrow ↑ UPWARDS ARROW */
  { 0x08fd, 0x2192 }, /* rightarrow → RIGHTWARDS ARROW */
  { 0x08fe, 0x2193 }, /* downarrow ↓ DOWNWARDS ARROW */
  { 0x09df, 0x2422 }, /* blank ␢ BLANK SYMBOL */
  { 0x09e0, 0x25c6 }, /* soliddiamond ◆ BLACK DIAMOND */
  { 0x09e1, 0x2592 }, /* checkerboard ▒ MEDIUM SHADE */
  { 0x09e2, 0x2409 }, /* ht ␉ SYMBOL FOR HORIZONTAL TABULATION */
  { 0x09e3, 0x240c }, /* ff ␌ SYMBOL FOR FORM FEED */
  { 0x09e4, 0x240d }, /* cr ␍ SYMBOL FOR CARRIAGE RETURN */
  { 0x09e5, 0x240a }, /* lf ␊ SYMBOL FOR LINE FEED */
  { 0x09e8, 0x2424 }, /* nl ␤ SYMBOL FOR NEWLINE */
  { 0x09e9, 0x240b }, /* vt ␋ SYMBOL FOR VERTICAL TABULATION */
  { 0x09ea, 0x2518 }, /* lowrightcorner ┘ BOX DRAWINGS LIGHT UP AND LEFT */
  { 0x09eb, 0x2510 }, /* uprightcorner ┐ BOX DRAWINGS LIGHT DOWN AND LEFT */
  { 0x09ec, 0x250c }, /* upleftcorner ┌ BOX DRAWINGS LIGHT DOWN AND RIGHT */
  { 0x09ed, 0x2514 }, /* lowleftcorner └ BOX DRAWINGS LIGHT UP AND RIGHT */
  { 0x09ee, 0x253c }, /* crossinglines ┼ BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL */
/* 0x09ef horizlinescan1 ? ??? */
/* 0x09f0 horizlinescan3 ? ??? */
  { 0x09f1, 0x2500 }, /* horizlinescan5 ─ BOX DRAWINGS LIGHT HORIZONTAL */
/* 0x09f2 horizlinescan7 ? ??? */
/* 0x09f3 horizlinescan9 ? ??? */
  { 0x09f4, 0x251c }, /* leftt ├ BOX DRAWINGS LIGHT VERTICAL AND RIGHT */
  { 0x09f5, 0x2524 }, /* rightt ┤ BOX DRAWINGS LIGHT VERTICAL AND LEFT */
  { 0x09f6, 0x2534 }, /* bott ┴ BOX DRAWINGS LIGHT UP AND HORIZONTAL */
  { 0x09f7, 0x252c }, /* topt ┬ BOX DRAWINGS LIGHT DOWN AND HORIZONTAL */
  { 0x09f8, 0x2502 }, /* vertbar │ BOX DRAWINGS LIGHT VERTICAL */
  { 0x0aa1, 0x2003 }, /* emspace   EM SPACE */
  { 0x0aa2, 0x2002 }, /* enspace   EN SPACE */
  { 0x0aa3, 0x2004 }, /* em3space   THREE-PER-EM SPACE */
  { 0x0aa4, 0x2005 }, /* em4space   FOUR-PER-EM SPACE */
  { 0x0aa5, 0x2007 }, /* digitspace   FIGURE SPACE */
  { 0x0aa6, 0x2008 }, /* punctspace   PUNCTUATION SPACE */
  { 0x0aa7, 0x2009 }, /* thinspace   THIN SPACE */
  { 0x0aa8, 0x200a }, /* hairspace   HAIR SPACE */
  { 0x0aa9, 0x2014 }, /* emdash — EM DASH */
  { 0x0aaa, 0x2013 }, /* endash – EN DASH */
/* 0x0aac signifblank ? ??? */
  { 0x0aae, 0x2026 }, /* ellipsis … HORIZONTAL ELLIPSIS */
/* 0x0aaf doubbaselinedot ? ??? */
  { 0x0ab0, 0x2153 }, /* onethird ⅓ VULGAR FRACTION ONE THIRD */
  { 0x0ab1, 0x2154 }, /* twothirds ⅔ VULGAR FRACTION TWO THIRDS */
  { 0x0ab2, 0x2155 }, /* onefifth ⅕ VULGAR FRACTION ONE FIFTH */
  { 0x0ab3, 0x2156 }, /* twofifths ⅖ VULGAR FRACTION TWO FIFTHS */
  { 0x0ab4, 0x2157 }, /* threefifths ⅗ VULGAR FRACTION THREE FIFTHS */
  { 0x0ab5, 0x2158 }, /* fourfifths ⅘ VULGAR FRACTION FOUR FIFTHS */
  { 0x0ab6, 0x2159 }, /* onesixth ⅙ VULGAR FRACTION ONE SIXTH */
  { 0x0ab7, 0x215a }, /* fivesixths ⅚ VULGAR FRACTION FIVE SIXTHS */
  { 0x0ab8, 0x2105 }, /* careof ℅ CARE OF */
  { 0x0abb, 0x2012 }, /* figdash ‒ FIGURE DASH */
  { 0x0abc, 0x2329 }, /* leftanglebracket 〈 LEFT-POINTING ANGLE BRACKET */
  { 0x0abd, 0x002e }, /* decimalpoint . FULL STOP */
  { 0x0abe, 0x232a }, /* rightanglebracket 〉 RIGHT-POINTING ANGLE BRACKET */
/* 0x0abf marker ? ??? */
  { 0x0ac3, 0x215b }, /* oneeighth ⅛ VULGAR FRACTION ONE EIGHTH */
  { 0x0ac4, 0x215c }, /* threeeighths ⅜ VULGAR FRACTION THREE EIGHTHS */
  { 0x0ac5, 0x215d }, /* fiveeighths ⅝ VULGAR FRACTION FIVE EIGHTHS */
  { 0x0ac6, 0x215e }, /* seveneighths ⅞ VULGAR FRACTION SEVEN EIGHTHS */
  { 0x0ac9, 0x2122 }, /* trademark ™ TRADE MARK SIGN */
  { 0x0aca, 0x2613 }, /* signaturemark ☓ SALTIRE */
/* 0x0acb trademarkincircle ? ??? */
  { 0x0acc, 0x25c1 }, /* leftopentriangle ◁ WHITE LEFT-POINTING TRIANGLE */
  { 0x0acd, 0x25b7 }, /* rightopentriangle ▷ WHITE RIGHT-POINTING TRIANGLE */
  { 0x0ace, 0x25cb }, /* emopencircle ○ WHITE CIRCLE */
  { 0x0acf, 0x25a1 }, /* emopenrectangle □ WHITE SQUARE */
  { 0x0ad0, 0x2018 }, /* leftsinglequotemark ‘ LEFT SINGLE QUOTATION MARK */
  { 0x0ad1, 0x2019 }, /* rightsinglequotemark ’ RIGHT SINGLE QUOTATION MARK */
  { 0x0ad2, 0x201c }, /* leftdoublequotemark “ LEFT DOUBLE QUOTATION MARK */
  { 0x0ad3, 0x201d }, /* rightdoublequotemark ” RIGHT DOUBLE QUOTATION MARK */
  { 0x0ad4, 0x211e }, /* prescription ℞ PRESCRIPTION TAKE */
  { 0x0ad6, 0x2032 }, /* minutes ′ PRIME */
  { 0x0ad7, 0x2033 }, /* seconds ″ DOUBLE PRIME */
  { 0x0ad9, 0x271d }, /* latincross ✝ LATIN CROSS */
/* 0x0ada hexagram ? ??? */
  { 0x0adb, 0x25ac }, /* filledrectbullet ▬ BLACK RECTANGLE */
  { 0x0adc, 0x25c0 }, /* filledlefttribullet ◀ BLACK LEFT-POINTING TRIANGLE */
  { 0x0add, 0x25b6 }, /* filledrighttribullet ▶ BLACK RIGHT-POINTING TRIANGLE */
  { 0x0ade, 0x25cf }, /* emfilledcircle ● BLACK CIRCLE */
  { 0x0adf, 0x25a0 }, /* emfilledrect ■ BLACK SQUARE */
  { 0x0ae0, 0x25e6 }, /* enopencircbullet ◦ WHITE BULLET */
  { 0x0ae1, 0x25ab }, /* enopensquarebullet ▫ WHITE SMALL SQUARE */
  { 0x0ae2, 0x25ad }, /* openrectbullet ▭ WHITE RECTANGLE */
  { 0x0ae3, 0x25b3 }, /* opentribulletup △ WHITE UP-POINTING TRIANGLE */
  { 0x0ae4, 0x25bd }, /* opentribulletdown ▽ WHITE DOWN-POINTING TRIANGLE */
  { 0x0ae5, 0x2606 }, /* openstar ☆ WHITE STAR */
  { 0x0ae6, 0x2022 }, /* enfilledcircbullet • BULLET */
  { 0x0ae7, 0x25aa }, /* enfilledsqbullet ▪ BLACK SMALL SQUARE */
  { 0x0ae8, 0x25b2 }, /* filledtribulletup ▲ BLACK UP-POINTING TRIANGLE */
  { 0x0ae9, 0x25bc }, /* filledtribulletdown ▼ BLACK DOWN-POINTING TRIANGLE */
  { 0x0aea, 0x261c }, /* leftpointer ☜ WHITE LEFT POINTING INDEX */
  { 0x0aeb, 0x261e }, /* rightpointer ☞ WHITE RIGHT POINTING INDEX */
  { 0x0aec, 0x2663 }, /* club ♣ BLACK CLUB SUIT */
  { 0x0aed, 0x2666 }, /* diamond ♦ BLACK DIAMOND SUIT */
  { 0x0aee, 0x2665 }, /* heart ♥ BLACK HEART SUIT */
  { 0x0af0, 0x2720 }, /* maltesecross ✠ MALTESE CROSS */
  { 0x0af1, 0x2020 }, /* dagger † DAGGER */
  { 0x0af2, 0x2021 }, /* doubledagger ‡ DOUBLE DAGGER */
  { 0x0af3, 0x2713 }, /* checkmark ✓ CHECK MARK */
  { 0x0af4, 0x2717 }, /* ballotcross ✗ BALLOT X */
  { 0x0af5, 0x266f }, /* musicalsharp ♯ MUSIC SHARP SIGN */
  { 0x0af6, 0x266d }, /* musicalflat ♭ MUSIC FLAT SIGN */
  { 0x0af7, 0x2642 }, /* malesymbol ♂ MALE SIGN */
  { 0x0af8, 0x2640 }, /* femalesymbol ♀ FEMALE SIGN */
  { 0x0af9, 0x260e }, /* telephone ☎ BLACK TELEPHONE */
  { 0x0afa, 0x2315 }, /* telephonerecorder ⌕ TELEPHONE RECORDER */
  { 0x0afb, 0x2117 }, /* phonographcopyright ℗ SOUND RECORDING COPYRIGHT */
  { 0x0afc, 0x2038 }, /* caret ‸ CARET */
  { 0x0afd, 0x201a }, /* singlelowquotemark ‚ SINGLE LOW-9 QUOTATION MARK */
  { 0x0afe, 0x201e }, /* doublelowquotemark „ DOUBLE LOW-9 QUOTATION MARK */
/* 0x0aff cursor ? ??? */
  { 0x0ba3, 0x003c }, /* leftcaret < LESS-THAN SIGN */
  { 0x0ba6, 0x003e }, /* rightcaret > GREATER-THAN SIGN */
  { 0x0ba8, 0x2228 }, /* downcaret ∨ LOGICAL OR */
  { 0x0ba9, 0x2227 }, /* upcaret ∧ LOGICAL AND */
  { 0x0bc0, 0x00af }, /* overbar ¯ MACRON */
  { 0x0bc2, 0x22a4 }, /* downtack ⊤ DOWN TACK */
  { 0x0bc3, 0x2229 }, /* upshoe ∩ INTERSECTION */
  { 0x0bc4, 0x230a }, /* downstile ⌊ LEFT FLOOR */
  { 0x0bc6, 0x005f }, /* underbar _ LOW LINE */
  { 0x0bca, 0x2218 }, /* jot ∘ RING OPERATOR */
  { 0x0bcc, 0x2395 }, /* quad ⎕ APL FUNCTIONAL SYMBOL QUAD (Unicode 3.0) */
  { 0x0bce, 0x22a5 }, /* uptack ⊥ UP TACK */
  { 0x0bcf, 0x25cb }, /* circle ○ WHITE CIRCLE */
  { 0x0bd3, 0x2308 }, /* upstile ⌈ LEFT CEILING */
  { 0x0bd6, 0x222a }, /* downshoe ∪ UNION */
  { 0x0bd8, 0x2283 }, /* rightshoe ⊃ SUPERSET OF */
  { 0x0bda, 0x2282 }, /* leftshoe ⊂ SUBSET OF */
  { 0x0bdc, 0x22a3 }, /* lefttack ⊣ LEFT TACK */
  { 0x0bfc, 0x22a2 }, /* righttack ⊢ RIGHT TACK */
  { 0x0cdf, 0x2017 }, /* hebrew_doublelowline ‗ DOUBLE LOW LINE */
  { 0x0ce0, 0x05d0 }, /* hebrew_aleph א HEBREW LETTER ALEF */
  { 0x0ce1, 0x05d1 }, /* hebrew_bet ב HEBREW LETTER BET */
  { 0x0ce2, 0x05d2 }, /* hebrew_gimel ג HEBREW LETTER GIMEL */
  { 0x0ce3, 0x05d3 }, /* hebrew_dalet ד HEBREW LETTER DALET */
  { 0x0ce4, 0x05d4 }, /* hebrew_he ה HEBREW LETTER HE */
  { 0x0ce5, 0x05d5 }, /* hebrew_waw ו HEBREW LETTER VAV */
  { 0x0ce6, 0x05d6 }, /* hebrew_zain ז HEBREW LETTER ZAYIN */
  { 0x0ce7, 0x05d7 }, /* hebrew_chet ח HEBREW LETTER HET */
  { 0x0ce8, 0x05d8 }, /* hebrew_tet ט HEBREW LETTER TET */
  { 0x0ce9, 0x05d9 }, /* hebrew_yod י HEBREW LETTER YOD */
  { 0x0cea, 0x05da }, /* hebrew_finalkaph ך HEBREW LETTER FINAL KAF */
  { 0x0ceb, 0x05db }, /* hebrew_kaph כ HEBREW LETTER KAF */
  { 0x0cec, 0x05dc }, /* hebrew_lamed ל HEBREW LETTER LAMED */
  { 0x0ced, 0x05dd }, /* hebrew_finalmem ם HEBREW LETTER FINAL MEM */
  { 0x0cee, 0x05de }, /* hebrew_mem מ HEBREW LETTER MEM */
  { 0x0cef, 0x05df }, /* hebrew_finalnun ן HEBREW LETTER FINAL NUN */
  { 0x0cf0, 0x05e0 }, /* hebrew_nun נ HEBREW LETTER NUN */
  { 0x0cf1, 0x05e1 }, /* hebrew_samech ס HEBREW LETTER SAMEKH */
  { 0x0cf2, 0x05e2 }, /* hebrew_ayin ע HEBREW LETTER AYIN */
  { 0x0cf3, 0x05e3 }, /* hebrew_finalpe ף HEBREW LETTER FINAL PE */
  { 0x0cf4, 0x05e4 }, /* hebrew_pe פ HEBREW LETTER PE */
  { 0x0cf5, 0x05e5 }, /* hebrew_finalzade ץ HEBREW LETTER FINAL TSADI */
  { 0x0cf6, 0x05e6 }, /* hebrew_zade צ HEBREW LETTER TSADI */
  { 0x0cf7, 0x05e7 }, /* hebrew_qoph ק HEBREW LETTER QOF */
  { 0x0cf8, 0x05e8 }, /* hebrew_resh ר HEBREW LETTER RESH */
  { 0x0cf9, 0x05e9 }, /* hebrew_shin ש HEBREW LETTER SHIN */
  { 0x0cfa, 0x05ea }, /* hebrew_taw ת HEBREW LETTER TAV */
  { 0x0da1, 0x0e01 }, /* Thai_kokai ก THAI CHARACTER KO KAI */
  { 0x0da2, 0x0e02 }, /* Thai_khokhai ข THAI CHARACTER KHO KHAI */
  { 0x0da3, 0x0e03 }, /* Thai_khokhuat ฃ THAI CHARACTER KHO KHUAT */
  { 0x0da4, 0x0e04 }, /* Thai_khokhwai ค THAI CHARACTER KHO KHWAI */
  { 0x0da5, 0x0e05 }, /* Thai_khokhon ฅ THAI CHARACTER KHO KHON */
  { 0x0da6, 0x0e06 }, /* Thai_khorakhang ฆ THAI CHARACTER KHO RAKHANG */
  { 0x0da7, 0x0e07 }, /* Thai_ngongu ง THAI CHARACTER NGO NGU */
  { 0x0da8, 0x0e08 }, /* Thai_chochan จ THAI CHARACTER CHO CHAN */
  { 0x0da9, 0x0e09 }, /* Thai_choching ฉ THAI CHARACTER CHO CHING */
  { 0x0daa, 0x0e0a }, /* Thai_chochang ช THAI CHARACTER CHO CHANG */
  { 0x0dab, 0x0e0b }, /* Thai_soso ซ THAI CHARACTER SO SO */
  { 0x0dac, 0x0e0c }, /* Thai_chochoe ฌ THAI CHARACTER CHO CHOE */
  { 0x0dad, 0x0e0d }, /* Thai_yoying ญ THAI CHARACTER YO YING */
  { 0x0dae, 0x0e0e }, /* Thai_dochada ฎ THAI CHARACTER DO CHADA */
  { 0x0daf, 0x0e0f }, /* Thai_topatak ฏ THAI CHARACTER TO PATAK */
  { 0x0db0, 0x0e10 }, /* Thai_thothan ฐ THAI CHARACTER THO THAN */
  { 0x0db1, 0x0e11 }, /* Thai_thonangmontho ฑ THAI CHARACTER THO NANGMONTHO */
  { 0x0db2, 0x0e12 }, /* Thai_thophuthao ฒ THAI CHARACTER THO PHUTHAO */
  { 0x0db3, 0x0e13 }, /* Thai_nonen ณ THAI CHARACTER NO NEN */
  { 0x0db4, 0x0e14 }, /* Thai_dodek ด THAI CHARACTER DO DEK */
  { 0x0db5, 0x0e15 }, /* Thai_totao ต THAI CHARACTER TO TAO */
  { 0x0db6, 0x0e16 }, /* Thai_thothung ถ THAI CHARACTER THO THUNG */
  { 0x0db7, 0x0e17 }, /* Thai_thothahan ท THAI CHARACTER THO THAHAN */
  { 0x0db8, 0x0e18 }, /* Thai_thothong ธ THAI CHARACTER THO THONG */
  { 0x0db9, 0x0e19 }, /* Thai_nonu น THAI CHARACTER NO NU */
  { 0x0dba, 0x0e1a }, /* Thai_bobaimai บ THAI CHARACTER BO BAIMAI */
  { 0x0dbb, 0x0e1b }, /* Thai_popla ป THAI CHARACTER PO PLA */
  { 0x0dbc, 0x0e1c }, /* Thai_phophung ผ THAI CHARACTER PHO PHUNG */
  { 0x0dbd, 0x0e1d }, /* Thai_fofa ฝ THAI CHARACTER FO FA */
  { 0x0dbe, 0x0e1e }, /* Thai_phophan พ THAI CHARACTER PHO PHAN */
  { 0x0dbf, 0x0e1f }, /* Thai_fofan ฟ THAI CHARACTER FO FAN */
  { 0x0dc0, 0x0e20 }, /* Thai_phosamphao ภ THAI CHARACTER PHO SAMPHAO */
  { 0x0dc1, 0x0e21 }, /* Thai_moma ม THAI CHARACTER MO MA */
  { 0x0dc2, 0x0e22 }, /* Thai_yoyak ย THAI CHARACTER YO YAK */
  { 0x0dc3, 0x0e23 }, /* Thai_rorua ร THAI CHARACTER RO RUA */
  { 0x0dc4, 0x0e24 }, /* Thai_ru ฤ THAI CHARACTER RU */
  { 0x0dc5, 0x0e25 }, /* Thai_loling ล THAI CHARACTER LO LING */
  { 0x0dc6, 0x0e26 }, /* Thai_lu ฦ THAI CHARACTER LU */
  { 0x0dc7, 0x0e27 }, /* Thai_wowaen ว THAI CHARACTER WO WAEN */
  { 0x0dc8, 0x0e28 }, /* Thai_sosala ศ THAI CHARACTER SO SALA */
  { 0x0dc9, 0x0e29 }, /* Thai_sorusi ษ THAI CHARACTER SO RUSI */
  { 0x0dca, 0x0e2a }, /* Thai_sosua ส THAI CHARACTER SO SUA */
  { 0x0dcb, 0x0e2b }, /* Thai_hohip ห THAI CHARACTER HO HIP */
  { 0x0dcc, 0x0e2c }, /* Thai_lochula ฬ THAI CHARACTER LO CHULA */
  { 0x0dcd, 0x0e2d }, /* Thai_oang อ THAI CHARACTER O ANG */
  { 0x0dce, 0x0e2e }, /* Thai_honokhuk ฮ THAI CHARACTER HO NOKHUK */
  { 0x0dcf, 0x0e2f }, /* Thai_paiyannoi ฯ THAI CHARACTER PAIYANNOI */
  { 0x0dd0, 0x0e30 }, /* Thai_saraa ะ THAI CHARACTER SARA A */
  { 0x0dd1, 0x0e31 }, /* Thai_maihanakat ั THAI CHARACTER MAI HAN-AKAT */
  { 0x0dd2, 0x0e32 }, /* Thai_saraaa า THAI CHARACTER SARA AA */
  { 0x0dd3, 0x0e33 }, /* Thai_saraam ำ THAI CHARACTER SARA AM */
  { 0x0dd4, 0x0e34 }, /* Thai_sarai ิ THAI CHARACTER SARA I */
  { 0x0dd5, 0x0e35 }, /* Thai_saraii ี THAI CHARACTER SARA II */
  { 0x0dd6, 0x0e36 }, /* Thai_saraue ึ THAI CHARACTER SARA UE */
  { 0x0dd7, 0x0e37 }, /* Thai_sarauee ื THAI CHARACTER SARA UEE */
  { 0x0dd8, 0x0e38 }, /* Thai_sarau ุ THAI CHARACTER SARA U */
  { 0x0dd9, 0x0e39 }, /* Thai_sarauu ู THAI CHARACTER SARA UU */
  { 0x0dda, 0x0e3a }, /* Thai_phinthu ฺ THAI CHARACTER PHINTHU */
  { 0x0dde, 0x0e3e }, /* Thai_maihanakat_maitho ฾ ??? */
  { 0x0ddf, 0x0e3f }, /* Thai_baht ฿ THAI CURRENCY SYMBOL BAHT */
  { 0x0de0, 0x0e40 }, /* Thai_sarae เ THAI CHARACTER SARA E */
  { 0x0de1, 0x0e41 }, /* Thai_saraae แ THAI CHARACTER SARA AE */
  { 0x0de2, 0x0e42 }, /* Thai_sarao โ THAI CHARACTER SARA O */
  { 0x0de3, 0x0e43 }, /* Thai_saraaimaimuan ใ THAI CHARACTER SARA AI MAIMUAN */
  { 0x0de4, 0x0e44 }, /* Thai_saraaimaimalai ไ THAI CHARACTER SARA AI MAIMALAI */
  { 0x0de5, 0x0e45 }, /* Thai_lakkhangyao ๅ THAI CHARACTER LAKKHANGYAO */
  { 0x0de6, 0x0e46 }, /* Thai_maiyamok ๆ THAI CHARACTER MAIYAMOK */
  { 0x0de7, 0x0e47 }, /* Thai_maitaikhu ็ THAI CHARACTER MAITAIKHU */
  { 0x0de8, 0x0e48 }, /* Thai_maiek ่ THAI CHARACTER MAI EK */
  { 0x0de9, 0x0e49 }, /* Thai_maitho ้ THAI CHARACTER MAI THO */
  { 0x0dea, 0x0e4a }, /* Thai_maitri ๊ THAI CHARACTER MAI TRI */
  { 0x0deb, 0x0e4b }, /* Thai_maichattawa ๋ THAI CHARACTER MAI CHATTAWA */
  { 0x0dec, 0x0e4c }, /* Thai_thanthakhat ์ THAI CHARACTER THANTHAKHAT */
  { 0x0ded, 0x0e4d }, /* Thai_nikhahit ํ THAI CHARACTER NIKHAHIT */
  { 0x0df0, 0x0e50 }, /* Thai_leksun ๐ THAI DIGIT ZERO */
  { 0x0df1, 0x0e51 }, /* Thai_leknung ๑ THAI DIGIT ONE */
  { 0x0df2, 0x0e52 }, /* Thai_leksong ๒ THAI DIGIT TWO */
  { 0x0df3, 0x0e53 }, /* Thai_leksam ๓ THAI DIGIT THREE */
  { 0x0df4, 0x0e54 }, /* Thai_leksi ๔ THAI DIGIT FOUR */
  { 0x0df5, 0x0e55 }, /* Thai_lekha ๕ THAI DIGIT FIVE */
  { 0x0df6, 0x0e56 }, /* Thai_lekhok ๖ THAI DIGIT SIX */
  { 0x0df7, 0x0e57 }, /* Thai_lekchet ๗ THAI DIGIT SEVEN */
  { 0x0df8, 0x0e58 }, /* Thai_lekpaet ๘ THAI DIGIT EIGHT */
  { 0x0df9, 0x0e59 }, /* Thai_lekkao ๙ THAI DIGIT NINE */
  { 0x0ea1, 0x3131 }, /* Hangul_Kiyeog ㄱ HANGUL LETTER KIYEOK */
  { 0x0ea2, 0x3132 }, /* Hangul_SsangKiyeog ㄲ HANGUL LETTER SSANGKIYEOK */
  { 0x0ea3, 0x3133 }, /* Hangul_KiyeogSios ㄳ HANGUL LETTER KIYEOK-SIOS */
  { 0x0ea4, 0x3134 }, /* Hangul_Nieun ㄴ HANGUL LETTER NIEUN */
  { 0x0ea5, 0x3135 }, /* Hangul_NieunJieuj ㄵ HANGUL LETTER NIEUN-CIEUC */
  { 0x0ea6, 0x3136 }, /* Hangul_NieunHieuh ㄶ HANGUL LETTER NIEUN-HIEUH */
  { 0x0ea7, 0x3137 }, /* Hangul_Dikeud ㄷ HANGUL LETTER TIKEUT */
  { 0x0ea8, 0x3138 }, /* Hangul_SsangDikeud ㄸ HANGUL LETTER SSANGTIKEUT */
  { 0x0ea9, 0x3139 }, /* Hangul_Rieul ㄹ HANGUL LETTER RIEUL */
  { 0x0eaa, 0x313a }, /* Hangul_RieulKiyeog ㄺ HANGUL LETTER RIEUL-KIYEOK */
  { 0x0eab, 0x313b }, /* Hangul_RieulMieum ㄻ HANGUL LETTER RIEUL-MIEUM */
  { 0x0eac, 0x313c }, /* Hangul_RieulPieub ㄼ HANGUL LETTER RIEUL-PIEUP */
  { 0x0ead, 0x313d }, /* Hangul_RieulSios ㄽ HANGUL LETTER RIEUL-SIOS */
  { 0x0eae, 0x313e }, /* Hangul_RieulTieut ㄾ HANGUL LETTER RIEUL-THIEUTH */
  { 0x0eaf, 0x313f }, /* Hangul_RieulPhieuf ㄿ HANGUL LETTER RIEUL-PHIEUPH */
  { 0x0eb0, 0x3140 }, /* Hangul_RieulHieuh ㅀ HANGUL LETTER RIEUL-HIEUH */
  { 0x0eb1, 0x3141 }, /* Hangul_Mieum ㅁ HANGUL LETTER MIEUM */
  { 0x0eb2, 0x3142 }, /* Hangul_Pieub ㅂ HANGUL LETTER PIEUP */
  { 0x0eb3, 0x3143 }, /* Hangul_SsangPieub ㅃ HANGUL LETTER SSANGPIEUP */
  { 0x0eb4, 0x3144 }, /* Hangul_PieubSios ㅄ HANGUL LETTER PIEUP-SIOS */
  { 0x0eb5, 0x3145 }, /* Hangul_Sios ㅅ HANGUL LETTER SIOS */
  { 0x0eb6, 0x3146 }, /* Hangul_SsangSios ㅆ HANGUL LETTER SSANGSIOS */
  { 0x0eb7, 0x3147 }, /* Hangul_Ieung ㅇ HANGUL LETTER IEUNG */
  { 0x0eb8, 0x3148 }, /* Hangul_Jieuj ㅈ HANGUL LETTER CIEUC */
  { 0x0eb9, 0x3149 }, /* Hangul_SsangJieuj ㅉ HANGUL LETTER SSANGCIEUC */
  { 0x0eba, 0x314a }, /* Hangul_Cieuc ㅊ HANGUL LETTER CHIEUCH */
  { 0x0ebb, 0x314b }, /* Hangul_Khieuq ㅋ HANGUL LETTER KHIEUKH */
  { 0x0ebc, 0x314c }, /* Hangul_Tieut ㅌ HANGUL LETTER THIEUTH */
  { 0x0ebd, 0x314d }, /* Hangul_Phieuf ㅍ HANGUL LETTER PHIEUPH */
  { 0x0ebe, 0x314e }, /* Hangul_Hieuh ㅎ HANGUL LETTER HIEUH */
  { 0x0ebf, 0x314f }, /* Hangul_A ㅏ HANGUL LETTER A */
  { 0x0ec0, 0x3150 }, /* Hangul_AE ㅐ HANGUL LETTER AE */
  { 0x0ec1, 0x3151 }, /* Hangul_YA ㅑ HANGUL LETTER YA */
  { 0x0ec2, 0x3152 }, /* Hangul_YAE ㅒ HANGUL LETTER YAE */
  { 0x0ec3, 0x3153 }, /* Hangul_EO ㅓ HANGUL LETTER EO */
  { 0x0ec4, 0x3154 }, /* Hangul_E ㅔ HANGUL LETTER E */
  { 0x0ec5, 0x3155 }, /* Hangul_YEO ㅕ HANGUL LETTER YEO */
  { 0x0ec6, 0x3156 }, /* Hangul_YE ㅖ HANGUL LETTER YE */
  { 0x0ec7, 0x3157 }, /* Hangul_O ㅗ HANGUL LETTER O */
  { 0x0ec8, 0x3158 }, /* Hangul_WA ㅘ HANGUL LETTER WA */
  { 0x0ec9, 0x3159 }, /* Hangul_WAE ㅙ HANGUL LETTER WAE */
  { 0x0eca, 0x315a }, /* Hangul_OE ㅚ HANGUL LETTER OE */
  { 0x0ecb, 0x315b }, /* Hangul_YO ㅛ HANGUL LETTER YO */
  { 0x0ecc, 0x315c }, /* Hangul_U ㅜ HANGUL LETTER U */
  { 0x0ecd, 0x315d }, /* Hangul_WEO ㅝ HANGUL LETTER WEO */
  { 0x0ece, 0x315e }, /* Hangul_WE ㅞ HANGUL LETTER WE */
  { 0x0ecf, 0x315f }, /* Hangul_WI ㅟ HANGUL LETTER WI */
  { 0x0ed0, 0x3160 }, /* Hangul_YU ㅠ HANGUL LETTER YU */
  { 0x0ed1, 0x3161 }, /* Hangul_EU ㅡ HANGUL LETTER EU */
  { 0x0ed2, 0x3162 }, /* Hangul_YI ㅢ HANGUL LETTER YI */
  { 0x0ed3, 0x3163 }, /* Hangul_I ㅣ HANGUL LETTER I */
  { 0x0ed4, 0x11a8 }, /* Hangul_J_Kiyeog ᆨ HANGUL JONGSEONG KIYEOK */
  { 0x0ed5, 0x11a9 }, /* Hangul_J_SsangKiyeog ᆩ HANGUL JONGSEONG SSANGKIYEOK */
  { 0x0ed6, 0x11aa }, /* Hangul_J_KiyeogSios ᆪ HANGUL JONGSEONG KIYEOK-SIOS */
  { 0x0ed7, 0x11ab }, /* Hangul_J_Nieun ᆫ HANGUL JONGSEONG NIEUN */
  { 0x0ed8, 0x11ac }, /* Hangul_J_NieunJieuj ᆬ HANGUL JONGSEONG NIEUN-CIEUC */
  { 0x0ed9, 0x11ad }, /* Hangul_J_NieunHieuh ᆭ HANGUL JONGSEONG NIEUN-HIEUH */
  { 0x0eda, 0x11ae }, /* Hangul_J_Dikeud ᆮ HANGUL JONGSEONG TIKEUT */
  { 0x0edb, 0x11af }, /* Hangul_J_Rieul ᆯ HANGUL JONGSEONG RIEUL */
  { 0x0edc, 0x11b0 }, /* Hangul_J_RieulKiyeog ᆰ HANGUL JONGSEONG RIEUL-KIYEOK */
  { 0x0edd, 0x11b1 }, /* Hangul_J_RieulMieum ᆱ HANGUL JONGSEONG RIEUL-MIEUM */
  { 0x0ede, 0x11b2 }, /* Hangul_J_RieulPieub ᆲ HANGUL JONGSEONG RIEUL-PIEUP */
  { 0x0edf, 0x11b3 }, /* Hangul_J_RieulSios ᆳ HANGUL JONGSEONG RIEUL-SIOS */
  { 0x0ee0, 0x11b4 }, /* Hangul_J_RieulTieut ᆴ HANGUL JONGSEONG RIEUL-THIEUTH */
  { 0x0ee1, 0x11b5 }, /* Hangul_J_RieulPhieuf ᆵ HANGUL JONGSEONG RIEUL-PHIEUPH */
  { 0x0ee2, 0x11b6 }, /* Hangul_J_RieulHieuh ᆶ HANGUL JONGSEONG RIEUL-HIEUH */
  { 0x0ee3, 0x11b7 }, /* Hangul_J_Mieum ᆷ HANGUL JONGSEONG MIEUM */
  { 0x0ee4, 0x11b8 }, /* Hangul_J_Pieub ᆸ HANGUL JONGSEONG PIEUP */
  { 0x0ee5, 0x11b9 }, /* Hangul_J_PieubSios ᆹ HANGUL JONGSEONG PIEUP-SIOS */
  { 0x0ee6, 0x11ba }, /* Hangul_J_Sios ᆺ HANGUL JONGSEONG SIOS */
  { 0x0ee7, 0x11bb }, /* Hangul_J_SsangSios ᆻ HANGUL JONGSEONG SSANGSIOS */
  { 0x0ee8, 0x11bc }, /* Hangul_J_Ieung ᆼ HANGUL JONGSEONG IEUNG */
  { 0x0ee9, 0x11bd }, /* Hangul_J_Jieuj ᆽ HANGUL JONGSEONG CIEUC */
  { 0x0eea, 0x11be }, /* Hangul_J_Cieuc ᆾ HANGUL JONGSEONG CHIEUCH */
  { 0x0eeb, 0x11bf }, /* Hangul_J_Khieuq ᆿ HANGUL JONGSEONG KHIEUKH */
  { 0x0eec, 0x11c0 }, /* Hangul_J_Tieut ᇀ HANGUL JONGSEONG THIEUTH */
  { 0x0eed, 0x11c1 }, /* Hangul_J_Phieuf ᇁ HANGUL JONGSEONG PHIEUPH */
  { 0x0eee, 0x11c2 }, /* Hangul_J_Hieuh ᇂ HANGUL JONGSEONG HIEUH */
  { 0x0eef, 0x316d }, /* Hangul_RieulYeorinHieuh ㅭ HANGUL LETTER RIEUL-YEORINHIEUH */
  { 0x0ef0, 0x3171 }, /* Hangul_SunkyeongeumMieum ㅱ HANGUL LETTER KAPYEOUNMIEUM */
  { 0x0ef1, 0x3178 }, /* Hangul_SunkyeongeumPieub ㅸ HANGUL LETTER KAPYEOUNPIEUP */
  { 0x0ef2, 0x317f }, /* Hangul_PanSios ㅿ HANGUL LETTER PANSIOS */
/* 0x0ef3 Hangul_KkogjiDalrinIeung ? ??? */
  { 0x0ef4, 0x3184 }, /* Hangul_SunkyeongeumPhieuf ㆄ HANGUL LETTER KAPYEOUNPHIEUPH */
  { 0x0ef5, 0x3186 }, /* Hangul_YeorinHieuh ㆆ HANGUL LETTER YEORINHIEUH */
  { 0x0ef6, 0x318d }, /* Hangul_AraeA ㆍ HANGUL LETTER ARAEA */
  { 0x0ef7, 0x318e }, /* Hangul_AraeAE ㆎ HANGUL LETTER ARAEAE */
  { 0x0ef8, 0x11eb }, /* Hangul_J_PanSios ᇫ HANGUL JONGSEONG PANSIOS */
/* 0x0ef9 Hangul_J_KkogjiDalrinIeung ? ??? */
  { 0x0efa, 0x11f9 }, /* Hangul_J_YeorinHieuh ᇹ HANGUL JONGSEONG YEORINHIEUH */
  { 0x0eff, 0x20a9 }, /* Korean_Won ₩ WON SIGN */
  { 0x13bc, 0x0152 }, /* OE Œ LATIN CAPITAL LIGATURE OE */
  { 0x13bd, 0x0153 }, /* oe œ LATIN SMALL LIGATURE OE */
  { 0x13be, 0x0178 }, /* Ydiaeresis Ÿ LATIN CAPITAL LETTER Y WITH DIAERESIS */
  { 0x20a0, 0x20a0 }, /* EcuSign ₠ EURO-CURRENCY SIGN */
  { 0x20a1, 0x20a1 }, /* ColonSign ₡ COLON SIGN */
  { 0x20a2, 0x20a2 }, /* CruzeiroSign ₢ CRUZEIRO SIGN */
  { 0x20a3, 0x20a3 }, /* FFrancSign ₣ FRENCH FRANC SIGN */
  { 0x20a4, 0x20a4 }, /* LiraSign ₤ LIRA SIGN */
  { 0x20a5, 0x20a5 }, /* MillSign ₥ MILL SIGN */
  { 0x20a6, 0x20a6 }, /* NairaSign ₦ NAIRA SIGN */
  { 0x20a7, 0x20a7 }, /* PesetaSign ₧ PESETA SIGN */
  { 0x20a8, 0x20a8 }, /* RupeeSign ₨ RUPEE SIGN */
  { 0x20a9, 0x20a9 }, /* WonSign ₩ WON SIGN */
  { 0x20aa, 0x20aa }, /* NewSheqelSign ₪ NEW SHEQEL SIGN */
  { 0x20ab, 0x20ab }, /* DongSign ₫ DONG SIGN */
  { 0x20ac, 0x20ac }, /* EuroSign € EURO SIGN */
};

/** END KEYSYMTAB **/


static x_keyboard_t *x_keyboard;

#endif
#ifdef GFX_FB
static int      x_bpl;
static uint32_t *x_image;
static uint8_t  *fb_mem;
static int      fb_fd;
static int      gfrot;


static int McursorX, McursorY;
static struct termios tty_settings;
static int tty_settings_valid;


static int RAWIfd_kb, RAWIfd_mo;
static kbmap_t kbmap[256];


static int mouse_proto;
static char *kb_device, *mo_device;
static int gfx_m_minx, gfx_m_miny, gfx_m_maxx, gfx_m_maxy,
           gfx_m_xresol, gfx_m_yresol;

#endif
#ifdef GFX_ANDROID

static app_t *my_app;


/***********************************************************************
 *##C                                                                  *
 *                          Application Init                           *
 *                                                                     *
 ***********************************************************************
  During the initialization, we need to do the following:
   - create a pipe for the asynchronous messages coming in
   - create a mutex and a condition variable for protecting shared memory
   - create a worker thread

  The onCreate function is the entry point from the Java world. We 
  initialize the 'activity' object with the system event handler functions.
 ***********************************************************************/


static uint32_t *Gpixels;

#endif

 // On Android, these are constants
#ifndef GFX_ANDROID
static uint32_t x_red_mask, x_red_shift,
                x_green_mask, x_green_shift,
                x_blue_mask, x_blue_shift;
#endif
static int      x_window_width, x_window_height;
static uint32_t **x_image_data;


static file_monitor_t fmon[100]; // safe limit, I guess
static int n_fmon;


static widget_t *widgets[_XX_WIDGETS_END];


static screen_t *screen; // top of the stack

static unsigned int font_hash(unsigned int V)
{
  static const struct
  { unsigned short val; unsigned char pos; } htable[109]= {
 {0x20,0}, {0x21,1}, {0x22,2}, {0x23,3}, {0x24,4}, {0x25,5}, {0x26,6},
 {0x27,7}, {0x28,8}, {0x29,9}, {0x2a,10}, {0x2b,11}, {0x2c,12},
 {0x2d,13}, {0x2e,14}, {0x2f,15}, {0x30,16}, {0x31,17}, {0x32,18},
 {0x33,19}, {0x34,20}, {0x35,21}, {0x36,22}, {0x37,23}, {0x38,24},
 {0x39,25}, {0x3a,26}, {0x3b,27}, {0x3c,28}, {0x3d,29}, {0x3e,30},
 {0x3f,31}, {0x40,32}, {0x41,33}, {0x42,34}, {0x43,35}, {0x44,36},
 {0x45,37}, {0x46,38}, {0x47,39}, {0x48,40}, {0x49,41}, {0x4a,42},
 {0x4b,43}, {0x4c,44}, {0x4d,45}, {0x4e,46}, {0x4f,47}, {0x50,48},
 {0x51,49}, {0x52,50}, {0x53,51}, {0x54,52}, {0x55,53}, {0x56,54},
 {0x57,55}, {0x58,56}, {0x59,57}, {0x5a,58}, {0x5b,59}, {0x5c,60},
 {0x5d,61}, {0x5e,62}, {0x5f,63}, {0x60,64}, {0x61,65}, {0x62,66},
 {0x63,67}, {0x64,68}, {0x65,69}, {0x66,70}, {0x67,71}, {0x68,72},
 {0x69,73}, {0x6a,74}, {0x6b,75}, {0x6c,76}, {0x6d,77}, {0x6e,78},
 {0x6f,79}, {0x70,80}, {0x71,81}, {0x72,82}, {0x73,83}, {0x74,84},
 {0x75,85}, {0x76,86}, {0x77,87}, {0x78,88}, {0x79,89}, {0x7a,90},
 {0x7b,91}, {0x7c,92}, {0x7d,93}, {0x7e,94}, {0xc7,95}, {0x15f,106},
 {0x11e,101}, {0xdc,97}, {0x11f,102}, {0x15e,105}, {0xd6,96}, {0x20,107},
 {0xe7,98}, {0x131,104}, {0xf6,99}, {0xfc,100}, {0x130,103}, {0x20,107},
  };
  unsigned int A;
  int p;
  A= V;
  p= 0;
  A-= 0x20;
  if (A<=0x5e) { p+= A; goto done; }
  A-= 0xa7;
  p+= 95;
  A^= A>>4;
  A &= 0x3f;
  A= (A&0xf) | ((A&0xffffffe0)>>1);
  A= (A&0x7) | ((A&0xfffffff0)>>1);
  A-= A>>2;
  A-= 0x0;
  if (A<=0xc) { p+= A; goto done; }
  A-= 0x0;
  p+= 13;
done:
  if (htable[p].val!=V) return 107;
  return htable[p].pos;
}
static 
void font1_render
        (uint32_t *str, size_t L, 
        int *RW, int *RH, int *RA,
        unsigned char **Rdata)
{
  static const uint8_t font_data[]= {

0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x70,0x27,0x03,0xff,0x7e,0x00,0xf9,0x74,0x00,0xef,0x6a,0x00,0xe4,
0x5f,0x00,0xd9,0x54,0x00,0xce,0x49,0x00,0xc4,0x3f,0x00,0xaa,0x2a,0x00,0x00,0x00,0x04,0x7c,
0x1e,0x19,0xf8,0x60,0x00,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x01,0x00,
0x00,0xe6,0x21,0xa0,0x67,0x00,0xef,0x21,0xa7,0x6a,0x00,0xe2,0x12,0x9a,0x5d,0x00,0x9f,0x03,
0x6c,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,
0xe0,0x00,0x00,0x68,0xb6,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xe8,0x00,0x00,0x6c,0xbc,0x00,
0x00,0x00,0x00,0x00,0x00,0x44,0xe8,0x00,0x00,0x6c,0xbc,0x00,0x00,0x00,0x00,0xfc,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x90,0x00,0x13,0x14,0x52,0xe9,0x14,0x14,0x77,0xc1,0x14,
0x14,0x0b,0x00,0x00,0x00,0x44,0xe8,0x00,0x00,0x6c,0xbc,0x00,0x00,0x00,0x00,0x46,0x48,0x78,
0xee,0x48,0x48,0x95,0xcf,0x48,0x48,0x28,0x00,0xd0,0xd4,0xdf,0xfb,0xd4,0xd4,0xe6,0xf4,0xd4,
0xd4,0x77,0x00,0x00,0x00,0x44,0xe8,0x00,0x00,0x6c,0xbc,0x00,0x00,0x00,0x00,0x00,0x00,0x44,
0xe8,0x00,0x00,0x6c,0xbc,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x86,0x00,0x00,0x3e,0x6c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0x8c,0x00,0x00,0x00,
0x00,0x2f,0xbf,0xf9,0xfd,0xc2,0x29,0x00,0x10,0xe8,0x95,0x86,0xa1,0x94,0xea,0x17,0x48,0xf8,
0x03,0x70,0x8c,0x00,0x4a,0x01,0x36,0xfe,0x16,0x70,0x8c,0x00,0x00,0x00,0x01,0xb5,0xd7,0xb5,
0x8d,0x00,0x00,0x00,0x00,0x03,0x63,0xcf,0xfb,0xb0,0x33,0x00,0x00,0x00,0x00,0x70,0x9f,0x8f,
0xfa,0x33,0x00,0x00,0x00,0x70,0x8c,0x00,0xc7,0x8b,0x3f,0x52,0x00,0x70,0x8c,0x00,0xbf,0x85,
0x62,0xf5,0x4f,0x71,0x8e,0x5e,0xfc,0x34,0x00,0x6c,0xf1,0xfc,0xfe,0xee,0x5d,0x00,0x00,0x00,
0x06,0x85,0x9c,0x03,0x00,0x00,0x00,0x00,0x00,0x18,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x70,0x6a,0x0a,
0x00,0x00,0x19,0x40,0x00,0x00,0x03,0xd0,0x93,0xa5,0xba,0x00,0x00,0xb7,0x69,0x00,0x00,0x25,
0xdc,0x00,0x04,0xf6,0x0e,0x54,0xcc,0x02,0x00,0x00,0x06,0xe3,0x60,0x75,0xd0,0x0c,0xe1,0x35,
0x00,0x00,0x00,0x00,0x25,0x96,0x8e,0x19,0x8c,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x2d,0xe6,0x12,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x01,0xc4,0x62,0x4a,0xe4,0xec,0x6d,0x00,
0x00,0x00,0x00,0x62,0xc6,0x02,0xea,0x31,0x1a,0xee,0x1d,0x00,0x00,0x12,0xe7,0x2f,0x03,0xf3,
0x1a,0x05,0xe3,0x25,0x00,0x00,0x88,0x8b,0x00,0x00,0x6e,0xdd,0xd9,0x93,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x15,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0x81,0xa3,0x78,0x10,0x00,0x00,0x00,0x00,0x19,0xe6,0xb7,0x79,0xba,
0xdb,0x12,0x00,0x00,0x00,0x85,0xc6,0x00,0x00,0x01,0x6e,0x13,0x00,0x00,0x00,0x9d,0xa2,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0xf1,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x97,0xfd,0xe0,0x30,0x00,0x00,0x00,0x00,0x00,0x61,0xe9,0x72,0x44,0x0e,0x00,0x00,0x00,0x00,
0x08,0xf1,0x4b,0x00,0x00,0x3d,0x48,0x48,0x48,0x04,0x2d,0xff,0x0f,0x00,0x00,0xb2,0xe1,0xfd,
0xd4,0x0d,0x17,0xfe,0x32,0x00,0x00,0x00,0x80,0xd6,0x00,0x00,0x00,0x9b,0xcb,0x1f,0x00,0x3d,
0xf1,0x6a,0x00,0x00,0x00,0x0a,0x9a,0xfd,0xf0,0xf9,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x18,
0x31,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0xe6,0x21,0x00,0xef,0x21,
0x00,0xe2,0x12,0x00,0x9f,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x17,0x0f,0x00,0x29,0xfa,0x38,0x00,0xa6,0xa7,0x00,0x0f,0xf7,0x3a,0x00,0x50,0xe8,
0x00,0x00,0x84,0xae,0x00,0x00,0x9f,0x93,0x00,0x00,0xa6,0x8a,0x00,0x00,0x94,0x9d,0x00,0x00,
0x6f,0xc9,0x00,0x00,0x34,0xfb,0x10,0x00,0x00,0xdc,0x6e,0x00,0x00,0x70,0xde,0x07,0x00,0x06,
0x9f,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x1c,0x02,0x00,0x0c,0xe6,0x66,0x00,0x00,0x68,
0xe2,0x02,0x00,0x0c,0xf2,0x45,0x00,0x00,0xac,0x8f,0x00,0x00,0x6e,0xc8,0x00,0x00,0x4e,0xe3,
0x00,0x00,0x42,0xee,0x00,0x00,0x55,0xde,0x00,0x00,0x84,0xb7,0x00,0x00,0xc6,0x7d,0x00,0x28,
0xfe,0x26,0x00,0xa0,0xb7,0x00,0x13,0xa6,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0xc8,0x01,0x92,0x70,0x00,0x00,0x09,0xda,0x78,0xf2,
0x25,0x00,0x52,0x86,0xad,0xff,0xca,0x83,0x6f,0x59,0x93,0xb7,0xff,0xd1,0x90,0x7a,0x00,0x08,
0xda,0x78,0xf1,0x25,0x00,0x00,0x44,0xcd,0x01,0x96,0x79,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xf8,0x1b,0x00,0x00,0x00,0x00,0x00,0xfc,0x1c,0x00,0x00,0x38,0x90,
0x90,0xfe,0x9c,0x90,0x4a,0x36,0x8c,0x8c,0xfe,0x98,0x8c,0x48,0x00,0x00,0x00,0xfc,0x1c,0x00,
0x00,0x00,0x00,0x00,0xf8,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x04,0x7c,0x1e,0x19,0xf7,0x73,0x00,0x75,0x36,0x00,0x5f,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x12,0x84,0x84,0x84,0x84,0x84,0x12,0x15,0x98,0x98,0x98,0x98,0x98,0x15,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x04,0x7c,0x1e,0x19,0xf8,0x60,0x00,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x0a,
0x00,0x00,0x00,0x00,0x00,0x01,0xd5,0x64,0x00,0x00,0x00,0x00,0x00,0x4e,0xe6,0x07,0x00,0x00,
0x00,0x00,0x00,0xc5,0x77,0x00,0x00,0x00,0x00,0x00,0x3c,0xf1,0x0f,0x00,0x00,0x00,0x00,0x00,
0xb3,0x8a,0x00,0x00,0x00,0x00,0x00,0x2b,0xf8,0x1a,0x00,0x00,0x00,0x00,0x00,0xa1,0x9c,0x00,
0x00,0x00,0x00,0x00,0x1d,0xf8,0x27,0x00,0x00,0x00,0x00,0x00,0x8f,0xaf,0x00,0x00,0x00,0x00,
0x00,0x12,0xf4,0x38,0x00,0x00,0x00,0x00,0x00,0x7d,0xc1,0x00,0x00,0x00,0x00,0x00,0x09,0xea,
0x4b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x06,0x6d,0xa3,0x7a,0x0b,0x00,0x00,0x00,0x03,0xbb,0xd3,0x7d,0xcb,0xc4,
0x02,0x00,0x00,0x68,0xe3,0x0f,0x00,0x09,0xe0,0x68,0x00,0x00,0xcd,0x7f,0x00,0x00,0x00,0x75,
0xc7,0x00,0x0d,0xfe,0x38,0x00,0x00,0x00,0x38,0xfd,0x04,0x2c,0xff,0x17,0x00,0x00,0x00,0x1e,
0xff,0x1d,0x31,0xff,0x0a,0x00,0x00,0x00,0x0f,0xff,0x2e,0x19,0xff,0x22,0x00,0x00,0x00,0x24,
0xff,0x1d,0x02,0xf3,0x48,0x00,0x00,0x00,0x55,0xef,0x01,0x00,0xa9,0x9c,0x00,0x00,0x00,0xa4,
0xa7,0x00,0x00,0x32,0xf7,0x49,0x00,0x4f,0xf6,0x30,0x00,0x00,0x00,0x68,0xf8,0xf1,0xf1,0x57,
0x00,0x00,0x00,0x00,0x00,0x12,0x32,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xb5,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x3f,0xc4,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,0xc8,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1a,0x82,0xa6,0x7f,0x15,0x00,0x00,0x00,0x37,0xf0,0xab,0x78,0xc6,0xe0,
0x15,0x00,0x00,0xd3,0x80,0x00,0x00,0x04,0xcf,0x80,0x00,0x00,0x1e,0x0a,0x00,0x00,0x00,0x85,
0xaf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9d,0x9b,0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0xf3,
0x2f,0x00,0x00,0x00,0x00,0x01,0x70,0xf2,0x57,0x00,0x00,0x00,0x00,0x09,0xb1,0xd4,0x33,0x00,
0x00,0x00,0x00,0x03,0xba,0xbe,0x0c,0x00,0x00,0x00,0x00,0x00,0x74,0xde,0x0d,0x00,0x00,0x00,
0x00,0x00,0x00,0xe1,0x7c,0x1c,0x1c,0x1c,0x1c,0x1a,0x00,0x12,0xff,0xff,0xff,0xff,0xff,0xff,
0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1a,0x87,0xab,0x7d,0x0f,0x00,0x00,0x00,0x1e,0xe8,0xa6,0x6e,0xc4,0xd7,
0x0d,0x00,0x00,0x1c,0x66,0x00,0x00,0x07,0xdd,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb5,
0x8b,0x00,0x00,0x00,0x00,0x00,0x00,0x25,0xf3,0x47,0x00,0x00,0x00,0x00,0x34,0xb7,0xf2,0x90,
0x00,0x00,0x00,0x00,0x00,0x15,0x52,0x98,0xeb,0x32,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x83,
0xcc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xfe,0x0c,0x00,0x28,0x11,0x00,0x00,0x00,0x4f,
0xf6,0x04,0x02,0xcd,0xbb,0x17,0x00,0x33,0xdf,0x90,0x00,0x00,0x17,0xb7,0xfb,0xf0,0xfa,0x88,
0x05,0x00,0x00,0x00,0x00,0x1b,0x2f,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xf6,0xc0,
0x00,0x00,0x00,0x00,0x00,0x00,0xa7,0xea,0xc0,0x00,0x00,0x00,0x00,0x00,0x3a,0xe8,0x7e,0xc0,
0x00,0x00,0x00,0x00,0x01,0xca,0x65,0x70,0xc0,0x00,0x00,0x00,0x00,0x5f,0xd1,0x02,0x70,0xc0,
0x00,0x00,0x00,0x0b,0xe5,0x42,0x00,0x70,0xc0,0x00,0x00,0x00,0x84,0xce,0x38,0x38,0x8f,0xcd,
0x34,0x0c,0x15,0xdb,0xe4,0xe4,0xe4,0xf1,0xf9,0xe4,0x35,0x00,0x00,0x00,0x00,0x00,0x78,0xc0,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xc0,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x46,0x60,0x60,0x60,0x60,0x34,0x00,0x00,0x00,0xd4,0xcc,0xb8,0xb8,0xb8,
0x64,0x00,0x00,0x01,0xf6,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0xfe,0x0a,0x00,0x00,0x00,
0x00,0x00,0x00,0x40,0xe1,0x2e,0x53,0x3b,0x02,0x00,0x00,0x00,0x5e,0xfe,0xea,0xb7,0xe3,0xcf,
0x19,0x00,0x00,0x01,0x47,0x08,0x00,0x08,0xba,0xb8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,
0xfe,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xff,0x2c,0x00,0x8c,0x5d,0x00,0x00,0x00,0x3b,
0xfb,0x0f,0x00,0x6b,0xed,0x39,0x00,0x1a,0xcb,0xa1,0x00,0x00,0x00,0x7f,0xf7,0xef,0xfe,0xae,
0x0d,0x00,0x00,0x00,0x00,0x0d,0x31,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0x5b,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0xa8,0x00,
0x00,0x00,0x00,0x00,0x00,0x26,0xf3,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0xb3,0x8a,0x00,0x00,
0x00,0x00,0x00,0x00,0x45,0xeb,0x0f,0x00,0x00,0x00,0x00,0x00,0x04,0xd5,0xcd,0xa7,0x83,0x17,
0x00,0x00,0x00,0x64,0xff,0xb9,0x7f,0xb7,0xed,0x2a,0x00,0x00,0xc7,0x9e,0x00,0x00,0x00,0x97,
0xba,0x00,0x00,0xf4,0x3e,0x00,0x00,0x00,0x2e,0xfc,0x02,0x00,0xe0,0x56,0x00,0x00,0x00,0x4b,
0xeb,0x00,0x00,0x78,0xdf,0x34,0x01,0x34,0xdc,0x76,0x00,0x00,0x02,0x91,0xfc,0xfc,0xfc,0x92,
0x03,0x00,0x00,0x00,0x00,0x12,0x33,0x13,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x0c,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x23,0x19,0xc8,0xc8,0xc8,0xc8,0xc8,0xdb,
0xfd,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0xb8,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0xf0,
0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x5f,0xed,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0x93,
0x00,0x00,0x00,0x00,0x00,0x00,0x29,0xff,0x31,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0xcf,0x00,
0x00,0x00,0x00,0x00,0x00,0x07,0xec,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x58,0xf9,0x13,0x00,
0x00,0x00,0x00,0x00,0x00,0xbd,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0xfe,0x48,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x14,0x81,0xa9,0x8b,0x21,0x00,0x00,0x00,0x17,0xe6,0xb3,0x71,0xa0,0xf0,
0x2e,0x00,0x00,0x7f,0xc8,0x00,0x00,0x00,0xa2,0xa6,0x00,0x00,0x99,0xa5,0x00,0x00,0x00,0x82,
0xbd,0x00,0x00,0x48,0xf1,0x33,0x00,0x20,0xdf,0x71,0x00,0x00,0x00,0x8c,0xff,0xed,0xfe,0xb0,
0x02,0x00,0x00,0x51,0xec,0x78,0x42,0x6a,0xe6,0x6c,0x00,0x04,0xeb,0x5b,0x00,0x00,0x00,0x31,
0xfb,0x21,0x25,0xff,0x16,0x00,0x00,0x00,0x00,0xe4,0x58,0x10,0xf9,0x40,0x00,0x00,0x00,0x16,
0xfd,0x39,0x00,0x98,0xd9,0x2a,0x00,0x1c,0xc0,0xc5,0x00,0x00,0x06,0x99,0xfc,0xee,0xfe,0xb1,
0x15,0x00,0x00,0x00,0x00,0x10,0x33,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x08,0x69,0x9b,0x83,0x1f,0x00,0x00,0x00,0x12,0xd2,0xd4,0x90,0xb7,0xf5,
0x3a,0x00,0x00,0x90,0xbf,0x05,0x00,0x00,0x7e,0xd6,0x00,0x00,0xd3,0x5b,0x00,0x00,0x00,0x12,
0xff,0x1b,0x00,0xc3,0x72,0x00,0x00,0x00,0x2c,0xff,0x0f,0x00,0x60,0xec,0x38,0x00,0x16,0xc3,
0xca,0x00,0x00,0x00,0x82,0xf9,0xeb,0xfd,0xff,0x55,0x00,0x00,0x00,0x00,0x15,0x40,0xa1,0xc4,
0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0xf4,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x9f,0xab,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0xf8,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0xbc,0x92,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7c,0x1e,0x19,0xf8,0x60,0x00,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7c,0x1e,0x19,0xf8,0x60,0x00,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7c,0x1e,0x19,
0xf8,0x60,0x00,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x7c,0x1e,0x19,
0xf7,0x73,0x00,0x75,0x36,0x00,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0x93,0x05,0x00,0x00,0x00,0x5b,0xf8,0x3b,0x00,0x00,0x00,
0x3a,0xf7,0x5c,0x00,0x00,0x00,0x21,0xea,0x83,0x00,0x00,0x00,0x0f,0xd5,0xa9,0x01,0x00,0x00,
0x00,0x15,0xdf,0x95,0x00,0x00,0x00,0x00,0x00,0x2d,0xf3,0x6b,0x00,0x00,0x00,0x00,0x00,0x4e,
0xf9,0x44,0x00,0x00,0x00,0x00,0x00,0x77,0xef,0x27,0x00,0x00,0x00,0x00,0x00,0x94,0xaa,0x05,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x5e,0xc4,0xc4,0xc4,0xc4,0xc4,0x96,0x28,0x54,0x54,0x54,0x54,0x54,0x40,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x70,0xe8,0xe8,0xe8,0xe8,0xe8,0xb1,0x19,0x34,0x34,0x34,0x34,0x34,0x27,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x9c,0x5d,0x00,0x00,0x00,
0x00,0x00,0x51,0xf9,0x45,0x00,0x00,0x00,0x00,0x00,0x77,0xef,0x28,0x00,0x00,0x00,0x00,0x00,
0x9f,0xdc,0x13,0x00,0x00,0x00,0x00,0x06,0xc1,0xc2,0x06,0x00,0x00,0x00,0x01,0xae,0xce,0x0a,
0x00,0x00,0x00,0x84,0xe9,0x1d,0x00,0x00,0x00,0x58,0xf8,0x3b,0x00,0x00,0x00,0x35,0xf6,0x62,
0x00,0x00,0x00,0x0c,0xbd,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,
0x63,0xa3,0x98,0x4b,0x00,0x00,0x01,0xaf,0xde,0x79,0x84,0xec,0x8c,0x00,0x4d,0xe6,0x13,0x00,
0x00,0x37,0xff,0x21,0x30,0x4c,0x00,0x00,0x00,0x01,0xfb,0x40,0x00,0x00,0x00,0x00,0x00,0x37,
0xf9,0x16,0x00,0x00,0x00,0x00,0x36,0xe9,0x77,0x00,0x00,0x00,0x00,0x35,0xf2,0x69,0x00,0x00,
0x00,0x00,0x00,0xaa,0xa0,0x00,0x00,0x00,0x00,0x00,0x00,0xbf,0x7c,0x00,0x00,0x00,0x00,0x00,
0x00,0x24,0x17,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0x45,0x00,0x00,0x00,0x00,0x00,0x00,0xc7,
0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x09,0x5f,0x95,0xa8,0x89,0x3a,0x00,0x00,0x00,0x00,0x00,0x00,0x45,0xe6,0xad,0x67,0x57,
0x7c,0xdf,0xb9,0x14,0x00,0x00,0x00,0x46,0xe6,0x38,0x00,0x00,0x00,0x00,0x08,0x8d,0xca,0x0b,
0x00,0x08,0xe7,0x3b,0x00,0x00,0x34,0x52,0x13,0x00,0x00,0x9f,0x98,0x00,0x5e,0xb0,0x00,0x00,
0x97,0xda,0xad,0xe7,0x2b,0x00,0x14,0xf2,0x0a,0x93,0x68,0x00,0x35,0xda,0x08,0x00,0x6a,0xac,
0x00,0x00,0xd2,0x30,0xa4,0x57,0x00,0x57,0xae,0x00,0x00,0x33,0xe0,0x01,0x02,0xe5,0x1d,0x88,
0x80,0x00,0x16,0xe9,0x48,0x16,0xa9,0xff,0x86,0x93,0xbc,0x00,0x3d,0xdf,0x02,0x00,0x3d,0xca,
0xea,0x9a,0x28,0x99,0x94,0x11,0x00,0x00,0xbb,0x91,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x17,0xd6,0x99,0x15,0x00,0x00,0x01,0x54,0x4a,0x00,0x00,0x00,0x00,0x00,0x0d,
0x92,0xf1,0xcc,0xbe,0xe7,0xd6,0x4b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x36,0x42,0x24,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0x45,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa9,0xf0,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,
0xf6,0xeb,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x61,0xd1,0x7f,0xb0,0x00,0x00,0x00,0x00,0x00,
0x00,0xbd,0x78,0x24,0xf9,0x12,0x00,0x00,0x00,0x00,0x1c,0xfd,0x20,0x00,0xc9,0x69,0x00,0x00,
0x00,0x00,0x76,0xc8,0x00,0x00,0x6e,0xc5,0x00,0x00,0x00,0x00,0xd2,0xf1,0xdc,0xdc,0xe4,0xff,
0x21,0x00,0x00,0x2e,0xfe,0x43,0x34,0x34,0x34,0xd2,0x7d,0x00,0x00,0x8a,0xc5,0x00,0x00,0x00,
0x00,0x7b,0xd8,0x00,0x02,0xe3,0x6f,0x00,0x00,0x00,0x00,0x27,0xff,0x35,0x42,0xfe,0x1c,0x00,
0x00,0x00,0x00,0x00,0xd2,0x91,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x60,0x60,0x50,0x2d,0x00,0x00,
0x00,0x0c,0xff,0xc3,0xb8,0xc7,0xf3,0xca,0x13,0x00,0x0c,0xff,0x30,0x00,0x00,0x0d,0xc2,0xa2,
0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x63,0xda,0x00,0x0c,0xff,0x30,0x00,0x00,0x02,0xad,0xa3,
0x00,0x0c,0xff,0xab,0x98,0xa5,0xdb,0xb5,0x13,0x00,0x0c,0xff,0x94,0x7c,0x7d,0x99,0xe8,0x75,
0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x25,0xf7,0x30,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xc4,
0x73,0x0c,0xff,0x30,0x00,0x00,0x00,0x06,0xe8,0x60,0x0c,0xff,0x46,0x1c,0x1d,0x3b,0xb5,0xe7,
0x0f,0x0c,0xff,0xff,0xff,0xfe,0xeb,0xae,0x26,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,
0x8d,0xa7,0x86,0x26,0x00,0x00,0x00,0x00,0x6f,0xfa,0xa1,0x74,0xa8,0xf6,0x48,0x00,0x00,0x37,
0xfa,0x4f,0x00,0x00,0x00,0x71,0xb6,0x00,0x00,0xb0,0xb5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0xf8,0x57,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x24,0xff,0x2d,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x31,0xff,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0x3a,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x02,0xe6,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0xe1,0x08,
0x00,0x00,0x00,0x1f,0x76,0x04,0x00,0x0f,0xe0,0xb4,0x18,0x00,0x23,0xcb,0xaf,0x00,0x00,0x00,
0x1f,0xb8,0xfc,0xe9,0xfd,0xa8,0x0d,0x00,0x00,0x00,0x00,0x00,0x1c,0x33,0x12,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,
0x60,0x60,0x5a,0x33,0x00,0x00,0x00,0x00,0x0c,0xff,0xc5,0xb8,0xc9,0xf6,0xc6,0x1e,0x00,0x00,
0x0c,0xff,0x30,0x00,0x00,0x17,0xbb,0xd6,0x07,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x0f,0xec,
0x6d,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x90,0xc4,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,
0x00,0x5a,0xf3,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x4c,0xfe,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x5d,0xe9,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x9b,0xb1,0x00,0x0c,0xff,
0x30,0x00,0x00,0x00,0x1a,0xf6,0x4d,0x00,0x0c,0xff,0x46,0x1c,0x25,0x59,0xdb,0xa8,0x00,0x00,
0x0c,0xff,0xff,0xff,0xfb,0xd9,0x76,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x60,0x60,
0x60,0x60,0x60,0x60,0x0d,0x0c,0xff,0xc5,0xb8,0xb8,0xb8,0xb8,0xb8,0x19,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x81,0x64,0x64,0x64,0x64,0x51,0x00,0x0c,0xff,0xc5,0xb8,
0xb8,0xb8,0xb8,0x95,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x46,0x1c,
0x1c,0x1c,0x1c,0x1c,0x03,0x0c,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x24,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x60,0x60,
0x60,0x60,0x60,0x60,0x0d,0x0c,0xff,0xc5,0xb8,0xb8,0xb8,0xb8,0xb8,0x19,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x81,0x64,0x64,0x64,0x64,0x51,0x00,0x0c,0xff,0xc5,0xb8,
0xb8,0xb8,0xb8,0x95,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x8a,0xa9,0x8f,0x31,0x00,0x00,0x00,0x00,0x00,0x60,
0xfa,0xa7,0x74,0x9e,0xf8,0x5a,0x00,0x00,0x00,0x29,0xf7,0x5f,0x00,0x00,0x00,0x53,0x53,0x00,
0x00,0x00,0xa6,0xc1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xf4,0x5d,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x23,0xff,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0xff,
0x1d,0x00,0x00,0x49,0x70,0x70,0x70,0x47,0x00,0x1c,0xff,0x3b,0x00,0x00,0x6e,0xa8,0xa8,0xdc,
0x9b,0x00,0x00,0xe3,0x7f,0x00,0x00,0x00,0x00,0x00,0xaf,0x7a,0x00,0x00,0x82,0xe5,0x0b,0x00,
0x00,0x00,0x12,0xf3,0x2d,0x00,0x00,0x0d,0xda,0xb7,0x18,0x00,0x19,0xbc,0xa7,0x00,0x00,0x00,
0x00,0x1c,0xb6,0xfb,0xe9,0xfd,0xa2,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x36,0x19,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x04,0x60,0x12,0x00,0x00,0x00,0x00,0x3f,0x37,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,0x0c,0xff,0x7e,0x60,0x60,0x60,0x60,0xc9,0x94,
0x0c,0xff,0xc8,0xbc,0xbc,0xbc,0xbc,0xe8,0x94,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0xa8,0x94,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x2a,0x00,0xcc,0x70,
0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,
0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0x60,0x03,0x00,0x00,0x00,
0x00,0x00,0x00,0x34,0xff,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0xff,0x08,0x00,0x00,0x00,
0x00,0x00,0x00,0x34,0xff,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0xff,0x08,0x00,0x00,0x00,
0x00,0x00,0x00,0x34,0xff,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0xff,0x08,0x04,0x2f,0x00,
0x00,0x00,0x00,0x34,0xff,0x07,0x0b,0xff,0x13,0x00,0x00,0x00,0x47,0xf9,0x00,0x00,0xd3,0x65,
0x00,0x00,0x00,0x92,0xc5,0x00,0x00,0x62,0xec,0x3f,0x03,0x58,0xfa,0x53,0x00,0x00,0x00,0x84,
0xfc,0xfd,0xf9,0x77,0x00,0x00,0x00,0x00,0x00,0x10,0x33,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x12,0x00,0x00,0x00,0x00,0x10,
0x5f,0x21,0x0c,0xff,0x30,0x00,0x00,0x00,0x0f,0xca,0xa6,0x03,0x0c,0xff,0x30,0x00,0x00,0x0e,
0xc8,0xa7,0x03,0x00,0x0c,0xff,0x30,0x00,0x0d,0xc6,0xa8,0x03,0x00,0x00,0x0c,0xff,0x30,0x0c,
0xc4,0xa9,0x04,0x00,0x00,0x00,0x0c,0xff,0x3b,0xc3,0xbd,0x04,0x00,0x00,0x00,0x00,0x0c,0xff,
0xde,0xca,0xf1,0x2a,0x00,0x00,0x00,0x00,0x0c,0xff,0xa5,0x03,0x8f,0xdc,0x12,0x00,0x00,0x00,
0x0c,0xff,0x30,0x00,0x04,0xbf,0xbe,0x04,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x15,0xe1,0x96,
0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x33,0xf7,0x6a,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,
0x00,0x5f,0xfb,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,
0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,
0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,
0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,
0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,
0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x46,0x1c,0x1c,0x1c,0x1c,0x1c,0x04,0x0c,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x04,0x60,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x60,0x28,0x0c,0xff,0xec,0x05,
0x00,0x00,0x00,0x00,0x00,0x83,0xff,0x6c,0x0c,0xff,0xf8,0x50,0x00,0x00,0x00,0x00,0x01,0xdf,
0xf8,0x6c,0x0c,0xff,0xad,0xaf,0x00,0x00,0x00,0x00,0x40,0xe5,0xc6,0x6c,0x0c,0xff,0x51,0xf9,
0x13,0x00,0x00,0x00,0x9e,0x8c,0xc4,0x6c,0x0c,0xff,0x24,0xd0,0x6c,0x00,0x00,0x0a,0xf2,0x2f,
0xc4,0x6c,0x0c,0xff,0x24,0x74,0xca,0x00,0x00,0x5b,0xd3,0x00,0xc4,0x6c,0x0c,0xff,0x24,0x1a,
0xfd,0x29,0x00,0xba,0x77,0x00,0xc4,0x6c,0x0c,0xff,0x24,0x00,0xbc,0x88,0x1b,0xfb,0x1d,0x00,
0xc4,0x6c,0x0c,0xff,0x24,0x00,0x5f,0xe3,0x7a,0xbe,0x00,0x00,0xc4,0x6c,0x0c,0xff,0x24,0x00,
0x0d,0xf6,0xf3,0x62,0x00,0x00,0xc4,0x6c,0x0c,0xff,0x24,0x00,0x00,0x96,0xdb,0x0e,0x00,0x00,
0xc4,0x6c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x04,0x60,0x18,0x00,0x00,0x00,0x00,0x07,0x60,0x0f,0x0c,0xff,0xb2,0x00,0x00,0x00,0x00,0x14,
0xff,0x28,0x0c,0xff,0xf9,0x55,0x00,0x00,0x00,0x14,0xff,0x28,0x0c,0xff,0x80,0xe7,0x11,0x00,
0x00,0x14,0xff,0x28,0x0c,0xff,0x30,0xb0,0x9c,0x00,0x00,0x14,0xff,0x28,0x0c,0xff,0x30,0x1c,
0xf1,0x40,0x00,0x14,0xff,0x28,0x0c,0xff,0x30,0x00,0x6f,0xda,0x08,0x14,0xff,0x28,0x0c,0xff,
0x30,0x00,0x03,0xcb,0x86,0x14,0xff,0x28,0x0c,0xff,0x30,0x00,0x00,0x31,0xf7,0x42,0xff,0x28,
0x0c,0xff,0x30,0x00,0x00,0x00,0x8d,0xd9,0xff,0x28,0x0c,0xff,0x30,0x00,0x00,0x00,0x0b,0xe1,
0xff,0x28,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x4c,0xff,0x28,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3f,0x96,0xa8,0x7d,0x17,0x00,0x00,0x00,0x00,0x88,0xf4,0x8f,0x73,
0xbb,0xec,0x2e,0x00,0x00,0x41,0xf6,0x33,0x00,0x00,0x00,0x94,0xcf,0x04,0x00,0xc0,0x8e,0x00,
0x00,0x00,0x00,0x0b,0xef,0x50,0x11,0xfc,0x3d,0x00,0x00,0x00,0x00,0x00,0xa7,0xa0,0x35,0xff,
0x13,0x00,0x00,0x00,0x00,0x00,0x85,0xc5,0x40,0xff,0x0a,0x00,0x00,0x00,0x00,0x00,0x75,0xd4,
0x27,0xff,0x22,0x00,0x00,0x00,0x00,0x00,0x88,0xbd,0x04,0xed,0x56,0x00,0x00,0x00,0x00,0x00,
0xc3,0x83,0x00,0x97,0xbf,0x00,0x00,0x00,0x00,0x30,0xfb,0x2b,0x00,0x14,0xea,0x94,0x0b,0x00,
0x31,0xdb,0x92,0x00,0x00,0x00,0x2e,0xd0,0xf9,0xec,0xf9,0x90,0x05,0x00,0x00,0x00,0x00,0x00,
0x23,0x34,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x04,0x60,0x60,0x5f,0x4c,0x24,0x00,0x00,0x00,0x0c,0xff,0xc5,0xb8,0xcb,0xf5,0xba,0x14,0x00,
0x0c,0xff,0x30,0x00,0x00,0x11,0xbb,0xb4,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x42,0xfe,0x07,
0x0c,0xff,0x30,0x00,0x00,0x00,0x5c,0xf3,0x02,0x0c,0xff,0x39,0x0c,0x1e,0x59,0xe8,0x86,0x00,
0x0c,0xff,0xff,0xff,0xff,0xd8,0x71,0x02,0x00,0x0c,0xff,0x3d,0x0f,0x05,0x00,0x00,0x00,0x00,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3d,0x95,0xa9,0x7c,0x11,0x00,0x00,
0x00,0x00,0x00,0x81,0xf2,0x91,0x74,0xbb,0xeb,0x2e,0x00,0x00,0x00,0x3a,0xf6,0x32,0x00,0x00,
0x00,0x8e,0xde,0x06,0x00,0x00,0xb9,0x9b,0x00,0x00,0x00,0x00,0x07,0xe6,0x62,0x00,0x0f,0xfa,
0x40,0x00,0x00,0x00,0x00,0x00,0x99,0xae,0x00,0x33,0xff,0x1b,0x00,0x00,0x00,0x00,0x00,0x75,
0xd4,0x00,0x40,0xff,0x0b,0x00,0x00,0x00,0x00,0x00,0x64,0xe6,0x00,0x27,0xff,0x23,0x00,0x00,
0x00,0x00,0x00,0x74,0xd2,0x00,0x04,0xef,0x5b,0x00,0x00,0x01,0x3d,0x00,0xa7,0x9c,0x00,0x00,
0x97,0xc7,0x01,0x00,0x2a,0xf3,0x9b,0xf6,0x40,0x00,0x00,0x19,0xe6,0x9e,0x0e,0x00,0x53,0xff,
0xef,0x23,0x00,0x00,0x00,0x29,0xc4,0xfa,0xed,0xfc,0x92,0x9c,0xcf,0x01,0x00,0x00,0x00,0x00,
0x18,0x35,0x14,0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x04,0x60,0x60,0x5f,0x49,0x20,0x00,0x00,0x00,0x0c,0xff,0xc5,0xb8,0xcb,
0xf4,0xb3,0x19,0x00,0x0c,0xff,0x30,0x00,0x00,0x12,0xbd,0xbe,0x00,0x0c,0xff,0x30,0x00,0x00,
0x00,0x46,0xff,0x09,0x0c,0xff,0x30,0x00,0x00,0x00,0x57,0xf2,0x01,0x0c,0xff,0x39,0x0c,0x1d,
0x52,0xe7,0x80,0x00,0x0c,0xff,0xff,0xff,0xff,0xdb,0x6e,0x00,0x00,0x0c,0xff,0x3d,0x13,0xd1,
0x9c,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x2f,0xf9,0x48,0x00,0x00,0x0c,0xff,0x30,0x00,0x00,
0x7c,0xe3,0x0f,0x00,0x0c,0xff,0x30,0x00,0x00,0x03,0xca,0x9e,0x00,0x0c,0xff,0x30,0x00,0x00,
0x00,0x28,0xf6,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x45,0x94,0xa4,0x76,0x11,0x00,0x00,0x00,0x7d,0xf3,0x8f,0x77,
0xc0,0xe3,0x22,0x00,0x04,0xf6,0x59,0x00,0x00,0x00,0x94,0x72,0x00,0x10,0xff,0x3a,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xc4,0xc6,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xbd,0xfa,0xa9,
0x3a,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xa0,0xfb,0xa6,0x09,0x00,0x00,0x00,0x00,0x00,0x00,
0x2c,0xde,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x45,0xf9,0x03,0x50,0xa5,0x01,0x00,0x00,
0x00,0x37,0xfe,0x07,0x1f,0xf0,0x9e,0x0e,0x00,0x2b,0xcf,0xb8,0x00,0x00,0x39,0xd7,0xfc,0xef,
0xfe,0xb5,0x15,0x00,0x00,0x00,0x02,0x23,0x34,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x15,
0x39,0xb8,0xb8,0xb8,0xe1,0xe7,0xb8,0xb8,0xb8,0x28,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xa8,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x60,0x15,0x00,0x00,0x00,0x00,0x0f,
0x60,0x0a,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,0x00,0x00,
0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,
0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0b,0xff,
0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1b,0x02,0xfc,0x44,0x00,0x00,0x00,0x00,0x2f,0xff,0x13,
0x00,0xe4,0x63,0x00,0x00,0x00,0x00,0x51,0xf4,0x02,0x00,0x9f,0xb8,0x00,0x00,0x00,0x00,0xa4,
0xb6,0x00,0x00,0x2e,0xf7,0x7d,0x05,0x05,0x73,0xfc,0x3e,0x00,0x00,0x00,0x4a,0xe3,0xf8,0xf8,
0xee,0x5b,0x00,0x00,0x00,0x00,0x00,0x03,0x26,0x30,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x5f,0x01,0x00,0x00,0x00,
0x00,0x06,0x60,0x13,0x1c,0xff,0x36,0x00,0x00,0x00,0x00,0x47,0xf6,0x09,0x00,0xcd,0x83,0x00,
0x00,0x00,0x00,0x94,0xb2,0x00,0x00,0x7f,0xd0,0x00,0x00,0x00,0x00,0xe0,0x65,0x00,0x00,0x30,
0xff,0x1d,0x00,0x00,0x2d,0xfe,0x19,0x00,0x00,0x00,0xe1,0x69,0x00,0x00,0x7a,0xca,0x00,0x00,
0x00,0x00,0x94,0xb6,0x00,0x00,0xc7,0x7d,0x00,0x00,0x00,0x00,0x45,0xf7,0x0b,0x16,0xfd,0x2f,
0x00,0x00,0x00,0x00,0x05,0xf1,0x4f,0x60,0xe1,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0x9c,0xad,
0x95,0x00,0x00,0x00,0x00,0x00,0x00,0x5a,0xe8,0xf3,0x47,0x00,0x00,0x00,0x00,0x00,0x00,0x10,
0xfb,0xf3,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x1e,0x59,0x00,0x00,0x00,0x0c,0x18,0x00,0x00,0x00,0x29,0x4e,0x35,0xfe,
0x09,0x00,0x00,0xa6,0xff,0x25,0x00,0x00,0x88,0xb4,0x0d,0xff,0x2c,0x00,0x00,0xde,0xeb,0x5d,
0x00,0x00,0xad,0x8b,0x00,0xe5,0x51,0x00,0x17,0xfb,0x89,0x96,0x00,0x00,0xd2,0x63,0x00,0xbd,
0x76,0x00,0x50,0xce,0x47,0xcf,0x00,0x01,0xf6,0x3b,0x00,0x95,0x9b,0x00,0x88,0x97,0x11,0xfb,
0x0b,0x1c,0xff,0x12,0x00,0x6d,0xc0,0x00,0xc1,0x60,0x00,0xd9,0x40,0x41,0xea,0x00,0x00,0x45,
0xe5,0x04,0xf5,0x28,0x00,0xa1,0x79,0x66,0xc1,0x00,0x00,0x1d,0xff,0x3d,0xf0,0x01,0x00,0x6a,
0xb1,0x8b,0x99,0x00,0x00,0x01,0xf4,0x9b,0xba,0x00,0x00,0x33,0xea,0xb0,0x70,0x00,0x00,0x00,
0xcd,0xf0,0x82,0x00,0x00,0x04,0xf6,0xf0,0x48,0x00,0x00,0x00,0xa4,0xff,0x4b,0x00,0x00,0x00,
0xc4,0xff,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x1d,0x60,0x0a,0x00,0x00,0x00,0x00,0x30,0x57,0x00,0x06,0xd6,0x85,0x00,0x00,0x00,
0x08,0xdf,0x7b,0x00,0x00,0x3c,0xf7,0x25,0x00,0x00,0x7e,0xd5,0x05,0x00,0x00,0x00,0x98,0xb7,
0x00,0x1e,0xf4,0x3c,0x00,0x00,0x00,0x00,0x0f,0xe6,0x50,0xab,0x9b,0x00,0x00,0x00,0x00,0x00,
0x00,0x52,0xec,0xe9,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xf1,0xaa,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x91,0xd2,0xf8,0x3e,0x00,0x00,0x00,0x00,0x00,0x33,0xf8,0x2e,0x85,0xd7,0x07,
0x00,0x00,0x00,0x03,0xcd,0x8c,0x00,0x0a,0xe0,0x80,0x00,0x00,0x00,0x71,0xe3,0x0c,0x00,0x00,
0x50,0xf9,0x28,0x00,0x1c,0xf3,0x52,0x00,0x00,0x00,0x00,0xb5,0xc1,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x1b,0x5e,0x03,0x00,0x00,0x00,0x00,0x3d,0x3f,0x06,0xd6,0x6c,0x00,0x00,0x00,0x19,0xf1,0x3c,
0x00,0x3c,0xed,0x14,0x00,0x00,0xa5,0x99,0x00,0x00,0x00,0x9b,0x9c,0x00,0x3d,0xe6,0x10,0x00,
0x00,0x00,0x11,0xe7,0x39,0xd1,0x56,0x00,0x00,0x00,0x00,0x00,0x5a,0xf1,0xb5,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xf1,0x4d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xf0,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xf0,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x5e,0x60,0x60,0x60,0x60,0x60,0x60,0x60,0x31,0x00,0xb5,0xb8,0xb8,
0xb8,0xb8,0xb8,0xda,0xf2,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0xdd,0x68,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x93,0xbe,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0xf3,0x22,0x00,0x00,
0x00,0x00,0x00,0x00,0x0a,0xdc,0x6f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xc4,0x02,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0xf5,0x26,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0xdb,0x76,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x8f,0xca,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0xfb,0x47,
0x1c,0x1c,0x1c,0x1c,0x1c,0x14,0x09,0xd9,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xbc,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xec,0xf4,0xf4,0x1a,0x00,0xf8,0x50,0x24,0x03,0x00,0xf8,0x34,0x00,
0x00,0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,
0x34,0x00,0x00,0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,0x34,0x00,0x00,
0x00,0xf8,0x34,0x00,0x00,0x00,0xf8,0x7a,0x58,0x09,0x00,0xba,0xc0,0xc0,0x15,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0x10,0x02,0x00,0x00,0x00,0x00,0x00,0x0b,0xed,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x82,
0xd7,0x01,0x00,0x00,0x00,0x00,0x00,0x14,0xf5,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xc6,
0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xfb,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0xa4,0xb3,0x00,
0x00,0x00,0x00,0x00,0x00,0x2d,0xfd,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0xb5,0xa1,0x00,0x00,
0x00,0x00,0x00,0x00,0x3e,0xfa,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0xc7,0x8e,0x00,0x00,0x00,
0x00,0x00,0x00,0x4f,0xf3,0x11,0x00,0x00,0x00,0x00,0x00,0x01,0xd6,0x7c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf0,0xf4,0xf4,0x16,0x00,
0x23,0x31,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,0x10,0xff,
0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,
0x10,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x00,0x10,0xff,0x18,0x00,0x5a,0x66,0xff,0x18,
0x00,0xbd,0xc0,0xc0,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0xa5,0x57,0x00,
0x00,0x00,0x03,0xba,0xb9,0xf1,0x37,0x00,0x00,0x8d,0xd5,0x0a,0x6d,0xe6,0x1a,0x00,0x00,0x00,
0x00,0x00,0x04,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x4c,0x4c,0x4c,
0x4c,0x4c,0x4c,0x4c,0x4c,0x0f,0x41,0xd0,0xd0,0xd0,0xd0,0xd0,0xd0,0xd0,0xd0,0x2a,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x0e,0x00,0x00,0x67,0xe2,0x2a,0x00,0x00,0x6e,0xe6,0x3c,0x00,0x00,0x2c,0x67,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x75,0x5f,0x0b,0x00,0x00,
0x00,0x58,0xd9,0x9a,0xbd,0xd9,0x0f,0x00,0x00,0x01,0x04,0x00,0x00,0xaa,0x82,0x00,0x00,0x01,
0x5b,0x90,0x65,0x64,0xb5,0x00,0x00,0xa8,0xe2,0x83,0xa4,0xde,0xc4,0x00,0x30,0xfb,0x1e,0x00,
0x00,0x90,0xc4,0x00,0x4b,0xe9,0x00,0x00,0x00,0x5e,0xc4,0x00,0x1a,0xf8,0x61,0x00,0x0f,0xc4,
0xc4,0x00,0x00,0x5f,0xf5,0xe3,0xdf,0x88,0xc4,0x00,0x00,0x00,0x0c,0x30,0x0c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x5a,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,
0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x35,0x5a,0x92,0x6a,0x06,0x00,0x00,0xfc,
0xaa,0xbe,0x87,0xe6,0xb3,0x00,0x00,0xfc,0xbe,0x02,0x00,0x2a,0xfd,0x31,0x00,0xfc,0x54,0x00,
0x00,0x00,0xbe,0x79,0x00,0xfc,0x31,0x00,0x00,0x00,0x9d,0x96,0x00,0xfc,0x3b,0x00,0x00,0x00,
0xa8,0x8a,0x00,0xfc,0x74,0x00,0x00,0x01,0xdc,0x62,0x00,0xfc,0xda,0x24,0x00,0x71,0xf6,0x10,
0x00,0xfc,0x6e,0xeb,0xe7,0xf6,0x59,0x00,0x00,0x00,0x00,0x0d,0x32,0x10,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x15,0x69,0x7f,0x31,0x00,0x00,0x32,0xec,0xb8,0x98,0xf2,0x57,0x00,0xd5,0x89,0x00,0x00,
0x41,0x4d,0x37,0xf7,0x0c,0x00,0x00,0x00,0x00,0x5d,0xd7,0x00,0x00,0x00,0x00,0x00,0x56,0xe2,
0x00,0x00,0x00,0x00,0x00,0x20,0xfd,0x23,0x00,0x00,0x01,0x00,0x00,0xa9,0xbc,0x0c,0x01,0x88,
0x88,0x00,0x0d,0xb4,0xf7,0xe7,0xd4,0x22,0x00,0x00,0x00,0x1f,0x2e,0x03,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x5c,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0x30,0x00,0x00,0x55,0x92,0x6c,0x07,0xff,0x30,0x00,0x7f,0xf6,0x8f,0xa7,0xa5,0xff,0x30,
0x0c,0xf3,0x57,0x00,0x00,0x91,0xff,0x30,0x49,0xee,0x02,0x00,0x00,0x25,0xff,0x30,0x63,0xd0,
0x00,0x00,0x00,0x04,0xfd,0x30,0x59,0xdb,0x00,0x00,0x00,0x0c,0xff,0x30,0x32,0xfa,0x15,0x00,
0x00,0x44,0xff,0x30,0x00,0xd3,0x9f,0x02,0x0f,0xbd,0xff,0x30,0x00,0x35,0xe9,0xed,0xf1,0x5e,
0xff,0x30,0x00,0x00,0x08,0x33,0x17,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x1d,0x76,0x7b,0x23,0x00,0x00,0x00,0x34,0xf2,0xab,0xa4,0xf4,0x3a,0x00,0x00,0xc9,
0x9b,0x00,0x00,0x7a,0xc1,0x00,0x18,0xff,0x2e,0x00,0x00,0x10,0xfe,0x12,0x35,0xff,0xbb,0xb8,
0xb8,0xb8,0xfb,0x31,0x2e,0xff,0x63,0x54,0x54,0x54,0x54,0x13,0x09,0xf8,0x49,0x00,0x00,0x00,
0x00,0x00,0x00,0x9d,0xd0,0x0c,0x01,0x6a,0x99,0x00,0x00,0x0e,0xbd,0xf0,0xe7,0xdd,0x39,0x00,
0x00,0x00,0x00,0x26,0x2c,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x57,0x81,0x1e,0x00,0x00,0x88,0xc4,0xa5,0x3e,0x00,0x00,0xe5,0x46,
0x00,0x00,0x01,0x64,0xf6,0x8d,0x4e,0x00,0x02,0xac,0xfa,0xc1,0x86,0x00,0x00,0x00,0xf0,0x40,
0x00,0x00,0x00,0x00,0xf0,0x40,0x00,0x00,0x00,0x00,0xf0,0x40,0x00,0x00,0x00,0x00,0xf0,0x40,
0x00,0x00,0x00,0x00,0xf0,0x40,0x00,0x00,0x00,0x00,0xf0,0x40,0x00,0x00,0x00,0x00,0xf0,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0x92,0x6c,0x07,0x64,0x12,
0x00,0x7f,0xf6,0x8f,0xa7,0xa5,0xff,0x30,0x0c,0xf3,0x57,0x00,0x00,0x91,0xff,0x30,0x49,0xee,
0x02,0x00,0x00,0x25,0xff,0x30,0x63,0xd0,0x00,0x00,0x00,0x04,0xfd,0x30,0x5d,0xdb,0x00,0x00,
0x00,0x0c,0xff,0x30,0x33,0xfa,0x15,0x00,0x00,0x44,0xff,0x30,0x01,0xd5,0x9f,0x02,0x0f,0xbe,
0xff,0x30,0x00,0x31,0xe4,0xed,0xf0,0x5d,0xff,0x30,0x07,0x20,0x08,0x33,0x15,0x0b,0xff,0x26,
0x0e,0xf4,0x32,0x00,0x00,0x60,0xe2,0x02,0x00,0x5e,0xee,0xa1,0xab,0xf1,0x44,0x00,0x00,0x00,
0x27,0x75,0x6a,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x5e,0x13,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,
0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x59,0x92,0x6b,0x05,0x00,0x00,0xfc,
0xb1,0xb0,0x81,0xe7,0xa7,0x00,0x00,0xfc,0xb2,0x00,0x00,0x34,0xff,0x28,0x00,0xfc,0x5c,0x00,
0x00,0x00,0xda,0x60,0x00,0xfc,0x3d,0x00,0x00,0x00,0xbb,0x74,0x00,0xfc,0x34,0x00,0x00,0x00,
0xb4,0x78,0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,
0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,
0x01,0x00,0xde,0x64,0x00,0x2d,0x0b,0x00,0x52,0x23,0x00,0xd4,0x5c,0x00,0xd4,0x5c,0x00,0xd4,
0x5c,0x00,0xd4,0x5c,0x00,0xd4,0x5c,0x00,0xd4,0x5c,0x00,0xd4,0x5c,0x00,0xd4,0x5c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x09,0x00,0x00,0x8f,0xaf,0x00,0x00,
0x17,0x20,0x00,0x00,0x35,0x41,0x00,0x00,0x88,0xa8,0x00,0x00,0x88,0xa8,0x00,0x00,0x88,0xa8,
0x00,0x00,0x88,0xa8,0x00,0x00,0x88,0xa8,0x00,0x00,0x88,0xa8,0x00,0x00,0x88,0xa8,0x00,0x00,
0x88,0xa8,0x00,0x00,0x88,0xa8,0x02,0x00,0x98,0x91,0xa0,0xc9,0xe3,0x28,0x19,0x4d,0x10,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5a,0x12,0x00,
0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,
0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x4d,0x3a,0x00,0x00,0xfc,0x34,0x00,0x59,0xe4,0x1b,0x00,
0x00,0xfc,0x34,0x36,0xed,0x33,0x00,0x00,0x00,0xfc,0x4f,0xe5,0x54,0x00,0x00,0x00,0x00,0xfc,
0xea,0xed,0x15,0x00,0x00,0x00,0x00,0xfc,0xa0,0x99,0xb8,0x01,0x00,0x00,0x00,0xfc,0x34,0x09,
0xd3,0x79,0x00,0x00,0x00,0xfc,0x34,0x00,0x2a,0xf1,0x3c,0x00,0x00,0xfc,0x34,0x00,0x00,0x62,
0xe3,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0x21,0x00,
0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,
0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,0x00,0xd4,0x5c,0x00,
0x00,0xce,0x6a,0x00,0x00,0x7a,0xf7,0x3b,0x00,0x00,0x20,0x10,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x62,0x17,0x6e,0x8e,0x36,0x00,0x32,0x8d,0x6e,0x05,0x00,0x00,0xfc,0xb2,0x93,0xad,0xf8,
0x53,0xce,0x93,0xeb,0x98,0x00,0x00,0xfc,0x92,0x00,0x00,0xd2,0xf2,0x18,0x00,0x56,0xf7,0x05,
0x00,0xfc,0x4d,0x00,0x00,0x97,0xc6,0x00,0x00,0x1c,0xff,0x1d,0x00,0xfc,0x38,0x00,0x00,0x86,
0xb0,0x00,0x00,0x0b,0xff,0x28,0x00,0xfc,0x34,0x00,0x00,0x84,0xac,0x00,0x00,0x08,0xff,0x28,
0x00,0xfc,0x34,0x00,0x00,0x84,0xac,0x00,0x00,0x08,0xff,0x28,0x00,0xfc,0x34,0x00,0x00,0x84,
0xac,0x00,0x00,0x08,0xff,0x28,0x00,0xfc,0x34,0x00,0x00,0x84,0xac,0x00,0x00,0x08,0xff,0x28,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x15,0x59,
0x92,0x6b,0x05,0x00,0x00,0xfc,0xb1,0xb0,0x81,0xe7,0xa7,0x00,0x00,0xfc,0xb2,0x00,0x00,0x34,
0xff,0x28,0x00,0xfc,0x5c,0x00,0x00,0x00,0xda,0x60,0x00,0xfc,0x3d,0x00,0x00,0x00,0xbb,0x74,
0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0xfc,
0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0xfc,0x34,0x00,0x00,0x00,0xb4,0x78,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0x72,0x7f,0x3e,
0x00,0x00,0x00,0x2f,0xf0,0xb0,0x92,0xeb,0x83,0x00,0x00,0xb6,0x8c,0x00,0x00,0x27,0xf8,0x2a,
0x0a,0xfe,0x2c,0x00,0x00,0x00,0xc0,0x79,0x29,0xff,0x0a,0x00,0x00,0x00,0x9f,0x98,0x25,0xff,
0x11,0x00,0x00,0x00,0xa6,0x91,0x05,0xf3,0x44,0x00,0x00,0x00,0xd9,0x65,0x00,0x91,0xc7,0x0c,
0x00,0x6a,0xef,0x12,0x00,0x09,0xae,0xf1,0xe0,0xe8,0x42,0x00,0x00,0x00,0x00,0x1e,0x2f,0x08,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x15,0x5a,0x92,0x6a,0x06,0x00,
0x00,0xfc,0xaa,0xbe,0x87,0xe6,0xb3,0x00,0x00,0xfc,0xbe,0x02,0x00,0x2a,0xfd,0x31,0x00,0xfc,
0x54,0x00,0x00,0x00,0xbe,0x79,0x00,0xfc,0x31,0x00,0x00,0x00,0x9d,0x96,0x00,0xfc,0x3b,0x00,
0x00,0x00,0xa8,0x8a,0x00,0xfc,0x74,0x00,0x00,0x01,0xdc,0x62,0x00,0xfc,0xda,0x24,0x00,0x71,
0xf6,0x10,0x00,0xfc,0x6e,0xeb,0xe7,0xf6,0x59,0x00,0x00,0xfc,0x34,0x0d,0x32,0x10,0x00,0x00,
0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x56,
0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,
0x92,0x6c,0x07,0x64,0x12,0x00,0x00,0x7f,0xf6,0x8f,0xa7,0xa5,0xff,0x30,0x00,0x0c,0xf3,0x57,
0x00,0x00,0x91,0xff,0x30,0x00,0x49,0xee,0x02,0x00,0x00,0x25,0xff,0x30,0x00,0x63,0xd0,0x00,
0x00,0x00,0x04,0xfd,0x30,0x00,0x59,0xdb,0x00,0x00,0x00,0x0c,0xff,0x30,0x00,0x32,0xfa,0x15,
0x00,0x00,0x44,0xff,0x30,0x00,0x00,0xd6,0x9f,0x02,0x0f,0xbd,0xff,0x30,0x00,0x00,0x37,0xea,
0xed,0xf2,0x5d,0xff,0x30,0x00,0x00,0x00,0x09,0x33,0x15,0x00,0xff,0x30,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xfd,0x33,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xca,0xc0,0x0f,0x00,0x00,0x00,
0x00,0x00,0x00,0x16,0x6e,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0x15,0x59,0x92,0x52,
0x00,0xfc,0xb1,0xb0,0x88,0x3d,0x00,0xfc,0xb2,0x00,0x00,0x00,0x00,0xfc,0x5c,0x00,0x00,0x00,
0x00,0xfc,0x3d,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,
0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0xfc,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x55,0x89,0x71,
0x14,0x00,0x00,0xa2,0xd9,0x83,0xb5,0xe7,0x1b,0x02,0xfa,0x33,0x00,0x00,0x52,0x18,0x00,0xd8,
0x90,0x08,0x00,0x00,0x00,0x00,0x2c,0xcc,0xef,0x98,0x22,0x00,0x00,0x00,0x00,0x34,0xa1,0xf3,
0x2c,0x00,0x00,0x00,0x00,0x00,0xbc,0x83,0x11,0xd3,0x3a,0x00,0x10,0xdc,0x61,0x00,0x69,0xf3,
0xdc,0xf3,0xa1,0x03,0x00,0x00,0x0e,0x32,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x08,0x58,0x08,0x00,0x00,0x18,0xff,0x18,0x00,0x14,0x72,0xff,0x72,0x3e,
0x22,0xb3,0xff,0xb3,0x6b,0x00,0x18,0xff,0x18,0x00,0x00,0x18,0xff,0x18,0x00,0x00,0x18,0xff,
0x18,0x00,0x00,0x18,0xff,0x18,0x00,0x00,0x18,0xff,0x18,0x00,0x00,0x10,0xff,0x2b,0x00,0x00,
0x00,0xc4,0xeb,0x6b,0x00,0x00,0x03,0x2d,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x64,0x0c,0x00,0x00,0x00,0x4e,0x28,0x10,0xff,
0x20,0x00,0x00,0x00,0xc8,0x68,0x10,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x10,0xff,0x20,0x00,
0x00,0x00,0xc8,0x68,0x0f,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x08,0xff,0x2d,0x00,0x00,0x00,
0xdf,0x68,0x00,0xe8,0x5a,0x00,0x00,0x0d,0xfc,0x68,0x00,0x9b,0xcf,0x0d,0x02,0x92,0xf4,0x68,
0x00,0x16,0xd3,0xf2,0xe9,0x95,0xc8,0x68,0x00,0x00,0x03,0x30,0x1f,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0x5f,0x00,0x00,0x00,0x00,0x49,0x31,0x14,0xfb,0x2c,0x00,
0x00,0x06,0xf0,0x41,0x00,0xb8,0x7e,0x00,0x00,0x4b,0xe6,0x02,0x00,0x61,0xcf,0x00,0x00,0x9f,
0x90,0x00,0x00,0x10,0xf9,0x21,0x04,0xed,0x38,0x00,0x00,0x00,0xb4,0x73,0x47,0xdf,0x00,0x00,
0x00,0x00,0x5d,0xc4,0x9b,0x88,0x00,0x00,0x00,0x00,0x0e,0xf6,0xef,0x30,0x00,0x00,0x00,0x00,
0x00,0xaf,0xd7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x29,0x4d,0x00,0x00,0x0e,0x54,0x07,0x00,0x00,0x55,0x21,
0x3c,0xee,0x01,0x00,0x57,0xff,0x42,0x00,0x0a,0xfb,0x26,0x04,0xf3,0x2c,0x00,0x99,0xdc,0x84,
0x00,0x41,0xe1,0x00,0x00,0xb3,0x68,0x00,0xda,0x5b,0xc6,0x00,0x7d,0x9d,0x00,0x00,0x6f,0xa3,
0x1d,0xdd,0x05,0xef,0x0c,0xb8,0x58,0x00,0x00,0x2b,0xdf,0x5f,0x9a,0x00,0xb7,0x4c,0xef,0x15,
0x00,0x00,0x00,0xe6,0xbb,0x57,0x00,0x75,0xbb,0xcf,0x00,0x00,0x00,0x00,0xa3,0xfe,0x15,0x00,
0x33,0xff,0x8a,0x00,0x00,0x00,0x00,0x5e,0xd1,0x00,0x00,0x02,0xee,0x46,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x2c,0x56,0x00,0x00,0x00,0x45,0x3d,0x18,0xf2,0x3e,0x00,0x1b,0xf5,0x37,0x00,0x75,0xc7,
0x00,0x9b,0xa0,0x00,0x00,0x06,0xd9,0x7a,0xee,0x18,0x00,0x00,0x00,0x51,0xff,0x7e,0x00,0x00,
0x00,0x00,0x8b,0xe5,0xbf,0x00,0x00,0x00,0x26,0xf3,0x27,0xdf,0x55,0x00,0x00,0xb5,0x94,0x00,
0x5a,0xe1,0x09,0x4a,0xf5,0x18,0x00,0x01,0xcc,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x06,0x64,0x0c,0x00,0x00,0x00,0x4e,0x28,0x10,0xff,0x20,0x00,0x00,0x00,
0xc8,0x68,0x10,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x10,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,
0x0f,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x08,0xff,0x2d,0x00,0x00,0x00,0xdf,0x68,0x00,0xe8,
0x5a,0x00,0x00,0x0d,0xfc,0x68,0x00,0x9b,0xcf,0x0d,0x02,0x92,0xf4,0x68,0x00,0x16,0xd3,0xf2,
0xe9,0x95,0xc8,0x68,0x00,0x00,0x03,0x30,0x1f,0x00,0xd6,0x5e,0x00,0x22,0x31,0x00,0x00,0x35,
0xf5,0x1e,0x00,0x62,0xf2,0xab,0xa2,0xf0,0x63,0x00,0x00,0x00,0x25,0x73,0x6d,0x24,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x60,0x64,0x64,0x64,0x64,0x5f,0x01,0x00,0xb2,0xb8,0xb8,0xb8,0xfc,0x8d,0x00,
0x00,0x00,0x00,0x00,0x5a,0xe4,0x0c,0x00,0x00,0x00,0x00,0x0e,0xe6,0x56,0x00,0x00,0x00,0x00,
0x00,0x91,0xba,0x00,0x00,0x00,0x00,0x00,0x2f,0xf5,0x26,0x00,0x00,0x00,0x00,0x01,0xc6,0x83,
0x00,0x00,0x00,0x00,0x00,0x63,0xe9,0x25,0x1c,0x1c,0x18,0x00,0x12,0xeb,0xff,0xff,0xff,0xff,
0xdc,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x35,0xcc,0xe6,0x00,0x00,0x00,0xb2,0x9a,0x1a,0x00,0x00,0x00,
0xc2,0x57,0x00,0x00,0x00,0x00,0xcd,0x4b,0x00,0x00,0x00,0x02,0xf1,0x28,0x00,0x00,0x00,0x5f,
0xe7,0x01,0x00,0x00,0x0c,0xc9,0xa7,0x00,0x00,0x00,0x00,0x25,0xfb,0x0e,0x00,0x00,0x00,0x00,
0xe1,0x2e,0x00,0x00,0x00,0x00,0xcb,0x47,0x00,0x00,0x00,0x00,0xbf,0x58,0x00,0x00,0x00,0x00,
0xa7,0xb5,0x44,0x00,0x00,0x00,0x20,0xa5,0xc3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x5c,0x08,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,
0x18,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,0x18,0x04,0xff,
0x18,0x04,0xff,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xe2,0xcc,0x37,0x00,0x00,0x00,0x19,0x9a,0xb3,0x00,0x00,0x00,0x00,
0x57,0xc2,0x00,0x00,0x00,0x00,0x43,0xd0,0x00,0x00,0x00,0x00,0x28,0xf0,0x02,0x00,0x00,0x00,
0x03,0xe9,0x59,0x00,0x00,0x00,0x00,0xa2,0xc6,0x0a,0x00,0x00,0x08,0xf9,0x29,0x00,0x00,0x00,
0x37,0xe4,0x00,0x00,0x00,0x00,0x50,0xcb,0x00,0x00,0x00,0x00,0x59,0xc2,0x00,0x00,0x00,0x4f,
0xbd,0xa9,0x00,0x00,0x00,0xb4,0x99,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x9a,0x74,0x00,0x00,0x10,0x76,0x82,
0xb6,0xbd,0xb1,0x72,0x04,0x00,0x02,0x6d,0x74,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0x8d,0xa7,0x86,0x26,0x00,0x00,
0x00,0x00,0x6f,0xfa,0xa1,0x74,0xa8,0xf6,0x48,0x00,0x00,0x37,0xfa,0x4f,0x00,0x00,0x00,0x71,
0xb6,0x00,0x00,0xb0,0xb5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xf8,0x57,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x24,0xff,0x2d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0xff,0x1d,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0x3a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xe6,
0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0xe1,0x08,0x00,0x00,0x00,0x1f,0x76,0x04,
0x00,0x0f,0xe0,0xb4,0x18,0x00,0x23,0xcb,0xaf,0x00,0x00,0x00,0x1f,0xb8,0xfc,0xe9,0xfd,0xa8,
0x0d,0x00,0x00,0x00,0x00,0x00,0x1c,0x6f,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,
0xd1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xdf,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xc0,0x03,0x00,0x7d,0x85,0x00,0x00,
0x00,0x00,0x1c,0x74,0x00,0x00,0x45,0x46,0x00,0x00,0x00,0x00,0x00,0x3f,0x96,0xa8,0x7d,0x17,
0x00,0x00,0x00,0x00,0x88,0xf4,0x8f,0x73,0xbb,0xec,0x2e,0x00,0x00,0x41,0xf6,0x33,0x00,0x00,
0x00,0x94,0xcf,0x04,0x00,0xc0,0x8e,0x00,0x00,0x00,0x00,0x0b,0xef,0x50,0x11,0xfc,0x3d,0x00,
0x00,0x00,0x00,0x00,0xa7,0xa0,0x35,0xff,0x13,0x00,0x00,0x00,0x00,0x00,0x85,0xc5,0x40,0xff,
0x0a,0x00,0x00,0x00,0x00,0x00,0x75,0xd4,0x27,0xff,0x22,0x00,0x00,0x00,0x00,0x00,0x88,0xbd,
0x04,0xed,0x56,0x00,0x00,0x00,0x00,0x00,0xc3,0x83,0x00,0x97,0xbf,0x00,0x00,0x00,0x00,0x30,
0xfb,0x2b,0x00,0x14,0xea,0x94,0x0b,0x00,0x31,0xdb,0x92,0x00,0x00,0x00,0x2e,0xd0,0xf9,0xec,
0xf9,0x90,0x05,0x00,0x00,0x00,0x00,0x00,0x23,0x34,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xc0,0x03,0x00,0x7d,0x85,
0x00,0x00,0x00,0x00,0x1c,0x74,0x00,0x00,0x45,0x46,0x00,0x00,0x04,0x60,0x15,0x00,0x00,0x00,
0x00,0x0f,0x60,0x0a,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,
0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,
0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,0x0c,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1c,
0x0b,0xff,0x38,0x00,0x00,0x00,0x00,0x28,0xff,0x1b,0x02,0xfc,0x44,0x00,0x00,0x00,0x00,0x2f,
0xff,0x13,0x00,0xe4,0x63,0x00,0x00,0x00,0x00,0x51,0xf4,0x02,0x00,0x9f,0xb8,0x00,0x00,0x00,
0x00,0xa4,0xb6,0x00,0x00,0x2e,0xf7,0x7d,0x05,0x05,0x73,0xfc,0x3e,0x00,0x00,0x00,0x4a,0xe3,
0xf8,0xf8,0xee,0x5b,0x00,0x00,0x00,0x00,0x00,0x03,0x26,0x30,0x06,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0x69,0x7f,0x31,
0x00,0x00,0x00,0x32,0xec,0xb8,0x98,0xf2,0x57,0x00,0x00,0xd5,0x89,0x00,0x00,0x41,0x4d,0x00,
0x37,0xf7,0x0c,0x00,0x00,0x00,0x00,0x00,0x5d,0xd7,0x00,0x00,0x00,0x00,0x00,0x00,0x56,0xe2,
0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xfd,0x23,0x00,0x00,0x01,0x00,0x00,0x00,0xa9,0xbc,0x0c,
0x01,0x88,0x88,0x00,0x00,0x0d,0xb4,0xf7,0xe7,0xd4,0x22,0x00,0x00,0x00,0x00,0x5b,0x70,0x03,
0x00,0x00,0x00,0x00,0x00,0x74,0xd1,0x00,0x00,0x00,0x00,0x00,0x02,0xdf,0x88,0x00,0x00,0x00,
0x00,0x00,0x00,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xc0,0x03,0x00,0x7d,
0x85,0x00,0x00,0x1c,0x74,0x00,0x00,0x45,0x46,0x00,0x00,0x00,0x1b,0x72,0x7f,0x3e,0x00,0x00,
0x00,0x2f,0xf0,0xb0,0x92,0xeb,0x83,0x00,0x00,0xb6,0x8c,0x00,0x00,0x27,0xf8,0x2a,0x0a,0xfe,
0x2c,0x00,0x00,0x00,0xc0,0x79,0x29,0xff,0x0a,0x00,0x00,0x00,0x9f,0x98,0x25,0xff,0x11,0x00,
0x00,0x00,0xa6,0x91,0x05,0xf3,0x44,0x00,0x00,0x00,0xd9,0x65,0x00,0x91,0xc7,0x0c,0x00,0x6a,
0xef,0x12,0x00,0x09,0xae,0xf1,0xe0,0xe8,0x42,0x00,0x00,0x00,0x00,0x1e,0x2f,0x08,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xc0,0x03,0x00,0x7d,0x85,0x00,
0x00,0x1c,0x74,0x00,0x00,0x45,0x46,0x00,0x06,0x64,0x0c,0x00,0x00,0x00,0x4e,0x28,0x10,0xff,
0x20,0x00,0x00,0x00,0xc8,0x68,0x10,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x10,0xff,0x20,0x00,
0x00,0x00,0xc8,0x68,0x0f,0xff,0x20,0x00,0x00,0x00,0xc8,0x68,0x08,0xff,0x2d,0x00,0x00,0x00,
0xdf,0x68,0x00,0xe8,0x5a,0x00,0x00,0x0d,0xfc,0x68,0x00,0x9b,0xcf,0x0d,0x02,0x92,0xf4,0x68,
0x00,0x16,0xd3,0xf2,0xe9,0x95,0xc8,0x68,0x00,0x00,0x03,0x30,0x1f,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,
0x2e,0x00,0x00,0x16,0x2b,0x00,0x00,0x00,0x00,0x00,0x0e,0xd3,0x1d,0x07,0xb7,0x45,0x00,0x00,
0x00,0x00,0x00,0x00,0x5c,0xf4,0xf3,0x99,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x99,0xc3,
0x8f,0x31,0x00,0x00,0x00,0x00,0x00,0x60,0xfa,0xa7,0x74,0x9e,0xf8,0x5a,0x00,0x00,0x00,0x29,
0xf7,0x5f,0x00,0x00,0x00,0x53,0x53,0x00,0x00,0x00,0xa6,0xc1,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x06,0xf4,0x5d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0xff,0x2e,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x32,0xff,0x1d,0x00,0x00,0x49,0x70,0x70,0x70,0x47,0x00,0x1c,
0xff,0x3b,0x00,0x00,0x6e,0xa8,0xa8,0xdc,0x9b,0x00,0x00,0xe3,0x7f,0x00,0x00,0x00,0x00,0x00,
0xaf,0x7a,0x00,0x00,0x82,0xe5,0x0b,0x00,0x00,0x00,0x12,0xf3,0x2d,0x00,0x00,0x0d,0xda,0xb7,
0x18,0x00,0x19,0xbc,0xa7,0x00,0x00,0x00,0x00,0x1c,0xb6,0xfb,0xe9,0xfd,0xa2,0x0d,0x00,0x00,
0x00,0x00,0x00,0x00,0x19,0x36,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x13,0x2e,0x00,0x00,0x16,0x2b,0x00,0x00,0x0e,0xd3,0x1d,0x07,0xb7,
0x45,0x00,0x00,0x00,0x5c,0xf4,0xf3,0x99,0x00,0x00,0x00,0x00,0x55,0xa1,0x87,0x07,0x64,0x12,
0x00,0x7f,0xf6,0x8f,0xa7,0xa5,0xff,0x30,0x0c,0xf3,0x57,0x00,0x00,0x91,0xff,0x30,0x49,0xee,
0x02,0x00,0x00,0x25,0xff,0x30,0x63,0xd0,0x00,0x00,0x00,0x04,0xfd,0x30,0x5d,0xdb,0x00,0x00,
0x00,0x0c,0xff,0x30,0x33,0xfa,0x15,0x00,0x00,0x44,0xff,0x30,0x01,0xd5,0x9f,0x02,0x0f,0xbe,
0xff,0x30,0x00,0x31,0xe4,0xed,0xf0,0x5d,0xff,0x30,0x07,0x20,0x08,0x33,0x15,0x0b,0xff,0x26,
0x0e,0xf4,0x32,0x00,0x00,0x60,0xe2,0x02,0x00,0x5e,0xee,0xa1,0xab,0xf1,0x44,0x00,0x00,0x00,
0x27,0x75,0x6a,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xc0,0x03,0x1c,0x74,0x00,
0x00,0x4c,0x2a,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,
0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,0x00,0xcc,0x70,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5a,0x1c,
0x00,0xe8,0x48,0x00,0xe8,0x48,0x00,0xe8,0x48,0x00,0xe8,0x48,0x00,0xe8,0x48,0x00,0xe8,0x48,
0x00,0xe8,0x48,0x00,0xe8,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x45,0x94,0xa4,0x76,0x11,0x00,0x00,0x00,0x7d,0xf3,0x8f,0x77,0xc0,0xe3,0x21,0x00,
0x04,0xf6,0x59,0x00,0x00,0x00,0x94,0x71,0x00,0x11,0xff,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xc3,0xc6,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0xbe,0xfa,0xa9,0x3c,0x00,0x00,0x00,
0x00,0x00,0x00,0x37,0xa0,0xfa,0xa9,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x2b,0xdd,0x9d,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x45,0xf8,0x03,0x50,0xa5,0x01,0x00,0x00,0x00,0x37,0xfe,0x07,
0x1f,0xf0,0x9e,0x0e,0x00,0x2b,0xcf,0xb9,0x00,0x00,0x37,0xd5,0xfc,0xef,0xfe,0xb3,0x14,0x00,
0x00,0x00,0x02,0x6b,0xa7,0x13,0x00,0x00,0x00,0x00,0x00,0x00,0x5b,0xee,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xd5,0x73,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x5d,0x8a,0x6d,
0x0f,0x00,0x00,0xb4,0xd4,0x83,0xbc,0xdf,0x13,0x0d,0xff,0x29,0x00,0x02,0x54,0x13,0x01,0xe2,
0x89,0x06,0x00,0x00,0x00,0x00,0x32,0xd2,0xed,0x93,0x1e,0x00,0x00,0x00,0x01,0x3a,0xa9,0xef,
0x22,0x00,0x00,0x00,0x00,0x00,0xca,0x75,0x1a,0xd4,0x2e,0x00,0x16,0xe7,0x51,0x00,0x76,0xf5,
0xdb,0xf4,0x94,0x01,0x00,0x00,0x14,0xc5,0x3f,0x00,0x00,0x00,0x00,0x00,0xc8,0x83,0x00,0x00,
0x00,0x00,0x44,0xdf,0x25,0x00,0x00,0x00,0x00,0x08,0x0c,0x00,0x00,0x00,
  };
  static const struct {
    uint32_t ds;
    uint16_t width;
  } glinfo[]= {

{0,5}, {100,3}, {160,5}, {260,12}, 
{500,8}, {660,11}, {880,10}, {1080,3}, 
{1140,4}, {1220,4}, {1300,7}, {1440,7}, 
{1580,3}, {1640,7}, {1780,3}, {1840,8}, 
{2000,9}, {2180,9}, {2360,9}, {2540,9}, 
{2720,9}, {2900,9}, {3080,9}, {3260,9}, 
{3440,9}, {3620,9}, {3800,3}, {3860,3}, 
{3920,7}, {4060,7}, {4200,7}, {4340,8}, 
{4500,13}, {4760,10}, {4960,9}, {5140,10}, 
{5340,10}, {5540,9}, {5720,9}, {5900,11}, 
{6120,9}, {6300,3}, {6360,9}, {6540,10}, 
{6740,9}, {6920,12}, {7160,10}, {7360,10}, 
{7560,9}, {7740,11}, {7960,9}, {8140,9}, 
{8320,10}, {8520,10}, {8720,10}, {8920,12}, 
{9160,10}, {9360,9}, {9540,10}, {9740,5}, 
{9840,8}, {10000,5}, {10100,7}, {10240,10}, 
{10440,4}, {10520,8}, {10680,8}, {10840,7}, 
{10980,8}, {11140,8}, {11300,6}, {11420,8}, 
{11580,8}, {11740,3}, {11800,4}, {11880,8}, 
{12040,4}, {12120,12}, {12360,8}, {12520,8}, 
{12680,8}, {12840,9}, {13020,6}, {13140,7}, 
{13280,5}, {13380,8}, {13540,8}, {13700,11}, 
{13920,7}, {14060,8}, {14220,8}, {14380,6}, 
{14500,3}, {14560,6}, {14680,6}, {14800,10}, 
{15000,10}, {15200,10}, {15400,8}, {15560,8}, 
{15720,8}, {15880,11}, {16100,8}, {16260,3}, 
{16320,3}, {16380,9}, {16560,7}, 
  };
  // static const int nmap= sizeof(glmap)/sizeof(glmap[0]);
  int i,j,k,e,x,y,sX,eX;
  int W, X, *Xpos;
  char buf[20];
  int *map, *gl;
  int ngl;
  unsigned int C;
  int glyph_width;
  const unsigned char *glyph_data;
  unsigned char *data;

  map= alloca(L*sizeof(int));

  e= 0;
  ngl= 0;
  for(i=0;i<L;i++)
  {
    C= str[i];
    
    if (C&(1<<31)) { ngl+=2; e= 1; continue; }
    map[i]= font_hash(C);
    if (map[i]!=107) { ngl++; continue; }
    sprintf(buf,"%x",C); ngl+= strlen(buf); e= 1;
  }

  if (e) goto fix_encoding_errors;
  else gl= map;

encoding_errors_fixed:

  W= 0;
  for(i=0;i<ngl;i++) W+= glinfo[gl[i]].width;

  if (Rdata) data= malloc(W*20);
  X= 0;
  if (e && Rdata) Xpos= alloca(sizeof(int)*(ngl+1));
  for(i=0;i<ngl;i++)
  {
    if (e && Rdata) Xpos[i]= X;
    glyph_width= glinfo[gl[i]].width;
    if (Rdata) {
      glyph_data= font_data + glinfo[gl[i]].ds;
      for(y=0;y<20;y++)
         for(x=0;x<glyph_width;x++)
            data[y*W+X+x]= glyph_data[y*glyph_width+x];
    }
    X+= glyph_width;
  }
  if (e && Rdata) Xpos[i]= X;
  if (RW) *RW= W;
  if (RA) *RA= 16;
  if (RH) *RH= 20;
  if (Rdata) *Rdata= data;

  if (!e || !Rdata) return ;

  j= 0;
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sX= Xpos[j]; eX= Xpos[j+2];
      for(x=sX;x<eX;x++)
        for(y=0;y<20;y++)
          data[y*W + x] ^= 0xff;
      j+= 2;
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x",str[i]);
      sX= Xpos[j]; eX= Xpos[j+strlen(buf)];
      for(x=sX;x<eX;x++) {
        data[ 0*W + x]= 0xff;
        data[ (20-1)*W + x]= 0xff;
      }
      for(y=0;y<20;y++)
      {
        data[y*W+sX] = 0xff;
        data[y*W+eX-1] = 0xff;
      }
      j+= strlen(buf);
      continue;
    }
    j++;
  }
  return ;


fix_encoding_errors:
  j= 0;
  gl= alloca(sizeof(int)*ngl);
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sprintf(buf,"%02x", str[i]&0xff);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x", str[i]);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    gl[j++]= map[i];
  }
  goto encoding_errors_fixed;
}

static 
void font2_render
        (uint32_t *str, size_t L, 
        int *RW, int *RH, int *RA,
        unsigned char **Rdata)
{
  static const uint8_t font_data[]= {

0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xc4,0xd1,0x07,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xdb,0xe3,0x0b,0x00,
0x6c,0xcb,0x4c,0x00,0xf3,0xff,0xca,0x00,0x91,0xf3,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd3,0xe4,0x15,0xdd,0xdc,0x00,0x00,0xff,0xff,
0x28,0xff,0xff,0x00,0x00,0xff,0xff,0x28,0xff,0xff,0x00,0x00,0xe8,0xe8,0x1a,0xe6,0xe3,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x14,0xff,0xff,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,
0xff,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x00,0x00,0xec,0xec,0xed,0xff,0xff,0xec,0xff,0xff,0xed,0xec,0xec,0x00,0x00,0x00,
0x00,0x14,0xff,0xff,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xec,0xec,0xed,0xff,0xff,0xec,0xff,0xff,0xed,0xec,0xec,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x14,
0xff,0xff,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0xff,0xff,
0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x2c,0xfc,0x00,0x00,0x00,0x00,0x00,0x39,0xa8,0xd8,0xff,0xc7,0x48,0x00,0x00,0x69,0xff,
0xff,0xff,0xff,0xff,0xfc,0x3f,0x00,0xeb,0xff,0x84,0x43,0xfc,0x83,0x8d,0x2b,0x00,0xe7,0xff,
0x3b,0x2c,0xfc,0x00,0x00,0x00,0x00,0x8b,0xff,0xf8,0xc4,0xfc,0x02,0x00,0x00,0x00,0x06,0x8a,
0xfa,0xff,0xff,0xde,0x51,0x00,0x00,0x00,0x00,0x0e,0x6c,0xff,0xff,0xfe,0x57,0x00,0x00,0x00,
0x00,0x2c,0xfc,0x71,0xff,0xd1,0x06,0x60,0xa9,0x10,0x2c,0xfc,0x1f,0xff,0xf5,0x03,0xd6,0xff,
0xc9,0x62,0xfc,0x82,0xff,0xd5,0x00,0x2b,0xec,0xff,0xff,0xff,0xff,0xff,0x60,0x00,0x00,0x17,
0x95,0xdd,0xff,0xcb,0x5d,0x00,0x00,0x00,0x00,0x00,0x2c,0xfc,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0xba,0xf3,0xc0,0x23,
0x00,0x06,0x81,0x17,0x00,0x00,0x00,0xbc,0xff,0xfd,0xff,0xcc,0x00,0x6f,0xc5,0x00,0x00,0x00,
0x00,0xf3,0xff,0x43,0xff,0xff,0x15,0xea,0x3e,0x00,0x00,0x00,0x00,0xbf,0xff,0xfc,0xff,0xd1,
0x82,0xb6,0x00,0x00,0x00,0x00,0x00,0x20,0xbc,0xf4,0xc3,0x3e,0xf2,0x30,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x94,0xa7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x23,0xf5,
0x3c,0xb4,0xf3,0xc5,0x27,0x00,0x00,0x00,0x00,0x00,0xa7,0x98,0xa9,0xff,0xda,0xff,0xcf,0x00,
0x00,0x00,0x00,0x31,0xf4,0x1a,0xe0,0xff,0x3a,0xff,0xff,0x08,0x00,0x00,0x00,0xb9,0x89,0x00,
0xab,0xff,0xfd,0xff,0xd2,0x00,0x00,0x00,0x0f,0x7b,0x11,0x00,0x18,0xb6,0xf3,0xc7,0x29,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x9a,0xe9,0xee,0x8f,0x04,0x00,0x00,0x00,
0x00,0x00,0xad,0xff,0xfb,0xfe,0xff,0x82,0x00,0x00,0x00,0x00,0x06,0xfa,0xff,0x26,0x33,0x69,
0x12,0x00,0x00,0x00,0x00,0x03,0xf6,0xff,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7f,
0xff,0xff,0xff,0x18,0x00,0x00,0x00,0x00,0x00,0x0e,0xbf,0xff,0xf9,0xec,0x16,0x00,0x00,0x00,
0x00,0x00,0x95,0xff,0xb0,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe5,0xff,0x2f,0x00,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0xf8,0xff,0x23,0x00,0xec,0xf6,0xff,0xf8,0xec,0x00,0x00,0xcb,
0xff,0x9f,0x06,0x0c,0xc1,0xff,0x8a,0x00,0x00,0x00,0x43,0xfb,0xff,0xf9,0xfc,0xff,0xee,0x20,
0x00,0x00,0x00,0x00,0x3c,0xbd,0xf4,0xea,0xae,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xd3,0xe4,0x0b,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,
0xe8,0xe8,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xfe,0xe6,0x0e,0x00,0x02,0xd9,
0xff,0x5c,0x00,0x00,0x4c,0xff,0xe4,0x04,0x00,0x00,0x9c,0xff,0x8c,0x00,0x00,0x00,0xd4,0xff,
0x4f,0x00,0x00,0x00,0xef,0xff,0x29,0x00,0x00,0x00,0xfc,0xff,0x19,0x00,0x00,0x00,0xf1,0xff,
0x28,0x00,0x00,0x00,0xd8,0xff,0x4c,0x00,0x00,0x00,0xa5,0xff,0x8c,0x00,0x00,0x00,0x55,0xff,
0xe4,0x04,0x00,0x00,0x04,0xde,0xff,0x5c,0x00,0x00,0x00,0x42,0xfe,0xe6,0x0e,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xdc,0xff,0x4b,0x00,0x00,0x00,0x51,0xff,
0xe3,0x06,0x00,0x00,0x02,0xdf,0xff,0x5b,0x00,0x00,0x00,0x83,0xff,0xad,0x00,0x00,0x00,0x41,
0xff,0xe6,0x00,0x00,0x00,0x18,0xff,0xfe,0x02,0x00,0x00,0x06,0xff,0xff,0x0f,0x00,0x00,0x17,
0xff,0xfe,0x03,0x00,0x00,0x3e,0xff,0xe7,0x00,0x00,0x00,0x80,0xff,0xb1,0x00,0x00,0x01,0xdb,
0xff,0x5f,0x00,0x00,0x4d,0xff,0xe6,0x08,0x00,0x07,0xdb,0xff,0x4d,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x6c,0x10,
0x0c,0x6c,0x18,0x00,0x00,0x00,0x00,0x70,0xff,0x8b,0x85,0xff,0x7d,0x00,0x00,0x00,0x00,0x06,
0xcc,0xf8,0xf5,0xd3,0x08,0x00,0x00,0x00,0xc9,0xec,0xf4,0xff,0xff,0xf5,0xec,0xc3,0x00,0x00,
0xd7,0xff,0xff,0xff,0xff,0xff,0xff,0xdd,0x00,0x00,0x00,0x02,0xc4,0xf9,0xfb,0xbf,0x02,0x00,
0x00,0x00,0x00,0x69,0xff,0x8c,0x93,0xff,0x65,0x00,0x00,0x00,0x00,0x23,0x7c,0x0e,0x10,0x7d,
0x23,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xec,0xec,0xff,0xff,0xed,0xec,0xec,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xf3,0x71,0x00,0xf3,0xff,0xc9,0x00,0x5f,0xff,0x85,
0x00,0x2f,0xd3,0x0e,0x00,0x00,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xec,0xec,0xec,0xec,0xec,0xec,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x6c,0xcb,0x4c,0x00,0xf3,0xff,0xca,0x00,0x91,0xf3,0x6d,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x7d,0x80,0x1a,0x00,0x00,0x00,0x00,0x00,0x58,0xff,0xe0,0x02,0x00,0x00,0x00,0x00,0x00,0xc7,
0xff,0x77,0x00,0x00,0x00,0x00,0x00,0x36,0xff,0xf7,0x13,0x00,0x00,0x00,0x00,0x00,0xa6,0xff,
0x9f,0x00,0x00,0x00,0x00,0x00,0x1a,0xfa,0xff,0x33,0x00,0x00,0x00,0x00,0x00,0x84,0xff,0xc6,
0x00,0x00,0x00,0x00,0x00,0x08,0xeb,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x63,0xff,0xe8,0x06,
0x00,0x00,0x00,0x00,0x00,0xd2,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x42,0xff,0xfb,0x1a,0x00,
0x00,0x00,0x00,0x00,0xb1,0xff,0xaa,0x00,0x00,0x00,0x00,0x00,0x22,0xfd,0xff,0x3e,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x16,0xa3,0xef,0xf3,0xb3,0x24,0x00,0x00,0x00,0x07,0xd2,0xff,0xfd,0xfb,0xff,0xe4,0x13,
0x00,0x00,0x6a,0xff,0xc2,0x11,0x09,0xa6,0xff,0x83,0x00,0x00,0xbe,0xff,0x48,0x00,0x00,0x30,
0xff,0xd3,0x00,0x00,0xea,0xff,0x21,0x00,0x00,0x0e,0xff,0xfb,0x03,0x00,0xfb,0xff,0x15,0x00,
0x00,0x02,0xff,0xff,0x0f,0x00,0xf4,0xff,0x19,0x00,0x00,0x04,0xff,0xff,0x07,0x00,0xdd,0xff,
0x28,0x00,0x00,0x17,0xff,0xef,0x00,0x00,0xa7,0xff,0x57,0x00,0x00,0x49,0xff,0xb7,0x00,0x00,
0x4e,0xff,0xc9,0x12,0x09,0xb9,0xff,0x5d,0x00,0x00,0x01,0xbb,0xff,0xfd,0xf9,0xff,0xc5,0x04,
0x00,0x00,0x00,0x0e,0x96,0xe9,0xeb,0x9d,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x89,0xff,0xff,0x14,
0x00,0x00,0x00,0x00,0x04,0xa2,0xff,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x03,0x10,0x10,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0x9f,0xe7,0xf4,0xc4,0x50,0x00,0x00,0x00,0x24,0xe7,
0xff,0xfd,0xf7,0xff,0xff,0x61,0x00,0x00,0x85,0xff,0xd0,0x17,0x02,0x84,0xff,0xd5,0x00,0x00,
0x00,0x1c,0x22,0x00,0x00,0x20,0xff,0xfa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5a,0xff,0xe7,
0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0xee,0xff,0x8e,0x00,0x00,0x00,0x00,0x06,0x87,0xfd,0xff,
0xbf,0x09,0x00,0x00,0x00,0x1a,0xcb,0xff,0xff,0x93,0x06,0x00,0x00,0x00,0x0e,0xd5,0xff,0xf1,
0x4d,0x00,0x00,0x00,0x00,0x00,0x87,0xff,0xf6,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0xd8,0xff,
0xfb,0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x68,0xd9,0xf7,0xdb,0x7e,0x07,0x00,0x00,0x00,0x64,0xff,0xff,0xf6,0xff,0xff,0x9c,0x00,
0x00,0x00,0x4c,0x9d,0x76,0x00,0x5e,0xff,0xf8,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0xff,
0xfb,0x07,0x00,0x00,0x00,0x00,0x00,0x04,0x7a,0xff,0xbe,0x00,0x00,0x00,0x00,0x00,0x80,0xff,
0xff,0xff,0x71,0x00,0x00,0x00,0x00,0x00,0x76,0xec,0xfc,0xff,0xfe,0x54,0x00,0x00,0x00,0x00,
0x00,0x00,0x0d,0xa1,0xff,0xd5,0x00,0x00,0x00,0x1d,0x00,0x00,0x00,0x23,0xff,0xf7,0x00,0x1d,
0xe6,0xff,0x6f,0x04,0x07,0x92,0xff,0xc7,0x00,0x00,0x93,0xff,0xff,0xf8,0xfb,0xff,0xf7,0x30,
0x00,0x00,0x00,0x68,0xd1,0xf8,0xf0,0xae,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xff,
0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0xfe,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x07,0xd8,
0xfd,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x86,0xff,0x91,0xff,0xff,0x00,0x00,0x00,0x00,0x31,
0xfb,0xd0,0x19,0xff,0xff,0x00,0x00,0x00,0x04,0xce,0xfb,0x32,0x14,0xff,0xff,0x00,0x00,0x00,
0x79,0xff,0x87,0x00,0x14,0xff,0xff,0x00,0x00,0x00,0xf8,0xff,0xf6,0xf4,0xf4,0xff,0xff,0xf4,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,
0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x14,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa6,0xff,0xff,0xff,0xff,0xff,0x0c,0x00,0x00,0x00,0xd3,
0xff,0xf0,0xec,0xec,0xec,0x0b,0x00,0x00,0x05,0xfa,0xff,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,
0x2c,0xff,0xe6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x59,0xff,0xf7,0xf6,0xef,0xb4,0x33,0x00,
0x00,0x00,0x60,0xf7,0xff,0xfa,0xfc,0xff,0xf9,0x3a,0x00,0x00,0x00,0x0e,0x4b,0x06,0x0b,0xab,
0xff,0xc7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xff,0xfd,0x06,0x08,0x4a,0x76,0x0d,0x00,
0x00,0x16,0xff,0xfd,0x06,0x07,0xea,0xff,0xa2,0x09,0x09,0xa2,0xff,0xc5,0x00,0x00,0x50,0xfb,
0xff,0xfa,0xfb,0xff,0xf9,0x39,0x00,0x00,0x00,0x3d,0xb9,0xee,0xf1,0xb6,0x33,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xa3,0xff,0xdd,0x08,0x00,0x00,0x00,0x00,0x00,0x2c,0xfd,0xff,0x4a,0x00,0x00,
0x00,0x00,0x00,0x00,0xb0,0xff,0xae,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xff,0xf4,0x1e,0x00,
0x00,0x00,0x00,0x00,0x00,0xbe,0xff,0xfd,0xf3,0xc2,0x3d,0x00,0x00,0x00,0x47,0xff,0xff,0xff,
0xff,0xff,0xfa,0x38,0x00,0x00,0xb0,0xff,0xbe,0x1b,0x1f,0xc1,0xff,0xb9,0x00,0x00,0xe6,0xff,
0x2f,0x00,0x00,0x32,0xff,0xf2,0x00,0x00,0xf6,0xff,0x29,0x00,0x00,0x2a,0xff,0xf3,0x00,0x00,
0xc1,0xff,0xaf,0x0c,0x0d,0xb3,0xff,0xa9,0x00,0x00,0x37,0xf8,0xff,0xfb,0xfc,0xff,0xed,0x1b,
0x00,0x00,0x00,0x31,0xb5,0xf1,0xf0,0xab,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x86,0x00,0xec,0xec,0xec,0xec,0xec,0xff,0xff,0xf1,0x12,0x00,0x00,0x00,0x00,0x00,
0x4a,0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0xc9,0xff,0xef,0x10,0x00,0x00,0x00,0x00,
0x00,0x49,0xff,0xff,0x7d,0x00,0x00,0x00,0x00,0x00,0x00,0xc8,0xff,0xed,0x0d,0x00,0x00,0x00,
0x00,0x00,0x47,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0xc6,0xff,0xea,0x0b,0x00,0x00,
0x00,0x00,0x00,0x46,0xff,0xff,0x74,0x00,0x00,0x00,0x00,0x00,0x00,0xc5,0xff,0xe7,0x09,0x00,
0x00,0x00,0x00,0x00,0x45,0xff,0xff,0x6f,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0xff,0xe4,0x08,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x85,0xdd,0xf6,0xda,0x7e,0x07,0x00,0x00,0x00,0xa5,
0xff,0xff,0xf4,0xff,0xff,0x9e,0x00,0x00,0x06,0xf9,0xff,0x3d,0x00,0x3d,0xff,0xf8,0x05,0x00,
0x03,0xf6,0xff,0x38,0x00,0x3a,0xff,0xf8,0x05,0x00,0x00,0x80,0xff,0xff,0xf2,0xff,0xff,0x85,
0x00,0x00,0x09,0xb6,0xff,0xff,0xff,0xff,0xff,0xb6,0x09,0x00,0x8b,0xff,0xca,0x31,0x0a,0x3c,
0xd8,0xff,0x8d,0x00,0xe7,0xff,0x32,0x00,0x00,0x00,0x39,0xff,0xe7,0x00,0xf6,0xff,0x2c,0x00,
0x00,0x00,0x2d,0xff,0xf5,0x00,0xbe,0xff,0xbd,0x1d,0x00,0x1f,0xc0,0xff,0xbd,0x00,0x35,0xf6,
0xff,0xff,0xf4,0xff,0xff,0xf3,0x33,0x00,0x00,0x2d,0xab,0xea,0xfb,0xe6,0x9b,0x21,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x35,0xb4,0xf2,0xf0,0xb4,0x2f,0x00,0x00,0x00,0x35,0xf9,0xff,0xfb,0xfa,0xff,0xf7,0x33,
0x00,0x00,0xcc,0xff,0x95,0x07,0x07,0x94,0xff,0xbd,0x00,0x00,0xf9,0xff,0x22,0x00,0x00,0x22,
0xff,0xf5,0x00,0x00,0xd6,0xff,0x96,0x08,0x06,0x93,0xff,0xe5,0x00,0x00,0x5b,0xff,0xff,0xfb,
0xfa,0xff,0xff,0xaf,0x00,0x00,0x00,0x4a,0xc7,0xf2,0xfe,0xff,0xff,0x44,0x00,0x00,0x00,0x00,
0x00,0x10,0xf0,0xff,0xbd,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0xff,0xff,0x35,0x00,0x00,0x00,
0x00,0x00,0x0d,0xed,0xff,0xaf,0x00,0x00,0x00,0x00,0x00,0x00,0x78,0xff,0xfd,0x2b,0x00,0x00,
0x00,0x00,0x00,0x0a,0xea,0xff,0xa3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xf3,0x6b,0x00,0xf3,0xff,
0xcb,0x00,0x6d,0xcb,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x6c,0xcb,0x4c,0x00,0xf3,0xff,0xca,0x00,0x91,0xf3,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xf3,0x6a,0x00,0xf3,0xff,0xcb,0x00,0x6d,0xcb,0x4f,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0x9b,0x34,0x00,0xef,0xff,
0xc7,0x00,0xac,0xff,0xa6,0x00,0x1c,0xf7,0x2d,0x00,0x12,0x38,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x82,0xff,0xfd,0x40,0x00,0x00,0x38,0xfc,0xff,0x8c,0x00,0x00,0x0c,0xdc,0xff,0xd2,0x07,
0x00,0x00,0x9c,0xff,0xf9,0x2e,0x00,0x00,0x4e,0xff,0xff,0x76,0x00,0x00,0x00,0x41,0xfe,0xff,
0x7a,0x00,0x00,0x00,0x00,0x90,0xff,0xfa,0x30,0x00,0x00,0x00,0x08,0xd7,0xff,0xd3,0x07,0x00,
0x00,0x00,0x34,0xfb,0xff,0x8b,0x00,0x00,0x00,0x00,0x80,0xff,0xfd,0x3d,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xec,0xec,
0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xec,0xec,0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xfb,0xff,0x9d,0x00,0x00,0x00,0x00,
0x7e,0xff,0xff,0x4f,0x00,0x00,0x00,0x03,0xc6,0xff,0xea,0x16,0x00,0x00,0x00,0x22,0xf2,0xff,
0xb2,0x00,0x00,0x00,0x00,0x60,0xff,0xff,0x64,0x00,0x00,0x00,0x6b,0xff,0xff,0x52,0x00,0x00,
0x26,0xf5,0xff,0xa4,0x00,0x00,0x04,0xca,0xff,0xe5,0x11,0x00,0x00,0x81,0xff,0xff,0x48,0x00,
0x00,0x36,0xfb,0xff,0x9a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x9c,0xe4,0xf6,0xcd,0x67,0x01,0x00,
0x07,0xcf,0xff,0xff,0xf6,0xff,0xff,0x8b,0x00,0x4e,0xff,0xf7,0x33,0x00,0x54,0xff,0xf4,0x02,
0x03,0x23,0x36,0x00,0x00,0x1c,0xff,0xfa,0x05,0x00,0x00,0x00,0x00,0x15,0xc2,0xff,0xb1,0x00,
0x00,0x00,0x00,0x3b,0xe8,0xff,0xc5,0x13,0x00,0x00,0x00,0x00,0xe2,0xff,0x97,0x04,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x19,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0x60,0x07,0x00,0x00,0x00,
0x00,0x00,0x00,0x6c,0xcb,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xf3,0xff,0xca,0x00,0x00,0x00,
0x00,0x00,0x00,0x8e,0xf3,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0xaa,
0xe5,0xf9,0xea,0xb7,0x5f,0x05,0x00,0x00,0x00,0x00,0x00,0x0f,0xb2,0xff,0xff,0xff,0xf2,0xfe,
0xff,0xff,0xd0,0x21,0x00,0x00,0x00,0x02,0xc0,0xff,0xf3,0x77,0x13,0x00,0x09,0x55,0xdd,0xff,
0xdb,0x0c,0x00,0x00,0x63,0xff,0xf4,0x2c,0x66,0xd2,0xf5,0xdb,0x76,0x13,0xd6,0xff,0x82,0x00,
0x00,0xc5,0xff,0x71,0x88,0xff,0xff,0xf4,0xff,0xff,0x8b,0x4b,0xff,0xe1,0x00,0x00,0xf2,0xff,
0x23,0xf1,0xff,0x53,0x00,0x4a,0xff,0xee,0x0e,0xff,0xff,0x09,0x00,0xf2,0xff,0x24,0xe7,0xff,
0x68,0x08,0x67,0xff,0xff,0x51,0xff,0xf6,0x02,0x00,0xc5,0xff,0x72,0x6c,0xff,0xff,0xff,0xff,
0xe8,0xf4,0xff,0xff,0x9b,0x00,0x00,0x65,0xff,0xf0,0x2f,0x4e,0xbf,0xe3,0xbf,0x31,0x58,0xdd,
0xa0,0x0b,0x00,0x00,0x03,0xc2,0xff,0xf8,0x87,0x1c,0x00,0x03,0x24,0x60,0x02,0x00,0x00,0x00,
0x00,0x00,0x10,0xb5,0xff,0xff,0xff,0xf4,0xfb,0xff,0xef,0x27,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x49,0xaa,0xe5,0xfa,0xe8,0xa0,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xae,0xff,0xff,0x46,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x11,0xf9,0xff,0xff,0xa2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xff,0xfb,
0xff,0xf4,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0xc3,0xff,0x94,0xec,0xff,0x5c,0x00,0x00,0x00,
0x00,0x00,0x21,0xfe,0xff,0x38,0x9a,0xff,0xb8,0x00,0x00,0x00,0x00,0x00,0x7c,0xff,0xdf,0x00,
0x43,0xff,0xfc,0x18,0x00,0x00,0x00,0x00,0xd8,0xff,0x88,0x00,0x03,0xe8,0xff,0x72,0x00,0x00,
0x00,0x35,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xce,0x00,0x00,0x00,0x91,0xff,0xfe,0xf4,0xf4,
0xf4,0xf7,0xff,0xff,0x2b,0x00,0x04,0xe9,0xff,0xac,0x00,0x00,0x00,0x18,0xfc,0xff,0x88,0x00,
0x4a,0xff,0xff,0x4d,0x00,0x00,0x00,0x00,0xb6,0xff,0xe2,0x01,0xa6,0xff,0xea,0x04,0x00,0x00,
0x00,0x00,0x57,0xff,0xff,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xfe,0xec,0xbe,0x56,0x00,0x00,0x00,0x00,0xff,0xff,0xed,0xee,0xfe,
0xff,0xff,0x6a,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x0b,0x93,0xff,0xe1,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x23,0xff,0xf8,0x00,0x00,0x00,0xff,0xff,0x14,0x01,0x1c,0xa0,0xff,0xc0,
0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x2b,0x00,0x00,0x00,0xff,0xff,0xed,0xec,
0xf2,0xff,0xff,0xe3,0x27,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x13,0x97,0xff,0xbb,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x24,0xff,0xf4,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x12,0x97,
0xff,0xd3,0x00,0x00,0xff,0xff,0xed,0xec,0xf2,0xff,0xff,0xfd,0x4d,0x00,0x00,0xff,0xff,0xff,
0xff,0xfe,0xed,0xb7,0x45,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x4f,0xc2,0xf4,0xf4,0xb8,0x3a,0x00,0x00,0x00,0x00,0x00,0x6f,
0xff,0xff,0xf6,0xfd,0xff,0xfd,0x5a,0x00,0x00,0x00,0x28,0xf8,0xfa,0x61,0x02,0x14,0xbd,0xff,
0xf6,0x1e,0x00,0x00,0x8e,0xff,0x96,0x00,0x00,0x00,0x10,0xf5,0xff,0x81,0x00,0x00,0xd7,0xff,
0x3f,0x00,0x00,0x00,0x00,0x13,0x18,0x0f,0x00,0x00,0xf4,0xff,0x1c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xf4,0xff,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd9,0xff,
0x3e,0x00,0x00,0x00,0x00,0x0c,0x10,0x0a,0x00,0x00,0x90,0xff,0x94,0x00,0x00,0x00,0x0f,0xf3,
0xff,0x84,0x00,0x00,0x29,0xf9,0xfa,0x60,0x06,0x14,0xb7,0xff,0xf7,0x22,0x00,0x00,0x00,0x72,
0xff,0xff,0xf9,0xfe,0xff,0xfe,0x60,0x00,0x00,0x00,0x00,0x00,0x52,0xc5,0xf5,0xeb,0xb8,0x3e,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xea,0xb1,0x36,0x00,0x00,0x00,0x00,0xff,0xff,0xed,0xf1,0xff,0xff,0xfb,0x5d,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x1d,0xa5,0xff,0xf7,0x26,0x00,0x00,0xff,0xff,0x14,0x00,
0x00,0x01,0xc5,0xff,0x94,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x4d,0xff,0xdb,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x22,0xff,0xf7,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x2d,
0xff,0xee,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x5a,0xff,0xcd,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x02,0xd0,0xff,0x82,0x00,0x00,0xff,0xff,0x14,0x00,0x1e,0xaa,0xff,0xf0,0x18,0x00,
0x00,0xff,0xff,0xed,0xf0,0xff,0xff,0xf8,0x4f,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xe9,0xaf,
0x31,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
0x00,0xff,0xff,0xed,0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0xff,0xff,0xed,
0xec,0xec,0xec,0xec,0x76,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xed,0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xed,0xec,0xec,
0xec,0xec,0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0xff,0xff,0xed,0xec,0xec,0xec,0xec,0x76,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4a,0xbb,0xf0,0xf5,0xc9,0x5a,0x00,0x00,0x00,
0x00,0x00,0x70,0xff,0xff,0xfb,0xfa,0xff,0xff,0x85,0x00,0x00,0x00,0x2f,0xfa,0xff,0x86,0x08,
0x0b,0x87,0xc2,0x7b,0x02,0x00,0x00,0x98,0xff,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xdc,0xff,0x45,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0xff,0x1e,0x00,0x00,
0xec,0xec,0xec,0xec,0xec,0x00,0x00,0xee,0xff,0x27,0x00,0x00,0xff,0xff,0xff,0xff,0xfa,0x00,
0x00,0xce,0xff,0x55,0x00,0x00,0x00,0x00,0x6f,0xff,0xe4,0x00,0x00,0x81,0xff,0xbc,0x00,0x00,
0x00,0x00,0xae,0xff,0xaa,0x00,0x00,0x1e,0xf2,0xff,0x91,0x08,0x07,0x67,0xfe,0xff,0x48,0x00,
0x00,0x00,0x5b,0xfd,0xff,0xfa,0xfb,0xff,0xff,0x9b,0x00,0x00,0x00,0x00,0x00,0x3d,0xb5,0xef,
0xf8,0xd2,0x6e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x14,0x00,0xff,0xff,0xed,0xec,0xec,0xec,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,
0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,
0x00,0xf5,0xff,0x1f,0x00,0x00,0x0b,0xff,0xff,0x0a,0x00,0xd9,0xff,0x46,0x00,0x00,0x37,0xff,
0xed,0x00,0x00,0x8e,0xff,0xc2,0x10,0x0a,0xbb,0xff,0xa5,0x00,0x00,0x19,0xe9,0xff,0xfd,0xf9,
0xff,0xf1,0x26,0x00,0x00,0x00,0x25,0xb0,0xf3,0xf0,0xb6,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x0b,0xcc,0xff,0xdc,0x15,0x00,0xff,0xff,0x14,0x00,0x03,
0xb5,0xff,0xed,0x26,0x00,0x00,0xff,0xff,0x14,0x00,0x9a,0xff,0xf9,0x3e,0x00,0x00,0x00,0xff,
0xff,0x14,0x7b,0xff,0xff,0x5b,0x00,0x00,0x00,0x00,0xff,0xff,0x71,0xff,0xff,0x7d,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xfd,0xff,0xee,0x0a,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xfe,0xfb,
0xff,0x9b,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x73,0x73,0xff,0xff,0x54,0x00,0x00,0x00,0x00,
0xff,0xff,0x14,0x01,0xb7,0xff,0xef,0x1f,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x16,0xe7,0xff,
0xc5,0x04,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x45,0xfe,0xff,0x84,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0x89,0xff,0xfd,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xf8,0xf8,0xf8,0xf8,0xf8,0xf8,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xfb,0x16,0x00,0x00,0x00,0x00,0x14,0xfa,
0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x6f,0x00,0x00,0x00,0x00,0x6e,0xff,0xff,0xff,0x00,0x00,
0xff,0xff,0xff,0xcc,0x00,0x00,0x00,0x00,0xcd,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,
0x29,0x00,0x00,0x2b,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xdb,0xff,0x86,0x00,0x00,0x8a,
0xff,0xda,0xff,0xff,0x00,0x00,0xff,0xff,0x84,0xff,0xe1,0x01,0x03,0xe5,0xff,0x81,0xff,0xff,
0x00,0x00,0xff,0xff,0x2f,0xfd,0xff,0x41,0x47,0xff,0xfc,0x2b,0xff,0xff,0x00,0x00,0xff,0xff,
0x14,0xc1,0xff,0x9e,0xa6,0xff,0xbb,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x6a,0xff,0xf2,
0xf6,0xff,0x62,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x16,0xfc,0xff,0xff,0xf9,0x10,0x14,
0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0xbb,0xff,0xff,0xb0,0x00,0x14,0xff,0xff,0x00,0x00,
0xff,0xff,0x14,0x00,0x64,0xff,0xff,0x58,0x00,0x14,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x56,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0xe8,0x11,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0xff,0xff,0xff,0x9f,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0xff,0xff,
0x43,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0xaf,0xff,0xdd,0x0a,0x00,0xff,0xff,0x14,0x00,
0xff,0xff,0x26,0xea,0xff,0x8d,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x5e,0xff,0xfc,0x34,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xbf,0xff,0xd1,0xff,0xff,0x14,0x00,0xff,0xff,0x14,
0x00,0x28,0xf9,0xff,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x84,0xff,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0x08,0xdd,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x47,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x49,0xbd,0xf2,0xf4,0xc5,0x57,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0xf9,
0xf8,0xff,0xff,0x7f,0x00,0x00,0x00,0x24,0xf6,0xfe,0x74,0x06,0x02,0x5a,0xf8,0xfc,0x33,0x00,
0x00,0x8a,0xff,0xa1,0x00,0x00,0x00,0x00,0x87,0xff,0x9d,0x00,0x00,0xd4,0xff,0x45,0x00,0x00,
0x00,0x00,0x2f,0xff,0xe7,0x00,0x00,0xf3,0xff,0x1e,0x00,0x00,0x00,0x00,0x0d,0xff,0xff,0x06,
0x00,0xf3,0xff,0x1d,0x00,0x00,0x00,0x00,0x0a,0xff,0xff,0x07,0x00,0xd5,0xff,0x43,0x00,0x00,
0x00,0x00,0x2e,0xff,0xe8,0x00,0x00,0x8c,0xff,0xa0,0x00,0x00,0x00,0x00,0x88,0xff,0x9f,0x00,
0x00,0x26,0xf7,0xfe,0x72,0x0a,0x07,0x61,0xf9,0xfc,0x35,0x00,0x00,0x00,0x6b,0xff,0xff,0xfc,
0xfb,0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x4c,0xc1,0xf3,0xf5,0xc8,0x5b,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xfc,0xe6,0xb3,0x47,0x00,0x00,
0x00,0xff,0xff,0xed,0xec,0xfb,0xff,0xff,0x69,0x00,0x00,0xff,0xff,0x14,0x00,0x04,0x73,0xff,
0xe5,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x0e,0xff,0xff,0x09,0x00,0xff,0xff,0x14,0x00,0x04,
0x73,0xff,0xe6,0x00,0x00,0xff,0xff,0xed,0xec,0xfa,0xff,0xff,0x6b,0x00,0x00,0xff,0xff,0xff,
0xfc,0xe5,0xb4,0x48,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x46,0xba,0xf1,
0xf6,0xca,0x61,0x00,0x00,0x00,0x00,0x00,0x69,0xff,0xff,0xfa,0xf9,0xff,0xff,0x8e,0x00,0x00,
0x00,0x25,0xf6,0xfb,0x65,0x05,0x03,0x61,0xfa,0xff,0x43,0x00,0x00,0x8f,0xff,0x94,0x00,0x00,
0x00,0x00,0x7f,0xff,0xad,0x00,0x00,0xda,0xff,0x3b,0x00,0x00,0x00,0x00,0x27,0xff,0xf0,0x00,
0x00,0xf7,0xff,0x1c,0x00,0x00,0x00,0x00,0x07,0xff,0xff,0x0a,0x00,0xed,0xff,0x1d,0x00,0x00,
0x00,0x00,0x11,0xff,0xff,0x09,0x00,0xcc,0xff,0x47,0x00,0x00,0x22,0x59,0x35,0xff,0xe8,0x00,
0x00,0x7a,0xff,0xa7,0x00,0x0c,0xd8,0xff,0xe1,0xff,0xa7,0x00,0x00,0x17,0xec,0xff,0x77,0x08,
0x5d,0xfa,0xff,0xff,0x53,0x00,0x00,0x00,0x50,0xfc,0xff,0xfb,0xf7,0xff,0xff,0xff,0xe4,0x07,
0x00,0x00,0x00,0x39,0xb5,0xf0,0xf9,0xd2,0x6e,0x7c,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xfc,0xe3,0xaf,0x45,0x00,0x00,0x00,0xff,0xff,0xed,0xec,0xfb,
0xff,0xff,0x69,0x00,0x00,0xff,0xff,0x14,0x00,0x04,0x74,0xff,0xe6,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x0e,0xff,0xff,0x0a,0x00,0xff,0xff,0x14,0x00,0x03,0x71,0xff,0xea,0x00,0x00,0xff,
0xff,0xed,0xec,0xfa,0xff,0xff,0x6c,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xec,0x4b,0x00,0x00,
0x00,0xff,0xff,0x14,0x53,0xff,0xfe,0x2f,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xc4,0xff,0xb4,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x38,0xff,0xff,0x39,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0xa9,0xff,0xbe,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x21,0xf9,0xff,0x45,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x56,0xc2,
0xef,0xed,0xb4,0x34,0x00,0x00,0x00,0x75,0xff,0xff,0xf7,0xfd,0xff,0xf7,0x3d,0x00,0x00,0xe6,
0xff,0x68,0x01,0x0c,0x93,0xae,0x5a,0x00,0x00,0xf1,0xff,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xa5,0xff,0xf1,0x82,0x1e,0x00,0x00,0x00,0x00,0x00,0x0c,0xa0,0xfe,0xff,0xfe,0xb8,0x32,
0x00,0x00,0x00,0x00,0x00,0x26,0x89,0xe7,0xff,0xfb,0x51,0x00,0x00,0x00,0x00,0x00,0x00,0x06,
0x91,0xff,0xdf,0x00,0x2b,0x93,0x95,0x00,0x00,0x00,0x10,0xff,0xff,0x0b,0x1e,0xfe,0xff,0x79,
0x04,0x03,0x75,0xff,0xed,0x01,0x00,0x7b,0xff,0xff,0xfa,0xf9,0xff,0xff,0x6c,0x00,0x00,0x00,
0x51,0xc3,0xef,0xec,0xbe,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xec,0xec,0xec,0xec,0xff,
0xff,0xed,0xec,0xec,0xec,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,
0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,
0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,
0x00,0xf5,0xff,0x22,0x00,0x00,0x00,0x1f,0xff,0xf4,0x00,0x00,0xd3,0xff,0x5b,0x00,0x00,0x00,
0x5a,0xff,0xd3,0x00,0x00,0x82,0xff,0xe1,0x2a,0x00,0x30,0xe0,0xff,0x82,0x00,0x00,0x0c,0xd7,
0xff,0xff,0xf5,0xff,0xff,0xd6,0x0c,0x00,0x00,0x00,0x11,0x8f,0xe0,0xf8,0xe0,0x8e,0x10,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x46,0xff,0xff,0x20,0x00,0x00,0x00,0x3d,
0xff,0xfd,0x15,0x07,0xf3,0xff,0x68,0x00,0x00,0x00,0x87,0xff,0xc9,0x00,0x00,0xaf,0xff,0xb0,
0x00,0x00,0x00,0xd1,0xff,0x7f,0x00,0x00,0x63,0xff,0xf3,0x05,0x00,0x1b,0xff,0xff,0x35,0x00,
0x00,0x19,0xfe,0xff,0x41,0x00,0x65,0xff,0xe9,0x01,0x00,0x00,0x00,0xcc,0xff,0x8a,0x00,0xaf,
0xff,0xa1,0x00,0x00,0x00,0x00,0x80,0xff,0xd2,0x06,0xf2,0xff,0x57,0x00,0x00,0x00,0x00,0x35,
0xff,0xff,0x5e,0xff,0xfc,0x10,0x00,0x00,0x00,0x00,0x01,0xe7,0xff,0xe4,0xff,0xc3,0x00,0x00,
0x00,0x00,0x00,0x00,0x9d,0xff,0xff,0xff,0x79,0x00,0x00,0x00,0x00,0x00,0x00,0x52,0xff,0xff,
0xff,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xf9,0xff,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x4f,0xff,0xed,0x00,0x00,0xac,0xff,0xff,0x20,0x00,0x7d,0xff,0xbf,0x00,
0x25,0xff,0xff,0x0f,0x00,0xdd,0xff,0xff,0x50,0x00,0x9f,0xff,0x95,0x00,0x03,0xf7,0xff,0x31,
0x0e,0xfe,0xff,0xff,0x80,0x00,0xc1,0xff,0x6b,0x00,0x00,0xd0,0xff,0x54,0x3e,0xff,0xff,0xff,
0xb1,0x00,0xe3,0xff,0x41,0x00,0x00,0xa6,0xff,0x76,0x6f,0xff,0xce,0xff,0xe1,0x06,0xfd,0xff,
0x17,0x00,0x00,0x7b,0xff,0x99,0xa0,0xff,0x75,0xfa,0xff,0x37,0xff,0xed,0x00,0x00,0x00,0x51,
0xff,0xbb,0xd0,0xff,0x41,0xd0,0xff,0x8a,0xff,0xc3,0x00,0x00,0x00,0x27,0xff,0xe4,0xfa,0xff,
0x12,0xa1,0xff,0xdb,0xff,0x99,0x00,0x00,0x00,0x03,0xf8,0xff,0xff,0xe3,0x00,0x72,0xff,0xff,
0xff,0x6f,0x00,0x00,0x00,0x00,0xd2,0xff,0xff,0xb4,0x00,0x42,0xff,0xff,0xff,0x45,0x00,0x00,
0x00,0x00,0xa8,0xff,0xff,0x85,0x00,0x13,0xff,0xff,0xff,0x1b,0x00,0x00,0x00,0x00,0x7d,0xff,
0xff,0x57,0x00,0x00,0xe4,0xff,0xf0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0xfa,0xff,0xa5,0x00,
0x00,0x00,0xa5,0xff,0xfa,0x2b,0x00,0x89,0xff,0xfe,0x31,0x00,0x32,0xfe,0xff,0x8a,0x00,0x00,
0x0b,0xe3,0xff,0xba,0x00,0xbb,0xff,0xe3,0x0c,0x00,0x00,0x00,0x54,0xff,0xff,0x8a,0xff,0xff,
0x54,0x00,0x00,0x00,0x00,0x00,0xb9,0xff,0xff,0xff,0xb9,0x00,0x00,0x00,0x00,0x00,0x00,0x25,
0xf9,0xff,0xf9,0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x29,0xfa,0xff,0xfa,0x29,0x00,0x00,0x00,
0x00,0x00,0x00,0xbe,0xff,0xff,0xff,0xbd,0x00,0x00,0x00,0x00,0x00,0x5a,0xff,0xff,0x81,0xff,
0xff,0x59,0x00,0x00,0x00,0x0e,0xe6,0xff,0xb6,0x00,0xb5,0xff,0xe6,0x0e,0x00,0x00,0x90,0xff,
0xfd,0x2e,0x00,0x2c,0xfd,0xff,0x8f,0x00,0x2e,0xfc,0xff,0xa1,0x00,0x00,0x00,0x9e,0xff,0xfc,
0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x8a,0xff,0xff,0x3b,0x00,0x00,0x30,0xfe,0xff,0x9a,0x0c,0xe3,0xff,
0xc1,0x00,0x00,0xb5,0xff,0xeb,0x12,0x00,0x53,0xff,0xff,0x48,0x3a,0xff,0xff,0x63,0x00,0x00,
0x00,0xb7,0xff,0xcd,0xc0,0xff,0xc7,0x01,0x00,0x00,0x00,0x23,0xf7,0xff,0xff,0xfc,0x30,0x00,
0x00,0x00,0x00,0x00,0x7f,0xff,0xff,0x91,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xff,0xff,0x1b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0x3c,0x00,0xec,0xec,
0xec,0xec,0xec,0xef,0xff,0xff,0x99,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8a,0xff,0xe7,0x10,
0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xfb,0xff,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xcb,
0xff,0xb4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0xf4,0x1f,0x00,0x00,0x00,0x00,0x00,
0x00,0x1f,0xf4,0xff,0x71,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb5,0xff,0xcc,0x03,0x00,0x00,
0x00,0x00,0x00,0x00,0x58,0xff,0xfc,0x32,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0xe9,0xff,0x8d,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9d,0xff,0xff,0xf0,0xec,0xec,0xec,0xec,0xec,0x76,0x3f,
0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0x00,
0x00,0xff,0xff,0xed,0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0xed,0xec,0x00,0x00,0xff,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x1c,0x80,0x80,0x19,0x00,0x00,0x00,0x00,0x00,0x04,0xe5,0xff,0x84,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0xff,0xea,0x07,0x00,0x00,0x00,0x00,0x00,0x1a,0xfb,0xff,0x5e,0x00,0x00,0x00,0x00,
0x00,0x00,0xab,0xff,0xcb,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xff,0xff,0x39,0x00,0x00,0x00,
0x00,0x00,0x00,0xd6,0xff,0xa6,0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0xff,0xfa,0x19,0x00,0x00,
0x00,0x00,0x00,0x0e,0xf3,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x98,0xff,0xe7,0x05,0x00,
0x00,0x00,0x00,0x00,0x2e,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x00,0xc4,0xff,0xc7,0x00,
0x00,0x00,0x00,0x00,0x00,0x59,0xff,0xff,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0x14,0x00,0xec,0xec,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xec,0xec,
0xff,0xff,0x14,0x00,0xff,0xff,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x1b,0xe9,0xff,0xb6,0x02,0x00,0x00,0x00,0x06,0xc7,0xff,0xe0,0xff,0x81,0x00,0x00,
0x00,0x97,0xff,0xad,0x13,0xe0,0xfe,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xec,0xec,0xec,0xec,0xec,0xec,0xec,0xec,0xec,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x65,0x11,
0x00,0x00,0x4a,0xff,0xd5,0x1d,0x00,0x0c,0xa6,0xff,0xe4,0x23,0x00,0x00,0x5a,0xe0,0x25,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xa6,0xed,0xf4,0xc6,
0x4b,0x00,0x00,0x00,0x1d,0xf3,0xf9,0xf6,0xff,0xfe,0x59,0x00,0x00,0x00,0x20,0x03,0x03,0x82,
0xff,0xd1,0x00,0x00,0x0a,0x97,0xed,0xde,0x59,0xff,0xfa,0x04,0x00,0x95,0xff,0xff,0xf5,0xf0,
0xff,0xff,0x13,0x00,0xea,0xff,0x5c,0x00,0x42,0xff,0xff,0x14,0x00,0xe9,0xff,0x58,0x00,0x3f,
0xff,0xff,0x14,0x00,0x92,0xff,0xff,0xf4,0xf6,0xff,0xff,0x14,0x00,0x0a,0x98,0xed,0xe0,0x5b,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x2f,0xad,0xf5,0xdf,
0x63,0x00,0x00,0x00,0xff,0xff,0xe4,0xfc,0xfb,0xff,0xff,0x40,0x00,0x00,0xff,0xff,0xba,0x12,
0x10,0xba,0xff,0xab,0x00,0x00,0xff,0xff,0x3a,0x00,0x00,0x3c,0xff,0xe1,0x00,0x00,0xff,0xff,
0x1c,0x00,0x00,0x1d,0xff,0xf8,0x00,0x00,0xff,0xff,0x3a,0x00,0x00,0x42,0xff,0xe2,0x00,0x00,
0xff,0xff,0xb8,0x10,0x14,0xc8,0xff,0xaf,0x00,0x00,0xff,0xff,0xe7,0xfc,0xfb,0xff,0xff,0x41,
0x00,0x00,0xff,0xff,0x30,0xae,0xf5,0xdf,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,
0xa9,0xef,0xf0,0xa9,0x1c,0x00,0x00,0x1a,0xe7,0xff,0xfd,0xfc,0xff,0xe4,0x14,0x00,0x9b,0xff,
0xcc,0x17,0x0e,0x98,0x55,0x02,0x00,0xe5,0xff,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0xfb,0xff,
0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0xe8,0xff,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0xa2,0xff,
0xce,0x1d,0x03,0x8d,0x53,0x01,0x00,0x21,0xed,0xff,0xff,0xf5,0xff,0xe1,0x13,0x00,0x00,0x25,
0xab,0xee,0xf4,0xb1,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x14,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0x00,0x63,0xdf,
0xf5,0xad,0x2e,0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfd,0xe4,0xff,0xff,0x00,0x00,0xaf,
0xff,0xb8,0x0f,0x14,0xbc,0xff,0xff,0x00,0x00,0xe4,0xff,0x3b,0x00,0x00,0x3d,0xff,0xff,0x00,
0x00,0xf9,0xff,0x1d,0x00,0x00,0x1e,0xff,0xff,0x00,0x00,0xe3,0xff,0x41,0x00,0x00,0x3d,0xff,
0xff,0x00,0x00,0xb0,0xff,0xc6,0x12,0x11,0xba,0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfc,
0xe2,0xff,0xff,0x00,0x00,0x00,0x63,0xe0,0xf5,0xab,0x2d,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1a,0xa3,0xee,0xf1,0xb1,0x26,0x00,0x00,
0x00,0x15,0xe1,0xff,0xf7,0xfb,0xff,0xec,0x1c,0x00,0x00,0x96,0xff,0x6d,0x01,0x08,0x9a,0xff,
0x9b,0x00,0x00,0xe4,0xff,0xed,0xec,0xec,0xf1,0xff,0xe4,0x00,0x00,0xfa,0xff,0xff,0xff,0xff,
0xff,0xff,0xfc,0x00,0x00,0xe1,0xff,0x23,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8f,0xff,0x9f,
0x07,0x09,0x50,0x0c,0x00,0x00,0x00,0x13,0xdc,0xff,0xf8,0xfb,0xff,0xef,0x1f,0x00,0x00,0x00,
0x0e,0x96,0xeb,0xf5,0xbd,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x05,0x7c,0xe5,0xf1,0xb1,0x10,0x00,0x00,0x9a,0xff,0xf8,0xf9,0x9c,0x00,0x00,0x00,0xfc,0xff,
0x22,0x06,0x03,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xec,0xff,0xff,0xed,0xec,
0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0xdf,0xf5,0xad,0x2e,0xff,0xff,0x00,
0x00,0x41,0xff,0xff,0xfb,0xfd,0xe4,0xff,0xff,0x00,0x00,0xaf,0xff,0xb8,0x0f,0x14,0xbc,0xff,
0xff,0x00,0x00,0xe4,0xff,0x3b,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,0xf9,0xff,0x1d,0x00,0x00,
0x1e,0xff,0xff,0x00,0x00,0xe3,0xff,0x41,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,0xb0,0xff,0xc6,
0x12,0x11,0xba,0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfc,0xe2,0xff,0xff,0x00,0x00,0x00,
0x63,0xe0,0xf5,0xab,0x2d,0xff,0xff,0x00,0x00,0x71,0xa8,0x54,0x01,0x01,0x61,0xff,0xe1,0x00,
0x00,0x45,0xfc,0xff,0xf6,0xf6,0xff,0xff,0x5d,0x00,0x00,0x00,0x44,0xbe,0xef,0xf7,0xcb,0x5b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x35,0xbb,0xf3,
0xac,0x0e,0x00,0x00,0xff,0xff,0xe4,0xf6,0xff,0xff,0x9c,0x00,0x00,0xff,0xff,0x90,0x00,0x6b,
0xff,0xea,0x00,0x00,0xff,0xff,0x2d,0x00,0x14,0xff,0xff,0x0e,0x00,0xff,0xff,0x17,0x00,0x01,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xbd,0x00,0x00,0xf6,0xff,0x0a,0x00,0x83,0x95,0x00,0x00,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xbd,0x00,0x00,0x00,0x00,
0xf6,0xff,0x0a,0x00,0x00,0x00,0x83,0x95,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0x13,0x00,0x11,0x1e,0xff,0xf3,0x02,0x50,0xf9,0xf9,
0xff,0x81,0x00,0x8b,0xee,0xeb,0x80,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x14,0x15,0xe2,0xff,0x9e,0x00,0x00,0xff,0xff,0x17,0xbc,0xff,0xc6,0x06,0x00,0x00,0xff,0xff,
0x9c,0xff,0xe3,0x17,0x00,0x00,0x00,0xff,0xff,0xff,0xf6,0x32,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xf4,0x23,0x00,0x00,0x00,0x00,0xff,0xff,0xa0,0xff,0xc6,0x03,0x00,0x00,0x00,0xff,0xff,
0x1b,0xd6,0xff,0x7b,0x00,0x00,0x00,0xff,0xff,0x14,0x38,0xfd,0xfa,0x32,0x00,0x00,0xff,0xff,
0x14,0x00,0x8c,0xff,0xd6,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,
0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xfc,0xff,0x20,0x00,0xd7,0xff,0xcb,0x00,0x40,
0xcf,0xce,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x36,0xbd,0xf4,0xba,0x11,0x1d,0xc1,0xf1,0xa2,0x09,0x00,
0x00,0xff,0xff,0xe8,0xf9,0xff,0xff,0x9e,0xdf,0xf9,0xff,0xff,0x7e,0x00,0x00,0xff,0xff,0x85,
0x02,0x88,0xff,0xff,0x71,0x02,0x9b,0xff,0xcc,0x00,0x00,0xff,0xff,0x2a,0x00,0x2c,0xff,0xff,
0x16,0x00,0x40,0xff,0xe7,0x00,0x00,0xff,0xff,0x16,0x00,0x17,0xff,0xff,0x02,0x00,0x2b,0xff,
0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x14,0xff,0xff,0x00,0x00,0x28,0xff,0xec,0x00,0x00,0xff,
0xff,0x14,0x00,0x14,0xff,0xff,0x00,0x00,0x28,0xff,0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x14,
0xff,0xff,0x00,0x00,0x28,0xff,0xec,0x00,0x00,0xff,0xff,0x14,0x00,0x14,0xff,0xff,0x00,0x00,
0x28,0xff,0xec,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x39,0xbe,0xf3,0xac,0x0e,0x00,0x00,0xff,0xff,
0xe8,0xf6,0xff,0xff,0x9c,0x00,0x00,0xff,0xff,0x90,0x00,0x6b,0xff,0xea,0x00,0x00,0xff,0xff,
0x2d,0x00,0x14,0xff,0xff,0x0e,0x00,0xff,0xff,0x17,0x00,0x01,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xbc,0xf3,0xf4,0xbe,0x37,0x00,0x00,0x00,0x2e,0xf7,
0xff,0xfb,0xfc,0xff,0xf7,0x2e,0x00,0x00,0xab,0xff,0xb0,0x0a,0x0b,0xb0,0xff,0xab,0x00,0x00,
0xea,0xff,0x34,0x00,0x00,0x35,0xff,0xe9,0x00,0x00,0xfc,0xff,0x1a,0x00,0x00,0x1b,0xff,0xfb,
0x00,0x00,0xea,0xff,0x34,0x00,0x00,0x35,0xff,0xe8,0x00,0x00,0xac,0xff,0xaf,0x0a,0x0a,0xb0,
0xff,0xa9,0x00,0x00,0x2f,0xf7,0xff,0xfb,0xfb,0xff,0xf6,0x2c,0x00,0x00,0x00,0x37,0xbd,0xf5,
0xf5,0xbe,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x32,0xb0,0xf5,0xdf,0x63,0x00,0x00,0x00,0xff,0xff,0xe8,0xfc,0xfb,0xff,0xff,0x40,
0x00,0x00,0xff,0xff,0xba,0x12,0x10,0xba,0xff,0xab,0x00,0x00,0xff,0xff,0x3a,0x00,0x00,0x3c,
0xff,0xe1,0x00,0x00,0xff,0xff,0x1c,0x00,0x00,0x1d,0xff,0xf8,0x00,0x00,0xff,0xff,0x3a,0x00,
0x00,0x42,0xff,0xe2,0x00,0x00,0xff,0xff,0xb8,0x10,0x14,0xc8,0xff,0xaf,0x00,0x00,0xff,0xff,
0xe2,0xfc,0xfb,0xff,0xff,0x41,0x00,0x00,0xff,0xff,0x2d,0xab,0xf5,0xdf,0x62,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0xdf,0xf5,0xad,0x2e,
0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfd,0xe4,0xff,0xff,0x00,0x00,0xaf,0xff,0xb8,0x0f,
0x14,0xbc,0xff,0xff,0x00,0x00,0xe4,0xff,0x3b,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,0xf9,0xff,
0x1d,0x00,0x00,0x1e,0xff,0xff,0x00,0x00,0xe3,0xff,0x41,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,
0xb0,0xff,0xc6,0x12,0x11,0xba,0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfc,0xe2,0xff,0xff,
0x00,0x00,0x00,0x63,0xe0,0xf5,0xab,0x2d,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,
0xff,0xff,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xea,0xff,0xdd,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x42,0xcb,0xd9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x3c,0xcc,0xec,0x7b,0x00,0xff,0xff,0xe8,0xf7,0xff,0x71,0x00,0xff,0xff,0xac,0x04,
0x2c,0x0d,0x00,0xff,0xff,0x35,0x00,0x00,0x00,0x00,0xff,0xff,0x16,0x00,0x00,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0xab,0xeb,0xf1,0xb6,0x29,0x00,
0x00,0xc8,0xff,0xfe,0xfa,0xff,0xe7,0x12,0x00,0xf6,0xff,0x30,0x08,0x9d,0x99,0x28,0x00,0xb8,
0xff,0xd0,0x66,0x0d,0x00,0x00,0x00,0x10,0x9c,0xfb,0xff,0xf0,0x68,0x00,0x00,0x00,0x00,0x1c,
0x89,0xfc,0xff,0x3f,0x2c,0xbe,0xb4,0x0d,0x04,0xd5,0xff,0x74,0x07,0xd9,0xff,0xfa,0xf5,0xff,
0xfc,0x38,0x00,0x1c,0xa6,0xeb,0xf2,0xc2,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,
0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xec,0xff,
0xff,0xed,0xec,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0xfa,0xff,
0x34,0x00,0x00,0x00,0x00,0xcb,0xff,0xfe,0xee,0x00,0x00,0x00,0x2a,0xb9,0xee,0xfe,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xfe,0xff,0x16,0x00,0x03,0xff,0xff,0x14,
0x00,0xf2,0xff,0x2b,0x00,0x1b,0xff,0xff,0x14,0x00,0xcb,0xff,0x74,0x00,0x6f,0xff,0xff,0x14,
0x00,0x78,0xff,0xfb,0xc7,0xf0,0xfe,0xff,0x14,0x00,0x07,0xac,0xf8,0xcb,0x3b,0xfc,0xff,0x14,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x40,0xff,0xf3,0x05,0x00,0x33,0xff,0xd8,0x00,0x03,0xec,0xff,0x3b,0x00,0x7a,0xff,0x88,0x00,
0x00,0xa0,0xff,0x7e,0x00,0xc1,0xff,0x38,0x00,0x00,0x50,0xff,0xc1,0x0d,0xfa,0xe6,0x01,0x00,
0x00,0x0a,0xf6,0xf9,0x59,0xff,0x98,0x00,0x00,0x00,0x00,0xb0,0xff,0xd9,0xff,0x48,0x00,0x00,
0x00,0x00,0x60,0xff,0xff,0xf1,0x06,0x00,0x00,0x00,0x00,0x13,0xfc,0xff,0xa8,0x00,0x00,0x00,
0x00,0x00,0x00,0xc0,0xff,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0xff,0xb7,
0x00,0x0b,0xfd,0xff,0x14,0x00,0xa5,0xff,0x5a,0x19,0xfe,0xf2,0x03,0x3a,0xff,0xff,0x45,0x00,
0xe6,0xfc,0x12,0x00,0xcd,0xff,0x36,0x6b,0xff,0xff,0x77,0x27,0xff,0xc5,0x00,0x00,0x83,0xff,
0x75,0x9c,0xf0,0xfe,0xa8,0x68,0xff,0x7a,0x00,0x00,0x38,0xff,0xb5,0xce,0xb5,0xd9,0xd9,0xa9,
0xff,0x2f,0x00,0x00,0x02,0xeb,0xf1,0xf9,0x7e,0xa6,0xfe,0xed,0xe4,0x00,0x00,0x00,0x00,0xa3,
0xff,0xff,0x48,0x72,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,0x58,0xff,0xff,0x12,0x3e,0xff,0xff,
0x4f,0x00,0x00,0x00,0x00,0x11,0xfc,0xdb,0x00,0x0c,0xfd,0xf9,0x0b,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xf5,0x1b,0x00,0x60,0xff,0xfc,0x34,
0x00,0xbb,0xff,0xa3,0x0a,0xe4,0xff,0x8a,0x00,0x00,0x28,0xfa,0xfe,0xac,0xff,0xda,0x09,0x00,
0x00,0x00,0x89,0xff,0xff,0xfe,0x3e,0x00,0x00,0x00,0x00,0x19,0xfe,0xff,0xcd,0x00,0x00,0x00,
0x00,0x00,0x92,0xff,0xff,0xff,0x4d,0x00,0x00,0x00,0x36,0xfd,0xfd,0xa4,0xff,0xe0,0x0a,0x00,
0x04,0xd1,0xff,0x9b,0x09,0xe2,0xff,0x8a,0x00,0x77,0xff,0xf3,0x18,0x00,0x5c,0xff,0xfb,0x2d,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xfe,0xff,0x17,0x00,0x05,0xff,0xff,0x14,0x00,0xf2,0xff,0x30,0x00,0x22,0xff,0xff,0x14,
0x00,0xcb,0xff,0x8f,0x01,0x8e,0xff,0xff,0x14,0x00,0x78,0xff,0xff,0xf6,0xe4,0xff,0xff,0x14,
0x00,0x07,0xac,0xf7,0xc5,0x2b,0xff,0xff,0x11,0x00,0x12,0x67,0x1f,0x00,0x46,0xff,0xdf,0x00,
0x00,0x70,0xff,0xff,0xf1,0xff,0xfd,0x45,0x00,0x00,0x00,0x65,0xd6,0xf8,0xcc,0x3d,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x81,0x00,0xec,0xec,0xec,0xfb,0xff,0xed,0x0f,0x00,
0x00,0x00,0x17,0xf5,0xff,0x77,0x00,0x00,0x00,0x00,0x91,0xff,0xe8,0x0a,0x00,0x00,0x00,0x1d,
0xf8,0xff,0x6d,0x00,0x00,0x00,0x00,0x9a,0xff,0xe2,0x07,0x00,0x00,0x00,0x22,0xfb,0xff,0x64,
0x00,0x00,0x00,0x00,0xa2,0xff,0xff,0xee,0xec,0xec,0x76,0x28,0xfc,0xff,0xff,0xff,0xff,0xff,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4c,0xd1,0xe9,0x00,0x00,0x00,0xe2,0xff,0xff,0x00,0x00,0x00,0xf9,
0xff,0x40,0x00,0x00,0x03,0xff,0xff,0x10,0x00,0x00,0x17,0xff,0xfd,0x03,0x00,0x00,0x48,0xff,
0xd6,0x00,0x00,0x0e,0xc7,0xfe,0x64,0x00,0x00,0x19,0xd3,0xfb,0x54,0x00,0x00,0x00,0x50,0xff,
0xd0,0x00,0x00,0x00,0x1a,0xff,0xfc,0x02,0x00,0x00,0x05,0xff,0xff,0x0f,0x00,0x00,0x00,0xfa,
0xff,0x32,0x00,0x00,0x00,0xe6,0xff,0xfa,0x00,0x00,0x00,0x5e,0xe6,0xfd,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x75,0xe5,0xc7,
0x48,0x00,0x00,0x80,0xff,0xff,0xef,0x00,0x00,0x03,0x47,0xff,0xff,0x09,0x00,0x00,0x01,0xfc,
0xff,0x16,0x00,0x00,0x00,0xed,0xff,0x28,0x00,0x00,0x00,0xc2,0xff,0x65,0x00,0x00,0x00,0x52,
0xfc,0xd5,0x14,0x00,0x00,0x45,0xf7,0xdf,0x21,0x00,0x00,0xbd,0xff,0x6e,0x00,0x00,0x00,0xeb,
0xff,0x2b,0x00,0x00,0x00,0xfb,0xff,0x18,0x00,0x00,0x33,0xff,0xff,0x0a,0x00,0x78,0xfe,0xff,
0xf4,0x00,0x00,0x80,0xfd,0xe1,0x5d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9f,0xf1,0x76,0x03,0x4e,0x00,0x00,0xff,0xf9,0xff,
0xf9,0xff,0x00,0x00,0x47,0x06,0x85,0xf0,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4d,0xc1,
0xf4,0xf4,0xba,0x3e,0x00,0x00,0x00,0x00,0x6c,0xff,0xff,0xf6,0xfd,0xff,0xfe,0x64,0x00,0x00,
0x27,0xf8,0xfa,0x61,0x02,0x12,0xb8,0xff,0xf9,0x26,0x00,0x8e,0xff,0x93,0x00,0x00,0x00,0x0c,
0xf0,0xff,0x8b,0x00,0xd7,0xff,0x3e,0x00,0x00,0x00,0x00,0x12,0x18,0x10,0x00,0xf4,0xff,0x1c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf4,0xff,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xd9,0xff,0x3d,0x00,0x00,0x00,0x00,0x0b,0x10,0x0b,0x00,0x90,0xff,0x91,0x00,0x00,0x00,
0x0b,0xed,0xff,0x8c,0x00,0x29,0xf8,0xfa,0x60,0x06,0x12,0xb1,0xff,0xfa,0x29,0x00,0x00,0x6f,
0xff,0xff,0xf9,0xfe,0xff,0xfe,0x6a,0x00,0x00,0x00,0x00,0x50,0xc3,0xf5,0xec,0xbb,0x42,0x00,
0x00,0x00,0x00,0x00,0x00,0x0f,0xa1,0x74,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xf4,
0xeb,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9f,0xff,0x9e,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x3a,0x5b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0xcb,0x4c,0x00,0x6c,0xcb,0x4c,0x00,0x00,0x00,0x00,0x00,
0xf3,0xff,0xca,0x00,0xf3,0xff,0xca,0x00,0x00,0x00,0x00,0x00,0x90,0xf3,0x6d,0x00,0x90,0xf3,
0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x49,0xbd,0xf2,0xf4,0xc5,0x57,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0xf9,0xf8,0xff,0xff,
0x7f,0x00,0x00,0x00,0x24,0xf6,0xfe,0x74,0x06,0x02,0x5a,0xf8,0xfc,0x33,0x00,0x00,0x8a,0xff,
0xa1,0x00,0x00,0x00,0x00,0x87,0xff,0x9d,0x00,0x00,0xd4,0xff,0x45,0x00,0x00,0x00,0x00,0x2f,
0xff,0xe7,0x00,0x00,0xf3,0xff,0x1e,0x00,0x00,0x00,0x00,0x0d,0xff,0xff,0x06,0x00,0xf3,0xff,
0x1d,0x00,0x00,0x00,0x00,0x0a,0xff,0xff,0x07,0x00,0xd5,0xff,0x43,0x00,0x00,0x00,0x00,0x2e,
0xff,0xe8,0x00,0x00,0x8c,0xff,0xa0,0x00,0x00,0x00,0x00,0x88,0xff,0x9f,0x00,0x00,0x26,0xf7,
0xfe,0x72,0x0a,0x07,0x61,0xf9,0xfc,0x35,0x00,0x00,0x00,0x6b,0xff,0xff,0xfc,0xfb,0xff,0xff,
0x82,0x00,0x00,0x00,0x00,0x00,0x4c,0xc1,0xf3,0xf5,0xc8,0x5b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x4f,0xcb,0x6b,0x00,0x6d,0xcb,0x4d,0x00,0x00,0x00,0x00,0xcb,0xff,0xf3,
0x00,0xf3,0xff,0xcb,0x00,0x00,0x00,0x00,0x6b,0xf3,0x8e,0x00,0x8e,0xf3,0x6a,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,
0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,
0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,
0x14,0xff,0xff,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x14,0xff,0xff,0x00,0x00,0xf5,0xff,
0x22,0x00,0x00,0x00,0x1f,0xff,0xf4,0x00,0x00,0xd3,0xff,0x5b,0x00,0x00,0x00,0x5a,0xff,0xd3,
0x00,0x00,0x82,0xff,0xe1,0x2a,0x00,0x30,0xe0,0xff,0x82,0x00,0x00,0x0c,0xd7,0xff,0xff,0xf5,
0xff,0xff,0xd6,0x0c,0x00,0x00,0x00,0x11,0x8f,0xe0,0xf8,0xe0,0x8e,0x10,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xa1,0xec,0xf4,0xb9,0x32,0x00,0x00,0x17,0xe2,
0xff,0xff,0xfa,0xff,0xf8,0x36,0x00,0x98,0xff,0xd2,0x1e,0x08,0x81,0x71,0x0a,0x00,0xe4,0xff,
0x46,0x00,0x00,0x00,0x00,0x00,0x00,0xfb,0xff,0x1d,0x00,0x00,0x00,0x00,0x00,0x00,0xe6,0xff,
0x45,0x00,0x00,0x00,0x00,0x00,0x00,0x9e,0xff,0xd2,0x22,0x00,0x7c,0x6a,0x07,0x00,0x1d,0xe8,
0xff,0xff,0xf4,0xff,0xf6,0x33,0x00,0x00,0x1e,0xa2,0xe9,0xf7,0xc2,0x34,0x00,0x00,0x00,0x00,
0x20,0xb6,0x74,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xea,0x00,0x00,0x00,0x00,0x00,0x04,
0xc6,0xff,0x8c,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0xf3,0x8f,0x00,0x6d,0xf3,
0x8f,0x00,0x00,0x00,0xcb,0xff,0xf3,0x00,0xcb,0xff,0xf3,0x00,0x00,0x00,0x4b,0xcb,0x6d,0x00,
0x4d,0xcb,0x6d,0x00,0x00,0x00,0x00,0x36,0xbc,0xf3,0xf4,0xbe,0x37,0x00,0x00,0x00,0x2e,0xf7,
0xff,0xfb,0xfc,0xff,0xf7,0x2e,0x00,0x00,0xab,0xff,0xb0,0x0a,0x0b,0xb0,0xff,0xab,0x00,0x00,
0xea,0xff,0x34,0x00,0x00,0x35,0xff,0xe9,0x00,0x00,0xfc,0xff,0x1a,0x00,0x00,0x1b,0xff,0xfb,
0x00,0x00,0xea,0xff,0x34,0x00,0x00,0x35,0xff,0xe8,0x00,0x00,0xac,0xff,0xaf,0x0a,0x0a,0xb0,
0xff,0xa9,0x00,0x00,0x2f,0xf7,0xff,0xfb,0xfb,0xff,0xf6,0x2c,0x00,0x00,0x00,0x37,0xbd,0xf5,
0xf5,0xbe,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x6d,0xf3,0x8f,0x00,0x6d,0xf3,0x8f,0x00,0x00,0xcb,0xff,0xf3,0x00,0xcb,0xff,0xf3,0x00,
0x00,0x4b,0xca,0x6b,0x00,0x4d,0xcb,0x6a,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0xfe,0xff,0x16,0x00,0x03,0xff,0xff,0x14,
0x00,0xf2,0xff,0x2b,0x00,0x1b,0xff,0xff,0x14,0x00,0xcb,0xff,0x74,0x00,0x6f,0xff,0xff,0x14,
0x00,0x78,0xff,0xfb,0xc7,0xf0,0xfe,0xff,0x14,0x00,0x07,0xac,0xf8,0xcb,0x3b,0xfc,0xff,0x14,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf2,0xc9,0x13,
0x10,0xc2,0xf1,0x00,0x00,0x00,0x00,0x00,0x00,0x9a,0xff,0xf9,0xf9,0xff,0x9a,0x00,0x00,0x00,
0x00,0x00,0x00,0x0a,0x92,0xed,0xed,0x91,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xbc,0xf1,0xf4,0xc6,0x54,0x00,0x00,0x00,
0x00,0x00,0x70,0xff,0xff,0xfa,0xfa,0xff,0xff,0x7b,0x00,0x00,0x00,0x2f,0xfa,0xff,0x82,0x07,
0x0d,0x8e,0xbb,0x72,0x00,0x00,0x00,0x98,0xff,0xaa,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xdc,0xff,0x45,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0xff,0x1e,0x00,0x00,
0xf8,0xf8,0xf8,0xf8,0xf8,0x00,0x00,0xee,0xff,0x27,0x00,0x00,0xff,0xff,0xff,0xff,0xf9,0x00,
0x00,0xce,0xff,0x55,0x00,0x00,0x00,0x00,0x7f,0xff,0xe3,0x00,0x00,0x81,0xff,0xbc,0x00,0x00,
0x00,0x00,0xbe,0xff,0xa9,0x00,0x00,0x1e,0xf2,0xff,0x8c,0x07,0x08,0x73,0xff,0xff,0x48,0x00,
0x00,0x00,0x5b,0xfd,0xff,0xfa,0xfb,0xff,0xff,0x9b,0x00,0x00,0x00,0x00,0x00,0x3d,0xb5,0xef,
0xf8,0xd2,0x6e,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xdc,0x03,0x00,0x25,
0xf3,0x00,0x00,0x00,0x00,0xc8,0xff,0x7d,0x11,0xbb,0xc8,0x00,0x00,0x00,0x00,0x57,0xff,0xff,
0xff,0xff,0x57,0x00,0x00,0x00,0x00,0x00,0x60,0xd4,0xd4,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0xdf,0xf5,0xad,0x2e,0xff,0xff,0x00,
0x00,0x41,0xff,0xff,0xfb,0xfd,0xe4,0xff,0xff,0x00,0x00,0xaf,0xff,0xb8,0x0f,0x14,0xbc,0xff,
0xff,0x00,0x00,0xe4,0xff,0x3b,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,0xf9,0xff,0x1d,0x00,0x00,
0x1e,0xff,0xff,0x00,0x00,0xe3,0xff,0x41,0x00,0x00,0x3d,0xff,0xff,0x00,0x00,0xb0,0xff,0xc6,
0x12,0x11,0xba,0xff,0xff,0x00,0x00,0x41,0xff,0xff,0xfb,0xfc,0xe2,0xff,0xff,0x00,0x00,0x00,
0x63,0xe0,0xf5,0xab,0x2d,0xff,0xff,0x00,0x00,0x97,0xa8,0x54,0x01,0x01,0x61,0xff,0xe1,0x00,
0x00,0x79,0xff,0xff,0xf6,0xf6,0xff,0xff,0x59,0x00,0x00,0x00,0x61,0xcb,0xf3,0xf5,0xc5,0x54,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x6c,0xcb,0x4c,0x00,0x00,0xf3,0xff,0xca,0x00,0x00,0x93,0xf3,0x6d,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,
0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,
0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0xff,0xff,
0x14,0x00,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,
0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x14,0x00,0xff,0xff,
0x14,0x00,0xff,0xff,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x56,0xc2,0xef,0xed,0xb4,0x34,0x00,0x00,0x00,0x75,0xff,0xff,0xf7,0xfd,0xff,0xf7,0x3d,
0x00,0x00,0xe6,0xff,0x68,0x01,0x0c,0x93,0xae,0x5a,0x00,0x00,0xf1,0xff,0x3b,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xa5,0xff,0xf1,0x82,0x1e,0x00,0x00,0x00,0x00,0x00,0x0c,0xa0,0xfe,0xff,
0xfe,0xb8,0x32,0x00,0x00,0x00,0x00,0x00,0x26,0x89,0xe7,0xff,0xfb,0x51,0x00,0x00,0x00,0x00,
0x00,0x00,0x06,0x91,0xff,0xdf,0x00,0x2b,0x93,0x95,0x00,0x00,0x00,0x10,0xff,0xff,0x0b,0x1e,
0xfe,0xff,0x79,0x04,0x03,0x75,0xff,0xed,0x01,0x00,0x7b,0xff,0xff,0xfa,0xf9,0xff,0xff,0x6c,
0x00,0x00,0x00,0x51,0xca,0xff,0xff,0xbe,0x48,0x00,0x00,0x00,0x00,0x00,0x02,0xe4,0xfe,0x16,
0x00,0x00,0x00,0x00,0x00,0x00,0x7a,0xfe,0xd7,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x3d,0x85,
0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0xab,0xeb,0xf1,0xb5,0x27,0x00,0x00,0xc8,0xff,
0xfc,0xfd,0xff,0xe5,0x10,0x00,0xf6,0xff,0x2d,0x23,0xb6,0x93,0x26,0x00,0xb8,0xff,0xd0,0x66,
0x0d,0x00,0x00,0x00,0x10,0x9c,0xfb,0xff,0xf0,0x68,0x00,0x00,0x00,0x00,0x1c,0x89,0xfc,0xff,
0x3f,0x2c,0xbe,0xb4,0x0d,0x04,0xd5,0xff,0x74,0x07,0xd9,0xff,0xfa,0xf5,0xff,0xfc,0x38,0x00,
0x1c,0xa6,0xff,0xff,0xc2,0x46,0x00,0x00,0x00,0x00,0xbc,0xe9,0x00,0x00,0x00,0x00,0x00,0x50,
0xf4,0xbd,0x00,0x00,0x00,0x00,0x00,0x1f,0x8a,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,
  };
  static const struct {
    uint32_t ds;
    uint16_t width;
  } glinfo[]= {

{0,5}, {105,4}, {189,7}, {336,13}, 
{609,9}, {798,12}, {1050,11}, {1281,4}, 
{1365,6}, {1491,6}, {1617,10}, {1827,9}, 
{2016,4}, {2100,8}, {2268,4}, {2352,9}, 
{2541,10}, {2751,10}, {2961,10}, {3171,10}, 
{3381,10}, {3591,10}, {3801,10}, {4011,10}, 
{4221,10}, {4431,10}, {4641,4}, {4725,4}, 
{4809,7}, {4956,9}, {5145,7}, {5292,9}, 
{5481,15}, {5796,12}, {6048,11}, {6279,12}, 
{6531,11}, {6762,10}, {6972,10}, {7182,12}, 
{7434,10}, {7644,4}, {7728,10}, {7938,11}, 
{8169,10}, {8379,14}, {8673,11}, {8904,12}, 
{9156,10}, {9366,12}, {9618,10}, {9828,10}, 
{10038,12}, {10290,11}, {10521,11}, {10752,14}, 
{11046,11}, {11277,10}, {11487,11}, {11718,6}, 
{11844,9}, {12033,6}, {12159,9}, {12348,11}, 
{12579,5}, {12684,9}, {12873,10}, {13083,9}, 
{13272,10}, {13482,10}, {13692,8}, {13860,10}, 
{14070,9}, {14259,4}, {14343,6}, {14469,9}, 
{14658,4}, {14742,14}, {15036,9}, {15225,10}, 
{15435,10}, {15645,10}, {15855,7}, {16002,8}, 
{16170,7}, {16317,9}, {16506,9}, {16695,12}, 
{16947,9}, {17136,9}, {17325,8}, {17493,6}, 
{17619,4}, {17703,6}, {17829,7}, {17976,11}, 
{18207,12}, {18459,11}, {18690,9}, {18879,10}, 
{19089,9}, {19278,12}, {19530,10}, {19740,5}, 
{19845,4}, {19929,10}, {20139,8}, 
  };
  // static const int nmap= sizeof(glmap)/sizeof(glmap[0]);
  int i,j,k,e,x,y,sX,eX;
  int W, X, *Xpos;
  char buf[20];
  int *map, *gl;
  int ngl;
  unsigned int C;
  int glyph_width;
  const unsigned char *glyph_data;
  unsigned char *data;

  map= alloca(L*sizeof(int));

  e= 0;
  ngl= 0;
  for(i=0;i<L;i++)
  {
    C= str[i];
    
    if (C&(1<<31)) { ngl+=2; e= 1; continue; }
    map[i]= font_hash(C);
    if (map[i]!=107) { ngl++; continue; }
    sprintf(buf,"%x",C); ngl+= strlen(buf); e= 1;
  }

  if (e) goto fix_encoding_errors;
  else gl= map;

encoding_errors_fixed:

  W= 0;
  for(i=0;i<ngl;i++) W+= glinfo[gl[i]].width;

  if (Rdata) data= malloc(W*21);
  X= 0;
  if (e && Rdata) Xpos= alloca(sizeof(int)*(ngl+1));
  for(i=0;i<ngl;i++)
  {
    if (e && Rdata) Xpos[i]= X;
    glyph_width= glinfo[gl[i]].width;
    if (Rdata) {
      glyph_data= font_data + glinfo[gl[i]].ds;
      for(y=0;y<21;y++)
         for(x=0;x<glyph_width;x++)
            data[y*W+X+x]= glyph_data[y*glyph_width+x];
    }
    X+= glyph_width;
  }
  if (e && Rdata) Xpos[i]= X;
  if (RW) *RW= W;
  if (RA) *RA= 17;
  if (RH) *RH= 21;
  if (Rdata) *Rdata= data;

  if (!e || !Rdata) return ;

  j= 0;
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sX= Xpos[j]; eX= Xpos[j+2];
      for(x=sX;x<eX;x++)
        for(y=0;y<21;y++)
          data[y*W + x] ^= 0xff;
      j+= 2;
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x",str[i]);
      sX= Xpos[j]; eX= Xpos[j+strlen(buf)];
      for(x=sX;x<eX;x++) {
        data[ 0*W + x]= 0xff;
        data[ (21-1)*W + x]= 0xff;
      }
      for(y=0;y<21;y++)
      {
        data[y*W+sX] = 0xff;
        data[y*W+eX-1] = 0xff;
      }
      j+= strlen(buf);
      continue;
    }
    j++;
  }
  return ;


fix_encoding_errors:
  j= 0;
  gl= alloca(sizeof(int)*ngl);
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sprintf(buf,"%02x", str[i]&0xff);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x", str[i]);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    gl[j++]= map[i];
  }
  goto encoding_errors_fixed;
}

static 
void font3_render
        (uint32_t *str, size_t L, 
        int *RW, int *RH, int *RA,
        unsigned char **Rdata)
{
  static const uint8_t font_data[]= {

0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0xb6,0xf2,0x7c,0x00,0x00,0x49,0xff,0xff,
0xfd,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x22,0xcc,0xf1,0xa9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xe4,0xe4,
0x49,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0xe3,0xff,0xff,0xe3,0x00,0x00,0x47,0xe3,0xe4,
0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x97,0xf5,0xcb,0x1e,0x16,0xc7,0xf2,0xa4,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4b,0x4b,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x4c,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xc2,0xf5,0xd5,0x29,0x22,0xd1,0xf4,0xba,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0xff,
0xff,0xff,0x6d,0x30,0x30,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0xff,0xff,0xff,0x6d,0x30,0x30,0xff,0xff,0xff,0x6d,
0x30,0x30,0x30,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x28,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0x3f,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x04,0x78,0xe4,0xff,0xff,0xff,0xff,0xee,0x8f,0x17,0x00,0x00,0x00,0x06,0xb8,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe3,0x2d,0x00,0x00,0x7a,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe0,0x10,0x00,0xda,0xff,0xff,0xd7,0x32,0xff,0xff,0x61,0xbf,0xff,0xd8,
0x85,0x1c,0x00,0xfa,0xff,0xff,0x5c,0x00,0xff,0xff,0x28,0x07,0x2b,0x00,0x00,0x00,0x00,0xec,
0xff,0xff,0x72,0x00,0xff,0xff,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xf0,0x5e,
0xff,0xff,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0xfe,0xff,0xff,0xff,0xff,0xff,0x45,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x73,0xfe,0xff,0xff,0xff,0xff,0xff,0xce,0x57,0x01,0x00,0x00,
0x00,0x00,0x00,0x3b,0xbb,0xfd,0xff,0xff,0xff,0xff,0xff,0xc9,0x22,0x00,0x00,0x00,0x00,0x00,
0x00,0x15,0xff,0xff,0xff,0xff,0xff,0xff,0xe4,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x54,0xac,0xff,0xff,0xff,0x8a,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x28,0x00,0xac,0xff,
0xff,0xdc,0x00,0x18,0x74,0xb2,0x03,0x00,0xff,0xff,0x28,0x00,0x56,0xff,0xff,0xf9,0x1e,0xfb,
0xff,0xff,0x6b,0x00,0xff,0xff,0x28,0x00,0x86,0xff,0xff,0xea,0x00,0xbe,0xff,0xff,0xf6,0x64,
0xff,0xff,0x4a,0x80,0xfa,0xff,0xff,0xab,0x00,0x2d,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xfb,0x33,0x00,0x00,0x60,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfa,0x5f,0x00,
0x00,0x00,0x00,0x47,0xd6,0xff,0xff,0xff,0xff,0xf8,0xaf,0x31,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x26,0xff,0xff,0x4f,0x09,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0x26,0x04,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0xd5,0xff,0xff,
0xed,0x6b,0x00,0x00,0x00,0x00,0x4a,0x64,0x27,0x00,0x00,0x00,0x00,0x00,0x35,0xf8,0xff,0xff,
0xff,0xff,0xff,0x73,0x00,0x00,0x20,0xf9,0xf4,0x16,0x00,0x00,0x00,0x00,0x00,0xba,0xff,0xff,
0xff,0xff,0xff,0xff,0xf5,0x0e,0x00,0x9f,0xff,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0xf5,0xff,
0xff,0x7c,0x31,0xff,0xff,0xff,0x40,0x27,0xfc,0xf1,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0xf1,
0xff,0xff,0x9f,0x62,0xff,0xff,0xff,0x3c,0xa9,0xff,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xed,0x38,0xfe,0xee,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x22,0xea,0xff,0xff,0xff,0xff,0xfd,0x57,0xb3,0xff,0x7b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x20,0xa7,0xee,0xf7,0xc3,0x44,0x37,0xff,0xeb,0x0c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbc,0xff,0x74,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x41,0xff,0xe7,0x09,0x51,0xb0,0xc4,0x93,
0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc6,0xff,0x6e,0x81,0xff,0xff,0xff,
0xff,0xeb,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xff,0xe3,0x3c,0xfe,0xff,0xff,
0xff,0xff,0xff,0xc9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xce,0xff,0x68,0x8f,0xff,0xff,
0x92,0x49,0xff,0xff,0xff,0x26,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xdf,0x05,0xae,0xff,
0xff,0x52,0x07,0xff,0xff,0xff,0x46,0x00,0x00,0x00,0x00,0x00,0x02,0xd6,0xff,0x61,0x00,0x9d,
0xff,0xff,0xa7,0x68,0xff,0xff,0xff,0x33,0x00,0x00,0x00,0x00,0x00,0x5e,0xff,0xda,0x03,0x00,
0x52,0xff,0xff,0xff,0xff,0xff,0xff,0xe3,0x03,0x00,0x00,0x00,0x00,0x05,0xde,0xff,0x5b,0x00,
0x00,0x01,0xb5,0xff,0xff,0xff,0xff,0xfc,0x4d,0x00,0x00,0x00,0x00,0x00,0x06,0x24,0x24,0x02,
0x00,0x00,0x00,0x07,0x89,0xe6,0xf9,0xc8,0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x2f,0x68,0x79,0x60,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2b,0xc6,
0xff,0xff,0xff,0xff,0xfe,0xad,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0xf1,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xd0,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0xcd,0xff,0xff,0xff,0xd8,
0xba,0xee,0xff,0xff,0xff,0x69,0x00,0x00,0x00,0x00,0x00,0x26,0xff,0xff,0xff,0x7b,0x00,0x00,
0x0d,0xb6,0xb8,0x43,0x00,0x00,0x00,0x00,0x00,0x00,0x44,0xff,0xff,0xff,0x0e,0x00,0x00,0x00,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x29,0xff,0xff,0xff,0x37,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xd3,0xff,0xff,0xe1,0x63,0x35,0x30,0x30,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0xf0,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5f,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x6d,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x2f,0xfb,0xff,0xff,0xc9,0x39,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x94,0xff,0xff,0xe9,0x10,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0x00,0x00,0xd6,0xff,0xff,0x7f,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
0x00,0xf0,0xff,0xff,0x57,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
0xf3,0xff,0xff,0x75,0x00,0x00,0x00,0x30,0x30,0x7e,0xff,0xff,0xf2,0x30,0x30,0x00,0x00,0xcc,
0xff,0xff,0xe2,0x0f,0x00,0x00,0x00,0x00,0xb6,0xff,0xff,0xc7,0x00,0x00,0x00,0x00,0x6a,0xff,
0xff,0xff,0xde,0x63,0x3a,0x50,0xb4,0xff,0xff,0xff,0x6a,0x00,0x00,0x00,0x00,0x07,0xc4,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xc0,0x05,0x00,0x00,0x00,0x00,0x00,0x12,0xb7,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xc9,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4f,0xac,
0xe2,0xf9,0xed,0xbc,0x61,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x97,0xf5,0xcb,0x1e,0x00,0x00,
0x00,0xff,0xff,0xff,0x4b,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xc2,0xf5,0xd5,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0xed,0xff,0xff,0x7e,0x00,0x00,
0x00,0x00,0xa0,0xff,0xff,0xe1,0x09,0x00,0x00,0x00,0x32,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,
0x00,0x9a,0xff,0xff,0xe7,0x04,0x00,0x00,0x00,0x0b,0xf2,0xff,0xff,0x88,0x00,0x00,0x00,0x00,
0x4a,0xff,0xff,0xff,0x2b,0x00,0x00,0x00,0x00,0x82,0xff,0xff,0xec,0x00,0x00,0x00,0x00,0x00,
0xb8,0xff,0xff,0xb3,0x00,0x00,0x00,0x00,0x00,0xd7,0xff,0xff,0x81,0x00,0x00,0x00,0x00,0x00,
0xe7,0xff,0xff,0x6b,0x00,0x00,0x00,0x00,0x00,0xf8,0xff,0xff,0x58,0x00,0x00,0x00,0x00,0x00,
0xf9,0xff,0xff,0x53,0x00,0x00,0x00,0x00,0x00,0xea,0xff,0xff,0x68,0x00,0x00,0x00,0x00,0x00,
0xdb,0xff,0xff,0x7d,0x00,0x00,0x00,0x00,0x00,0xbd,0xff,0xff,0xab,0x00,0x00,0x00,0x00,0x00,
0x8c,0xff,0xff,0xe8,0x00,0x00,0x00,0x00,0x00,0x5b,0xff,0xff,0xff,0x28,0x00,0x00,0x00,0x00,
0x17,0xfd,0xff,0xff,0x86,0x00,0x00,0x00,0x00,0x00,0xb7,0xff,0xff,0xe7,0x04,0x00,0x00,0x00,
0x00,0x42,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0xb4,0xff,0xff,0xe0,0x09,0x00,0x00,
0x00,0x00,0x1d,0xef,0xff,0xff,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0xfe,0xff,0xff,0x45,0x00,0x00,0x00,0x00,
0x00,0xa0,0xff,0xff,0xda,0x07,0x00,0x00,0x00,0x00,0x1a,0xf8,0xff,0xff,0x75,0x00,0x00,0x00,
0x00,0x00,0xa8,0xff,0xff,0xdd,0x01,0x00,0x00,0x00,0x00,0x46,0xff,0xff,0xff,0x45,0x00,0x00,
0x00,0x00,0x02,0xe6,0xff,0xff,0x92,0x00,0x00,0x00,0x00,0x00,0xa9,0xff,0xff,0xca,0x00,0x00,
0x00,0x00,0x00,0x6c,0xff,0xff,0xf9,0x07,0x00,0x00,0x00,0x00,0x38,0xff,0xff,0xff,0x20,0x00,
0x00,0x00,0x00,0x21,0xff,0xff,0xff,0x31,0x00,0x00,0x00,0x00,0x0a,0xff,0xff,0xff,0x43,0x00,
0x00,0x00,0x00,0x0b,0xff,0xff,0xff,0x43,0x00,0x00,0x00,0x00,0x20,0xff,0xff,0xff,0x33,0x00,
0x00,0x00,0x00,0x36,0xff,0xff,0xff,0x23,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0xfa,0x07,0x00,
0x00,0x00,0x00,0xa5,0xff,0xff,0xce,0x00,0x00,0x00,0x00,0x01,0xe3,0xff,0xff,0x9a,0x00,0x00,
0x00,0x00,0x41,0xff,0xff,0xff,0x51,0x00,0x00,0x00,0x00,0xa4,0xff,0xff,0xeb,0x08,0x00,0x00,
0x00,0x18,0xf6,0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x9e,0xff,0xff,0xe6,0x0c,0x00,0x00,0x00,
0x31,0xfd,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0x6c,0x04,
0x00,0x02,0x6a,0x52,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0x66,0x00,0x5f,0xff,
0xff,0x84,0x00,0x00,0x00,0x00,0x00,0x00,0x62,0xff,0xff,0xe5,0x0f,0xde,0xff,0xff,0x6c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xb2,0xff,0xff,0xcd,0xff,0xff,0xbb,0x01,0x00,0x00,0x00,0x00,
0x10,0x30,0x30,0x45,0xf6,0xff,0xff,0xff,0xfa,0x4c,0x30,0x30,0x0c,0x00,0x00,0xc6,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xbf,0x00,0x00,0xf6,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xf4,0x00,0x00,0xa2,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xad,0x00,0x00,0x00,0x00,0x00,0x32,0xfb,0xff,0xff,0xff,0xf7,0x28,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x06,0xd2,0xff,0xff,0xb4,0xff,0xff,0xc8,0x03,0x00,0x00,0x00,0x00,
0x00,0x00,0x7d,0xff,0xff,0xd5,0x07,0xdf,0xff,0xff,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x6f,
0xff,0xff,0x5a,0x00,0x63,0xff,0xff,0x63,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0x6c,0x02,
0x00,0x03,0x6b,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x30,
0x6d,0xff,0xff,0xff,0x30,0x30,0x30,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x3b,0xe1,0xe1,0x40,0x00,0x00,0xd7,0xff,0xff,0xd8,0x00,0x00,0xf5,0xff,0xff,
0xf8,0x00,0x00,0xad,0xff,0xff,0xcc,0x00,0x00,0x0c,0xb4,0xff,0x6a,0x00,0x00,0x00,0xc5,0xda,
0x0a,0x00,0x00,0x04,0xa1,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
0x30,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x4b,0xe4,0xe4,0x49,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0xe4,0xff,0xff,
0xe3,0x00,0x00,0x49,0xe4,0xe4,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0xfe,0xff,0xff,0x68,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x8a,0xff,0xff,0xf4,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,
0xeb,0xff,0xff,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xff,0x36,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc5,0xff,0xff,0xd0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x2e,0xff,0xff,0xff,0x6a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x97,0xff,0xff,0xf5,
0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xf3,0xff,0xff,0x9e,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x6a,0xff,0xff,0xff,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd3,0xff,
0xff,0xd1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0xff,0xff,0xff,0x6b,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xa5,0xff,0xff,0xf5,0x0f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,
0xf9,0xff,0xff,0x9f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0xff,0xff,0xff,0x39,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xde,0xff,0xff,0xd3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x4a,0xff,0xff,0xff,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xf6,
0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,0xfd,0xff,0xff,0xa1,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x85,0xff,0xff,0xff,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xe8,0xff,
0xff,0xd4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x57,0xff,0xff,0xff,0x6f,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x93,0xdc,0xf7,
0xea,0xb9,0x51,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4d,0xf3,0xff,0xff,0xff,0xff,0xff,
0xff,0x9e,0x01,0x00,0x00,0x00,0x00,0x00,0x2f,0xf6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0x7e,0x00,0x00,0x00,0x00,0x00,0xbf,0xff,0xff,0xe6,0x67,0x38,0x49,0xb0,0xff,0xff,0xf7,0x1c,
0x00,0x00,0x00,0x2f,0xff,0xff,0xfc,0x2b,0x00,0x00,0x00,0x01,0xc5,0xff,0xff,0x80,0x00,0x00,
0x00,0x81,0xff,0xff,0xbb,0x00,0x00,0x00,0x00,0x00,0x65,0xff,0xff,0xd1,0x00,0x00,0x00,0xb6,
0xff,0xff,0x83,0x00,0x00,0x00,0x00,0x00,0x32,0xff,0xff,0xfc,0x07,0x00,0x00,0xdf,0xff,0xff,
0x64,0x00,0x00,0x00,0x00,0x00,0x17,0xff,0xff,0xff,0x2b,0x00,0x00,0xf1,0xff,0xff,0x53,0x00,
0x00,0x00,0x00,0x00,0x08,0xff,0xff,0xff,0x3c,0x00,0x00,0xfc,0xff,0xff,0x4d,0x00,0x00,0x00,
0x00,0x00,0x02,0xff,0xff,0xff,0x47,0x00,0x00,0xf2,0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x00,
0x05,0xff,0xff,0xff,0x3d,0x00,0x00,0xe1,0xff,0xff,0x58,0x00,0x00,0x00,0x00,0x00,0x0e,0xff,
0xff,0xff,0x2b,0x00,0x00,0xcb,0xff,0xff,0x70,0x00,0x00,0x00,0x00,0x00,0x23,0xff,0xff,0xff,
0x15,0x00,0x00,0x97,0xff,0xff,0x98,0x00,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xdf,0x00,0x00,
0x00,0x5c,0xff,0xff,0xce,0x00,0x00,0x00,0x00,0x00,0x88,0xff,0xff,0xa3,0x00,0x00,0x00,0x12,
0xf4,0xff,0xff,0x40,0x00,0x00,0x00,0x10,0xea,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x91,0xff,
0xff,0xf4,0x6d,0x37,0x54,0xd0,0xff,0xff,0xd5,0x01,0x00,0x00,0x00,0x00,0x15,0xdf,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xfa,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x2b,0xea,0xff,0xff,0xff,
0xff,0xff,0xfc,0x61,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x91,0xdf,0xfa,0xeb,0xac,
0x35,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x7f,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x8e,
0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x9c,0xff,0xff,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0x70,0x70,0x70,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x46,0xb2,0xec,0xf7,0xdf,0xa8,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x06,0xa0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8d,0x00,0x00,0x00,0x00,0x00,0x00,0xa5,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x62,0x00,0x00,0x00,0x00,0x3f,0xff,0xff,0xff,0xda,
0x5b,0x3b,0x73,0xf3,0xff,0xff,0xdc,0x00,0x00,0x00,0x00,0x60,0xec,0xff,0xf6,0x1e,0x00,0x00,
0x00,0x60,0xff,0xff,0xff,0x22,0x00,0x00,0x00,0x00,0x03,0x3c,0x58,0x00,0x00,0x00,0x00,0x14,
0xff,0xff,0xff,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0xff,0xff,
0xff,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x60,0xff,0xff,0xff,0x29,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xe9,0xff,0xff,0xe6,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,0xdf,0xff,0xff,0xff,0x6e,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x5a,0xf3,0xff,0xff,0xff,0xb1,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x9d,0xff,0xff,0xff,0xff,0xb8,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0xc5,0xff,
0xff,0xff,0xff,0x94,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0xcb,0xff,0xff,0xff,0xf5,
0x5b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x99,0xff,0xff,0xff,0xe9,0x33,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2d,0xfe,0xff,0xff,0xeb,0x24,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x88,0xff,0xff,0xff,0x83,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
0x00,0x00,0x00,0xc5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
0x00,0xe7,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xf8,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x55,0xbb,0xe4,0xfa,0xe8,0xb4,0x5a,0x02,0x00,0x00,
0x00,0x00,0x00,0x00,0x05,0xab,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xc5,0x12,0x00,0x00,0x00,
0x00,0x00,0x89,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa7,0x00,0x00,0x00,0x00,0x0a,
0xda,0xff,0xff,0xe0,0x5d,0x39,0x6c,0xea,0xff,0xff,0xfc,0x16,0x00,0x00,0x00,0x00,0x00,0x20,
0x5c,0x22,0x00,0x00,0x00,0x47,0xff,0xff,0xff,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x0d,0xff,0xff,0xff,0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x55,0xff,0xff,0xf4,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x30,0x36,0x74,0xf3,
0xff,0xff,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xff,0xff,0xff,0xff,0xff,0xbc,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xff,0xff,0xff,0xff,0xff,0xff,0x92,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x59,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x21,0x8d,0xfd,0xff,0xff,0xd7,0x01,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x82,0xff,0xff,0xff,0x2a,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x19,0xff,0xff,0xff,0x46,0x00,0x00,0x00,0x0e,0x4f,0x4d,0x00,
0x00,0x00,0x00,0x00,0x1c,0xff,0xff,0xff,0x39,0x00,0x00,0xa9,0xfb,0xff,0xf0,0x26,0x00,0x00,
0x00,0x00,0x87,0xff,0xff,0xf7,0x0c,0x00,0x00,0x6f,0xff,0xff,0xff,0xec,0x78,0x3c,0x4b,0xa3,
0xff,0xff,0xff,0x9b,0x00,0x00,0x00,0x03,0xbe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xe1,0x16,0x00,0x00,0x00,0x00,0x0f,0xb8,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xd5,0x25,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x52,0xb2,0xe7,0xfa,0xed,0xbd,0x65,0x05,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xd7,0xff,
0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x76,0xff,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1b,0xf3,0xff,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x41,0xff,0xff,0xfd,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x04,0xd5,0xff,0xff,0x98,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x73,0xff,0xff,0xb2,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0xf2,0xff,
0xf6,0x21,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa5,0xff,0xff,0x7e,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0xff,0xff,0xdc,0x07,0x00,0x4c,0xff,
0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x04,0xd3,0xff,0xff,0x4a,0x00,0x00,0x4c,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0x00,0x71,0xff,0xff,0xb0,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0x00,0xf1,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x6d,0xff,0xff,0xff,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,
0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x55,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0xd1,0xff,0xff,0x98,0x30,0x30,0x30,0x30,0x30,
0x20,0x00,0x00,0x00,0x00,0x00,0x03,0xf7,0xff,0xff,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x24,0xff,0xff,0xff,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x4d,0xff,0xff,0xf5,0x14,0x2a,0x19,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x77,0xff,0xff,0xfc,0xfd,0xff,0xff,0xf2,0x9b,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0x48,0x00,0x00,0x00,0x00,0x00,0x8a,0xf8,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xf1,0x24,0x00,0x00,0x00,0x00,0x00,0x10,0x66,0xae,0x44,0x0d,
0x19,0x86,0xff,0xff,0xff,0xa5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x9c,0xff,0xff,0xf8,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0xff,
0xff,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0xff,0xff,0xff,
0x43,0x00,0x00,0x3e,0x76,0xa3,0x9e,0x00,0x00,0x00,0x00,0x00,0x2e,0xff,0xff,0xff,0x2a,0x00,
0x00,0x9d,0xff,0xff,0xff,0x50,0x00,0x00,0x00,0x00,0xa9,0xff,0xff,0xef,0x07,0x00,0x00,0x30,
0xfd,0xff,0xff,0xf8,0x83,0x3e,0x50,0xb4,0xff,0xff,0xff,0x91,0x00,0x00,0x00,0x00,0x7a,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xdf,0x11,0x00,0x00,0x00,0x00,0x00,0x78,0xfd,0xff,
0xff,0xff,0xff,0xff,0xff,0xd6,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2f,0x9c,0xdf,0xf9,
0xea,0xc4,0x6b,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xa6,0xff,0xff,0xfc,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x26,0xfd,0xff,0xff,0x99,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa0,
0xff,0xff,0xf3,0x17,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0xfb,0xff,0xff,
0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9a,0xff,0xff,0xe3,0x09,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xf9,0xff,0xff,0x5e,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xff,0xff,0xcd,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0xf7,0xff,0xff,0xfd,0xf8,0xdd,0x97,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x8e,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x4b,0x00,0x00,0x00,0x00,0x00,0x13,
0xf5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf5,0x27,0x00,0x00,0x00,0x00,0x6c,0xff,0xff,
0xff,0xc4,0x49,0x46,0xa6,0xff,0xff,0xff,0xaa,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xe2,0x0a,
0x00,0x00,0x00,0xa6,0xff,0xff,0xf9,0x09,0x00,0x00,0x00,0xe3,0xff,0xff,0x78,0x00,0x00,0x00,
0x00,0x2f,0xff,0xff,0xff,0x34,0x00,0x00,0x00,0xfa,0xff,0xff,0x55,0x00,0x00,0x00,0x00,0x0a,
0xff,0xff,0xff,0x46,0x00,0x00,0x00,0xeb,0xff,0xff,0x75,0x00,0x00,0x00,0x00,0x29,0xff,0xff,
0xff,0x34,0x00,0x00,0x00,0xbe,0xff,0xff,0xdd,0x08,0x00,0x00,0x00,0x9e,0xff,0xff,0xf2,0x06,
0x00,0x00,0x00,0x5f,0xff,0xff,0xff,0xcc,0x51,0x44,0xa1,0xff,0xff,0xff,0x90,0x00,0x00,0x00,
0x00,0x02,0xc0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe1,0x11,0x00,0x00,0x00,0x00,0x00,
0x14,0xc0,0xff,0xff,0xff,0xff,0xff,0xff,0xde,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,
0x5f,0xc2,0xec,0xf5,0xcf,0x78,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb5,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x39,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xbd,0x00,0x00,0x00,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x61,0xff,0xff,0xff,0xff,0x41,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xab,0xff,0xff,0xff,0xc5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x27,
0xfd,0xff,0xff,0xff,0x48,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9e,0xff,0xff,
0xff,0xcb,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xfa,0xff,0xff,0xff,0x50,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xff,0xff,0xff,0xd2,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xf5,0xff,0xff,0xff,0x58,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x83,0xff,0xff,0xff,0xd8,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x0d,0xef,0xff,0xff,0xff,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x76,0xff,0xff,0xff,0xde,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0xe7,0xff,
0xff,0xff,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x69,0xff,0xff,0xff,0xe4,
0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0xde,0xff,0xff,0xff,0x6e,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5b,0xff,0xff,0xff,0xe8,0x09,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0xd3,0xff,0xff,0xff,0x76,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x4e,0xff,0xff,0xff,0xed,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xc7,0xff,0xff,0xff,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x34,0x9f,0xdd,0xf7,0xf6,0xd9,0x97,0x28,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xf9,0x68,0x00,
0x00,0x00,0x00,0x00,0x56,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x49,0x00,0x00,
0x00,0x00,0xc7,0xff,0xff,0xf6,0x7b,0x3e,0x3f,0x7d,0xf7,0xff,0xff,0xc2,0x00,0x00,0x00,0x00,
0xf5,0xff,0xff,0x77,0x00,0x00,0x00,0x00,0x78,0xff,0xff,0xf4,0x00,0x00,0x00,0x00,0xe8,0xff,
0xff,0x62,0x00,0x00,0x00,0x00,0x63,0xff,0xff,0xee,0x00,0x00,0x00,0x00,0xa8,0xff,0xff,0xdf,
0x44,0x0d,0x0c,0x47,0xe2,0xff,0xff,0xaf,0x00,0x00,0x00,0x00,0x24,0xee,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xef,0x27,0x00,0x00,0x00,0x00,0x00,0x5d,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x52,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xfb,0x54,0x00,0x00,0x00,0x18,0xf3,0xff,0xff,0xea,0x75,0x43,0x46,0x87,0xf7,0xff,0xff,0xf4,
0x1b,0x00,0x00,0x89,0xff,0xff,0xeb,0x18,0x00,0x00,0x00,0x00,0x2b,0xef,0xff,0xff,0x8d,0x00,
0x00,0xd5,0xff,0xff,0x7d,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0xff,0xff,0xd5,0x00,0x00,0xf6,
0xff,0xff,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x52,0xff,0xff,0xf6,0x00,0x00,0xee,0xff,0xff,
0x74,0x00,0x00,0x00,0x00,0x00,0x00,0x75,0xff,0xff,0xeb,0x00,0x00,0xbe,0xff,0xff,0xe4,0x19,
0x00,0x00,0x00,0x00,0x1a,0xe6,0xff,0xff,0xbc,0x00,0x00,0x62,0xff,0xff,0xff,0xed,0x78,0x43,
0x43,0x79,0xee,0xff,0xff,0xff,0x5f,0x00,0x00,0x03,0xc3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xc1,0x02,0x00,0x00,0x00,0x11,0xb9,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xb2,0x0e,0x00,0x00,0x00,0x00,0x00,0x01,0x4e,0xab,0xe2,0xf8,0xf6,0xdb,0xa2,0x42,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x5a,0xbb,0xed,0xf4,
0xd2,0x7c,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0xc0,0xff,0xff,0xff,0xff,0xff,0xff,
0xe3,0x34,0x00,0x00,0x00,0x00,0x00,0x03,0xc2,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xec,
0x1b,0x00,0x00,0x00,0x00,0x61,0xff,0xff,0xff,0xc3,0x50,0x41,0x92,0xfe,0xff,0xff,0xa6,0x00,
0x00,0x00,0x00,0xc3,0xff,0xff,0xcc,0x03,0x00,0x00,0x00,0x80,0xff,0xff,0xf8,0x0f,0x00,0x00,
0x00,0xf3,0xff,0xff,0x65,0x00,0x00,0x00,0x00,0x1b,0xff,0xff,0xff,0x36,0x00,0x00,0x00,0xf6,
0xff,0xff,0x61,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x46,0x00,0x00,0x00,0xd6,0xff,0xff,
0xb5,0x00,0x00,0x00,0x00,0x67,0xff,0xff,0xff,0x2f,0x00,0x00,0x00,0x8c,0xff,0xff,0xff,0x98,
0x21,0x10,0x5f,0xf3,0xff,0xff,0xf7,0x06,0x00,0x00,0x00,0x1c,0xf2,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xb6,0x00,0x00,0x00,0x00,0x00,0x4c,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x51,0x00,0x00,0x00,0x00,0x00,0x00,0x2f,0xb2,0xf8,0xff,0xff,0xff,0xff,0xff,0xd5,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x25,0x8b,0xff,0xff,0xff,0x58,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0xe1,0xff,0xff,0xd9,0x02,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xff,0xff,0xff,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x05,0xe1,0xff,0xff,0xde,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x66,0xff,0xff,0xff,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xe0,
0xff,0xff,0xe3,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x65,0xff,0xff,0xff,
0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xdf,0xff,0xff,0xe8,0x09,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,
0xe3,0xe3,0x47,0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0xe4,0xff,0xff,0xe4,0x00,0x00,0x4b,
0xe4,0xe4,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4b,0xe4,0xe4,0x49,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0xe4,
0xff,0xff,0xe3,0x00,0x00,0x49,0xe4,0xe4,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0xe4,
0xff,0xff,0xe4,0x00,0x00,0x4b,0xe4,0xe4,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x03,0x61,0x61,0x04,0x00,0x00,0x99,0xff,0xff,0x9e,0x00,0x00,0xf3,
0xff,0xff,0xf4,0x00,0x00,0xde,0xff,0xff,0xe8,0x00,0x00,0x4f,0xee,0xff,0xa0,0x00,0x00,0x00,
0x99,0xfd,0x2e,0x00,0x00,0x03,0xe8,0x85,0x00,0x00,0x00,0x00,0x26,0x02,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0xfd,0xff,0xff,0xfa,0x2d,0x00,
0x00,0x00,0x00,0x08,0xd7,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x87,0xff,0xff,0xff,
0xd3,0x06,0x00,0x00,0x00,0x00,0x32,0xfb,0xff,0xff,0xfc,0x35,0x00,0x00,0x00,0x00,0x05,0xd1,
0xff,0xff,0xff,0x8b,0x00,0x00,0x00,0x00,0x00,0x7e,0xff,0xff,0xff,0xda,0x09,0x00,0x00,0x00,
0x00,0x2c,0xf9,0xff,0xff,0xfe,0x3e,0x00,0x00,0x00,0x00,0x03,0xca,0xff,0xff,0xff,0x95,0x00,
0x00,0x00,0x00,0x00,0x3d,0xff,0xff,0xff,0xff,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0xb7,0xff,
0xff,0xff,0x9d,0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0xf3,0xff,0xff,0xff,0x43,0x00,0x00,0x00,
0x00,0x00,0x00,0x6e,0xff,0xff,0xff,0xdd,0x0a,0x00,0x00,0x00,0x00,0x00,0x02,0xc7,0xff,0xff,
0xff,0x8c,0x00,0x00,0x00,0x00,0x00,0x00,0x2a,0xf9,0xff,0xff,0xfc,0x34,0x00,0x00,0x00,0x00,
0x00,0x00,0x80,0xff,0xff,0xff,0xd1,0x05,0x00,0x00,0x00,0x00,0x00,0x06,0xd5,0xff,0xff,0xff,
0x7b,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xfd,0xff,0xff,0xf8,0x28,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0xe4,0xff,0xff,0xff,0x83,
0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xff,0xff,0xff,0xfa,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,
0xa2,0xff,0xff,0xff,0xcc,0x03,0x00,0x00,0x00,0x00,0x00,0x12,0xe7,0xff,0xff,0xff,0x77,0x00,
0x00,0x00,0x00,0x00,0x00,0x51,0xff,0xff,0xff,0xf7,0x26,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,
0xff,0xff,0xff,0xc2,0x01,0x00,0x00,0x00,0x00,0x00,0x15,0xea,0xff,0xff,0xff,0x6b,0x00,0x00,
0x00,0x00,0x00,0x00,0x56,0xff,0xff,0xff,0xf2,0x1e,0x00,0x00,0x00,0x00,0x00,0x01,0xe1,0xff,
0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0x69,0xff,0xff,0xff,0xe1,0x0b,0x00,0x00,0x00,0x00,
0x1d,0xf2,0xff,0xff,0xff,0x4b,0x00,0x00,0x00,0x00,0x00,0xb5,0xff,0xff,0xff,0xaa,0x00,0x00,
0x00,0x00,0x00,0x5c,0xff,0xff,0xff,0xef,0x18,0x00,0x00,0x00,0x00,0x16,0xec,0xff,0xff,0xff,
0x66,0x00,0x00,0x00,0x00,0x00,0xa9,0xff,0xff,0xff,0xc2,0x01,0x00,0x00,0x00,0x00,0x4e,0xff,
0xff,0xff,0xf9,0x28,0x00,0x00,0x00,0x00,0x0f,0xe5,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0f,0x52,0x75,0x71,0x52,0x11,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x73,
0xf2,0xff,0xff,0xff,0xff,0xf7,0x9c,0x0d,0x00,0x00,0x00,0x00,0x89,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xd9,0x1a,0x00,0x00,0x39,0xfe,0xff,0xff,0xff,0xd7,0xbd,0xe7,0xff,0xff,0xff,
0xb2,0x00,0x00,0xa1,0xff,0xff,0xff,0x77,0x00,0x00,0x03,0x97,0xff,0xff,0xfe,0x17,0x00,0x9f,
0xe7,0xff,0xd6,0x00,0x00,0x00,0x00,0x11,0xff,0xff,0xff,0x41,0x00,0x00,0x00,0x10,0x22,0x00,
0x00,0x00,0x00,0x15,0xff,0xff,0xff,0x3b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7a,
0xff,0xff,0xff,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x46,0xf7,0xff,0xff,0xd3,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5b,0xf9,0xff,0xff,0xfd,0x45,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x58,0xfe,0xff,0xff,0xff,0x6b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0xee,0xff,
0xff,0xfc,0x63,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0xff,0xff,0xff,0x76,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x11,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x29,
0x8c,0x8c,0x8c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xe4,0xe4,0x49,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xe3,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x47,0xe3,0xe4,
0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0x48,
0x66,0x79,0x6a,0x50,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x38,0xb3,0xf8,0xff,0xff,0xff,0xff,0xff,0xfe,0xc7,0x55,0x02,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0d,0xa7,0xff,0xff,0xff,0xee,0xc1,0xb0,0xcc,0xf3,0xff,0xff,0xff,0xcc,
0x23,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xd6,0xff,0xff,0xd7,0x50,0x05,0x00,0x00,0x00,
0x0a,0x65,0xe1,0xff,0xff,0xf1,0x37,0x00,0x00,0x00,0x00,0x00,0x08,0xc9,0xff,0xff,0xa3,0x06,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0xb7,0xff,0xff,0xeb,0x21,0x00,0x00,0x00,0x00,0x81,
0xff,0xff,0xb2,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0xd1,0xff,0xff,0xb3,
0x00,0x00,0x00,0x16,0xf4,0xff,0xf1,0x13,0x00,0x00,0x2b,0x9e,0xe2,0xfa,0xee,0xbc,0x58,0x00,
0x00,0x2e,0xff,0xff,0xff,0x39,0x00,0x00,0x6b,0xff,0xff,0x86,0x00,0x00,0x63,0xf9,0xff,0xff,
0xff,0xff,0xff,0xff,0xae,0x06,0x00,0xbe,0xff,0xff,0x91,0x00,0x00,0xb9,0xff,0xff,0x30,0x00,
0x44,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x85,0x00,0x79,0xff,0xff,0xd3,0x00,0x00,
0xe0,0xff,0xf6,0x00,0x00,0xc2,0xff,0xff,0xf0,0x6d,0x39,0x64,0xec,0xff,0xff,0xe6,0x00,0x58,
0xff,0xff,0xee,0x00,0x00,0xf8,0xff,0xdf,0x00,0x00,0xf5,0xff,0xff,0x6b,0x00,0x00,0x00,0x65,
0xff,0xff,0xff,0x09,0x5c,0xff,0xff,0xf7,0x00,0x00,0xed,0xff,0xeb,0x00,0x00,0xef,0xff,0xff,
0x73,0x00,0x00,0x00,0x79,0xff,0xff,0xff,0x58,0xac,0xff,0xff,0xd4,0x00,0x00,0xd3,0xff,0xfe,
0x11,0x00,0xb2,0xff,0xff,0xf5,0x72,0x3a,0x6a,0xf3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7e,
0x00,0x00,0x95,0xff,0xff,0x5d,0x00,0x36,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xd0,0xff,
0xff,0xff,0xff,0xd9,0x0b,0x00,0x00,0x43,0xff,0xff,0xcd,0x01,0x00,0x5a,0xf8,0xff,0xff,0xff,
0xff,0xff,0xb2,0x0b,0xad,0xff,0xff,0xc2,0x1d,0x00,0x00,0x00,0x00,0xc8,0xff,0xff,0x68,0x00,
0x00,0x29,0xa0,0xe4,0xf9,0xdf,0x83,0x06,0x00,0x00,0x1a,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0xfb,0xff,0xf9,0x47,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x6a,0xff,0xff,0xfc,0x7d,0x08,0x00,0x00,0x00,0x00,0x00,0x00,
0x36,0x8d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xf8,0xff,0xff,0xe5,0x8d,
0x4b,0x30,0x38,0x65,0xb8,0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x30,0xb9,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xcf,0x36,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0x85,0xc9,0xe7,0xfa,0xf0,0xd6,0x9e,0x47,0x01,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
0xf6,0xff,0xff,0xff,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x5d,0xff,0xff,0xff,0xff,0xc8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xb5,0xff,0xff,0xff,0xff,0xff,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x12,0xfa,0xff,0xff,0xff,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x65,0xff,0xff,0xff,0xf8,0xff,0xff,0xd0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xbd,0xff,0xff,0xf2,0x8a,0xff,0xff,0xff,0x29,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x18,0xfd,0xff,0xff,0xa7,0x31,0xff,0xff,0xff,0x81,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x6e,0xff,0xff,0xff,0x54,0x00,0xde,0xff,0xff,0xd8,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xc6,0xff,0xff,0xf6,0x0b,0x00,0x8d,0xff,0xff,0xff,0x31,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x1f,0xfe,0xff,0xff,0xae,0x00,0x00,0x3a,0xff,0xff,0xff,0x89,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x76,0xff,0xff,0xff,0x5c,0x00,0x00,0x01,0xe6,0xff,0xff,0xe0,
0x01,0x00,0x00,0x00,0x00,0x00,0x00,0xcf,0xff,0xff,0xfe,0x3f,0x30,0x30,0x30,0xaf,0xff,0xff,
0xff,0x3a,0x00,0x00,0x00,0x00,0x00,0x27,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x92,0x00,0x00,0x00,0x00,0x00,0x7f,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xe7,0x02,0x00,0x00,0x00,0x00,0xd6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x42,0x00,0x00,0x00,0x2f,0xff,0xff,0xff,0xf1,0x08,0x00,0x00,0x00,
0x00,0x00,0x8e,0xff,0xff,0xff,0x9b,0x00,0x00,0x00,0x88,0xff,0xff,0xff,0x9e,0x00,0x00,0x00,
0x00,0x00,0x00,0x33,0xff,0xff,0xff,0xed,0x05,0x00,0x00,0xdf,0xff,0xff,0xff,0x42,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xd8,0xff,0xff,0xff,0x4b,0x00,0x38,0xff,0xff,0xff,0xe3,0x02,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0xff,0xff,0xff,0xa3,0x00,0x90,0xff,0xff,0xff,0x8a,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0xff,0xff,0xff,0xf2,0x08,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xfd,0xea,0xd0,0x9c,0x3a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xfe,0x93,0x01,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x7c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x31,
0x43,0x83,0xf6,0xff,0xff,0xf1,0x06,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x5e,0xff,0xff,0xff,0x36,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x0e,0xff,0xff,0xff,0x44,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x40,
0xff,0xff,0xff,0x28,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x01,0x11,0x4f,0xe2,0xff,
0xff,0xcf,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xdc,
0x28,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xd0,0x53,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x7b,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x3d,0x68,0xcc,0xff,0xff,0xff,0x41,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x04,0xbe,0xff,0xff,0xb8,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xf2,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xf2,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x04,0xbe,0xff,0xff,0xd2,0x00,0x00,0x00,0xff,
0xff,0xff,0x6d,0x30,0x30,0x30,0x3c,0x67,0xcb,0xff,0xff,0xff,0x7e,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe2,0x0e,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xda,0x29,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xf8,0xe4,0xb4,0x63,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2f,0x96,0xda,0xf6,0xf2,0xcc,0x7d,0x15,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x8a,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x4b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x94,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf9,
0x48,0x00,0x00,0x00,0x00,0x00,0x4b,0xff,0xff,0xff,0xd9,0x64,0x38,0x56,0xca,0xff,0xff,0xff,
0xf5,0x23,0x00,0x00,0x00,0x00,0xd4,0xff,0xff,0xcd,0x0c,0x00,0x00,0x00,0x05,0xb3,0xff,0xff,
0xff,0xa7,0x00,0x00,0x00,0x3d,0xff,0xff,0xff,0x33,0x00,0x00,0x00,0x00,0x00,0x15,0xf3,0xff,
0xff,0xfa,0x10,0x00,0x00,0x8b,0xff,0xff,0xcf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8d,0xd4,
0xd4,0xd4,0x38,0x00,0x00,0xc4,0xff,0xff,0x8e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xe8,0xff,0xff,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xfa,0xff,0xff,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xfa,0xff,0xff,0x53,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xe9,0xff,0xff,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xc6,0xff,0xff,0x8d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x8d,0xff,0xff,0xce,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x89,0xc8,
0xc8,0xc8,0x35,0x00,0x00,0x3e,0xff,0xff,0xff,0x3d,0x00,0x00,0x00,0x00,0x00,0x15,0xf5,0xff,
0xff,0xfa,0x10,0x00,0x00,0x01,0xd6,0xff,0xff,0xcd,0x0b,0x00,0x00,0x00,0x03,0xb4,0xff,0xff,
0xff,0xa9,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0xd7,0x62,0x37,0x4f,0xc0,0xff,0xff,0xff,
0xf6,0x25,0x00,0x00,0x00,0x00,0x00,0x94,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfa,
0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x8b,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0x51,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2f,0x97,0xdb,0xf6,0xf3,0xce,0x82,0x18,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xf7,0xd7,0x91,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf8,0x6a,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,
0x30,0x37,0x5a,0xb2,0xff,0xff,0xff,0xfe,0x3b,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x59,0xfb,0xff,0xff,0xd0,0x02,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x78,0xff,0xff,0xff,0x3c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x05,0xe6,0xff,0xff,0x8e,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0x94,0xff,0xff,0xc9,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x62,0xff,0xff,0xe2,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x51,0xff,0xff,0xf8,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x59,
0xff,0xff,0xec,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x73,0xff,
0xff,0xd5,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xaa,0xff,0xff,
0xb7,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x0e,0xf5,0xff,0xff,0x70,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x8e,0xff,0xff,0xff,0x23,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x67,0xfe,0xff,0xff,0xb1,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x6d,0x30,0x37,0x5b,0xb8,0xff,0xff,0xff,0xf9,0x24,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x5b,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf4,0x57,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xf7,0xd6,0x8c,0x1e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x6d,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x30,0x30,0x30,
0x30,0x30,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x30,0x30,0x30,
0x30,0x30,0x30,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x4a,0x6c,0x7a,0x63,0x25,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x12,0x8f,0xf6,0xff,0xff,0xff,0xff,0xff,0xbb,0x23,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x24,0xdc,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xec,0x3a,0x00,
0x00,0x00,0x00,0x00,0x00,0x0d,0xd9,0xff,0xff,0xff,0xf6,0xc4,0xc8,0xfe,0xff,0xff,0xff,0xe6,
0x0e,0x00,0x00,0x00,0x00,0x00,0x8c,0xff,0xff,0xff,0xa7,0x14,0x00,0x00,0x31,0xd5,0xff,0xff,
0xd2,0x3f,0x00,0x00,0x00,0x00,0x13,0xf7,0xff,0xff,0xb8,0x01,0x00,0x00,0x00,0x00,0x1f,0x7a,
0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0xff,0xff,0xfd,0x27,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb1,0xff,0xff,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdd,0xff,0xff,0x7e,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0xff,0x59,0x00,0x00,0x00,0x00,
0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0xfd,0xff,0xff,0x4f,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xf3,0xff,0xff,0x5c,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xda,0xff,0xff,0x7f,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xee,0x00,0x00,0x00,0xb1,0xff,0xff,0xba,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe3,0xff,0xff,0xd7,0x00,0x00,0x00,0x72,0xff,0xff,
0xf9,0x16,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0xfb,0xff,0xff,0xb8,0x00,0x00,0x00,0x1c,0xfd,
0xff,0xff,0x88,0x00,0x00,0x00,0x00,0x00,0x00,0x5e,0xff,0xff,0xff,0x77,0x00,0x00,0x00,0x00,
0xa9,0xff,0xff,0xfb,0x47,0x00,0x00,0x00,0x00,0x14,0xe4,0xff,0xff,0xfc,0x1c,0x00,0x00,0x00,
0x00,0x23,0xf5,0xff,0xff,0xfa,0x90,0x44,0x3a,0x70,0xe3,0xff,0xff,0xff,0x98,0x00,0x00,0x00,
0x00,0x00,0x00,0x5a,0xfe,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xda,0x10,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x54,0xee,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xca,0x1c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x7a,0xc8,0xec,0xfa,0xe6,0xb2,0x59,0x02,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,
0x30,0x30,0x30,0x30,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x4b,
0x4c,0x4c,0x17,0x00,0x00,0x00,0x00,0x00,0x01,0xff,0xff,0xff,0x4a,0x00,0x00,0xee,0xff,0xff,
0x54,0x00,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x3b,0x00,0x00,0xd8,0xff,0xff,0x70,0x00,
0x00,0x00,0x00,0x00,0x31,0xff,0xff,0xff,0x26,0x00,0x00,0xb7,0xff,0xff,0xad,0x00,0x00,0x00,
0x00,0x00,0x7b,0xff,0xff,0xf3,0x05,0x00,0x00,0x72,0xff,0xff,0xfb,0x2c,0x00,0x00,0x00,0x0b,
0xde,0xff,0xff,0xb3,0x00,0x00,0x00,0x15,0xf5,0xff,0xff,0xe8,0x67,0x37,0x52,0xcc,0xff,0xff,
0xff,0x48,0x00,0x00,0x00,0x00,0x74,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb2,0x00,
0x00,0x00,0x00,0x00,0x00,0x8c,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb9,0x09,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x3d,0xa9,0xe5,0xfa,0xf0,0xc0,0x61,0x02,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x16,0xe0,0xff,0xff,0xff,
0x76,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x07,0xc5,0xff,0xff,0xff,0xa3,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0xa2,0xff,0xff,0xff,0xc9,0x08,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x79,0xff,0xff,0xff,0xe5,0x19,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x50,0xfe,0xff,0xff,0xf6,0x34,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x30,0xf4,0xff,0xff,0xff,0x59,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x18,0xe2,0xff,0xff,0xff,0x86,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x54,0xc8,0xff,0xff,0xff,0xb1,0x02,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xde,0xff,0xff,0xff,0xd5,0x0d,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe3,0x11,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa7,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xc0,0xf1,0xff,0xff,0xff,0x58,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xd3,0x0e,0x60,0xff,0xff,0xff,0xee,0x1b,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4f,0x00,0x00,0xae,0xff,0xff,0xff,0xba,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x14,0xe8,0xff,0xff,0xff,0x6e,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0xf6,0x28,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x9a,0xff,0xff,0xff,0xcb,0x04,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x0c,0xdc,0xff,0xff,0xff,0x83,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x3a,0xfc,0xff,0xff,0xfc,
0x38,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x85,0xff,0xff,0xff,
0xdb,0x0b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,
0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xc0,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xbd,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xfd,0x1a,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0xfd,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xff,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0xff,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xc9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcb,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x21,0x00,0x00,
0x00,0x00,0x00,0x24,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0x79,0x00,0x00,0x00,0x00,0x00,0x7e,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0xfe,0xff,0xff,0xd2,0x00,0x00,0x00,0x00,0x00,0xd7,0xff,0xff,0xfd,0xff,
0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xc4,0xff,0xff,0xff,0x29,0x00,0x00,0x00,0x32,
0xff,0xff,0xff,0xc3,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x72,0xff,0xff,0xff,
0x82,0x00,0x00,0x00,0x8b,0xff,0xff,0xff,0x6e,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0xd3,0xff,0xff,0xda,0x00,0x00,0x01,0xe3,0xff,0xff,0xce,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x80,0xff,0xff,0xff,0x33,0x00,0x3f,0xff,0xff,0xff,0x79,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x2d,0xff,0xff,0xff,0x8b,0x00,
0x99,0xff,0xff,0xff,0x25,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0xda,0xff,0xff,0xe2,0x06,0xed,0xff,0xff,0xd0,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x87,0xff,0xff,0xff,0x88,0xff,0xff,0xff,0x7c,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x34,0xff,0xff,0xff,0xfd,0xff,0xff,0xff,
0x28,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0xe0,0xff,
0xff,0xff,0xff,0xff,0xd3,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x8e,0xff,0xff,0xff,0xff,0xff,0x7f,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x3b,0xff,0xff,0xff,0xff,0xff,0x2a,0x00,0x00,0x4c,
0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x01,0xe6,0xff,0xff,0xff,
0xd6,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x95,0xff,0xff,0xff,0x82,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xf7,0x23,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xb5,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0x50,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xe0,0x0a,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0x86,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0xf6,0xff,0xff,0xf9,0x26,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x82,0xfe,0xff,0xff,0xba,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0xa0,0xff,0xff,0xff,0x56,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x19,0xf3,0xff,0xff,0xe4,0x0c,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x77,0xff,0xff,0xff,0x8b,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x06,0xdc,0xff,0xff,0xfb,0x2a,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x4e,0xff,0xff,0xff,0xc0,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xb9,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x2a,0xfb,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x91,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x10,0xeb,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x03,0xd0,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x3f,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x29,0x90,0xd6,0xf3,0xf4,0xd7,0x92,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
0x82,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x86,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x00,0x44,0xff,
0xff,0xff,0xea,0x77,0x3d,0x40,0x79,0xe9,0xff,0xff,0xff,0x47,0x00,0x00,0x00,0x00,0xcd,0xff,
0xff,0xdc,0x19,0x00,0x00,0x00,0x00,0x1b,0xdc,0xff,0xff,0xd0,0x00,0x00,0x00,0x37,0xff,0xff,
0xff,0x43,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0xff,0xff,0xff,0x3c,0x00,0x00,0x89,0xff,0xff,
0xd9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd5,0xff,0xff,0x8b,0x00,0x00,0xc4,0xff,0xff,
0x95,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xff,0xff,0xc4,0x00,0x00,0xe8,0xff,0xff,
0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0xff,0xe8,0x00,0x00,0xfa,0xff,0xff,
0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x59,0xff,0xff,0xf9,0x00,0x00,0xfa,0xff,0xff,
0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xff,0xfa,0x00,0x00,0xe9,0xff,0xff,
0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xff,0xff,0xe9,0x00,0x00,0xc6,0xff,0xff,
0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xc6,0x00,0x00,0x8b,0xff,0xff,
0xd8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd6,0xff,0xff,0x8d,0x00,0x00,0x39,0xff,0xff,
0xff,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x4d,0xff,0xff,0xff,0x3e,0x00,0x00,0x00,0xcf,0xff,
0xff,0xdc,0x17,0x00,0x00,0x00,0x00,0x16,0xdc,0xff,0xff,0xd2,0x00,0x00,0x00,0x00,0x45,0xff,
0xff,0xff,0xe8,0x75,0x3c,0x3c,0x74,0xe7,0xff,0xff,0xff,0x48,0x00,0x00,0x00,0x00,0x00,0x8c,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x01,
0x82,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x86,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x29,0x91,0xd7,0xf4,0xf4,0xd8,0x93,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xfc,0xec,0xce,0x9c,0x40,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xcb,0x28,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe7,0x13,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,
0x30,0x30,0x39,0x59,0xb0,0xff,0xff,0xff,0x81,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xb5,0xff,0xff,0xd1,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x59,0xff,0xff,0xf6,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x59,
0xff,0xff,0xf6,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xb6,0xff,0xff,
0xd1,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x39,0x59,0xb0,0xff,0xff,0xff,0x80,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe1,0x10,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xc0,0x21,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xfb,0xeb,0xcc,0x97,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0x51,0x70,0x75,0x59,0x17,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x12,0x96,0xf8,0xff,0xff,0xff,0xff,0xfd,0xaa,0x1f,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x21,0xdc,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xea,0x32,0x00,0x00,0x00,
0x00,0x00,0x09,0xd3,0xff,0xff,0xff,0xef,0xc1,0xc4,0xf1,0xff,0xff,0xff,0xe3,0x13,0x00,0x00,
0x00,0x00,0x81,0xff,0xff,0xfe,0x83,0x0a,0x00,0x00,0x0d,0x95,0xff,0xff,0xff,0x96,0x00,0x00,
0x00,0x0c,0xf2,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x00,0x00,0x9d,0xff,0xff,0xf9,0x16,0x00,
0x00,0x5f,0xff,0xff,0xf4,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xf6,0xff,0xff,0x6d,0x00,
0x00,0xa7,0xff,0xff,0xab,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xad,0xff,0xff,0xae,0x00,
0x00,0xd8,0xff,0xff,0x7b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x76,0xff,0xff,0xda,0x00,
0x00,0xf4,0xff,0xff,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xf3,0x00,
0x00,0xfc,0xff,0xff,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x50,0xff,0xff,0xfc,0x00,
0x00,0xf2,0xff,0xff,0x5b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xf1,0x00,
0x00,0xd6,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7b,0xff,0xff,0xdf,0x00,
0x00,0xa8,0xff,0xff,0xa8,0x00,0x00,0x00,0x00,0x00,0x9d,0x48,0x00,0xaa,0xff,0xff,0xb6,0x00,
0x00,0x64,0xff,0xff,0xf0,0x08,0x00,0x00,0x00,0x78,0xff,0xfd,0x80,0xed,0xff,0xff,0x81,0x00,
0x00,0x12,0xf7,0xff,0xff,0x69,0x00,0x00,0x2d,0xfc,0xff,0xff,0xff,0xff,0xff,0xff,0x34,0x00,
0x00,0x00,0x97,0xff,0xff,0xf1,0x26,0x00,0x00,0x5f,0xf1,0xff,0xff,0xff,0xff,0xcb,0x00,0x00,
0x00,0x00,0x16,0xed,0xff,0xff,0xee,0x79,0x3b,0x3f,0xa1,0xff,0xff,0xff,0xff,0xdc,0x28,0x00,
0x00,0x00,0x00,0x49,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe3,0x05,
0x00,0x00,0x00,0x00,0x47,0xea,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb8,0xf2,0xff,0x5d,0x00,
0x00,0x00,0x00,0x00,0x00,0x0f,0x79,0xca,0xef,0xf9,0xe2,0xaa,0x49,0x00,0x33,0x91,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xfd,0xed,0xd1,0x9f,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xcb,0x28,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xe7,0x13,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x3a,0x5d,
0xb4,0xff,0xff,0xff,0x83,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x01,
0xb9,0xff,0xff,0xd2,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x5a,
0xff,0xff,0xf6,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x59,0xff,
0xff,0xef,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xb5,0xff,0xff,
0xcf,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x39,0x59,0xb0,0xff,0xff,0xff,0x7e,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe4,0x14,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xd2,0x25,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xfd,0xff,0xff,0xff,0x87,0x01,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x43,0xff,0xff,0xff,0xd2,0x01,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0xb2,0xff,0xff,0xff,0x59,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x26,0xfa,0xff,0xff,0xda,0x03,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x90,0xff,0xff,0xff,0x62,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x12,0xed,0xff,0xff,0xe0,0x06,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x6e,0xff,0xff,0xff,0x6c,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x05,0xd8,0xff,0xff,0xe6,0x09,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x75,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0x7b,0xc6,0xef,0xfa,0xe6,0xad,0x46,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4e,0xf0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xaa,0x0a,
0x00,0x00,0x00,0x00,0x2e,0xfa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb4,0x00,0x00,
0x00,0x00,0xaa,0xff,0xff,0xfd,0x90,0x47,0x37,0x5c,0xd3,0xff,0xff,0xff,0x52,0x00,0x00,0x00,
0xea,0xff,0xff,0x85,0x00,0x00,0x00,0x00,0x10,0x9d,0x73,0x41,0x0e,0x00,0x00,0x00,0xf9,0xff,
0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xda,0xff,0xff,0xd2,
0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0xff,0xff,0xff,0xf2,0x8d,
0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xb0,0xff,0xff,0xff,0xff,0xff,0xc3,
0x60,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x72,0xed,0xff,0xff,0xff,0xff,0xff,0xdc,
0x47,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x69,0xd0,0xff,0xff,0xff,0xff,0xfe,0x71,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0xa1,0xfc,0xff,0xff,0xfe,0x40,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x35,0xf3,0xff,0xff,0xb1,0x00,0x00,0x00,
0x00,0x12,0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0xff,0xff,0xe4,0x00,0x00,0x75,0xe5,0xff,
0xe4,0x04,0x00,0x00,0x00,0x00,0x00,0x5a,0xff,0xff,0xf8,0x00,0x00,0x61,0xff,0xff,0xff,0x8a,
0x00,0x00,0x00,0x00,0x00,0xaf,0xff,0xff,0xdb,0x00,0x00,0x0a,0xe7,0xff,0xff,0xff,0xb2,0x53,
0x38,0x53,0xb5,0xff,0xff,0xff,0x8d,0x00,0x00,0x00,0x48,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xe4,0x13,0x00,0x00,0x00,0x00,0x4a,0xea,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xd3,0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x78,0xc6,0xf0,0xfb,0xea,0xb8,0x62,0x06,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x6d,0xff,0xff,0xff,0x30,
0x30,0x30,0x30,0x30,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xfe,0xff,0xff,0x4d,0x00,0x00,0x00,0x00,0x00,0x00,
0x4c,0xff,0xff,0xfe,0x00,0x00,0x00,0x00,0xee,0xff,0xff,0x60,0x00,0x00,0x00,0x00,0x00,0x00,
0x5b,0xff,0xff,0xed,0x00,0x00,0x00,0x00,0xd8,0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0xff,0xff,0xd7,0x00,0x00,0x00,0x00,0xa7,0xff,0xff,0xd5,0x00,0x00,0x00,0x00,0x00,0x00,
0xce,0xff,0xff,0xa5,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xff,0x55,0x00,0x00,0x00,0x00,0x63,
0xff,0xff,0xff,0x58,0x00,0x00,0x00,0x00,0x09,0xe0,0xff,0xff,0xfa,0x87,0x3e,0x3d,0x90,0xfe,
0xff,0xff,0xdc,0x07,0x00,0x00,0x00,0x00,0x00,0x4b,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xfc,0x47,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x52,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,
0xf6,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0x93,0xd9,0xf8,0xf8,0xd8,0x91,
0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,
0xed,0xff,0xff,0xde,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xff,0x19,0x00,0xa8,
0xff,0xff,0xff,0x23,0x00,0x00,0x00,0x00,0x00,0x00,0xda,0xff,0xff,0xd2,0x00,0x00,0x60,0xff,
0xff,0xff,0x69,0x00,0x00,0x00,0x00,0x00,0x20,0xff,0xff,0xff,0x8b,0x00,0x00,0x19,0xff,0xff,
0xff,0xae,0x00,0x00,0x00,0x00,0x00,0x66,0xff,0xff,0xff,0x45,0x00,0x00,0x00,0xd0,0xff,0xff,
0xef,0x03,0x00,0x00,0x00,0x00,0xac,0xff,0xff,0xf6,0x08,0x00,0x00,0x00,0x88,0xff,0xff,0xff,
0x39,0x00,0x00,0x00,0x03,0xef,0xff,0xff,0xb8,0x00,0x00,0x00,0x00,0x40,0xff,0xff,0xff,0x7e,
0x00,0x00,0x00,0x39,0xff,0xff,0xff,0x72,0x00,0x00,0x00,0x00,0x05,0xf2,0xff,0xff,0xc3,0x00,
0x00,0x00,0x7f,0xff,0xff,0xff,0x2b,0x00,0x00,0x00,0x00,0x00,0xb0,0xff,0xff,0xfb,0x0d,0x00,
0x00,0xc5,0xff,0xff,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,0x68,0xff,0xff,0xff,0x4e,0x00,0x0f,
0xfb,0xff,0xff,0x9f,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xff,0xff,0xff,0x93,0x00,0x51,0xff,
0xff,0xff,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd8,0xff,0xff,0xd9,0x00,0x98,0xff,0xff,
0xfd,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xff,0xff,0xff,0x1e,0xdd,0xff,0xff,0xcb,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xff,0x88,0xff,0xff,0xff,0x85,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0xf7,0xff,0xff,0xf7,0xff,0xff,0xff,0x3f,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb8,0xff,0xff,0xff,0xff,0xff,0xf2,0x05,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x70,0xff,0xff,0xff,0xff,0xff,0xb2,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x28,0xff,0xff,0xff,0xff,0xff,0x6b,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xdf,0xff,0xff,0xff,0xff,0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x98,0xff,0xff,0xff,0xdf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf3,0xff,0xff,0x9c,0x00,0x00,0x00,0x7b,0xff,0xff,
0xff,0xd7,0x00,0x00,0x00,0x40,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xcc,0xff,0xff,0xbc,0x00,
0x00,0x00,0xaa,0xff,0xff,0xff,0xfc,0x08,0x00,0x00,0x61,0xff,0xff,0xff,0x24,0x00,0x00,0x00,
0xa4,0xff,0xff,0xdd,0x00,0x00,0x00,0xd9,0xff,0xff,0xff,0xff,0x34,0x00,0x00,0x82,0xff,0xff,
0xf8,0x03,0x00,0x00,0x00,0x7c,0xff,0xff,0xfb,0x03,0x00,0x0a,0xfd,0xff,0xff,0xff,0xff,0x63,
0x00,0x00,0xa2,0xff,0xff,0xd4,0x00,0x00,0x00,0x00,0x53,0xff,0xff,0xff,0x1f,0x00,0x37,0xff,
0xff,0xff,0xff,0xff,0x91,0x00,0x00,0xc3,0xff,0xff,0xac,0x00,0x00,0x00,0x00,0x2b,0xff,0xff,
0xff,0x40,0x00,0x66,0xff,0xff,0xff,0xff,0xff,0xc0,0x00,0x00,0xe4,0xff,0xff,0x84,0x00,0x00,
0x00,0x00,0x06,0xfc,0xff,0xff,0x61,0x00,0x95,0xff,0xff,0xed,0xff,0xff,0xee,0x00,0x06,0xfd,
0xff,0xff,0x5c,0x00,0x00,0x00,0x00,0x00,0xdb,0xff,0xff,0x81,0x00,0xc4,0xff,0xff,0x9b,0xff,
0xff,0xff,0x1d,0x25,0xff,0xff,0xff,0x34,0x00,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xa2,0x01,
0xf2,0xff,0xff,0x4e,0xf4,0xff,0xff,0x4c,0x46,0xff,0xff,0xff,0x0c,0x00,0x00,0x00,0x00,0x00,
0x8a,0xff,0xff,0xc3,0x22,0xff,0xff,0xff,0x21,0xc9,0xff,0xff,0x7b,0x66,0xff,0xff,0xe4,0x00,
0x00,0x00,0x00,0x00,0x00,0x62,0xff,0xff,0xe4,0x51,0xff,0xff,0xf3,0x01,0x9d,0xff,0xff,0xa9,
0x87,0xff,0xff,0xbc,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0xff,0xff,0xfe,0x87,0xff,0xff,0xc9,
0x00,0x71,0xff,0xff,0xd8,0xa8,0xff,0xff,0x94,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0xff,0xff,
0xff,0xd5,0xff,0xff,0x9d,0x00,0x44,0xff,0xff,0xfd,0xd2,0xff,0xff,0x6c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xea,0xff,0xff,0xff,0xff,0xff,0x71,0x00,0x18,0xff,0xff,0xff,0xff,0xff,0xff,
0x44,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc1,0xff,0xff,0xff,0xff,0xff,0x45,0x00,0x00,0xeb,
0xff,0xff,0xff,0xff,0xff,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x99,0xff,0xff,0xff,0xff,
0xff,0x19,0x00,0x00,0xc0,0xff,0xff,0xff,0xff,0xf3,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x71,0xff,0xff,0xff,0xff,0xec,0x00,0x00,0x00,0x93,0xff,0xff,0xff,0xff,0xcc,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x49,0xff,0xff,0xff,0xff,0xc1,0x00,0x00,0x00,0x67,0xff,0xff,0xff,
0xff,0xa4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0xff,0xff,0xff,0xff,0x95,0x00,0x00,
0x00,0x3b,0xff,0xff,0xff,0xff,0x7c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xf6,0xff,
0xff,0xff,0x69,0x00,0x00,0x00,0x0f,0xff,0xff,0xff,0xff,0x54,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xcf,0xff,0xff,0xff,0x9e,0x00,0x00,0x00,
0x00,0x00,0x29,0xfd,0xff,0xff,0xff,0x4e,0x00,0x3f,0xff,0xff,0xff,0xfc,0x25,0x00,0x00,0x00,
0x00,0xab,0xff,0xff,0xff,0xb9,0x00,0x00,0x00,0xac,0xff,0xff,0xff,0xa6,0x00,0x00,0x00,0x30,
0xfe,0xff,0xff,0xfb,0x2a,0x00,0x00,0x00,0x21,0xf7,0xff,0xff,0xfd,0x2c,0x00,0x00,0xb3,0xff,
0xff,0xff,0x93,0x00,0x00,0x00,0x00,0x00,0x85,0xff,0xff,0xff,0xaf,0x00,0x38,0xff,0xff,0xff,
0xed,0x12,0x00,0x00,0x00,0x00,0x00,0x0c,0xe6,0xff,0xff,0xff,0x33,0xbc,0xff,0xff,0xff,0x6b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5f,0xff,0xff,0xff,0xda,0xff,0xff,0xff,0xd4,0x03,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xca,0xff,0xff,0xff,0xff,0xff,0xff,0x44,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xff,0xff,0xff,0xff,0xff,0xb0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xa5,0xff,0xff,0xff,0xf9,0x24,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xaf,0xff,0xff,0xff,0xfb,0x2a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x42,0xff,0xff,0xff,0xff,0xff,0xb9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x03,0xd2,0xff,0xff,0xff,0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x69,0xff,0xff,0xff,0xd1,0xff,0xff,0xff,0xdb,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0xeb,
0xff,0xff,0xfe,0x2d,0xb3,0xff,0xff,0xff,0x76,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0xff,0xff,
0xff,0xa6,0x00,0x30,0xfe,0xff,0xff,0xf2,0x17,0x00,0x00,0x00,0x00,0x28,0xfb,0xff,0xff,0xfc,
0x25,0x00,0x00,0xa9,0xff,0xff,0xff,0x9e,0x00,0x00,0x00,0x00,0xb7,0xff,0xff,0xff,0x9e,0x00,
0x00,0x00,0x28,0xfc,0xff,0xff,0xfe,0x33,0x00,0x00,0x4b,0xff,0xff,0xff,0xf9,0x20,0x00,0x00,
0x00,0x00,0x9f,0xff,0xff,0xff,0xc4,0x00,0x05,0xd8,0xff,0xff,0xff,0x96,0x00,0x00,0x00,0x00,
0x00,0x20,0xfa,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xcc,0xff,0xff,0xff,0xa0,0x00,
0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xff,0xf6,0x1f,0x00,0x3b,0xff,0xff,0xff,0xfc,0x24,0x00,
0x00,0x00,0x02,0xd8,0xff,0xff,0xff,0x82,0x00,0x00,0x00,0xa5,0xff,0xff,0xff,0xa0,0x00,0x00,
0x00,0x5b,0xff,0xff,0xff,0xe3,0x0a,0x00,0x00,0x00,0x1c,0xf5,0xff,0xff,0xfc,0x24,0x00,0x02,
0xd7,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x00,0x7d,0xff,0xff,0xff,0xa0,0x00,0x59,0xff,
0xff,0xff,0xc5,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xdf,0xff,0xff,0xfc,0x26,0xd6,0xff,0xff,
0xfe,0x34,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xff,0xff,0xdc,0xff,0xff,0xff,0x9e,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbf,0xff,0xff,0xff,0xff,0xff,0xf2,0x17,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2e,0xfc,0xff,0xff,0xff,0xff,0x76,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x97,0xff,0xff,0xff,0xdb,0x06,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x45,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa6,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0x17,0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x30,0xc9,0xff,0xff,0xff,0x6a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4b,0xff,0xff,0xff,0xc9,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x0a,0xdf,0xff,0xff,0xfc,0x30,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x88,0xff,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x2c,0xfa,0xff,0xff,0xe4,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xc3,0xff,0xff,0xff,0x53,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x63,0xff,0xff,0xff,0xb4,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0xec,0xff,0xff,0xf5,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa0,0xff,0xff,0xff,0x78,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0xff,0xff,0xff,0xd4,0x05,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xd5,0xff,0xff,0xfe,0x3c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7a,0xff,0xff,0xff,0x9d,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x21,0xf6,0xff,0xff,0xeb,0x13,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0xff,0xff,0xff,0x8b,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x30,0x30,0x18,0x00,0x00,0x00,0x55,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x0d,0xe5,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x91,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,
0x30,0x30,0x30,0x30,0x18,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x6d,0x30,0x30,0x18,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x52,0xff,0xff,0xff,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,
0xe8,0xff,0xff,0xe8,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x89,0xff,0xff,0xff,0x55,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x25,0xff,0xff,0xff,0xbc,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xc1,0xff,0xff,0xfe,0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5c,
0xff,0xff,0xff,0x8b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0xef,0xff,0xff,0xeb,0x06,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xff,0x59,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x2f,0xff,0xff,0xff,0xc1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcb,
0xff,0xff,0xff,0x28,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x66,0xff,0xff,0xff,0x8f,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xf4,0xff,0xff,0xed,0x08,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x9e,0xff,0xff,0xff,0x5e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x39,0xff,
0xff,0xff,0xc5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd4,0xff,0xff,0xff,0x2c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x70,0xff,0xff,0xff,0x93,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x13,0xf8,0xff,0xff,0xf0,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xa8,0xff,
0xff,0xff,0x62,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0xff,0xff,0xff,0xc9,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0xdd,0xff,0xff,0xff,0x30,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x7a,0xff,0xff,0xff,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x0e,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x30,0x30,
0x30,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x22,0xec,0xff,0xff,0xd4,0x0d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0e,0xd5,0xff,0xff,0xff,
0xff,0xb3,0x02,0x00,0x00,0x00,0x00,0x00,0x03,0xb6,0xff,0xff,0xcb,0xe7,0xff,0xff,0x8a,0x00,
0x00,0x00,0x00,0x00,0x8f,0xff,0xff,0xeb,0x1d,0x38,0xf8,0xff,0xff,0x5f,0x00,0x00,0x00,0x17,
0x7f,0x80,0x80,0x3a,0x00,0x00,0x48,0x80,0x80,0x78,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x30,0x30,
0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x0c,0x69,0x17,0x00,0x00,0x00,0x00,0xb5,0xff,0xde,0x28,0x00,0x00,0x00,0xef,0xff,0xff,
0xed,0x3d,0x00,0x00,0x41,0xe3,0xff,0xff,0xf8,0x57,0x00,0x00,0x10,0xa6,0xff,0xff,0xd6,0x00,
0x00,0x00,0x00,0x57,0xe4,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x6c,0xbd,0xee,0xf6,0xdb,
0xb2,0x57,0x02,0x00,0x00,0x00,0x00,0x05,0xdc,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xc5,0x16,
0x00,0x00,0x00,0x00,0x6b,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xcc,0x04,0x00,0x00,0x00,
0x00,0x60,0x4c,0x3a,0x35,0x54,0xac,0xff,0xff,0xff,0x60,0x00,0x00,0x00,0x00,0x47,0xbf,0xf3,
0xec,0xad,0x29,0xa4,0xff,0xff,0xb6,0x00,0x00,0x00,0x72,0xff,0xff,0xff,0xff,0xff,0xf1,0x86,
0xff,0xff,0xe8,0x00,0x00,0x39,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xf3,0xff,0xff,0xfb,0x00,
0x00,0xac,0xff,0xff,0xff,0xa5,0x48,0x42,0x94,0xfe,0xff,0xff,0xff,0x00,0x00,0xe9,0xff,0xff,
0xa4,0x00,0x00,0x00,0x00,0x9b,0xff,0xff,0xff,0x00,0x00,0xfb,0xff,0xff,0x5a,0x00,0x00,0x00,
0x00,0x59,0xff,0xff,0xff,0x00,0x00,0xe8,0xff,0xff,0x9e,0x00,0x00,0x00,0x00,0x95,0xff,0xff,
0xff,0x00,0x00,0xaa,0xff,0xff,0xff,0x9f,0x46,0x40,0x90,0xfe,0xff,0xff,0xff,0x00,0x00,0x36,
0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xfa,0xff,0xff,0xff,0x00,0x00,0x00,0x6f,0xff,0xff,0xff,
0xff,0xff,0xf9,0x8c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x45,0xbd,0xf3,0xef,0xb8,0x38,0x4c,
0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x0a,0x81,0xde,0xf6,0xcf,0x5f,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x5c,0xce,0xff,0xff,
0xff,0xff,0xff,0x88,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xe7,0xff,0xff,0xff,0xff,0xff,0xff,
0xfe,0x36,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xd7,0x5a,0x44,0xa7,0xff,0xff,0xff,0xa4,0x00,
0x00,0x00,0xff,0xff,0xff,0xec,0x16,0x00,0x00,0x00,0xb5,0xff,0xff,0xee,0x02,0x00,0x00,0xff,
0xff,0xff,0x91,0x00,0x00,0x00,0x00,0x47,0xff,0xff,0xff,0x21,0x00,0x00,0xff,0xff,0xff,0x5d,
0x00,0x00,0x00,0x00,0x12,0xff,0xff,0xff,0x3e,0x00,0x00,0xff,0xff,0xff,0x4f,0x00,0x00,0x00,
0x00,0x04,0xff,0xff,0xff,0x48,0x00,0x00,0xff,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x16,0xff,
0xff,0xff,0x3f,0x00,0x00,0xff,0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x52,0xff,0xff,0xff,0x24,
0x00,0x00,0xff,0xff,0xff,0xec,0x15,0x00,0x00,0x05,0xc6,0xff,0xff,0xf1,0x02,0x00,0x00,0xff,
0xff,0xff,0xff,0xdc,0x5a,0x3f,0xbd,0xff,0xff,0xff,0xa8,0x00,0x00,0x00,0xff,0xff,0xff,0xed,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x3a,0x00,0x00,0x00,0xff,0xff,0xff,0x60,0xd3,0xff,0xff,
0xff,0xff,0xff,0x8d,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x0b,0x83,0xde,0xf6,0xd1,0x64,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3a,0xa9,0xe6,0xf7,0xd9,0x88,0x18,0x00,
0x00,0x00,0x00,0x00,0x00,0x84,0xfe,0xff,0xff,0xff,0xff,0xff,0xeb,0x41,0x00,0x00,0x00,0x00,
0x73,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xf4,0x25,0x00,0x00,0x1c,0xf9,0xff,0xff,0xeb,
0x65,0x38,0x73,0xf6,0xff,0xc8,0x36,0x00,0x00,0x83,0xff,0xff,0xfe,0x35,0x00,0x00,0x00,0x48,
0x4c,0x00,0x00,0x00,0x00,0xc7,0xff,0xff,0xae,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xed,0xff,0xff,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfb,0xff,0xff,
0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xef,0xff,0xff,0x6d,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xcd,0xff,0xff,0xad,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x8c,0xff,0xff,0xfe,0x3c,0x00,0x00,0x00,0x4d,0x50,0x00,0x00,0x00,0x00,0x25,
0xfd,0xff,0xff,0xf1,0x74,0x36,0x56,0xeb,0xff,0xc7,0x31,0x00,0x00,0x00,0x83,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xf1,0x21,0x00,0x00,0x00,0x02,0x91,0xff,0xff,0xff,0xff,0xff,0xff,
0xf1,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x3c,0xa6,0xe2,0xf8,0xe3,0x9f,0x21,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x36,0xb7,0xf0,0xeb,0xa5,0x23,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x45,0xf9,0xff,0xff,0xff,0xff,0xf0,0x3a,0xff,0xff,0xff,
0x4c,0x00,0x00,0x07,0xe5,0xff,0xff,0xff,0xff,0xff,0xff,0xe7,0xff,0xff,0xff,0x4c,0x00,0x00,
0x5a,0xff,0xff,0xff,0xd2,0x54,0x48,0xaf,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0xa5,0xff,0xff,
0xea,0x13,0x00,0x00,0x01,0xb8,0xff,0xff,0xff,0x4c,0x00,0x00,0xd6,0xff,0xff,0x8f,0x00,0x00,
0x00,0x00,0x48,0xff,0xff,0xff,0x4c,0x00,0x00,0xf2,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x13,
0xff,0xff,0xff,0x4c,0x00,0x00,0xfc,0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x04,0xff,0xff,0xff,
0x4c,0x00,0x00,0xf4,0xff,0xff,0x61,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,
0xdb,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xff,0x4c,0x00,0x00,0xac,0xff,0xff,
0xf4,0x1f,0x00,0x00,0x01,0xb7,0xff,0xff,0xff,0x4c,0x00,0x00,0x5f,0xff,0xff,0xff,0xdd,0x52,
0x47,0xb6,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x08,0xe8,0xff,0xff,0xff,0xff,0xff,0xff,0xed,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x4a,0xfa,0xff,0xff,0xff,0xff,0xf2,0x41,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x3a,0xba,0xf1,0xec,0xa5,0x25,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x35,0xa7,0xe6,0xf7,0xd8,0x90,0x1d,0x00,0x00,0x00,0x00,0x00,
0x00,0x76,0xfd,0xff,0xff,0xff,0xff,0xff,0xf0,0x42,0x00,0x00,0x00,0x00,0x65,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xf6,0x22,0x00,0x00,0x17,0xf5,0xff,0xff,0xb3,0x4b,0x42,0x90,0xfd,
0xff,0xff,0xb2,0x00,0x00,0x7f,0xff,0xff,0xba,0x00,0x00,0x00,0x00,0x7c,0xff,0xff,0xfc,0x15,
0x00,0xc6,0xff,0xff,0x79,0x28,0x28,0x28,0x28,0x3c,0xff,0xff,0xff,0x54,0x00,0xee,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x6f,0x00,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0x7f,0x00,0xea,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xbe,0xff,0xff,0x83,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x74,
0xff,0xff,0xde,0x0c,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x00,0x00,0x10,0xf1,0xff,0xff,0xd0,
0x52,0x3d,0x7f,0xf4,0xa5,0x37,0x00,0x00,0x00,0x00,0x5c,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x45,0x00,0x00,0x00,0x00,0x6b,0xfa,0xff,0xff,0xff,0xff,0xff,0xfa,0x73,0x00,0x00,
0x00,0x00,0x00,0x00,0x2a,0x9d,0xe2,0xf8,0xdf,0x99,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x80,0xe3,0xf7,0xc6,
0x3d,0x00,0x00,0x00,0x00,0x05,0xc0,0xff,0xff,0xff,0xff,0xc0,0x00,0x00,0x00,0x00,0x80,0xff,
0xff,0xff,0xff,0xdf,0x16,0x00,0x00,0x00,0x00,0xe8,0xff,0xff,0x93,0x4d,0x2a,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x30,0x30,0xff,0xff,0xff,0x6d,0x30,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x36,0xb7,0xf0,0xeb,0xa6,0x26,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x45,
0xf9,0xff,0xff,0xff,0xff,0xf3,0x44,0xff,0xff,0xff,0x4c,0x00,0x00,0x07,0xe5,0xff,0xff,0xff,
0xff,0xff,0xff,0xee,0xff,0xff,0xff,0x4c,0x00,0x00,0x5a,0xff,0xff,0xff,0xd2,0x54,0x48,0xaf,
0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0xa5,0xff,0xff,0xea,0x13,0x00,0x00,0x01,0xb8,0xff,0xff,
0xff,0x4c,0x00,0x00,0xd6,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xff,0x4c,0x00,
0x00,0xf2,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,0xfc,0xff,
0xff,0x4f,0x00,0x00,0x00,0x00,0x04,0xff,0xff,0xff,0x4c,0x00,0x00,0xf4,0xff,0xff,0x61,0x00,
0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,0xdb,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,
0x48,0xff,0xff,0xff,0x4c,0x00,0x00,0xac,0xff,0xff,0xf4,0x1f,0x00,0x00,0x01,0xb7,0xff,0xff,
0xff,0x4c,0x00,0x00,0x5f,0xff,0xff,0xff,0xdd,0x52,0x47,0xb6,0xff,0xff,0xff,0xff,0x4c,0x00,
0x00,0x08,0xe8,0xff,0xff,0xff,0xff,0xff,0xff,0xe5,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x4a,
0xfa,0xff,0xff,0xff,0xff,0xee,0x38,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x3a,0xba,0xf1,
0xeb,0xa3,0x22,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x11,0x1c,0x1c,0x0d,0x00,0x00,0x00,0x00,
0x05,0xff,0xff,0xff,0x47,0x00,0x00,0x7d,0xff,0xff,0xb2,0x00,0x00,0x00,0x00,0x46,0xff,0xff,
0xff,0x2a,0x00,0x00,0x2f,0xfe,0xff,0xff,0xa0,0x45,0x3a,0x70,0xeb,0xff,0xff,0xde,0x00,0x00,
0x00,0x00,0xa5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x0a,
0xc3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x6a,0xc5,
0xf2,0xf9,0xe1,0xa4,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x05,0x6f,0xd0,0xf5,0xdb,0x68,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x59,0xc5,0xff,0xff,0xff,0xff,0xff,0x88,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xe0,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0x35,0x00,0x00,0x00,0xff,
0xff,0xff,0xff,0xbd,0x47,0x41,0x9a,0xff,0xff,0xff,0x9c,0x00,0x00,0x00,0xff,0xff,0xff,0xdb,
0x09,0x00,0x00,0x00,0xc8,0xff,0xff,0xdc,0x00,0x00,0x00,0xff,0xff,0xff,0x83,0x00,0x00,0x00,
0x00,0x7c,0xff,0xff,0xf7,0x00,0x00,0x00,0xff,0xff,0xff,0x5b,0x00,0x00,0x00,0x00,0x5a,0xff,
0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x4e,0xff,0xff,0xff,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,
0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x10,0x6f,0x2e,0x00,0x00,0x00,0x00,0xba,0xff,0xf2,0x13,0x00,0x00,0x00,0xf6,0xff,
0xff,0x41,0x00,0x00,0x00,0xba,0xff,0xf2,0x14,0x00,0x00,0x00,0x11,0x6f,0x2e,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x10,0x6f,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0xba,0xff,0xf2,0x13,0x00,0x00,
0x00,0x00,0x00,0xf6,0xff,0xff,0x41,0x00,0x00,0x00,0x00,0x00,0xba,0xff,0xf2,0x14,0x00,0x00,
0x00,0x00,0x00,0x11,0x6f,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x47,0x00,0x00,
0x00,0x00,0x0b,0xff,0xff,0xff,0x28,0x00,0x05,0x87,0x40,0x9a,0xff,0xff,0xd9,0x00,0x02,0xa8,
0xff,0xff,0xff,0xff,0xff,0x59,0x00,0x74,0xff,0xff,0xff,0xff,0xff,0x8c,0x00,0x00,0x0e,0x9b,
0xea,0xf7,0xcb,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x5f,0xff,0xff,0xff,0xbf,0x03,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x29,0xf4,0xff,0xff,0xe4,0x16,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x09,0xd2,0xff,0xff,0xfa,0x39,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x9a,0xff,
0xff,0xff,0x6b,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xa3,0xff,0xff,0xff,0xa2,0x00,0x00,
0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xd1,0x09,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xff,0xff,0xff,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,
0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xd9,0xff,0xff,0xfa,0x2f,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x53,0xd9,0xff,0xff,0xce,0x04,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x41,0xff,0xff,0xff,0x7c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x9f,0xff,0xff,0xf9,0x2b,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x13,
0xeb,0xff,0xff,0xc9,0x03,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x5d,0xff,0xff,0xff,
0x76,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xbc,0xff,0xff,0xf7,0x27,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0xf6,0xff,0xff,0xaa,0x1d,0x00,0x00,0xcf,0xff,0xff,0xff,
0x84,0x00,0x00,0x63,0xff,0xff,0xff,0x84,0x00,0x00,0x00,0x5c,0xc3,0xf0,0x82,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x1b,0xab,
0xf5,0xd5,0x50,0x00,0x00,0x16,0xaa,0xf4,0xd6,0x51,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
0x66,0xe1,0xff,0xff,0xff,0xfb,0x33,0x15,0xdc,0xff,0xff,0xff,0xfc,0x3d,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xed,0xff,0xff,0xff,0xff,0xff,0xa6,0xa7,0xff,0xff,0xff,0xff,0xff,0xc0,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0xfa,0x61,0x45,0xdd,0xff,0xff,0xf8,0xfa,0x64,0x46,0xdf,0xff,
0xff,0xfd,0x0f,0x00,0x00,0x00,0xff,0xff,0xff,0xa5,0x00,0x00,0x5e,0xff,0xff,0xff,0xaa,0x00,
0x00,0x62,0xff,0xff,0xff,0x36,0x00,0x00,0x00,0xff,0xff,0xff,0x6e,0x00,0x00,0x24,0xff,0xff,
0xff,0x6f,0x00,0x00,0x26,0xff,0xff,0xff,0x47,0x00,0x00,0x00,0xff,0xff,0xff,0x55,0x00,0x00,
0x0b,0xff,0xff,0xff,0x55,0x00,0x00,0x0b,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4d,0x00,0x00,0x01,0xff,0xff,0xff,0x4d,0x00,0x00,0x01,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x06,0x72,0xd1,0xf5,0xdb,0x68,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x5c,0xcb,0xff,0xff,0xff,0xff,0xff,0x88,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0xe7,0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0x35,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xbd,0x47,0x41,0x9a,0xff,0xff,0xff,0x9c,0x00,0x00,0x00,0xff,0xff,0xff,0xdb,0x09,0x00,
0x00,0x00,0xc8,0xff,0xff,0xdc,0x00,0x00,0x00,0xff,0xff,0xff,0x83,0x00,0x00,0x00,0x00,0x7c,
0xff,0xff,0xf7,0x00,0x00,0x00,0xff,0xff,0xff,0x5b,0x00,0x00,0x00,0x00,0x5a,0xff,0xff,0xff,
0x00,0x00,0x00,0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x4e,0xff,0xff,0xff,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,
0xff,0xff,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x05,0x6e,0xc7,0xf0,0xf7,0xda,0x91,0x1a,0x00,0x00,0x00,0x00,0x00,0x11,0xca,0xff,0xff,
0xff,0xff,0xff,0xff,0xf1,0x3b,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xec,0x15,0x00,0x00,0x40,0xff,0xff,0xff,0xbd,0x48,0x3b,0x90,0xff,0xff,0xff,0x8c,0x00,
0x00,0x9b,0xff,0xff,0xdd,0x07,0x00,0x00,0x00,0x9b,0xff,0xff,0xe7,0x00,0x00,0xd4,0xff,0xff,
0x83,0x00,0x00,0x00,0x00,0x39,0xff,0xff,0xff,0x1f,0x00,0xf1,0xff,0xff,0x59,0x00,0x00,0x00,
0x00,0x0f,0xff,0xff,0xff,0x3c,0x00,0xfc,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x03,0xff,0xff,
0xff,0x47,0x00,0xf1,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x0f,0xff,0xff,0xff,0x3b,0x00,0xd4,
0xff,0xff,0x84,0x00,0x00,0x00,0x00,0x3a,0xff,0xff,0xff,0x1e,0x00,0x9c,0xff,0xff,0xde,0x08,
0x00,0x00,0x00,0x9c,0xff,0xff,0xe5,0x00,0x00,0x41,0xff,0xff,0xff,0xbd,0x47,0x3a,0x8f,0xff,
0xff,0xff,0x89,0x00,0x00,0x00,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xeb,0x13,0x00,
0x00,0x00,0x13,0xcd,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0x39,0x00,0x00,0x00,0x00,0x00,0x06,
0x71,0xc9,0xf1,0xf7,0xdb,0x91,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x0b,0x84,0xde,0xf6,0xcf,0x5f,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x61,0xd6,0xff,0xff,0xff,0xff,0xff,0x88,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xee,
0xff,0xff,0xff,0xff,0xff,0xff,0xfe,0x36,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xd7,0x5a,0x44,
0xa7,0xff,0xff,0xff,0xa4,0x00,0x00,0x00,0xff,0xff,0xff,0xec,0x16,0x00,0x00,0x00,0xb5,0xff,
0xff,0xee,0x02,0x00,0x00,0xff,0xff,0xff,0x91,0x00,0x00,0x00,0x00,0x47,0xff,0xff,0xff,0x21,
0x00,0x00,0xff,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x12,0xff,0xff,0xff,0x3e,0x00,0x00,0xff,
0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x04,0xff,0xff,0xff,0x48,0x00,0x00,0xff,0xff,0xff,0x5d,
0x00,0x00,0x00,0x00,0x16,0xff,0xff,0xff,0x3f,0x00,0x00,0xff,0xff,0xff,0x90,0x00,0x00,0x00,
0x00,0x52,0xff,0xff,0xff,0x24,0x00,0x00,0xff,0xff,0xff,0xec,0x15,0x00,0x00,0x05,0xc6,0xff,
0xff,0xf1,0x02,0x00,0x00,0xff,0xff,0xff,0xff,0xdc,0x5a,0x3f,0xbd,0xff,0xff,0xff,0xa8,0x00,
0x00,0x00,0xff,0xff,0xff,0xe5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x3a,0x00,0x00,0x00,0xff,
0xff,0xff,0x5b,0xcc,0xff,0xff,0xff,0xff,0xff,0x8d,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x09,0x80,0xde,0xf6,0xd1,0x64,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x36,0xb7,0xf0,0xeb,0xa6,0x26,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,
0x45,0xf9,0xff,0xff,0xff,0xff,0xf3,0x44,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x07,0xe5,0xff,
0xff,0xff,0xff,0xff,0xff,0xee,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x5a,0xff,0xff,0xff,0xd2,
0x54,0x48,0xaf,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xa5,0xff,0xff,0xea,0x13,0x00,0x00,
0x01,0xb8,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xd6,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x48,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xf2,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x13,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xfc,0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x04,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xf4,0xff,0xff,0x61,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xdb,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xac,
0xff,0xff,0xf4,0x1f,0x00,0x00,0x01,0xb7,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x5f,0xff,0xff,
0xff,0xdd,0x52,0x47,0xb6,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x08,0xe8,0xff,0xff,0xff,
0xff,0xff,0xff,0xe5,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4a,0xfa,0xff,0xff,0xff,0xff,
0xee,0x38,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x3a,0xba,0xf1,0xeb,0xa3,0x22,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xee,0xff,0xff,0xa1,0x38,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x31,0xf5,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x28,0x9f,0xdf,0xf9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x1a,0xaa,
0xf4,0xd9,0x6a,0x03,0x00,0x00,0xff,0xff,0xff,0x65,0xe0,0xff,0xff,0xff,0xf8,0x16,0x00,0x00,
0xff,0xff,0xff,0xea,0xff,0xff,0xff,0xff,0xa1,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xbe,0x43,
0x56,0xc5,0x34,0x00,0x00,0x00,0xff,0xff,0xff,0xe7,0x0a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x94,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x61,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x20,0x99,0xdd,0xf9,0xf2,0xbf,0x4c,0x00,0x00,0x00,0x00,0x00,0x31,0xf0,0xff,0xff,0xff,
0xff,0xff,0xff,0x81,0x00,0x00,0x00,0x00,0xbf,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x46,
0x00,0x00,0x00,0xf7,0xff,0xff,0xb0,0x3b,0x49,0xd8,0xff,0xff,0xb4,0x00,0x00,0x00,0xf5,0xff,
0xff,0x5f,0x00,0x00,0x41,0x7c,0x50,0x21,0x00,0x00,0x00,0xbb,0xff,0xff,0xec,0x68,0x0d,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xf5,0xff,0xff,0xff,0xf3,0x94,0x1e,0x00,0x00,0x00,0x00,
0x00,0x00,0x32,0xca,0xff,0xff,0xff,0xff,0xf5,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,
0xc2,0xff,0xff,0xff,0xfe,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xdc,0xff,0xff,
0xc3,0x00,0x00,0x36,0x83,0xae,0x85,0x00,0x00,0x00,0x5f,0xff,0xff,0xef,0x00,0x00,0x4e,0xff,
0xff,0xfe,0x85,0x39,0x43,0xbe,0xff,0xff,0xf1,0x00,0x00,0x04,0xd8,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xa2,0x00,0x00,0x00,0x26,0xed,0xff,0xff,0xff,0xff,0xff,0xff,0xcc,0x13,0x00,
0x00,0x00,0x00,0x1c,0x95,0xdf,0xfb,0xf2,0xc5,0x6b,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,
0x80,0x80,0x26,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0x00,0x00,0x30,0x30,0xff,0xff,0xff,0x6d,0x30,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0xff,
0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0xff,0xb1,0x35,0x00,0x00,0x00,0x00,0xce,
0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x60,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x5a,0xc5,0xf0,0xfe,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,
0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xfd,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x4f,0xff,0xff,0xff,0x00,0x00,0xf5,0xff,0xff,0x57,0x00,0x00,0x00,0x00,0x65,0xff,0xff,
0xff,0x00,0x00,0xdf,0xff,0xff,0x79,0x00,0x00,0x00,0x00,0x84,0xff,0xff,0xff,0x00,0x00,0xb8,
0xff,0xff,0xc2,0x00,0x00,0x00,0x02,0xd5,0xff,0xff,0xff,0x00,0x00,0x79,0xff,0xff,0xff,0x70,
0x00,0x09,0x99,0xff,0xff,0xff,0xff,0x00,0x00,0x1d,0xfa,0xff,0xff,0xff,0xed,0xf6,0xff,0xf9,
0xff,0xff,0xff,0x00,0x00,0x00,0x7f,0xff,0xff,0xff,0xff,0xff,0xe2,0x70,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x6e,0xdd,0xf7,0xd9,0x84,0x10,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe5,0xff,0xff,0xa3,0x00,0x00,0x00,
0x00,0xb2,0xff,0xff,0x8d,0x00,0x00,0x9a,0xff,0xff,0xe2,0x00,0x00,0x00,0x04,0xf1,0xff,0xff,
0x41,0x00,0x00,0x4e,0xff,0xff,0xff,0x22,0x00,0x00,0x3a,0xff,0xff,0xf0,0x04,0x00,0x00,0x0a,
0xf7,0xff,0xff,0x61,0x00,0x00,0x7e,0xff,0xff,0xa8,0x00,0x00,0x00,0x00,0xb5,0xff,0xff,0xa0,
0x00,0x00,0xc2,0xff,0xff,0x5c,0x00,0x00,0x00,0x00,0x69,0xff,0xff,0xe0,0x00,0x0b,0xfa,0xff,
0xfc,0x13,0x00,0x00,0x00,0x00,0x1d,0xff,0xff,0xff,0x1f,0x4a,0xff,0xff,0xc4,0x00,0x00,0x00,
0x00,0x00,0x00,0xd0,0xff,0xff,0x5e,0x8e,0xff,0xff,0x77,0x00,0x00,0x00,0x00,0x00,0x00,0x84,
0xff,0xff,0x9e,0xd2,0xff,0xff,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xff,0xff,0xe9,0xfe,
0xff,0xde,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0xe9,0xff,0xff,0xff,0xff,0x93,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x9f,0xff,0xff,0xff,0xff,0x46,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x53,0xff,0xff,0xff,0xf3,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xf9,
0xff,0xff,0xae,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xba,0xff,0xff,0x62,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xff,0xff,0xff,0x3a,0x00,0x00,0x0d,0xfe,0xff,0xff,0x2f,
0x00,0x00,0x10,0xfd,0xff,0xff,0x20,0x00,0xd6,0xff,0xff,0x76,0x00,0x00,0x3b,0xff,0xff,0xff,
0x5e,0x00,0x00,0x4d,0xff,0xff,0xd9,0x00,0x00,0x8f,0xff,0xff,0xb3,0x00,0x00,0x6a,0xff,0xff,
0xff,0x8d,0x00,0x00,0x8b,0xff,0xff,0x92,0x00,0x00,0x48,0xff,0xff,0xee,0x01,0x00,0x99,0xff,
0xff,0xff,0xbc,0x00,0x00,0xc9,0xff,0xff,0x4b,0x00,0x00,0x09,0xf7,0xff,0xff,0x2c,0x00,0xc8,
0xff,0xff,0xff,0xeb,0x00,0x0b,0xfb,0xff,0xf9,0x0b,0x00,0x00,0x00,0xba,0xff,0xff,0x69,0x02,
0xf5,0xff,0xfc,0xff,0xff,0x1b,0x45,0xff,0xff,0xbd,0x00,0x00,0x00,0x00,0x73,0xff,0xff,0xa6,
0x26,0xff,0xff,0xb1,0xff,0xff,0x4a,0x82,0xff,0xff,0x76,0x00,0x00,0x00,0x00,0x2c,0xff,0xff,
0xe2,0x55,0xff,0xff,0x4c,0xff,0xff,0x79,0xc0,0xff,0xff,0x2f,0x00,0x00,0x00,0x00,0x00,0xe4,
0xff,0xff,0xa4,0xff,0xdc,0x0c,0xfe,0xff,0xaf,0xf7,0xff,0xe7,0x01,0x00,0x00,0x00,0x00,0x00,
0x9e,0xff,0xff,0xf9,0xff,0xa8,0x00,0xd9,0xff,0xfa,0xff,0xff,0xa1,0x00,0x00,0x00,0x00,0x00,
0x00,0x57,0xff,0xff,0xff,0xff,0x74,0x00,0xa7,0xff,0xff,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,
0x00,0x00,0x13,0xfd,0xff,0xff,0xff,0x40,0x00,0x76,0xff,0xff,0xff,0xfe,0x15,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xc9,0xff,0xff,0xfe,0x0e,0x00,0x44,0xff,0xff,0xff,0xcc,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x82,0xff,0xff,0xd9,0x00,0x00,0x13,0xff,0xff,0xff,0x85,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x3b,0xff,0xff,0xa5,0x00,0x00,0x00,0xe1,0xff,0xff,0x3f,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x25,0xfa,
0xff,0xff,0xb1,0x00,0x00,0x00,0x05,0xdb,0xff,0xff,0xfe,0x3a,0x00,0x8e,0xff,0xff,0xff,0x3b,
0x00,0x00,0x6a,0xff,0xff,0xff,0x9a,0x00,0x00,0x10,0xec,0xff,0xff,0xc5,0x00,0x0b,0xe7,0xff,
0xff,0xe9,0x11,0x00,0x00,0x00,0x6b,0xff,0xff,0xff,0x51,0x7c,0xff,0xff,0xff,0x5d,0x00,0x00,
0x00,0x00,0x03,0xd5,0xff,0xff,0xdb,0xf1,0xff,0xff,0xbe,0x00,0x00,0x00,0x00,0x00,0x00,0x47,
0xff,0xff,0xff,0xff,0xff,0xf9,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb6,0xff,0xff,0xff,
0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0xff,0xff,0xff,0xff,0x20,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xbd,0xff,0xff,0xff,0xff,0xa1,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x57,0xff,0xff,0xff,0xff,0xff,0xfe,0x38,0x00,0x00,0x00,0x00,0x00,0x0c,0xe4,0xff,0xff,
0xd1,0xee,0xff,0xff,0xcb,0x02,0x00,0x00,0x00,0x00,0x8b,0xff,0xff,0xff,0x45,0x76,0xff,0xff,
0xff,0x64,0x00,0x00,0x00,0x29,0xfa,0xff,0xff,0xbd,0x00,0x09,0xe4,0xff,0xff,0xea,0x10,0x00,
0x00,0xbd,0xff,0xff,0xff,0x35,0x00,0x00,0x65,0xff,0xff,0xff,0x91,0x00,0x57,0xff,0xff,0xff,
0xac,0x00,0x00,0x00,0x03,0xd8,0xff,0xff,0xfb,0x2c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,
0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xfd,0xff,0xff,
0x4e,0x00,0x00,0x00,0x00,0x4f,0xff,0xff,0xff,0x00,0x00,0xf5,0xff,0xff,0x5c,0x00,0x00,0x00,
0x00,0x61,0xff,0xff,0xff,0x00,0x00,0xdf,0xff,0xff,0x87,0x00,0x00,0x00,0x00,0x93,0xff,0xff,
0xff,0x00,0x00,0xb8,0xff,0xff,0xde,0x09,0x00,0x00,0x18,0xec,0xff,0xff,0xff,0x00,0x00,0x79,
0xff,0xff,0xff,0xb9,0x42,0x53,0xd5,0xff,0xff,0xff,0xff,0x00,0x00,0x1d,0xfa,0xff,0xff,0xff,
0xff,0xff,0xff,0xde,0xff,0xff,0xff,0x00,0x00,0x00,0x7f,0xff,0xff,0xff,0xff,0xff,0xc3,0x58,
0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x6e,0xdd,0xf6,0xd3,0x72,0x05,0x4c,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xff,0xf1,0x00,0x00,0x00,0x0e,0x8d,
0x3c,0x00,0x00,0x00,0x00,0x9d,0xff,0xff,0xba,0x00,0x00,0x42,0xe7,0xff,0xf0,0x76,0x3c,0x45,
0x9c,0xff,0xff,0xff,0x4b,0x00,0x00,0x1d,0xf1,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xa0,
0x00,0x00,0x00,0x00,0x38,0xe9,0xff,0xff,0xff,0xff,0xff,0xff,0x9d,0x05,0x00,0x00,0x00,0x00,
0x00,0x13,0x7d,0xcf,0xf0,0xf0,0xb6,0x46,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x2f,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xb3,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x38,
0x00,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x58,0xff,0xff,0xff,0xbd,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xa1,0xff,0xff,0xff,0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1f,
0xfb,0xff,0xff,0xc7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xf7,0xff,0xff,0xd0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x8a,0xff,0xff,0xff,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x11,
0xf2,0xff,0xff,0xd9,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7e,0xff,0xff,0xff,0x60,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0b,0xed,0xff,0xff,0xef,0x35,0x30,0x30,0x30,0x30,
0x00,0x00,0x00,0x00,0x73,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x07,
0xe5,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x67,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x7b,0xda,0xf7,0xfe,0x00,0x00,0x00,
0x00,0x85,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0xd9,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0xef,0xff,0xff,0xd1,0x44,0x00,0x00,0x00,0x00,0xf8,0xff,0xff,0x60,0x00,0x00,0x00,0x00,
0x03,0xff,0xff,0xff,0x4a,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0xff,0x42,0x00,0x00,0x00,0x00,
0x27,0xff,0xff,0xff,0x2e,0x00,0x00,0x00,0x00,0x50,0xff,0xff,0xfd,0x0c,0x00,0x00,0x00,0x00,
0xa0,0xff,0xff,0xcb,0x00,0x00,0x00,0x00,0x35,0xf9,0xff,0xff,0x5b,0x00,0x00,0x00,0x1b,0xe2,
0xff,0xff,0xb4,0x00,0x00,0x00,0x00,0x00,0x33,0xf9,0xff,0xff,0x5c,0x00,0x00,0x00,0x00,0x00,
0x9f,0xff,0xff,0xcc,0x00,0x00,0x00,0x00,0x00,0x50,0xff,0xff,0xfe,0x0c,0x00,0x00,0x00,0x00,
0x27,0xff,0xff,0xff,0x2e,0x00,0x00,0x00,0x00,0x14,0xff,0xff,0xff,0x42,0x00,0x00,0x00,0x00,
0x03,0xff,0xff,0xff,0x4a,0x00,0x00,0x00,0x00,0x00,0xf8,0xff,0xff,0x60,0x00,0x00,0x00,0x00,
0x00,0xef,0xff,0xff,0xcf,0x43,0x00,0x00,0x00,0x00,0xda,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
0x00,0x88,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x03,0x7f,0xde,0xf8,0xfe,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xfe,0xf7,0xe3,0x92,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
0xff,0xff,0xc5,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x1f,0x00,0x00,0x00,
0x00,0x00,0x3f,0xad,0xff,0xff,0xff,0x37,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xff,0xff,
0x42,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xff,0xff,0x4d,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xf7,0xff,0xff,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe4,0xff,0xff,0x72,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0xbf,0xff,0xff,0x9d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xff,
0xff,0xe8,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xf3,0xff,0xff,0x7e,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x69,0xff,0xff,0xfd,0x51,0x00,0x00,0x00,0x00,0x00,0x1d,0xf4,0xff,0xff,0x7c,
0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xff,0xff,0xe7,0x06,0x00,0x00,0x00,0x00,0x00,0x00,0xbf,
0xff,0xff,0x9c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe4,0xff,0xff,0x72,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xf7,0xff,0xff,0x5f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfe,0xff,0xff,0x4d,
0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xff,0xff,0xff,0x42,0x00,0x00,0x00,0x00,0x00,0x3e,0xaa,
0xff,0xff,0xff,0x37,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0x20,0x00,0x00,0x00,
0x00,0x00,0xff,0xff,0xff,0xff,0xca,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xfd,0xe7,0x9e,0x17,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x1b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4b,0xeb,0xff,0x9a,0x04,0x00,0x00,0x2d,0x00,0x00,0xfc,0xff,0xff,
0xff,0xbf,0x45,0x69,0xee,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0xd0,
0x36,0x17,0xb2,0xff,0xff,0xff,0xf8,0x00,0x00,0x0b,0x00,0x00,0x02,0x7d,0xf0,0xce,0x39,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x88,0xd0,0xef,0xf8,0xdd,
0x9e,0x39,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x75,0xf8,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xa1,0x06,0x00,0x00,0x00,0x00,0x00,0x81,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xb1,0x05,0x00,0x00,0x00,0x3f,0xfe,0xff,0xff,0xe7,0x74,0x3c,0x44,0x95,0xfc,0xff,0xff,
0xff,0x93,0x00,0x00,0x00,0xcc,0xff,0xff,0xda,0x16,0x00,0x00,0x00,0x00,0x4a,0xfc,0xff,0xff,
0xfe,0x2b,0x00,0x39,0xff,0xff,0xff,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x89,0xff,0xff,0xff,
0x90,0x00,0x8a,0xff,0xff,0xd6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0xd4,0xd4,0xd4,0xaa,
0x00,0xc4,0xff,0xff,0x91,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xe8,0xff,0xff,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfa,
0xff,0xff,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfa,0xff,
0xff,0x53,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xe9,0xff,0xff,
0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xc6,0xff,0xff,0x8f,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8c,0xff,0xff,0xd4,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1e,0xc8,0xc8,0xc8,0x9e,0x00,0x3b,0xff,0xff,0xff,0x4a,0x00,
0x00,0x00,0x00,0x00,0x00,0x89,0xff,0xff,0xff,0x90,0x00,0x00,0xce,0xff,0xff,0xda,0x15,0x00,
0x00,0x00,0x00,0x45,0xfc,0xff,0xff,0xfe,0x2c,0x00,0x00,0x40,0xfe,0xff,0xff,0xe6,0x73,0x3b,
0x3e,0x88,0xf8,0xff,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,0x81,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xb8,0x08,0x00,0x00,0x00,0x00,0x00,0x76,0xf8,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xa6,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x20,0x89,0xd1,0xf0,0xf9,0xde,0xa0,
0x3c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x67,0xb4,0x0f,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x98,0xff,0xff,0x9a,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xff,0xff,0xf0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0f,0xb4,0xff,0xff,0xd0,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbc,0xff,0xff,0xe8,0x32,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xdd,0x93,0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xe4,0xff,0xff,0xe3,0x00,0x00,0xe4,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xe3,0xff,0xff,0xe3,0x00,0x00,0xe4,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x47,0xe3,0xe4,0x49,0x00,0x00,0x49,0xe3,0xe4,0x49,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x29,0x90,0xd6,0xf3,0xf4,0xd7,0x92,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x01,0x82,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x86,0x01,0x00,0x00,0x00,0x00,0x00,
0x00,0x8c,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x00,
0x44,0xff,0xff,0xff,0xea,0x77,0x3d,0x40,0x79,0xe9,0xff,0xff,0xff,0x47,0x00,0x00,0x00,0x00,
0xcd,0xff,0xff,0xdc,0x19,0x00,0x00,0x00,0x00,0x1b,0xdc,0xff,0xff,0xd0,0x00,0x00,0x00,0x37,
0xff,0xff,0xff,0x43,0x00,0x00,0x00,0x00,0x00,0x00,0x43,0xff,0xff,0xff,0x3c,0x00,0x00,0x89,
0xff,0xff,0xd9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd5,0xff,0xff,0x8b,0x00,0x00,0xc4,
0xff,0xff,0x95,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x91,0xff,0xff,0xc4,0x00,0x00,0xe8,
0xff,0xff,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0xff,0xe8,0x00,0x00,0xfa,
0xff,0xff,0x55,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x59,0xff,0xff,0xf9,0x00,0x00,0xfa,
0xff,0xff,0x54,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xff,0xff,0xfa,0x00,0x00,0xe9,
0xff,0xff,0x67,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x67,0xff,0xff,0xe9,0x00,0x00,0xc6,
0xff,0xff,0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x93,0xff,0xff,0xc6,0x00,0x00,0x8b,
0xff,0xff,0xd8,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd6,0xff,0xff,0x8d,0x00,0x00,0x39,
0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x4d,0xff,0xff,0xff,0x3e,0x00,0x00,0x00,
0xcf,0xff,0xff,0xdc,0x17,0x00,0x00,0x00,0x00,0x16,0xdc,0xff,0xff,0xd2,0x00,0x00,0x00,0x00,
0x45,0xff,0xff,0xff,0xe8,0x75,0x3c,0x3c,0x74,0xe7,0xff,0xff,0xff,0x48,0x00,0x00,0x00,0x00,
0x00,0x8c,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x90,0x00,0x00,0x00,0x00,0x00,
0x00,0x01,0x82,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x86,0x01,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x29,0x91,0xd7,0xf4,0xf4,0xd8,0x93,0x2b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xe4,0xff,0xff,0xe4,0x00,0x00,0xe3,0xff,0xff,0xe4,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x49,0xe3,0xe4,0x4a,0x00,0x00,0x47,0xe3,0xe4,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
0xfe,0xff,0xff,0x4d,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xfe,0x00,0x00,0x00,0x00,
0xee,0xff,0xff,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x5b,0xff,0xff,0xed,0x00,0x00,0x00,0x00,
0xd8,0xff,0xff,0x82,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xff,0xff,0xd7,0x00,0x00,0x00,0x00,
0xa7,0xff,0xff,0xd5,0x00,0x00,0x00,0x00,0x00,0x00,0xce,0xff,0xff,0xa5,0x00,0x00,0x00,0x00,
0x5c,0xff,0xff,0xff,0x55,0x00,0x00,0x00,0x00,0x63,0xff,0xff,0xff,0x58,0x00,0x00,0x00,0x00,
0x09,0xe0,0xff,0xff,0xfa,0x87,0x3e,0x3d,0x90,0xfe,0xff,0xff,0xdc,0x07,0x00,0x00,0x00,0x00,
0x00,0x4b,0xfd,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xfc,0x47,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x52,0xf7,0xff,0xff,0xff,0xff,0xff,0xff,0xf6,0x4f,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x22,0x93,0xd9,0xf8,0xf8,0xd8,0x91,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3d,0xab,0xe7,0xf7,
0xd6,0x82,0x13,0x00,0x00,0x00,0x00,0x00,0x88,0xff,0xff,0xff,0xff,0xff,0xff,0xe5,0x35,0x00,
0x00,0x00,0x76,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xec,0x19,0x00,0x1d,0xf9,0xff,0xff,
0xe9,0x62,0x39,0x7b,0xfa,0xff,0xbf,0x2b,0x00,0x84,0xff,0xff,0xfd,0x31,0x00,0x00,0x00,0x52,
0x42,0x00,0x00,0x00,0xc7,0xff,0xff,0xad,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xed,
0xff,0xff,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfb,0xff,0xff,0x54,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xef,0xff,0xff,0x6d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xce,0xff,0xff,0xad,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x8e,0xff,0xff,
0xfe,0x3b,0x00,0x00,0x00,0x54,0x48,0x00,0x00,0x00,0x27,0xfd,0xff,0xff,0xf0,0x72,0x36,0x5a,
0xf0,0xff,0xbe,0x27,0x00,0x00,0x87,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xe8,0x16,0x00,
0x00,0x02,0x96,0xff,0xff,0xff,0xff,0xff,0xff,0xea,0x32,0x00,0x00,0x00,0x00,0x00,0x3f,0xa8,
0xe4,0xf9,0xe0,0x97,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x17,0x9f,0x86,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbf,0xff,0xfe,0x2e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x76,0xff,0xff,0x73,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x25,0xd7,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0xd5,0xff,0xff,0x9a,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x28,0xcf,0x58,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4b,0xe4,0xe4,0x49,0x00,0x00,0x4b,0xe4,0xe4,0x49,0x00,
0x00,0x00,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0xe5,0xff,0xff,0xe4,0x00,0x00,0x00,0x00,
0x00,0xe3,0xff,0xff,0xe3,0x00,0x00,0xe4,0xff,0xff,0xe3,0x00,0x00,0x00,0x00,0x00,0x47,0xe3,
0xe4,0x49,0x00,0x00,0x49,0xe4,0xe4,0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0x6e,0xc7,0xf0,0xf7,0xda,0x91,
0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x11,0xca,0xff,0xff,0xff,0xff,0xff,0xff,0xf1,0x3b,0x00,
0x00,0x00,0x00,0x00,0xb3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xec,0x15,0x00,0x00,0x00,
0x40,0xff,0xff,0xff,0xbd,0x48,0x3b,0x90,0xff,0xff,0xff,0x8c,0x00,0x00,0x00,0x9b,0xff,0xff,
0xdd,0x07,0x00,0x00,0x00,0x9b,0xff,0xff,0xe7,0x00,0x00,0x00,0xd4,0xff,0xff,0x83,0x00,0x00,
0x00,0x00,0x39,0xff,0xff,0xff,0x1f,0x00,0x00,0xf1,0xff,0xff,0x59,0x00,0x00,0x00,0x00,0x0f,
0xff,0xff,0xff,0x3c,0x00,0x00,0xfc,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x03,0xff,0xff,0xff,
0x47,0x00,0x00,0xf1,0xff,0xff,0x5a,0x00,0x00,0x00,0x00,0x0f,0xff,0xff,0xff,0x3b,0x00,0x00,
0xd4,0xff,0xff,0x84,0x00,0x00,0x00,0x00,0x3a,0xff,0xff,0xff,0x1e,0x00,0x00,0x9c,0xff,0xff,
0xde,0x08,0x00,0x00,0x00,0x9c,0xff,0xff,0xe5,0x00,0x00,0x00,0x41,0xff,0xff,0xff,0xbd,0x47,
0x3a,0x8f,0xff,0xff,0xff,0x89,0x00,0x00,0x00,0x00,0xb6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xeb,0x13,0x00,0x00,0x00,0x00,0x13,0xcd,0xff,0xff,0xff,0xff,0xff,0xff,0xf0,0x39,0x00,
0x00,0x00,0x00,0x00,0x00,0x06,0x71,0xc9,0xf1,0xf7,0xdb,0x91,0x1a,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,0x49,0xe3,0xe3,0x47,0x00,0x00,
0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0xe4,0xff,0xff,0xe2,0x00,0x00,0x00,0x00,0xe3,0xff,
0xff,0xe4,0x00,0x00,0xe4,0xff,0xff,0xe4,0x00,0x00,0x00,0x00,0x47,0xe3,0xe4,0x4a,0x00,0x00,
0x49,0xe3,0xe4,0x4a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,
0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0xfd,0xff,0xff,0x4c,0x00,0x00,0x00,
0x00,0x4f,0xff,0xff,0xff,0x00,0x00,0xf5,0xff,0xff,0x57,0x00,0x00,0x00,0x00,0x65,0xff,0xff,
0xff,0x00,0x00,0xdf,0xff,0xff,0x79,0x00,0x00,0x00,0x00,0x84,0xff,0xff,0xff,0x00,0x00,0xb8,
0xff,0xff,0xc2,0x00,0x00,0x00,0x02,0xd5,0xff,0xff,0xff,0x00,0x00,0x79,0xff,0xff,0xff,0x70,
0x00,0x09,0x99,0xff,0xff,0xff,0xff,0x00,0x00,0x1d,0xfa,0xff,0xff,0xff,0xed,0xf6,0xff,0xf9,
0xff,0xff,0xff,0x00,0x00,0x00,0x7f,0xff,0xff,0xff,0xff,0xff,0xe2,0x70,0xff,0xff,0xff,0x00,
0x00,0x00,0x00,0x6e,0xdd,0xf7,0xd9,0x84,0x10,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xfa,0xf6,0x12,0x00,0x00,0x00,0x7a,0xff,0xf9,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xdb,0xff,0x87,0x00,0x00,0x17,0xf1,0xff,
0xda,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x9b,0xff,0xfc,0x6a,0x39,0xbe,0xff,
0xff,0x9b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0xfe,0xff,0xff,0xff,0xff,
0xff,0xfe,0x32,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xff,0xff,0xff,
0xff,0xff,0x81,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x56,0xce,
0xf6,0xce,0x56,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x49,
0x6c,0x7a,0x63,0x27,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x8d,0xf5,
0xff,0xff,0xff,0xff,0xff,0xbe,0x25,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x22,0xdb,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xed,0x3e,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0xd7,0xff,
0xff,0xff,0xff,0xd5,0xbe,0xf7,0xff,0xff,0xff,0xe9,0x11,0x00,0x00,0x00,0x00,0x00,0x8b,0xff,
0xff,0xff,0xf1,0x4b,0x00,0x00,0x1d,0xc6,0xff,0xff,0xd5,0x44,0x00,0x00,0x00,0x00,0x13,0xf7,
0xff,0xff,0xff,0x4e,0x00,0x00,0x00,0x00,0x15,0x7d,0x29,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,
0xff,0xff,0xff,0xc6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xb1,0xff,0xff,0xff,0x6b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xdd,0xff,0xff,0xff,0x2f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xf6,0xff,0xff,0xff,0x0c,0x00,0x00,0x00,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,
0x00,0x00,0x00,0xfd,0xff,0xff,0xff,0x03,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0x00,0x00,0x00,0xf3,0xff,0xff,0xff,0x0f,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0x00,0x00,0x00,0xda,0xff,0xff,0xff,0x30,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xee,0x00,0x00,0x00,0xb1,0xff,0xff,0xff,0x66,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0xd2,0xff,0xff,0xd7,0x00,0x00,0x00,0x72,0xff,0xff,0xff,0xb4,0x00,0x00,0x00,0x00,0x00,0x00,
0x03,0xf0,0xff,0xff,0xb8,0x00,0x00,0x00,0x1c,0xfd,0xff,0xff,0xfc,0x27,0x00,0x00,0x00,0x00,
0x00,0x42,0xff,0xff,0xff,0x77,0x00,0x00,0x00,0x00,0xa9,0xff,0xff,0xff,0xc7,0x0b,0x00,0x00,
0x00,0x07,0xca,0xff,0xff,0xfc,0x1c,0x00,0x00,0x00,0x00,0x23,0xf5,0xff,0xff,0xff,0xd3,0x5b,
0x37,0x5b,0xcd,0xff,0xff,0xff,0x98,0x00,0x00,0x00,0x00,0x00,0x00,0x5a,0xfe,0xff,0xff,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xda,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xee,0xff,
0xff,0xff,0xff,0xff,0xff,0xff,0xca,0x1c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,
0x7a,0xc8,0xec,0xfa,0xe6,0xb2,0x59,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf9,0xf5,0x11,0x00,0x00,0x00,0x6f,0xff,0xf9,0x00,0x00,
0x00,0x00,0x00,0x00,0xdb,0xff,0x88,0x00,0x00,0x13,0xec,0xff,0xda,0x00,0x00,0x00,0x00,0x00,
0x00,0x9b,0xff,0xfc,0x6c,0x38,0xbb,0xff,0xff,0x9b,0x00,0x00,0x00,0x00,0x00,0x00,0x32,0xfe,
0xff,0xff,0xff,0xff,0xff,0xfe,0x32,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x81,0xff,0xff,0xff,
0xff,0xff,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x54,0xcd,0xf6,0xce,0x54,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x36,0xb7,0xf0,0xeb,0xa6,0x26,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x45,0xf9,0xff,0xff,0xff,0xff,0xf3,0x44,0xff,0xff,0xff,0x4c,0x00,0x00,0x07,0xe5,0xff,
0xff,0xff,0xff,0xff,0xff,0xee,0xff,0xff,0xff,0x4c,0x00,0x00,0x5a,0xff,0xff,0xff,0xd2,0x54,
0x48,0xaf,0xff,0xff,0xff,0xff,0x4c,0x00,0x00,0xa5,0xff,0xff,0xea,0x13,0x00,0x00,0x01,0xb8,
0xff,0xff,0xff,0x4c,0x00,0x00,0xd6,0xff,0xff,0x8f,0x00,0x00,0x00,0x00,0x48,0xff,0xff,0xff,
0x4c,0x00,0x00,0xf2,0xff,0xff,0x5d,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,
0xfc,0xff,0xff,0x4f,0x00,0x00,0x00,0x00,0x04,0xff,0xff,0xff,0x4c,0x00,0x00,0xf4,0xff,0xff,
0x61,0x00,0x00,0x00,0x00,0x13,0xff,0xff,0xff,0x4c,0x00,0x00,0xdb,0xff,0xff,0x9a,0x00,0x00,
0x00,0x00,0x48,0xff,0xff,0xff,0x4c,0x00,0x00,0xac,0xff,0xff,0xf4,0x1f,0x00,0x00,0x01,0xb7,
0xff,0xff,0xff,0x4c,0x00,0x00,0x5f,0xff,0xff,0xff,0xdd,0x52,0x47,0xb6,0xff,0xff,0xff,0xff,
0x4c,0x00,0x00,0x08,0xe8,0xff,0xff,0xff,0xff,0xff,0xff,0xe5,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0x4a,0xfa,0xff,0xff,0xff,0xff,0xee,0x38,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x3a,
0xba,0xf1,0xeb,0xa3,0x22,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x0b,0x1c,0x1c,0x0d,0x00,0x00,
0x00,0x00,0x05,0xff,0xff,0xff,0x47,0x00,0x00,0x4f,0xff,0xff,0xb2,0x00,0x00,0x00,0x00,0x46,
0xff,0xff,0xff,0x2a,0x00,0x00,0x10,0xf1,0xff,0xff,0xa0,0x45,0x3a,0x70,0xeb,0xff,0xff,0xde,
0x00,0x00,0x00,0x00,0x79,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x5c,0x00,0x00,0x00,
0x00,0x01,0xa3,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x58,0xbd,0xef,0xfa,0xe4,0xa8,0x3d,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x49,0xe3,0xe3,
0x47,0x00,0x00,0xe4,0xff,0xff,0xe3,0x00,0x00,0xe3,0xff,0xff,0xe3,0x00,0x00,0x47,0xe3,0xe4,
0x49,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x4c,0xff,0xff,
0xff,0x00,0x00,0x4c,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,
0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,
0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,
0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,
0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,
0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0xff,0xff,0xff,0x4c,0x00,0x00,0x00,
0xff,0xff,0xff,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x15,0x7b,0xc6,0xef,0xfa,0xe6,0xad,0x46,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4e,0xf0,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xaa,0x0a,0x00,0x00,
0x00,0x00,0x2e,0xfa,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xb4,0x00,0x00,0x00,0x00,
0xaa,0xff,0xff,0xfc,0x8e,0x46,0x37,0x5d,0xd4,0xff,0xff,0xff,0x52,0x00,0x00,0x00,0xea,0xff,
0xff,0x84,0x00,0x00,0x00,0x00,0x11,0x9d,0x72,0x41,0x0e,0x00,0x00,0x00,0xf9,0xff,0xff,0x5a,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xda,0xff,0xff,0xd2,0x1a,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7d,0xff,0xff,0xff,0xf2,0x8d,0x24,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x05,0xb0,0xff,0xff,0xff,0xff,0xff,0xc3,0x60,0x05,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x72,0xed,0xff,0xff,0xff,0xff,0xff,0xdc,0x47,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0c,0x69,0xd0,0xff,0xff,0xff,0xff,0xfe,0x71,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x33,0xa1,0xfc,0xff,0xff,0xfe,0x40,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x35,0xf3,0xff,0xff,0xb1,0x00,0x00,0x00,0x00,0x12,
0x24,0x00,0x00,0x00,0x00,0x00,0x00,0x77,0xff,0xff,0xe4,0x00,0x00,0x75,0xe5,0xff,0xe4,0x04,
0x00,0x00,0x00,0x00,0x00,0x5a,0xff,0xff,0xf8,0x00,0x00,0x61,0xff,0xff,0xff,0x8a,0x00,0x00,
0x00,0x00,0x00,0xaf,0xff,0xff,0xdb,0x00,0x00,0x0a,0xe7,0xff,0xff,0xff,0xb2,0x53,0x38,0x53,
0xb5,0xff,0xff,0xff,0x8d,0x00,0x00,0x00,0x48,0xfb,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
0xff,0xe4,0x13,0x00,0x00,0x00,0x00,0x4a,0xea,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xd3,0x25,
0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x78,0xed,0xff,0xff,0xff,0xb8,0x62,0x06,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x1d,0xfc,0xff,0xff,0x2c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x0f,0xf4,0xff,0xff,0x51,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x38,0xd8,0xff,0xff,0xdc,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2e,
0xf1,0xff,0xb5,0x1b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3e,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x20,0x99,0xdd,0xf9,0xf2,0xbf,0x4c,0x00,0x00,0x00,0x00,0x00,0x31,0xf0,0xff,0xff,0xff,
0xff,0xff,0xff,0x81,0x00,0x00,0x00,0x00,0xbf,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x46,
0x00,0x00,0x00,0xf7,0xff,0xff,0xb0,0x3b,0x49,0xd8,0xff,0xff,0xb4,0x00,0x00,0x00,0xf5,0xff,
0xff,0x5f,0x00,0x00,0x41,0x7c,0x50,0x21,0x00,0x00,0x00,0xbb,0xff,0xff,0xec,0x68,0x0d,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x36,0xf5,0xff,0xff,0xff,0xf3,0x94,0x1e,0x00,0x00,0x00,0x00,
0x00,0x00,0x32,0xca,0xff,0xff,0xff,0xff,0xf5,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x4c,
0xc2,0xff,0xff,0xff,0xfe,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xdc,0xff,0xff,
0xc3,0x00,0x00,0x36,0x83,0xae,0x85,0x00,0x00,0x00,0x5f,0xff,0xff,0xef,0x00,0x00,0x4e,0xff,
0xff,0xfe,0x85,0x39,0x43,0xbe,0xff,0xff,0xf1,0x00,0x00,0x04,0xd8,0xff,0xff,0xff,0xff,0xff,
0xff,0xff,0xff,0xa2,0x00,0x00,0x00,0x26,0xed,0xff,0xff,0xff,0xff,0xff,0xff,0xcc,0x13,0x00,
0x00,0x00,0x00,0x1c,0x95,0xff,0xff,0xff,0xe2,0x6b,0x05,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x67,0xff,0xff,0x86,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x59,0xff,0xff,0xa1,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x68,0xf4,0xff,0xff,0x47,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x64,0xff,0xef,0x57,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x59,0x15,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  };
  static const struct {
    uint32_t ds;
    uint16_t width;
  } glinfo[]= {

{0,8}, {272,6}, {476,12}, {884,21}, 
{1598,14}, {2074,19}, {2720,17}, {3298,7}, 
{3536,9}, {3842,9}, {4148,15}, {4658,12}, 
{5066,6}, {5270,12}, {5678,6}, {5882,13}, 
{6324,16}, {6868,16}, {7412,16}, {7956,16}, 
{8500,16}, {9044,16}, {9588,16}, {10132,16}, 
{10676,16}, {11220,16}, {11764,6}, {11968,6}, 
{12172,11}, {12546,13}, {12988,11}, {13362,14}, 
{13838,23}, {14620,19}, {15266,17}, {15844,18}, 
{16456,17}, {17034,17}, {17612,16}, {18156,19}, 
{18802,17}, {19380,7}, {19618,16}, {20162,18}, 
{20774,16}, {21318,23}, {22100,18}, {22712,18}, 
{23324,16}, {23868,18}, {24480,17}, {25058,16}, 
{25602,18}, {26214,18}, {26826,17}, {27404,23}, 
{28186,17}, {28764,17}, {29342,19}, {29988,10}, 
{30328,13}, {30770,10}, {31110,14}, {31586,16}, 
{32130,7}, {32368,14}, {32844,15}, {33354,14}, 
{33830,15}, {34340,14}, {34816,11}, {35190,15}, 
{35700,15}, {36210,7}, {36448,9}, {36754,14}, 
{37230,7}, {37468,21}, {38182,15}, {38692,14}, 
{39168,15}, {39678,16}, {40222,12}, {40630,13}, 
{41072,9}, {41378,14}, {41854,14}, {42330,19}, 
{42976,14}, {43452,14}, {43928,14}, {44404,9}, 
{44710,7}, {44948,11}, {45322,10}, {45662,17}, 
{46240,18}, {46852,18}, {47464,13}, {47906,15}, 
{48416,14}, {48892,19}, {49538,15}, {50048,6}, 
{50252,7}, {50490,16}, {51034,13}, 
  };
  // static const int nmap= sizeof(glmap)/sizeof(glmap[0]);
  int i,j,k,e,x,y,sX,eX;
  int W, X, *Xpos;
  char buf[20];
  int *map, *gl;
  int ngl;
  unsigned int C;
  int glyph_width;
  const unsigned char *glyph_data;
  unsigned char *data;

  map= alloca(L*sizeof(int));

  e= 0;
  ngl= 0;
  for(i=0;i<L;i++)
  {
    C= str[i];
    
    if (C&(1<<31)) { ngl+=2; e= 1; continue; }
    map[i]= font_hash(C);
    if (map[i]!=107) { ngl++; continue; }
    sprintf(buf,"%x",C); ngl+= strlen(buf); e= 1;
  }

  if (e) goto fix_encoding_errors;
  else gl= map;

encoding_errors_fixed:

  W= 0;
  for(i=0;i<ngl;i++) W+= glinfo[gl[i]].width;

  if (Rdata) data= malloc(W*34);
  X= 0;
  if (e && Rdata) Xpos= alloca(sizeof(int)*(ngl+1));
  for(i=0;i<ngl;i++)
  {
    if (e && Rdata) Xpos[i]= X;
    glyph_width= glinfo[gl[i]].width;
    if (Rdata) {
      glyph_data= font_data + glinfo[gl[i]].ds;
      for(y=0;y<34;y++)
         for(x=0;x<glyph_width;x++)
            data[y*W+X+x]= glyph_data[y*glyph_width+x];
    }
    X+= glyph_width;
  }
  if (e && Rdata) Xpos[i]= X;
  if (RW) *RW= W;
  if (RA) *RA= 27;
  if (RH) *RH= 34;
  if (Rdata) *Rdata= data;

  if (!e || !Rdata) return ;

  j= 0;
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sX= Xpos[j]; eX= Xpos[j+2];
      for(x=sX;x<eX;x++)
        for(y=0;y<34;y++)
          data[y*W + x] ^= 0xff;
      j+= 2;
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x",str[i]);
      sX= Xpos[j]; eX= Xpos[j+strlen(buf)];
      for(x=sX;x<eX;x++) {
        data[ 0*W + x]= 0xff;
        data[ (34-1)*W + x]= 0xff;
      }
      for(y=0;y<34;y++)
      {
        data[y*W+sX] = 0xff;
        data[y*W+eX-1] = 0xff;
      }
      j+= strlen(buf);
      continue;
    }
    j++;
  }
  return ;


fix_encoding_errors:
  j= 0;
  gl= alloca(sizeof(int)*ngl);
  for(i=0;i<L;i++)
  {
    if (str[i]&(1<<31))
    {
      sprintf(buf,"%02x", str[i]&0xff);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    if (map[i]==107)
    {
      sprintf(buf,"%x", str[i]);
      for(k=0;buf[k];k++)
         gl[j++]= font_hash(buf[k]);
      continue;
    }
    gl[j++]= map[i];
  }
  goto encoding_errors_fixed;
}


static unsigned int *radio_on, *radio_off;

RES_COLOR(radio_bg,0xffededed, "Radio Button background");
RES_COLOR(radio_fg,0x00000000, "Radio Button foreground");
RES_INT(radio_pad_left,  2, "Radio Button left padding");
RES_INT(radio_pad_mid, 2, "Radio Button middle padding");

RES_GRAYIMG(Gradio_on, "Radio button ON image")
   15, 15,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x1b,0x5a,0x71,0x5a,0x1b,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x43,0xc8,0xb4,0x1b,
    0x89,0xdd,0xff,0xdd,0x89,0x1b,0xb4,0xc8,0x43,0x00,
    0x00,0x65,0xf0,0x82,0x5a,0xdd,0xff,0xff,0xff,0xdd,
    0x5a,0x82,0xf0,0x65,0x00,0x00,0x71,0xff,0x71,0x71,
    0xff,0xff,0xff,0xff,0xff,0x71,0x71,0xff,0x71,0x00,
    0x00,0x65,0xf0,0x82,0x5a,0xdd,0xff,0xff,0xff,0xdd,
    0x5a,0x82,0xf0,0x65,0x00,0x00,0x43,0xc8,0xb4,0x1b,
    0x89,0xdd,0xff,0xdd,0x89,0x1b,0xb4,0xc8,0x43,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x1b,0x5a,0x71,0x5a,0x1b,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,
RES_END

RES_GRAYIMG(Gradio_off,"Radio button OFF image")
   15, 15,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x39,0x00,0x00,0x00,0x39,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x43,0xc8,0xb4,0x39,
    0x00,0x00,0x00,0x00,0x00,0x39,0xb4,0xc8,0x43,0x00,
    0x00,0x65,0xf0,0x82,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x82,0xf0,0x65,0x00,0x00,0x71,0xff,0x71,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x71,0xff,0x71,0x00,
    0x00,0x65,0xf0,0x82,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x82,0xf0,0x65,0x00,0x00,0x43,0xc8,0xb4,0x39,
    0x00,0x00,0x00,0x00,0x00,0x39,0xb4,0xc8,0x43,0x00,
    0x00,0x0d,0x89,0xff,0x93,0x39,0x00,0x00,0x00,0x39,
    0x93,0xff,0x89,0x0d,0x00,0x00,0x00,0x38,0xa1,0xff,
    0xb4,0x82,0x71,0x82,0xb4,0xff,0xa1,0x38,0x00,0x00,
    0x00,0x00,0x00,0x38,0x89,0xc8,0xf0,0xff,0xf0,0xc8,
    0x89,0x38,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,
    0x43,0x65,0x71,0x65,0x43,0x0d,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,
RES_END

static unsigned int  gfx_radio_width, gfx_radio_height;


static unsigned int *checkbox_ok, *checkbox_nok;

RES_COLOR(checkbox_bg,0xffededed, "Checkbox background");
RES_COLOR(checkbox_fg,0x00000000, "Checkbox foreground");
RES_INT(checkbox_pad_left,  2, "Checkbox left padding");
RES_INT(checkbox_pad_mid, 2, "Checkbox middle padding");

RES_GRAYIMG(Gcheckbox_ok, "Checkbox ON image")
   18, 18,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xdd,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xdd,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0xdd,0xdd,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0xff,0xdd,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xdd,0xff,0xff,0xdd,
    0x00,0x00,0x00,0xff,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0xdd,0xff,0xff,0xdd,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0xff,0xff,0x00,0x00,0x00,0x00,
    0xdd,0xff,0xff,0xdd,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0xdd,0xff,0xdd,0x00,0x00,0xdd,0xff,0xff,
    0xdd,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0xdd,0xdd,0xff,0xdd,0xdd,0xff,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xdd,
    0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0xdd,0xff,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0xdd,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,
RES_END

RES_GRAYIMG(Gcheckbox_nok,"Checkbox OFF image")
   18, 18,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,
RES_END

static unsigned int  gfx_checkbox_width, gfx_checkbox_height;


RES_COLORIMG(Hscroll_ind_left, "Left part of the scroll indicator (H)")
  2 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,0xff9a9694,0xffffffff,
    0xff9a9694,0xffffffff,0xff9a9694,0xffcdcbca,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_ind_mid, "Mid part of the scroll indicator (H)")
  1 | (1<<31), 15,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xffdcdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd1cecd,0xffcecbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_ind_right, "Right part of the scroll indicator (H)")
  2 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,
    0xffcdcbca,0xff9a9694,0xffcdcbca,0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Hscroll_trough, "Gradient for horizontal scroll trough")
  1 | (1<<31), 15,
    0xffd9d7d6,0xffd6d6d3,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f5,0xfffafaf9,0xffd9d7d6,
RES_END
RES_COLORIMG(Vscroll_ind_top, "Top part of the scroll indicator (V)")
  15 | (1<<31), 2,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_ind_mid, "Mid part of the scroll indicator (V)")
  15 | (1<<31), 1,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xffdcdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd1cecd,0xffcecbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_ind_bot, "Bottom part of the scroll indicator (V)")
  15 | (1<<31), 2,
    0xff9a9694,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(Vscroll_trough, "Gradient for vertical scroll trough")
  15 | (1<<31), 1,
    0xffd9d7d6,0xffd6d6d3,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f5,0xfffafaf9,0xffd9d7d6,
RES_END

RES_COLORIMG(scroll_nor_up, "Scroll bar normal up button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_nor_down, "Scroll bar normal down button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_dpd_up, "Scroll bar depressed up button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_dpd_down, "Scroll bar depressed down button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xff444444,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff444444,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_nor_left, "Scroll bar normal left button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xff444444,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff000000,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xff444444,0xff000000,0xff000000,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff444444,0xff000000,0xff000000,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xffdbdad9,0xff444444,0xff000000,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_nor_right, "Scroll bar normal right button")
  15 | (1<<31), 15,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xff444444,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xff000000,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff000000,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xff000000,0xff000000,0xff000000,
    0xff444444,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddc,
    0xff000000,0xff000000,0xff444444,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddc,0xff000000,0xff444444,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xff444444,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcbca,0xff9a9694,0xff9a9694,0xffffffff,0xffe7e6e5,
    0xffe4e3e2,0xffe1e0df,0xffdedddb,0xffdbdad9,0xffd9d7d6,0xffd6d4d3,
    0xffd3d1d0,0xffd0cecd,0xffcdcbca,0xffcbc9c7,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xffffffff,0xffe7e6e5,0xffe4e3e2,0xffe1e0df,0xffdedddb,
    0xffdbdad9,0xffd9d7d6,0xffd6d4d3,0xffd3d1d0,0xffd0cecd,0xffcdcbca,
    0xffcbc9c7,0xffcdcaca,0xff9a9694,0xff9a9694,0xffcdcbca,0xffcdcaca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,
    0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xffcdcbca,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9594,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,0xff9a9694,
    0xff9a9694,0xff9a9694,0xff9a9694,
RES_END
RES_COLORIMG(scroll_dpd_left, "Scroll bar depressed left button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff000000,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xff444444,0xff000000,0xff000000,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xff000000,0xff000000,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xff444444,0xff000000,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END
RES_COLORIMG(scroll_dpd_right, "Scroll bar depressed right button")
  15 | (1<<31), 15,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffa5a59f,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,
    0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffd2d2cf,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff000000,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff000000,0xff000000,
    0xff444444,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff000000,0xff000000,0xff444444,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xff000000,0xff444444,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xff444444,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffd9d9d6,
    0xffdcdcd9,0xffdfdfdc,0xffe2e2df,0xffe5e5e2,0xffe8e8e6,0xffebebe9,
    0xffeeeeec,0xfff1f1ef,0xfff4f4f2,0xfff7f7f6,0xffffffff,0xffa5a59f,
    0xffa5a59f,0xffd2d2cf,0xffd9d9d6,0xffdcdcd9,0xffdfdfdc,0xffe2e2df,
    0xffe5e5e2,0xffe8e8e6,0xffebebe9,0xffeeeeec,0xfff1f1ef,0xfff4f4f2,
    0xfff7f7f6,0xffffffff,0xffa5a59f,0xffa5a59f,0xffd2d2cf,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffa5a59f,
    0xffd2d2cf,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,0xffa5a59f,
    0xffa5a59f,0xffa5a59f,0xffd2d2cf,
RES_END

/* The following has two functions: when called with a NULL scrollbar,
   it sets the gui_scrollbar_width/_height variables so that the layout
   engines can do their stuff. If SB is not NULL, then it assigns the
   images to the scrollbar, depending on the orientation */

static unsigned int gui_scrollbar_width;
static unsigned int gui_scrollbar_height;


RES_INT(dropdown_list_padv, 2, "");
RES_INT(dropdown_list_spc, 2, "");
RES_COLOR(dropdown_list_hcolor, 0xFF0088ff, "");
RES_COLOR(dropdown_list_border, 0xcccac9, "");


static int gui_list_pad_horz= 2,
           gui_list_pad_vert= 2,
           gui_list_icontext_sep= 2,
           gui_list_spacing= 2,
           gui_list_border= 0x888888;


static uint32_t TE_fg        = 0;
static uint32_t TE_bg        = 0xffffff;
static uint32_t TE_cfg       = 0xffffff;
static uint32_t TE_cbg       = 0x000088;


RES_COLOR(confirm_bg, 0xcece88, "background color for confirmation dialog");
RES_COLOR(confirm_fg, 0x000000, "foreground color for confirmation dialog");
RES_INT(dialog_spacing, 10, 
                      "Padding between widgets in the confirmation dialog");


RES_INT(filesel_pad,10,"Padding between widgets in file selector");
RES_INT(filesel_ipad,6,"Internal padding for buttons in file selector");
RES_COLOR(filesel_bg, 0xbcbcbc, "Background color for file selector dialog");
RES_COLOR(filesel_fg, 0x000000, "Foreground color for file selector title");

RES_STRING(filesel_lbl_ok,"OK","Label for OK button");

RES_STRING(filesel_lbl_cancel, "Cancel", "Label for Cancel button");
RES_STRING(filesel_lbl_refresh, "Refresh", "Label for Refresh button");
RES_STRING(filesel_lbl_home, "Home", "Label for Home button");
RES_STRING(filesel_lbl_load, "Select File to Load", "File selector load mode title");
RES_STRING(filesel_lbl_save, "Select File to Save", "File selector write mode title");

RES_INT(filesel_dirst_pad , 6, "File selector padding between directory stack buttons");
RES_INT(filesel_dirst_ipad, 6, "File selector internal padding for directory stack buttons");
RES_INT(filesel_dirst_left, 10, "File selector directory stack left padding");


static int spinner_lessb_width, spinner_moreb_width;

RES_COLORIMG(RESspinLESS,"Spinner: Icon for the less button")
  16 | (1<<31), 16,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
RES_END


RES_COLORIMG(RESspinMORE,"Spinner: Icon for the more button")
  16 | (1<<31), 16,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0xff000000,0xff000000,0xff000000,0xff000000,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0xff000000,0xff000000,0xff000000,0xff000000,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0xff000000,0xff000000,
    0xff000000,0xff000000,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
    0x00ffffff,0x00ffffff,0x00ffffff,0x00ffffff,
RES_END


RES_COLOR(logview_background,0xffffff,"Background color for logview");
RES_INT(logview_pad, 4, "Padding around content for logview");
RES_COLOR(logview_foreground,0x00,"Foreground color for logview");

void *__gfx_library__unused_symbol_holder__[]= 
  { gui_canvas_new, gui_spinner, gui_logview, gfx_pixgrid, 
    dropdown_new, panel_new, checkbox_new, radio_new,
// imported utilities that could be removed
   buffer_append, mprintf, fdprintf, 
  };
  //below comment is a MARK, do not remove
/** USER RESOURCES **/
RES_COLORIMG(GFXRES_directory,"User resource")
0x80000010,0x00000010,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x0a000000,0x5b000000,
0x62000000,0x62000000,0x62000000,0x62000000,0x62000000,
0x54000000,0x03000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x86070600,
0xffc9b800,0xffd9ca00,0xffd9cc00,0xffd9cc00,0xffd9cb00,
0xffd9ca00,0xffb6a700,0x69000000,0x01000000,0x01000000,
0x01000000,0x01000000,0x01000000,0x00000000,0x00000000,
0x9c141100,0xfffcdc00,0xfffcdc00,0xfffcdc00,0xfffcdc00,
0xfffcdc00,0xfffcdc00,0xfffbda00,0xfc847100,0xf9736300,
0xf9736100,0xf9736000,0xf9735e00,0xf9735d00,0xf1624d00,
0x51000000,0x9c130e00,0xfff6ba00,0xfff6ba00,0xfff6ba00,
0xfff6ba00,0xfff6ba00,0xfff6ba00,0xfff5bc00,0xfffef322,
0xfffff313,0xfffff202,0xfffff200,0xfffff200,0xfffff200,
0xfffff100,0x98100e00,0x9c130f00,0xfffbe260,0xfffceb76,
0xfffcec66,0xfffcec53,0xfffcea3f,0xfffce82b,0xfffdea1b,
0xffffee14,0xffffec02,0xffffec00,0xffffec00,0xffffec00,
0xffffec00,0xffffec00,0x98100f00,0x9c141200,0xfffff7b2,
0xfffff9c2,0xfffff6a1,0xfffff27d,0xffffef57,0xffffeb33,
0xffffe915,0xffffe702,0xffffe700,0xffffe700,0xffffe700,
0xffffe700,0xffffe700,0xffffe700,0x98100f00,0x9c141100,
0xfffff39b,0xfffff4a1,0xffffef7d,0xffffeb57,0xffffe733,
0xffffe314,0xffffe102,0xffffe100,0xffffe100,0xffffe100,
0xffffe100,0xffffe100,0xffffe100,0xffffe100,0x98100e00,
0x9c141100,0xffffed80,0xffffec77,0xffffe64a,0xffffe126,
0xffffdd0d,0xffffdc01,0xffffdb00,0xffffdb00,0xffffdb00,
0xffffdb00,0xffffdb00,0xffffdb00,0xffffdb00,0xffffdb00,
0x98100e00,0x9c141100,0xffffe03d,0xffffdd30,0xffffda1a,
0xffffd70a,0xffffd601,0xffffd600,0xffffd600,0xffffd600,
0xffffd600,0xffffd600,0xffffd600,0xffffd600,0xffffd600,
0xffffd600,0x98100e00,0x9c141000,0xffffd725,0xffffd51a,
0xffffd20a,0xffffd001,0xffffd000,0xffffd000,0xffffd000,
0xffffd000,0xffffd000,0xffffd000,0xffffd000,0xffffd000,
0xffffd000,0xffffd000,0x98100d00,0x9c141000,0xffffcd0e,
0xffffcb04,0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,
0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,
0xffffcb00,0xffffcb00,0xffffcb00,0x98100d00,0x9c140f00,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0x98100c00,
0x6f030200,0xfe936f00,0xffa37a00,0xffa37a00,0xffa37a00,
0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,
0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,0xfe926e00,
0x6d030200,0x00000000,0x25000000,0x2c000000,0x2c000000,
0x2c000000,0x2c000000,0x2c000000,0x2c000000,0x2c000000,
0x2c000000,0x2c000000,0x2c000000,0x2c000000,0x2c000000,
0x23000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,
RES_END
RES_COLORIMG(res0,"User resource")
0x80000010,0x00000010,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x0a000000,0x5b000000,
0x62000000,0x62000000,0x62000000,0x62000000,0x62000000,
0x54000000,0x03000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x86070600,
0xffc9b800,0xffd9ca00,0xffd9cc00,0xffd9cc00,0xffd9cb00,
0xffd9ca00,0xffb6a700,0x69000000,0x01000000,0x01000000,
0x01000000,0x01000000,0x01000000,0x00000000,0x00000000,
0x9c141100,0xfffcdc00,0xfffcdc00,0xfffcdc00,0xfffcdc00,
0xfffcdc00,0xfffcdc00,0xfffbda00,0xfc847100,0xf9736300,
0xf9736100,0xf9736000,0xf9735e00,0xf9735d00,0xf1624d00,
0x51000000,0x9c130e00,0xfff6ba00,0xfff6ba00,0xfff6ba00,
0xfff6ba00,0xfff6ba00,0xfff6ba00,0xfff5bc00,0xfffef322,
0xfffff313,0xfffff202,0xfffff200,0xfffff200,0xfffff200,
0xfffff100,0x98100e00,0x9c130f00,0xfffbe260,0xfffceb76,
0xfffcec66,0xfffcec53,0xfffcea3f,0xfffce82b,0xfffdea1b,
0xffffee14,0xffffec02,0xffffec00,0xffffec00,0xffffec00,
0xffffec00,0xffffec00,0x98100f00,0x9c141200,0xfffff7b2,
0xfffff9c2,0xfffff6a1,0xfffff27d,0xffffef57,0xffffeb33,
0xffffe915,0xffffe702,0xffffe700,0xffffe700,0xffffe700,
0xffffe700,0xffffe700,0xffffe700,0x98100f00,0x9c141100,
0xfffff39b,0xfffff4a1,0xffffef7d,0xffffeb57,0xffffe733,
0xffffe314,0xffffe102,0xffffe100,0xffffe100,0xffffe100,
0xffffe100,0xffffe100,0xffffe100,0xffffe100,0x98100e00,
0x9c141100,0xffffed80,0xffffec77,0xffffe64a,0xffffe126,
0xffffdd0d,0xffffdc01,0xffffdb00,0xffffdb00,0xffffdb00,
0xffffdb00,0xffffdb00,0xffffdb00,0xffffdb00,0xffffdb00,
0x98100e00,0x9c141100,0xffffe03d,0xffffdd30,0xffffda1a,
0xffffd70a,0xffffd601,0xffffd600,0xffffd600,0xffffd600,
0xffffd600,0xffffd600,0xffffd600,0xffffd600,0xffffd600,
0xffffd600,0x98100e00,0x9c141000,0xffffd725,0xffffd51a,
0xffffd20a,0xffffd001,0xffffd000,0xffffd000,0xffffd000,
0xffffd000,0xffffd000,0xffffd000,0xffffd000,0xffffd000,
0xffffd000,0xffffd000,0x98100d00,0x9c141000,0xffffcd0e,
0xffffcb04,0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,
0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,0xffffcb00,
0xffffcb00,0xffffcb00,0xffffcb00,0x98100d00,0x9c140f00,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,
0xfffdc000,0xfffdc000,0xfffdc000,0xfffdc000,0x98100c00,
0x6f030200,0xfe936f00,0xffa37a00,0xffa37a00,0xffa37a00,
0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,
0xffa37a00,0xffa37a00,0xffa37a00,0xffa37a00,0xfe926e00,
0x6d030200,0x00000000,0x25000000,0x2c000000,0x2c000000,
0x2c000000,0x2c000000,0x2c000000,0x2c000000,0x2c000000,
0x2c000000,0x2c000000,0x2c000000,0x2c000000,0x2c000000,
0x23000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,0x00000000,0x00000000,
0x00000000,0x00000000,0x00000000,
RES_END

/***********************************************************************
 *                                                                     *
 *                                CODE                                 *
 *                                                                     *
 ***********************************************************************/
#ifdef GFX_X11

/***********************************************************************
  In order to create images etc, we need to find a suitable visual 
  with depth==24 or depth==32.
 ***********************************************************************/
static uint32_t trailing_zero_bits(uint32_t Y)
{
  uint32_t shif;
  for(shif=0;Y%2==0;shif++) Y= Y>>1;
  return shif;
}

static int get_x_visual()
{
  int depth, ndepths, i;
  int *depths;
  XVisualInfo xvinfo;

  depths= XListDepths(x_display, x_screen_number, &ndepths);
  if (!depths) 
  {
    fprintf(stderr,"can't get depth list for display\n");
    return 1;
  }

  depth=0;
  for(i=0;i<ndepths;i++)
    if (depths[i]==32 || depths[i]==24)
    {
      depth= depths[i];
      break;
    }
  XFree(depths);

  if (!depth)
  {
    fprintf(stderr, "display doesn't support 24 or 32 bit depth.\n");
    return 1;
  }

  x_depth= depth;
  x_visual= NULL;
  if (XMatchVisualInfo(x_display, x_screen_number, depth, TrueColor,&xvinfo))
     x_visual= xvinfo.visual;
  else if (XMatchVisualInfo(x_display, x_screen_number,
                                       depth, DirectColor,&xvinfo))
     x_visual= xvinfo.visual;
  else
  {
    fprintf(stderr,"can't find a 24 or 32 bit TrueColor/DirectColor visual\n");
    return 1;
  }
  x_red_mask= x_visual->red_mask;
  x_red_shift= trailing_zero_bits(x_red_mask);
  x_green_mask= x_visual->green_mask;
  x_green_shift= trailing_zero_bits(x_green_mask);
  x_blue_mask= x_visual->blue_mask;
  x_blue_shift= trailing_zero_bits(x_blue_mask);
  return 0;
}

static Window create_window(char *title,int width, int height)
{
  int                  x,y;
  Window               window;
  XSetWindowAttributes attribs;
  XTextProperty        title_prop;
  XSizeHints          *size;

  x= (x_root_width-width)/2;
  y= (x_root_height-height)/2;

  attribs.background_pixmap= None;

  window= XCreateWindow(x_display, x_root_window,
                        x, y, width, height,
                        1, x_depth, InputOutput, x_visual, 
                        CWBackPixmap, &attribs);

  if (XStringListToTextProperty(&title, 1, &title_prop))
  {
    XSetWMName(x_display, window, &title_prop);
  }
  size= XAllocSizeHints();
  size->flags= PMinSize | PMaxSize;
  size->min_width= size->max_width= width;
  size->min_height= size->max_height= height;
  XSetWMNormalHints(x_display,window, size);

  unsigned long protos[4];

  wm_protocols= XInternAtom(x_display, "WM_PROTOCOLS", False);
  wm_delete_window= XInternAtom(x_display, "WM_DELETE_WINDOW", False);
  protos[0]= wm_delete_window;
  protos[1]= 0;
 
  XChangeProperty(x_display, window, wm_protocols, XA_ATOM, 32,
                  PropModeReplace, (unsigned char*)protos, 1);

  XFlush(x_display);
  XFree(size);

  return window;
}

static void get_root_attribs()
{
  x_screen_number= DefaultScreen(x_display);
  x_root_window= DefaultRootWindow(x_display);
  x_root_width= DisplayWidth(x_display, x_screen_number);
  x_root_height= DisplayHeight(x_display, x_screen_number);
}

int gfx_init(char *name, int width, int height, char *title)
{
  int y;

  x_display= XOpenDisplay(name);

  if (!x_display) 
  {
    //FIXME: log this
    fprintf(stderr,"can't open display\n");
    return 1;
  }
  get_root_attribs();
  if (get_x_visual())
  {
    XCloseDisplay(x_display);
    x_display= NULL;
    return 1;
  }
  x_window= create_window(title,width, height);
  XSelectInput(x_display, x_window, PointerMotionMask | KeyPressMask |
                                    ButtonPressMask |
                                    ButtonReleaseMask | ExposureMask );
                                    // StructureNotifyMask);

  x_pixmap= XCreatePixmap(x_display, x_window, width, height, x_depth);
  x_image= create_image(width, height);

  x_image_data= malloc(sizeof(uint32_t*) * height);
  for(y=0;y<height;y++)
    x_image_data[y]= (uint32_t*) ((char*) x_image->data + y*x_image->bpl);
  checker_pattern(x_image, 17);

  x_window_width= width;
  x_window_height= height;
   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];


  gfx_update_all();
#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  XMapWindow(x_display, x_window);
  return 0;
}


/***********************************************************************
 *                                                                     *
 *                           Image Functions                           *
 *                                                                     *
 ***********************************************************************/

static ximage_t *create_image(uint32_t width, uint32_t height)
{
  ximage_t *image;
  size_t data_size;
  struct shmid_ds dummy_shmid_ds;

  if (!can_use_shared_images()) goto fail_nolib;

  image= calloc(1,sizeof(*image));
  image->width= width;
  image->height= height;
  image->shared= 1;

  // Create the image on the server
  //
  image->x11image= XShmCreateImage(x_display,x_visual, x_depth, ZPixmap,
                                   NULL, &image->shminfo, width, height);
  if (!image->x11image) goto fail_create;

  image->bpl= image->x11image->bytes_per_line;
  data_size= height*image->bpl;

  // Create the shared memory area
  //
  image->shminfo.shmid= shmget(IPC_PRIVATE, data_size, IPC_CREAT | 0777);
  if (image->shminfo.shmid <0)
  {
    fprintf(stderr,"can't shmget shared memory\n");
    goto fail_shmcreate;
  }
  
  image->shminfo.shmaddr= shmat(image->shminfo.shmid,0,0);
   // we remove the ID now, so that when the program exits, the memory
   // will be automatically freed
   //
  shmctl(image->shminfo.shmid, IPC_RMID, &dummy_shmid_ds); 
  if (image->shminfo.shmaddr==(char*) -1) 
  {
    fprintf(stderr,"can't attach shared memory\n");
    goto fail_shmat;
  }

  // bind the area to the image 
  //
  image->data= (uint32_t*) image->shminfo.shmaddr;
  image->x11image->data= (char*) image->shminfo.shmaddr;
  if (!XShmAttach(x_display, &image->shminfo)) 
  {
    fprintf(stderr,"couldn't attach shared memory to the ximage\n");
    goto fail_attach_x;
  }

  return image;

fail_attach_x:
  shmdt(image->shminfo.shmaddr);
fail_shmat:      // We have already removed the ID
fail_shmcreate:
  XDestroyImage(image->x11image);
fail_create:
  free(image);
fail_nolib:
  return ximage_create_simple(width,height);
}

static ximage_t *ximage_create_simple(uint32_t width,uint32_t height)
{
  ximage_t *image;

  image= calloc(1,sizeof(*image));
  image->width= width;
  image->height= height;
  image->data= malloc(sizeof(uint32_t)*width*height);

  image->x11image= XCreateImage(x_display, x_visual, x_depth,
                                ZPixmap, 0, (char*) image->data,
                                width, height, 32, width*sizeof(uint32_t));
      // FIXME: error checking??
  image->bpl= image->x11image->bytes_per_line;
  image->shared= 0;
  return image;
}

static void destroy_image(ximage_t *image)
{
  XSync(x_display, False);
  if (image->shared) 
    XShmDetach(x_display, &image->shminfo);
  XDestroyImage(image->x11image);
  if (image->shared)
    shmdt(image->shminfo.shmaddr);
  free(image);
}


/************************************************************
  Putting an image on the screen is also handled differently
  for shared and non-shared images.
 ***********************************************************/

static void put_image(Drawable draw, int dest_x, int dest_y,
               ximage_t *image, int src_x, int src_y,
               int width, int height)
{
  if (src_x >= image->width ) return ;
  if (src_y >= image->height ) return ;
  if (src_x<0) { width+= src_x; src_x= 0; }
  if (src_y<0) { height+= src_y; src_y= 0; }
  
  if (width + src_x> image->width)  width= image->width-src_x;
  if (height+ src_y> image->height) height= image->height-src_y;

  if (image->shared)
    XShmPutImage(x_display, draw, DefaultGC(x_display,0),
      image->x11image, src_x, src_y, dest_x, dest_y,
      width, height, False);
  else
    XPutImage(x_display, draw, DefaultGC(x_display,0),
      image->x11image, src_x, src_y, dest_x, dest_y,
      width, height);
}

/*******************************************************
  Images in X11 can be in shared memory if the server 
  supports the "MIT-SHM" extension.
 ******************************************************/
static int can_use_shared_images()
{
  static int tried;
  static int can;
  if (!tried)
  {
    int ignore, major, minor;
    Bool pixmaps;
    tried= 1;
    can= XQueryExtension(x_display, "MIT-SHM", &ignore, &ignore, &ignore)
         && XShmQueryVersion(x_display, &major, &minor, &pixmaps);
  }
  return can;
}

static void gfx_update(int x,int y,int width,int height)
{
  clip_for_rect(&x, &width, x_window_width);
  clip_for_rect(&y, &height, x_window_height);
  if (width<=0 || height<=0) return ;
  put_image(x_pixmap, x, y, x_image, x,y, width, height); 
  XClearArea(x_display, x_window, x,y, width, height, True);
}

void gfx_close()
{
#ifdef GFX_X11
  x_keyboard_free(x_keyboard);
  x_keyboard= NULL;
#endif

  if (x_image) destroy_image(x_image);
  XDestroyWindow(x_display, x_window);
  XFreePixmap(x_display, x_pixmap);

  x_display= NULL;
  x_window= None;
  x_pixmap= None;
  x_image= NULL;
}

static void checker_pattern(ximage_t *img,int N)
{
  int x,y;
  uint32_t all_mask;
  if (N<=0) N= 4;
  all_mask= x_red_mask | x_green_mask | x_blue_mask;
  for(y=0;y<img->height;y++)
   for(x=0;x<img->width;x++)
     *(uint32_t*)  ((unsigned char*) img->data + y*img->bpl + 4*x)= 
            (x%(2*N)/N ^ y%(2*N)/N)  ? all_mask : 0;
}


static x_keyboard_t *x_keyboard_init(Window window)
{
  x_keyboard_t *xk;

  xk= calloc(1,sizeof(*xk));

  xk->method= 'S';
  xk->window= window;
  xk->sbuf= 20;   xk->buf= malloc(xk->sbuf);
  xk->swbuf= 20;  xk->wbuf= malloc(sizeof(uint32_t)*xk->swbuf);
  get_xim();

  if (xim)
  {
    xk->ic= XCreateIC(xim, XNInputStyle, xim_style, 
                      XNClientWindow, window, 
                      XNFocusWindow, window, 
                      NULL);
    if (xk->ic!=NULL)
       xk->method= 'M'; 
  }
  return xk;
}

static void x_keyboard_free(x_keyboard_t *xk)
{
  free(xk->buf);
  free(xk->wbuf);
  if (xk->method=='M') XDestroyIC(xk->ic);
  free(xk);
}

static void get_xim()
{
  int i;
  XIMStyles *xim_styles;
  XIMStyle simple_style;
  char *failed_param;

  if (xim_tried) return ;
  xim_tried= 1;

  xim_styles= NULL;
  
  xim= XOpenIM(x_display, NULL, NULL, NULL);
  if (xim==NULL) return ;

  failed_param= XGetIMValues (xim, XNQueryInputStyle, &xim_styles, NULL);
  if (failed_param || !xim_styles)
     goto fail_no_styles;

  simple_style= (XIMPreeditNothing | XIMStatusNothing);
  for(i=0;i<xim_styles->count_styles;i++) 
    if (xim_styles->supported_styles[i] == simple_style)
       break;

  if (i==xim_styles->count_styles)
     goto fail_no_styles;

  xim_style= simple_style;
  XFree(xim_styles);

  return ;

fail_no_styles:
  if (xim_styles) XFree(xim_styles);
  
  XCloseIM(xim);
  xim= NULL;
}


static int x_keyboard_event
             (x_keyboard_t *xk, XEvent *ev, gfx_event_t *Revent)
{
  Status status;
  KeySym sym;
  int lk;

  sym= NoSymbol;

  Revent->type= GFXEV_KEY_PRESS;

  if (xk->method=='S') goto simple;
  if (XFilterEvent(ev, xk->window)) return 1;
  if (ev->type!=KeyPress) return 0;


retry:
  lk= Xutf8LookupString(xk->ic, (XKeyPressedEvent *) ev,
                        xk->buf, xk->sbuf-1, &sym, &status);
  switch(status)
  {
    case XBufferOverflow:
      free(xk->buf);
      xk->sbuf= lk+lk/2;
      xk->buf= malloc(xk->sbuf);
      goto retry;
    case XLookupBoth:
      if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
      Revent->key= GFX_K_PRT;
      Revent->string= xk->buf;
      Revent->string[lk]= 0;
      Revent->wide= utf8_decode_single_char(Revent->string);
      return 1;
    case XLookupChars: 
      if (xk->buf[0]>0 && xk->buf[0]<0x20) // control character
      { // I don't know what to do here.
        return -1;
      }
      Revent->key= GFX_K_PRT;
      Revent->string= xk->buf;
      Revent->string[lk]= 0;
      Revent->wide= utf8_decode_single_char(Revent->string);
      return 1;
      
    case XLookupKeySym:
      if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
      if ((Revent->wide= keysym2ucs(sym)))
      {
        utf8_encode_single_char(Revent->wide, xk->buf);
        Revent->string= xk->buf;
        Revent->string[lk]= 0;
        Revent->key= GFX_K_PRT;
        return 1;
      }
  }

  return -1;

simple:
  sym= NoSymbol;
  lk= XLookupString(&ev->xkey, xk->buf, xk->sbuf-1, &sym, NULL);
  if ((Revent->key=lookup_key(sym,ev->xkey.state))) return 1;
  if (lk>0) 
  {
    Revent->string= xk->buf;
    Revent->string[lk]= 0;
    Revent->wide= utf8_decode_single_char(Revent->string);
    Revent->key= GFX_K_PRT; 
    return 1;
  } 
  return -1;
}


static uint32_t keysym2ucs(KeySym keysym)
{
    int min = 0;
    int max = sizeof(keysymtab) / sizeof(struct codepair);
    int mid;

    if (keysym<=0xff) return keysym;

    if (keysym & 0x1000000) return keysym ^0x1000000;

    /* binary search */
    while (max > min) {
        mid = (min + max) / 2;
        if (keysymtab[mid].keysym < keysym)
            min = mid + 1;
        else if (keysymtab[mid].keysym > keysym)
            max = mid - 1;
        else {
            /* found it */
            return keysymtab[mid].ucs;
        }
    }

    /* no matching Unicode value found */
    return 0;
} 


static int lookup_key(KeySym sym, unsigned int modifiers)
{
   static const struct { KeySym sym; int meaning; } all[]=
   {
     { XK_BackSpace , GFX_K_BACKSPACE },
     { XK_Tab,        GFX_K_TAB },
     { XK_Linefeed,   GFX_K_RETURN },
     { XK_Return,     GFX_K_RETURN },
     { XK_Escape,     GFX_K_ESCAPE },
     { XK_Insert,     GFX_K_INSERT },
     { XK_Delete,     GFX_K_DELETE }, 
     { XK_Home,       GFX_K_HOME },
     { XK_End,        GFX_K_END },
     { XK_Page_Up,    GFX_K_PAGEUP },
     { XK_Page_Down,  GFX_K_PAGEDOWN },
     { XK_Left,       GFX_K_LEFT },
     { XK_Right,      GFX_K_RIGHT },
     { XK_Down,       GFX_K_DOWN },
     { XK_Up,         GFX_K_UP },
     { XK_VoidSymbol, 0 }
   };
   int i,B;
   B= 0;
   if (sym>=0x20 && sym<=0x7e && (modifiers&ControlMask))
      return sym | GFX_K_CONTROL; 
   for(i=0;all[i].sym!=XK_VoidSymbol;i++)
      if (all[i].sym==sym) 
       {
         B= all[i].meaning; 
         if (modifiers & ControlMask) B |= GFX_K_CONTROL;
         if (modifiers & ShiftMask) B |= GFX_K_SHIFT;
         return B;
       }
   return 0;
}



static void tv2msecs(struct timeval *tv, unsigned int* msecs)
{
  if (!msecs) return ;
  *msecs= tv->tv_sec*1000 + tv->tv_usec/1000;
}

static int event_noprocess(unsigned int *msecs,gfx_event_t *Revent)
{
  int x,R,maxfd;
  XEvent event;
  fd_set rfd, xfd, wfd;
  XExposeEvent *expose;

  struct timeval tv,*tvp;
  unsigned int delay,remaining,elapsed;
  unsigned int user_delay, sys_delay;
  int have_sys_delay, have_user_delay;

  if (msecs && *msecs) { have_user_delay= 1; user_delay= *msecs; }
                else     have_user_delay= 0;

  XSync(x_display,False);
again:
      // no time has passed. no timers will fire and the user delay
      // is unaffected.
  if (XPending(x_display)) goto have_event; 

  have_sys_delay= gui_timer_get(&sys_delay); 

     // FIXME: should this be above XPending??
  if (have_sys_delay && sys_delay==0 && gui_timer_elapsed(0,Revent))
  {
    //printf("emitting timer left over\n");
    goto done;
  }

  tvp= &tv;
  switch(flag2(have_user_delay,have_sys_delay))
  {
  case 0: tvp= NULL; break;
  case 1: delay= sys_delay; break;
  case 2: delay= user_delay; break;
  case 3: delay= user_delay<sys_delay ? user_delay : sys_delay; break;
  }

  if (tvp)
  {
    tv.tv_sec= delay/1000;
    tv.tv_usec= (delay%1000)*1000;
  }   

  x= ConnectionNumber(x_display);

  FD_ZERO(&rfd); FD_ZERO(&xfd); FD_ZERO(&wfd);
  FD_SET(x, &rfd); FD_SET(x, &xfd);
  maxfd= x;

  populate_select_set(&maxfd, &rfd, &wfd, &xfd);

  //if (tvp)
  //printf("waiting for event: secs= %d usecs= %d\n",tvp->tv_sec,tvp->tv_usec);

  R= select(maxfd+1, &rfd, &wfd, &xfd, tvp);
  if (R<0)
  {
    if (errno==EINTR)
    {
       usleep(1000);
       tv2msecs(&tv, msecs);
       goto again;
    }
    return -1; // FIXME: log this stuff.
  }
  if (tvp)
  {
    tv2msecs(&tv, &remaining);
    elapsed= delay-remaining;
    if (have_user_delay) { if (elapsed>user_delay) user_delay= 0;
                                          else     user_delay-= elapsed; }
    if (have_sys_delay && gui_timer_elapsed(elapsed,Revent)) 
    { //printf("timer resulted in event. elapsed= %d sys_delay=%d\n",
       //elapsed, sys_delay);
      goto done; }
  }
  if (get_file_monitor_event(&rfd,&wfd,&xfd,Revent))
    goto done;
  if (FD_ISSET(x, &xfd)) return -1; // FIXME: log this stuff.

  if (!FD_ISSET(x, &rfd)) 
  {
    if (have_user_delay && user_delay==0) { *msecs=0; return 0; }
    goto again;
  }

have_event:
  XNextEvent(x_display, &event);

  switch(x_keyboard_event(x_keyboard,&event,Revent))
  {
  case 0: break;
  case 1: goto done;
  case -1: goto again;
  }

  switch(event.type)
  {
   case Expose:
     expose= &event.xexpose;
                                                  // FIXME: This zero should be
                                                  // something else
     XCopyArea(x_display, x_pixmap, x_window, DefaultGC(x_display,0), 
               expose->x, expose->y, expose->width, expose->height,
               expose->x, expose->y);
     goto again; 
   case MotionNotify:
     // if (gfx_recsel_event(&event)) goto again;
     Revent->type= GFXEV_POINTER_MOVE; 
     Revent->x= event.xmotion.x; 
     Revent->y= event.xmotion.y; 
     Revent->modifiers= event.xmotion.state; 
     break;
   case ButtonPress:
     Revent->type= GFXEV_BUTTON_PRESS; 
     Revent->x= event.xbutton.x; 
     Revent->y= event.xbutton.y; 
     Revent->modifiers= event.xbutton.state; 
     Revent->button= event.xbutton.button;
     Revent->time= event.xbutton.time;
     break;
   case ButtonRelease:
     Revent->type= GFXEV_BUTTON_RELEASE; 
     Revent->x= event.xbutton.x; 
     Revent->y= event.xbutton.y; 
     Revent->modifiers= event.xbutton.state; 
     Revent->button= event.xbutton.button;
     Revent->time= event.xbutton.time;
     break;
   case ClientMessage: 
     if (event.xclient.message_type!=wm_protocols) goto again;
     if (event.xclient.data.l[0]!=wm_delete_window) goto again;
     Revent->type= GFXEV_QUIT;
     break;
   default:
//     printf("unknown event type: %d\n", event.type);
     goto again;
  }
done:

  if (have_user_delay) *msecs= user_delay;

  return 1; 
}

#endif
#ifdef GFX_FB

static uint32_t all_ones(uint32_t S,uint32_t L)
{
  uint32_t i;
  S= (1<<S);
  for(i=0;i<L-1;i++) S|= (S<<1);
  return S;
}

int gfx_init(char *DUMMYname, int DUMMYwidth, int DUMMYheight, char *DUMMYtitle)
{
  int y;
 
  struct fb_fix_screeninfo finfo;
  struct fb_var_screeninfo vinfo;

  gfrot= atoi(getenvd("GFX_ROTATION","0"));
  gfrot= imax2(0,imin2(3,gfrot));

  fb_fd = open(getenvd("GFX_VIDEO","/dev/fb0"),O_RDWR);
  if (fb_fd<0) return 1;
  if (ioctl(fb_fd, FBIOGET_VSCREENINFO, &vinfo)<0) return 1;
  if (vinfo.grayscale || vinfo.bits_per_pixel!=32)
  {
    vinfo.grayscale=0;
    vinfo.bits_per_pixel=32;
    if (ioctl(fb_fd, FBIOPUT_VSCREENINFO, &vinfo)<0) return 1;
    if (ioctl(fb_fd, FBIOGET_VSCREENINFO, &vinfo)<0) return 1;
    if (vinfo.grayscale || vinfo.bits_per_pixel!=32)
       return 1;
  }
  if (vinfo.xoffset!=0 || vinfo.yoffset!=0)
  {
    vinfo.xoffset= 0;
    vinfo.yoffset= 0;
    if (ioctl(fb_fd, FBIOPAN_DISPLAY, &vinfo)<0) return 1;
  }
  if (ioctl(fb_fd, FBIOGET_FSCREENINFO, &finfo)<0) return 1;

  switch(gfrot)
  {
  case 0:
  case 2:
    x_window_width= vinfo.xres;
    x_window_height= vinfo.yres;
    break;
  case 1:
  case 3:
    x_window_width= vinfo.yres;
    x_window_height= vinfo.xres;
    break;
  }

  x_red_shift= vinfo.red.offset;
  x_green_shift= vinfo.green.offset;
  x_blue_shift= vinfo.blue.offset;

  x_red_mask= all_ones(x_red_shift,vinfo.red.length);
  x_green_mask= all_ones(x_green_shift,vinfo.green.length);
  x_blue_mask= all_ones(x_blue_shift,vinfo.blue.length);
  
  x_bpl= finfo.line_length;

  fb_mem= mmap(0, vinfo.yres*x_bpl, PROT_READ | PROT_WRITE, MAP_SHARED,
                fb_fd, (off_t)0);

  if (!fb_mem) return 1;


  x_image= malloc(sizeof(uint32_t)*x_window_width*x_window_height);

  x_image_data= malloc(sizeof(uint32_t*) * x_window_height);
  for(y=0;y<x_window_height;y++)
    x_image_data[y]= x_image + y*x_window_width;
  checker_pattern(17);

  rawinput_init();

  struct termios ttynew;
  // now we're confident that everything will be fine, we can disable
  // the echo etc.
  if (tcgetattr(0, &tty_settings)) goto failterm;
  tty_settings_valid= 1;
  ttynew = tty_settings;
  ttynew.c_iflag = 0;
  ttynew.c_oflag = 0;
  ttynew.c_lflag &= ~ICANON;
  ttynew.c_lflag &= ~ECHO;
  ttynew.c_cc[VMIN] = 1;
  ttynew.c_cc[VTIME] = 1;
  tcsetattr(0, TCSANOW, &ttynew);

  //printf("\033[?25l\033[100B\033[100C\033[2J");
  printf("\033[?25l\033[2J"); // hide cursor, erase display
  fflush(0);
failterm:

   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];


  gfx_update_all();
#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  return 0;
}

static void destroy_image()
{
}

static void gfx_update(int x,int y,int width,int height)
{
  int xx,yy;
  int sx,sy;
  clip_for_rect(&x, &width, x_window_width);
  clip_for_rect(&y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  switch(gfrot)
  {
  case 0:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      D= (uint32_t*) (fb_mem + (y+yy)*x_bpl + (xx+x)*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 3:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sx= (y+yy); sy= x_window_width-1 - (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 2:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sy= x_window_height-1-(y+yy); sx= x_window_width-1 - (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  case 1:
  for(xx=0;xx<width;xx++)
    for(yy=0;yy<height;yy++)
    {
      uint32_t *D;
      sx= x_window_height-1-(y+yy); sy= (x+xx);
      D= (uint32_t*) (fb_mem + sy*x_bpl + sx*4);
      D[0]= x_image_data[y+yy][x+xx];
    }
  break;
  }
#ifdef GFX_FB
  if (mouse_proto=='M')
#endif
    draw_cursor(x,y,width,height);
}

void gfx_close()
{
  if (tty_settings_valid)
    tcsetattr(0, TCSANOW, &tty_settings);

  printf("\033[?25h\033[2J"); // show cursor, erase display
  fflush(0);
#ifdef GFX_X11
  x_keyboard_free(x_keyboard);
  x_keyboard= NULL;
#endif

}

static void checker_pattern(int N)
{
  int x,y;
  uint32_t all_mask;
  if (N<=0) N= 4;
  all_mask= x_red_mask | x_green_mask | x_blue_mask;
  for(y=0;y<x_window_height;y++)
   for(x=0;x<x_window_width;x++)
     x_image_data[y][x]= (x%(2*N)/N ^ y%(2*N)/N)  ? all_mask : 0;
}



static void draw_cursor(int ux,int uy,int uw,int uh)
{
  static const unsigned char cursor[]= {
  0x92,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0xeb,0x87,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x33,0xef,0x78,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x0e,0x40,0xf2,0x68,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x09,0x15,0x4b,0xf4,0x5a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x04,0x10,0x1d,0x56,0xf6,0x4e,0x00,0x00,0x00,0x00,0x00,0x00,
  0xff,0x00,0x0b,0x17,0x24,0x61,0xf7,0x42,0x00,0x00,0x00,0x00,0x00,
  0xff,0x00,0x05,0x12,0x1f,0x2b,0x6d,0xf8,0x36,0x00,0x00,0x00,0x00,
  0xff,0x00,0x00,0x0d,0x19,0x26,0x32,0x77,0xf8,0x2d,0x00,0x00,0x00,
  0xff,0x00,0x00,0x07,0x14,0x20,0x2d,0x3a,0x83,0xf8,0x24,0x00,0x00,
  0xff,0x00,0x00,0x02,0x0f,0x1b,0x28,0x34,0x41,0x8b,0xf6,0x1d,0x00,
  0xff,0x00,0x00,0x00,0x09,0x18,0xd9,0xf8,0xf8,0xf9,0xfe,0xf9,0x12,
  0xff,0x00,0x00,0x18,0x5f,0x11,0x7e,0xde,0x0f,0x0d,0x0d,0x0c,0x03,
  0xff,0x00,0x1b,0xe2,0xf2,0x17,0x21,0xf2,0x25,0x00,0x00,0x00,0x00,
  0xff,0x1d,0xe4,0x97,0xcd,0x7d,0x13,0x8d,0xc7,0x00,0x00,0x00,0x00,
  0xff,0xe7,0x8e,0x00,0x20,0xf1,0x17,0x28,0xf6,0x14,0x00,0x00,0x00,
  0xff,0x82,0x00,0x00,0x00,0xcd,0x7b,0x14,0xc9,0x59,0x00,0x00,0x00,
  0x6e,0x00,0x00,0x00,0x00,0x1f,0xf6,0xbf,0xf3,0x23,0x00,0x00,0x00,
  0x00,0x00,0x00,0x00,0x00,0x00,0x1c,0x66,0x15,0x00,0x00,0x00,0x00,
  };
  static const uint16_t mask[]={
  0x0001, 0x0003, 0x0007, 0x000f, 
  0x001f, 0x003f, 0x007f, 0x00ff, 
  0x01ff, 0x03ff, 0x07ff, 0x0fff, 
  0x1fff, 0x1fff, 0x01ff, 0x01ff, 
  0x03f7, 0x03e3, 0x03e1, 0x01c0, 
  };
  const int cursorW= 13, cursorH= 20;
  int ux_e, uy_e;
  int mx_e, my_e,mx,my,dx,dy;
  int ccx_s, ccx_e, ccy_s, ccy_e;
  uint32_t *D,V;
  int xx,yy;

  mx= McursorX; my= McursorY;
  mx_e= mx+cursorW; my_e= my+cursorH;
  ux_e= ux+uw; uy_e= uy+uh;

  if (ux_e<=mx || uy_e<=my || mx_e<=ux || my_e<=uy) return ;

  if (ux>mx) ccx_s= ux-mx;
        else ccx_s= 0;

  if (mx_e>ux_e) ccx_e= cursorW - (mx_e-ux_e);
            else ccx_e= cursorW - ccx_s;

  if (uy>my) ccy_s= uy-my;
        else ccy_s= 0;

  if (my_e>uy_e) ccy_e= cursorH - (my_e-uy_e);
            else ccy_e= cursorH - ccy_s;

 switch(gfrot)
 {
 case 0:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= mx+xx;
      dy= my+yy;

      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 1:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= x_window_height-1-(my+yy); dy= (mx+xx);

      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 2:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dy= x_window_height-1-(my+yy); dx= x_window_width-1 - (mx+xx);
      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 case 3:
  for(yy=ccy_s;yy<ccy_e;yy++)
    for(xx=ccx_s;xx<ccx_e;xx++)
    {
      if ((mask[yy]&(1<<xx))==0) continue;
      dx= (my+yy); dy= x_window_width-1 - (mx+xx);
      D= (uint32_t*) (fb_mem + dy*x_bpl + dx*4);
      V=  cursor[yy*cursorW+xx];
      D[0]= (V<<x_red_shift) | (V<<x_green_shift) | (V<<x_blue_shift);
    }
  break;
 }
}

static void move_cursor(int cx,int cy)
{
  int ox,oy;
  if (cx==McursorX && cy==McursorY) return ;
  ox= McursorX;
  oy= McursorY;
  McursorX= cx;
  McursorY= cy;
  gfx_update(ox,oy,13,20);
  gfx_update(McursorX,McursorY,13,20);
}

static void prt_key(int key,char *lo,char *hi)
{
  kbmap[key].type= 'P';
  kbmap[key].lo= lo;
  kbmap[key].hi= hi;
}

static void prt_keys(int SK,int EK, char *lo,char *hi)
{
  int i,k;
  for(i=0,k=SK;k<=EK;i++,k++)
  {
    kbmap[k].ss[0]= lo[i];
    kbmap[k].ss[2]= hi[i];
    prt_key(k, kbmap[k].ss,kbmap[k].ss+2);
  }
}

static void prt_keys_upper(int SK,int EK,char *inp)
{
  int i,k;
  for(i=0,k=SK;k<=EK;i++,k++)
  {
    kbmap[k].ss[0]= inp[i];
    kbmap[k].ss[2]= toupper(inp[i]);
    prt_key(k, kbmap[k].ss,kbmap[k].ss+2);
  }
}

static void ctl_key(int raw,int gf)
{
  kbmap[raw].type= 'C';
  kbmap[raw].value= gf;
}

static void mod_key(int raw,int gf)
{
  kbmap[raw].type= 'M';
  kbmap[raw].value= gf;
}


static char *getenvd(char *name,char *def)
{
  char *S;
  S= getenv(name);
  if (!S) S= def;
  return S;
}

static void read_environ_vars()
{
  char *S;
  S= getenvd("GFX_MOUSE_PROTO",NULL);
  mouse_proto= 'M';
  if (S)
  {
    if (!strcmp(S,"ft5x06")) mouse_proto= 'F';
    if (!strcmp(S,"absolute")) mouse_proto= 'A';
  }

  mo_device= strdup(getenvd("GFX_MOUSE_FILE", 
                             mouse_proto=='F' ? "/dev/hidraw2" :
                                                "/dev/input/mice"));
  if (mouse_proto=='F')
  {
    gfx_m_minx= atoi(getenvd("GFX_MOUSE_MINX", "0"));
    gfx_m_maxx= atoi(getenvd("GFX_MOUSE_MAXX", "1000"));
    gfx_m_miny= atoi(getenvd("GFX_MOUSE_MINY", "0"));
    gfx_m_maxy= atoi(getenvd("GFX_MOUSE_MAXY", "1000"));
    gfx_m_xresol= atoi(getenvd("GFX_MOUSE_XRESOL","1000"));
    gfx_m_yresol= atoi(getenvd("GFX_MOUSE_YRESOL","1000"));
  }

  kb_device= strdup(getenvd("GFX_KB_FILE", "/dev/input/event10"));
}

static void rawinput_init()
{
  read_environ_vars();
  RAWIfd_kb= open(kb_device,O_RDWR);
  RAWIfd_mo= open(mo_device,mouse_proto=='F' ? O_RDONLY : O_RDWR);
  if (RAWIfd_kb<0 && RAWIfd_mo<0) exit(1);
  if (RAWIfd_mo>=0 && mouse_proto=='M')
  {
    static const unsigned char mousedev_imps_seq[]=
        {0xf3, 0xc8, 0xf3, 0x64, 0xf3, 0x50};
    write(RAWIfd_mo, mousedev_imps_seq, sizeof(mousedev_imps_seq));
  }

  prt_keys_upper(KEY_Q,KEY_P,"qwertyuiop");
  prt_keys_upper(KEY_A,KEY_L,"asdfghjkl");
  prt_keys_upper(KEY_Z,KEY_M,"zxcvbnm");
  prt_keys(KEY_1,KEY_EQUAL,"1234567890-=","!@#$%^&*()_+");
  prt_key(KEY_LEFTBRACE,"[","{");
  prt_key(KEY_RIGHTBRACE,"]","}");
  prt_key(KEY_SEMICOLON,";",":");
  prt_key(KEY_APOSTROPHE,"'","\"");
  prt_key(KEY_BACKSLASH, "\\", "|");
  prt_keys(KEY_COMMA,KEY_SLASH,",./","<>?");
  prt_key(KEY_SPACE," "," ");

  ctl_key(KEY_ESC, GFX_K_ESCAPE);
  ctl_key(KEY_TAB, GFX_K_TAB);
  ctl_key(KEY_BACKSPACE, GFX_K_BACKSPACE);
  ctl_key(KEY_ENTER, GFX_K_RETURN);
  ctl_key(KEY_KPENTER, GFX_K_RETURN);
  ctl_key(KEY_UP, GFX_K_UP);
  ctl_key(KEY_DOWN, GFX_K_DOWN);
  ctl_key(KEY_RIGHT, GFX_K_RIGHT);
  ctl_key(KEY_LEFT, GFX_K_LEFT);
  ctl_key(KEY_HOME, GFX_K_HOME);
  ctl_key(KEY_END, GFX_K_END);
  ctl_key(KEY_INSERT, GFX_K_INSERT);
  ctl_key(KEY_DELETE, GFX_K_DELETE);
  ctl_key(KEY_PAGEUP, GFX_K_PAGEUP);
  ctl_key(KEY_PAGEDOWN, GFX_K_PAGEDOWN);

  mod_key(KEY_LEFTSHIFT, GFX_K_SHIFT);
  mod_key(KEY_RIGHTSHIFT, GFX_K_SHIFT);
  mod_key(KEY_LEFTALT, GFX_K_ALT);
  mod_key(KEY_RIGHTALT, GFX_K_ALT);
  mod_key(KEY_LEFTCTRL, GFX_K_CONTROL);
  mod_key(KEY_RIGHTCTRL, GFX_K_CONTROL);
}

static int event_noprocess(unsigned int *msecs, gfx_event_t *Revent)
{
  fd_set rset,wset,xset;
  int nfd;
  int R;
  static int modifiers;
  static int buttons;
  static int mX,mY;

again:
  nfd= 0;
  FD_ZERO(&rset); FD_ZERO(&wset); FD_ZERO(&xset);
  if (RAWIfd_kb>=0) { FD_SET(RAWIfd_kb, &rset); nfd=imax2(nfd,RAWIfd_kb); }
  if (RAWIfd_mo>=0) { FD_SET(RAWIfd_mo, &rset); nfd=imax2(nfd,RAWIfd_mo); }
  populate_select_set(&nfd,&rset,&wset,&xset);

  R= select(nfd+1, &rset, &wset,&xset,NULL);
  if (R<0) { if (errno==EINTR) goto again; exit(1); }
  if (get_file_monitor_event(&rset,&wset,&xset,Revent)) return 1;
  if (RAWIfd_kb>=0 && FD_ISSET(RAWIfd_kb, &rset))
  {
    struct input_event EV;
    unsigned int code;
    read(RAWIfd_kb, &EV, sizeof(EV));
    // I don't check the return value, I want weird things to happen
    // if our basic assumptions fail.
    if (EV.type!=EV_KEY) goto again;

    code= EV.code;
    if (code>255) goto again;
    switch(kbmap[code].type)
    {
    case 'M':
      modifiers= (modifiers&~kbmap[code].value);
      if (EV.value) modifiers |= kbmap[code].value;
      goto again;
    case 'P': 
         // we don't report release of printable chars, only of ctl chars
      if (!EV.value) goto again;
      Revent->type= GFXEV_KEY_PRESS;
      Revent->key= GFX_K_PRT;
      Revent->modifiers= modifiers;
      Revent->string= modifiers&GFX_K_SHIFT? kbmap[code].hi : kbmap[code].lo;
      Revent->wide= Revent->string[0];
      return 1;
    case 'C':
          // it turns out, we don't report release of control chars
          // either :P
      if (!EV.value) goto again;
      Revent->type= GFXEV_KEY_PRESS;
      Revent->key= kbmap[code].value | modifiers;
      Revent->modifiers= modifiers;
      return 1;
    }
    goto again;
  }
  if (mouse_proto=='M' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    unsigned char buf[4],BB;
    int aX,aY,dx,dy;
    R= read(RAWIfd_mo,buf,4);
    if (R<3) goto again;

    dx= (buf[0]&(1<<4))? buf[1]-256:buf[1];
    dy= (buf[0]&(1<<5))? 256-buf[2]:-buf[2];
    aX= imax2(0,imin2(x_window_width,mX+dx));
    aY= imax2(0,imin2(x_window_height,mY+dy));

    move_cursor(aX,aY);

    BB= buf[0] & 7;
    if (R==4)
    { 
      if (buf[3]==1) BB|= (1<<3);
      if (buf[3]==0xff) BB|= (1<<4);
    }
    if (BB^buttons || aY!=mY || aX!=mX)
    {
      Revent->modifiers= modifiers;
      Revent->x= mX= aX; Revent->y= mY= aY;

      if (BB^buttons)
      {
        unsigned char K= BB^buttons,B;
        for(B=0;B<5;B++) if (K&(1<<B)) break;
        buttons= BB;
        Revent->type= (buttons&(1<<B)) ? GFXEV_BUTTON_PRESS:GFXEV_BUTTON_RELEASE;
        Revent->button= B+1;
      }
      else
        Revent->type= GFXEV_POINTER_MOVE;
      return 1;
    }
  }
  if (mouse_proto=='F' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    unsigned char buf[22],BB;
    int rx,ry;
    int aX,aY,dx,dy;
    R= read(RAWIfd_mo,buf,22);
    if (R<6) goto again;

    if (buf[1]==0) BB= 0;
              else BB= 1;

    if (BB)
    {
      rx= ((buf[2]&0x0f)<<8) | buf[3];
      ry= ((buf[4]&0x0f)<<8) | buf[5];

      rx= (rx - gfx_m_minx)*gfx_m_xresol / (gfx_m_maxx-gfx_m_minx);
      ry= (ry - gfx_m_miny)*gfx_m_yresol / (gfx_m_maxy-gfx_m_miny);

      switch(gfrot)
      {
       case 0: aX= rx; aY= ry; break;
       case 3: aX= gfx_m_yresol-1-ry; aY= rx; break;
       case 2: aX= gfx_m_xresol-1-rx; aY= gfx_m_yresol-1-ry; break;
       case 1: aX= ry; aY= gfx_m_xresol-1-rx; break;
      }
      aX= imax2(0,imin2(x_window_width-1,aX));
      aY= imax2(0,imin2(x_window_height-1,aY));
    }
    else
    {
      aX= mX;
      aY= mY;
    }

    if (BB^buttons || aY!=mY || aX!=mX)
    {
      Revent->modifiers= modifiers;
      Revent->x= mX= aX; Revent->y= mY= aY;

      if (BB^buttons)
      {
        buttons= BB;
        Revent->type= (buttons&1) ? GFXEV_BUTTON_PRESS:GFXEV_BUTTON_RELEASE;
        Revent->button= 1;
      }
      else
        Revent->type= GFXEV_POINTER_MOVE;
      return 1;
    }
  }
  if (mouse_proto=='A' && RAWIfd_mo>=0 && FD_ISSET(RAWIfd_mo, &rset))
  {
    struct input_event iev;
    static int have_pos,is_down;
    static int pos_x,pos_y;
    int aX,aY;

    R= read(RAWIfd_mo,&iev,sizeof(iev));
    if (R<sizeof(iev)) goto again;

    if (iev.type==EV_SYN && iev.code==SYN_MT_REPORT)
    {
      if (have_pos)
      {
        have_pos= 0;
        Revent->type= is_down ? GFXEV_BUTTON_PRESS : GFXEV_POINTER_MOVE;
        is_down= 1;
        goto have_abs_event;
      }
      else
      {
        Revent->type= GFXEV_BUTTON_RELEASE;
        is_down= 0;
        goto have_abs_event;
      }
    }
    if (iev.type==EV_ABS && iev.code==ABS_MT_POSITION_X)
    {
       pos_x= iev.value;
       have_pos= 1;
       goto again;
    }
    if (iev.type==EV_ABS && iev.code==ABS_MT_POSITION_Y)
    {
       pos_y= iev.value;
       have_pos= 1;
       goto again;
    }
    goto again;
have_abs_event:
    switch(gfrot)
    {
     case 0: aX= pos_x; aY= pos_y; break;
          // we subtrack pos_y from window_WIDTH, because it's actually
          // height but was switched around because of the rotation.
     case 3: aX= x_window_width-1-pos_y; aY= pos_x; break;
          // here, width and height are correct, since they were not
          // switched around
     case 2: aX= x_window_width-1-pos_x; aY= x_window_height-1-pos_y; break;
          // again, subtract from HEIGHT because of the rotation.
     case 1: aX= pos_y; aY= x_window_height-1-pos_x; break;
    }
    aX= imax2(0,imin2(x_window_width-1,aX));
    aY= imax2(0,imin2(x_window_height-1,aY));

    Revent->button= 1;
    Revent->modifiers= modifiers;
    Revent->x= mX= aX; Revent->y= mY= aY;

    return 1;
  }
  goto again;
}

#endif
#ifdef GFX_ANDROID

void ANativeActivity_onCreate
      (ANativeActivity* activity, void* state, size_t state_size)
{
  int cmdpipe[2];
  pthread_attr_t attr; 
  app_t *app;

  LOGV("Creating: %p\n", activity);

  // #C.1: Activity callback installation
  // activity->callbacks->onDestroy = onDestroy;
  activity->callbacks->onStart = onStart;
  activity->callbacks->onResume = onResume;
  activity->callbacks->onPause = onPause;
  activity->callbacks->onStop = onStop;
  activity->callbacks->onNativeWindowCreated = onNativeWindowCreated;
  activity->callbacks->onNativeWindowDestroyed = onNativeWindowDestroyed;
  activity->callbacks->onInputQueueCreated = onInputQueueCreated;
  activity->callbacks->onInputQueueDestroyed = onInputQueueDestroyed;
  activity->callbacks->onSaveInstanceState = onSaveInstanceState;
  activity->callbacks->onWindowFocusChanged = onWindowFocusChanged;
  activity->callbacks->onLowMemory = onLowMemory;
  activity->callbacks->onConfigurationChanged = onConfigurationChanged;

  ANativeActivity_setWindowFormat(activity, WINDOW_FORMAT_RGBX_8888);

  activity->instance= my_app= app= calloc(1,sizeof(*app));
  app->activity= activity;
  app->last_pointer_id= -1;

  if (state && state_size)
  {
    app->init_state= malloc(state_size);
    memcpy(app->init_state, state, state_size);
    app->init_state_size= state_size;
  }

  pthread_mutex_init(&app->mutex, NULL);
  pthread_cond_init(&app->cond,NULL);

  if (pipe(cmdpipe))
  {
    LOGE("Couldn't create pipe: %s\n",strerror(errno));
    return ;
  }
  app->cmdpipe_r= cmdpipe[0];
  app->cmdpipe_w= cmdpipe[1];

  pthread_attr_init(&attr);
  pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED);
  pthread_create(&app->worker_thread, &attr, worker_entry, app);

  
  pthread_mutex_lock(&app->mutex); 
  while(!app->running) pthread_cond_wait(&app->cond, &app->mutex); 
  pthread_mutex_unlock(&app->mutex);
}

  // #C.2 Worker Function
static void* worker_entry(void* arg)
{
  app_t *app;

  app= arg;

  app->config= AConfiguration_new();
  AConfiguration_fromAssetManager(app->config, app->activity->assetManager);

  app->looper= ALooper_prepare(ALOOPER_PREPARE_ALLOW_NON_CALLBACKS);
  ALooper_addFd(app->looper, app->cmdpipe_r,
                PIPE_CMD, ALOOPER_EVENT_INPUT, NULL, app);
  
  pthread_mutex_lock(&app->mutex); 
  app->running=1; 
  pthread_cond_broadcast(&app->cond);
  pthread_mutex_unlock(&app->mutex);

  while(!app->inputq || !app->window)
    if (execute_commands(app)) goto done;

   gfx_radio_width= Gradio_on[0];
   gfx_radio_height= Gradio_on[1];

   gfx_checkbox_width= Gcheckbox_ok[0];
   gfx_checkbox_height= Gcheckbox_ok[1];

#ifdef GFX_X11
  x_keyboard= x_keyboard_init(x_window);
#endif


  scrollbar_init_buttons(NULL);

  android_main(app->init_state, app->init_state_size);

  while(!app->quit_request)
     if (execute_commands(app))
       break;

done:
  //free_saved_state(A);
  if (app->inputq) 
      { AInputQueue_detachLooper(app->inputq); app->inputq= NULL; }
  AConfiguration_delete(app->config);
  app->config= NULL;

  if (app->quit_request)
     complete_request(app, app->quit_request);
  return NULL;
}


static void make_request(app_t *A, request_t *R)
{
   R->complete= 0;
   if (write(A->cmdpipe_w, &R, sizeof(R))!=sizeof(R))
   {
     LOGE("Couldn't write to command pipe: %s\n", strerror(errno));
     return ;
   }
   
   pthread_mutex_lock(&A->mutex); 
   while(!R->complete) pthread_cond_wait(&A->cond, &A->mutex); 
   pthread_mutex_unlock(&A->mutex); 
}

static int get_request(app_t *A,request_t **R)
{
   request_t *T;
   if (read(A->cmdpipe_r, &T, sizeof(T))!=sizeof(T))
   {
     LOGE("Couldn't read from command pipe: %s\n", strerror(errno));
     return 1;
   }
   *R= T;
   return 0;
}

static void complete_request(app_t *A, request_t *R)
{
   pthread_mutex_lock(&A->mutex); 
   R->complete= 1;
   pthread_cond_broadcast(&A->cond);
   pthread_mutex_unlock(&A->mutex); 
}


static void simple_command(ANativeActivity *ac, int cmd)
{
   request_t R;
   R.type= cmd;
   make_request(ac->instance, &R);
}

static void onStart(ANativeActivity* activity)
{
   LOGV("Start: %p\n", activity);
   simple_command(activity, CMD_APP_START);
}

static void onResume(ANativeActivity* activity)
{
   LOGV("Resume: %p\n", activity);
   simple_command(activity, CMD_APP_RESUME);
}

static void onPause(ANativeActivity* activity)
{
   LOGV("Pause: %p\n", activity);
   simple_command(activity, CMD_APP_PAUSE);
}

static void onStop(ANativeActivity* activity)
{
   LOGV("Stop: %p\n", activity);
   simple_command(activity, CMD_APP_STOP);
}


static void onNativeWindowCreated
   (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowCreated: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_CREATED;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onNativeWindowDestroyed
   (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowDestroyed: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_DESTROYED;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onNativeWindowRedrawNeeded
              (ANativeActivity* activity, ANativeWindow* window)
{
  request_t R;
  LOGV("NativeWindowRedraw: %p -- %p\n", activity, window);
  R.type= CMD_WINDOW_REDRAW;
  R.d.window= window;
  make_request(activity->instance, &R);
}

static void onInputQueueCreated
   (ANativeActivity* activity, AInputQueue* queue)
{
  request_t R;
  LOGV("InputQueueCreated: %p -- %p\n", activity, queue);
  R.type= CMD_INPUTQ_CREATED;
  R.d.inputq= queue;
  make_request(activity->instance, &R);
}

static void onInputQueueDestroyed
   (ANativeActivity* activity, AInputQueue* queue)
{
  request_t R;
  LOGV("InputQueueDestroyed: %p -- %p\n", activity, queue);
  R.type= CMD_INPUTQ_DESTROYED;
  R.d.inputq= queue;
  make_request(activity->instance, &R);
}

static void* onSaveInstanceState
   (ANativeActivity* activity, size_t* outLen)
{
  request_t R;
  LOGV("SaveInstanceState: %p\n", activity);
  R.type= CMD_SAVE_STATE;
  R.d.buffer.ptr= NULL;
  R.d.buffer.size= 0;
  make_request(activity->instance, &R);
  if (R.d.buffer.ptr)
    *outLen= R.d.buffer.size;
  return R.d.buffer.ptr;
}

static void onWindowFocusChanged
   (ANativeActivity* activity, int focused)
{
  request_t R;
  LOGV("WindowFocusChanged: %p -- %d\n", activity, focused);
  R.type= CMD_FOCUS_CHANGE;
  R.d.intv= focused;
  make_request(activity->instance, &R);
}

static void onLowMemory(ANativeActivity* activity)
{
  request_t R;
  LOGV("LowMemory: %p\n", activity);
  R.type= CMD_LOW_MEMORY;
  make_request(activity->instance, &R);
}

static void onConfigurationChanged(ANativeActivity* activity)
{
  request_t R;
  LOGV("ConfigurationChanged: %p\n", activity);
  R.type= CMD_CONFIG_CHANGE;
  make_request(activity->instance, &R);
}


static int handle_command(app_t *A)
{

  request_t *R;
  if (get_request(A, &R)) return 0;
  switch(R->type)
  {
  case CMD_APP_STOP:
  case CMD_APP_START:
  case CMD_APP_PAUSE:
  case CMD_APP_RESUME:
     // FIXME: inform the client, maybe??
     complete_request(A,R);
     break;
  case CMD_WINDOW_DESTROYED:
     graphics_window_destroyed(A, R->d.window);
     complete_request(A,R);
     break;
  case CMD_WINDOW_CREATED:
     graphics_window_created(A, R->d.window);
     complete_request(A,R);
     gfx_update_all();
     break;
  case CMD_WINDOW_REDRAW:
     gfx_update_all();
     break;
  case CMD_SAVE_STATE:
  case CMD_FOCUS_CHANGE:
  case CMD_LOW_MEMORY:
     complete_request(A,R);
     break;
  case CMD_CONFIG_CHANGE:
     LOGV("APP_CMD_CONFIG_CHANGED\n");
     AConfiguration_fromAssetManager(A->config, A->activity->assetManager);
     complete_request(A,R);
     break;
  case CMD_INPUTQ_DESTROYED:
     if (A->inputq!=R->d.inputq)
     {
       complete_request(A,R);
       break;
     }
     AInputQueue_detachLooper(A->inputq);
     A->inputq= NULL;
     complete_request(A,R);
     break;
  case CMD_INPUTQ_CREATED:
     if (A->inputq!=NULL)
        AInputQueue_detachLooper(A->inputq);
     A->inputq= R->d.inputq;
     AInputQueue_attachLooper(A->inputq, A->looper, PIPE_EVENT, NULL,A);
     complete_request(A,R);
     break;
  case CMD_QUIT:
     // FIXME: when do we get this?
     LOGV("APP_CMD_QUIT\n");
     A->quit_request= R;
     return 1;
  }
  return 0;
}


static int execute_commands(app_t *app)
{
   int ident;
   int dFD, dEV;
   void *dPTR;

again:
   ident= ALooper_pollAll(-1,  &dFD, &dEV,  &dPTR);

   switch(ident)
   {
     // somebody might have woke us up because the looper
     // has changed and we need to poll again.
   case ALOOPER_POLL_WAKE:
      goto again;
   case PIPE_CMD:
      if (handle_command(app)) return 1;
      return 0;
   case PIPE_EVENT:
     handle_input(app, NULL);
     goto again;
   }

   // other things are not possible. maybe I can add some
   // sort of a time-out later.
   // so, unhandled stuff corresponds to an error, which
   // makes the application quit. I think it's OK.
   return 1;
}


static void graphics_window_destroyed(app_t *A, ANativeWindow *window)
{
  if (A->window!=window) return ;
  A->window= NULL;
}

static void graphics_window_created(app_t *A, ANativeWindow *window)
{
   int W,H;
   A->window= window;
   W= ANativeWindow_getWidth(A->window);
   H= ANativeWindow_getHeight(A->window);
   if (W<=0) W= 1;
   if (H<=0) H= 1;

   if (W!=x_window_width || H!=x_window_height || !Gpixels)
   {
     int y;
     if (Gpixels) free(Gpixels);
     Gpixels= malloc(sizeof(uint32_t)*W*H);
     if (x_image_data) free(x_image_data);
     x_image_data= malloc(sizeof(x_image_data[0])*H);
     for(y=0;y<H;y++)
       x_image_data[y]= y*W + Gpixels;
     x_window_width= W;
     x_window_height= H;
   }
}


static void gfx_update(int x,int y,int w,int h)
{
   ARect rect;
   ANativeWindow_Buffer buffer;
   int R;
   uint32_t *spixels;
   uint16_t *wpixels;
   int eX, eY;

   if (!Gpixels) return ; // display not initialized yet

   eX= x+w; eY= y+h;

   if (x>=x_window_width || eX<=0 || y>=x_window_height || eY<=0) return ;

   eX= imin2(eX, x_window_width); eY= imin2(eY, x_window_height);
   x= imax2(x, 0); y= imax2(y,0);

   rect.left= x; rect.top= y;
   rect.right= eX; rect.bottom= eY;

   R= ANativeWindow_lock(my_app->window, &buffer, &rect);
   if (R<0)
   {
      LOGV("Unable to lock buffer: %d\n", R);
      return ;
   }

   // LOGV("GFX::Buffer width=%d height=%d stride=%d format=%d\n", buffer.width, buffer.height,  buffer.stride, buffer.format);

   // LOGV("GFX::Rect left=%d top=%d right=%d bottom=%d\n", rect.left,
           // rect.top, rect.right, rect.bottom);
   
  switch(buffer.format)
  {
   case WINDOW_FORMAT_RGBX_8888:
     spixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
         spixels[y*buffer.stride+x]= Gpixels[x+ y*x_window_width];
     break;
   case WINDOW_FORMAT_RGBA_8888:
     spixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
         spixels[y*buffer.stride+x]= Gpixels[x+ y*x_window_width] | 0xff000000;
     break;
   case WINDOW_FORMAT_RGB_565:
     wpixels= buffer.bits;
     for(y=rect.top;y<rect.bottom;y++)
       for(x=rect.left;x<rect.right;x++)
       {
         uint32_t P,R,G,B;
         P= x_image_data[y][x];
         R= (P>>16)&0xff;  R>>= 3;
         G= (P>>8) &0xff;  G>>= 2;
         B= P&0xff;        B>>= 3;
         wpixels[y*buffer.stride+x]= (R<<11) | (G<<5) | B;
       }
      break;
    default:
      LOGV("unknown buffer format %d",buffer.format);
      break;
  }
  ANativeWindow_unlockAndPost(my_app->window);
}



static int handle_input(app_t *A, gfx_event_t *ev)
{
  AInputEvent* event;
  int type;
  uint32_t action,index, i, npointers;
  gfx_event_t dummy;
  event = NULL;
  if (!ev) ev= &dummy;
again:
     // Is this an error? should I log it or somehow
     // return an indication? FIXME

  if (AInputQueue_getEvent(A->inputq, &event)<0) return 1;

  type= AInputEvent_getType(event);
  // LOGV("New input event: type=%d\n", type);

  if (AInputQueue_preDispatchEvent(A->inputq, event)) goto again;

  switch(type)
  {
  case AINPUT_EVENT_TYPE_KEY: goto next_event;
  case AINPUT_EVENT_TYPE_MOTION: goto touch_event;
  }

next_event:
  AInputQueue_finishEvent(A->inputq, event, 1);
  goto again;

touch_event:
  action= AMotionEvent_getAction(event);
  index= (action & AMOTION_EVENT_ACTION_POINTER_INDEX_MASK)
              >>AMOTION_EVENT_ACTION_POINTER_INDEX_SHIFT;
  action= (action & AMOTION_EVENT_ACTION_MASK);

  switch(action)
  {
  case AMOTION_EVENT_ACTION_UP:
     ev->type= GFXEV_BUTTON_RELEASE;
     ev->button= 1;
     ev->x= AMotionEvent_getX(event,index);
     ev->y= AMotionEvent_getY(event,index);
     // LOGV("Mouse up: %d %d\n", ev->mouse.x, ev->mouse.y);
     A->last_pointer_id= -1;
     break;
  case AMOTION_EVENT_ACTION_DOWN:
     ev->type= GFXEV_BUTTON_PRESS;
     ev->x= AMotionEvent_getX(event,index);
     ev->y= AMotionEvent_getY(event,index);
     ev->button= 1;
     A->last_pointer_id= AMotionEvent_getPointerId(event, index);    
     // LOGV("Mouse down: %d %d\n", ev->mouse.x, ev->mouse.y);
     break;
  case AMOTION_EVENT_ACTION_MOVE:
     npointers= AMotionEvent_getPointerCount(event);
     for(i=0;i<npointers;i++)
        if (AMotionEvent_getPointerId(event, i)==A->last_pointer_id)
        { 
          ev->type= GFXEV_POINTER_MOVE;
          ev->x= AMotionEvent_getX(event,i);
          ev->y= AMotionEvent_getY(event,i);
          // LOGV("Mouse move: %d %d [%d %d %d]\n", ev->mouse.x, ev->mouse.y,
                             // npointers, i, A->last_pointer_id);
          goto done;
        }
  default:
     goto next_event;
  }

done:
  AInputQueue_finishEvent(A->inputq, event, 1);
  return 0;
}


static int get_event(unsigned int *msecs, gfx_event_t *E)
{
   int ident;
   int dFD, dEV;
   app_t *app;
again:
   ident= ALooper_pollAll(-1,  &dFD, &dEV, (void**) &app);

   switch(ident)
   {
     // somebody might have woke us up because the looper
     // has changed and we need to poll again.
   case ALOOPER_POLL_WAKE:
      goto again;
   case PIPE_CMD:
      if (handle_command(app)) // quit was requested.
      {
        E->type= GFXEV_QUIT;
        return 1;
      }
      goto again;
   case PIPE_EVENT:
     if (handle_input(app, E) || !app->window)
       goto again;
     return 1;
   }

   // other things are not possible. maybe I can add some
   // sort of a time-out later.
   return 0;
}

int gfx_event (unsigned int *msecs, gfx_event_t *E)
{
retry:
  if (!get_event(msecs,E)) return 0;
  switch(E->type)
  {
  case GFXEV_POINTER_MOVE:
     if (handle_motion_event(E)==2) goto retry;
     break;
  case GFXEV_BUTTON_PRESS:
     if (handle_click_event(E)==2) goto retry;
     break;
  case GFXEV_BUTTON_RELEASE:
     if (handle_release_event(E)==2) goto retry;
     break;
  }
  return 1;
}

static int event_noprocess(unsigned int *msecs,gfx_event_t *E)
{
  return get_event(msecs,E);
}


JavaVM *gfx_get_javavm()
{
  return my_app -> activity -> vm ;
}
#endif

#ifndef GFX_ANDROID
/* The event routine returns an event from the queue. It waits a maximum
   of 'msecs' milliseconds for the event. If msecs is zero, it waits 
   until an event is received. 

   The return value is one if an event is returned. It's zero if the
   return was due to timeout.

   In case of an event, *msecs is updated to reflect the remaining
   wait time.  */
   
int gfx_event(unsigned int *msecs,gfx_event_t *Revent)
{
  int K;

again:
  K= event_noprocess(msecs, Revent);
  if (!K) return 0;
  
  switch(Revent->type)
  {
  case GFXEV_BUTTON_PRESS:
  case GFXEV_BUTTON_RELEASE:
  case GFXEV_POINTER_MOVE:
    if (handle_grabbed_event(Revent)) goto again; break;
  }

  switch(Revent->type)
  {
  case GFXEV_BUTTON_PRESS:
     if (handle_click_event(Revent)) goto again; break;
  case GFXEV_BUTTON_RELEASE:
     if (handle_release_event(Revent)) goto again; break;
  case GFXEV_POINTER_MOVE:
     if (handle_motion_event(Revent)) goto again; break;
  }

  if (focusable_event(Revent)) goto again;

  return 1; 
}

#endif


static void gfx_update_all()
{
  gfx_update(0,0,x_window_width, x_window_height);
}

static uint32_t *get_server_pix(int src_x,int src_y,int w,int h)
{
  uint32_t *D; int dw;
  int x,y;
  D= calloc(1,sizeof(uint32_t*)*w*h);
  dw= w;
  clip_for_rect(&src_x, &w, x_window_width);
  clip_for_rect(&src_y, &h, x_window_height);

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      D[x+y*dw]= x_image_data[y+src_y][x+src_x];
  return D;
}

static void put_server_pix(uint32_t *D,int dst_x,int dst_y,int w, int h)
{
  int dw;
  int x,y;
  dw= w;
  clip_for_rect(&dst_x, &w, x_window_width);
  clip_for_rect(&dst_y, &h, x_window_height);

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
      x_image_data[y+dst_y][x+dst_x]= D[x+y*dw];
}


static void populate_select_set
  (int *Rmaxfd, fd_set *rfd, fd_set *wfd, fd_set *xfd)
{
  int maxfd;
  int i;
  maxfd= *Rmaxfd;
  for(i=0;i<n_fmon;i++)
  {
    if (fmon[i].events&1) FD_SET(fmon[i].fd, rfd);
    if (fmon[i].events&2) FD_SET(fmon[i].fd, wfd);
    if (fmon[i].events&4) FD_SET(fmon[i].fd, xfd);
    maxfd= imax2(maxfd, fmon[i].fd);
  }
  *Rmaxfd= maxfd;
}

static int get_file_monitor_event
  (fd_set *rfd, fd_set *wfd, fd_set *xfd, gfx_event_t *Revent)
{
  static int last_pos;
  file_monitor_t *F;
  int i;

  if (!n_fmon) return 0;
  if (last_pos>=n_fmon) last_pos%=n_fmon;
  for(i=0;i<n_fmon;i++)
  {
     F= fmon + (i+last_pos)%n_fmon;
     if ((F->events&4) && FD_ISSET(F->fd, xfd)) 
          { Revent->type= GFXEV_READY_EXCEPT; goto found; }
     if ((F->events&2) && FD_ISSET(F->fd, wfd)) 
          { Revent->type= GFXEV_READY_WRITE; goto found; }
     if ((F->events&1) && FD_ISSET(F->fd, rfd)) 
          { Revent->type= GFXEV_READY_READ; goto found; }
  }
  return 0;
found:
  Revent->key= F->ident;
  Revent->wide= F->fd;
  last_pos= (last_pos+1)%n_fmon;
  return 1;
}


static int flag2(int a,int b)
{
  int S= 0;
  if (a) S|= 2;
  if (b) S|= 1;
  return S;
}
static int range_test(int v, int s, int w) { return v>=s && v<(s+w); }


static int imin2(int a,int b) { return a < b ? a : b; }
static int imax2(int a,int b) { return a > b ? a : b; }


static double dmin2(double a,double b) { return a<b?a:b; }
static double dmax2(double a,double b) { return a>b?a:b; }

static int utf8_encode_string
    (const uint32_t* wstr,size_t wlen, uint8_t *dst, size_t *dlen)
{
/*
  This is all from
  http://www.cl.cam.ac.uk/~mgk25/unicode.html

  TODO: what to do if the input has invalid
  unicode chars such as unassigned chars etc?
  pass them thru?
*/

/* Encoding Table
                  Start-Byte    
 Min Value    8421 8421   hex     Length
0x04000000    1111 110x   fc        6
0x00200000    1111 10xx   f8        5
0x00010000    1111 0xxx   f0        4
0x00000800    1110 xxxx   e0        3
0x00000080    110x xxxx   c0        2 */
  int i,k,len;
  uint32_t chr;
  unsigned char *odst;

  static const unsigned int lowerlimit[]=
    { 0x04000000, 0x00200000, 0x00010000, 0x00000800, 0x00000080 };
  static const unsigned char topbits []= { 0xfc, 0xf8, 0xf0, 0xe0, 0xc0 };
  const unsigned char lower6=  0x3f; // binary 0011 1111
  const unsigned char seventh= 0x80; // binary 1000 0000
  const unsigned int bit31=    0x80000000; 

  odst= dst;

  while(wlen)
  {
    chr= *(wstr++); wlen--;
    if (chr<=0x7f)   { *(dst++)= chr; continue; }
    if (chr & bit31) { *(dst++)= chr & ~bit31; continue; }

    for(i=0;i<4;i++) if (chr >= lowerlimit[i]) break;
    len= 4-i+2;

    for(k=len-1;k>0;k--)
    {
      dst[k]= seventh | (chr & lower6);
      chr >>= 6;
    }
    dst[k]= chr | topbits[i];
    dst+= len;
  }

  *dlen= dst-odst;
  return 0;
}


/*
UTF-8 Table
8421 8421
110x xxxx   2 bytes    mask= e0  result= c0   min= 80       vmask= 1f
1110 xxxx   3 bytes    mask= f0  result= e0   min= 800      vmask= 0f
1111 0xxx   4 bytes    mask= f8  result= f0   min= 10000    vmask= 07
1111 10xx   5 bytes    mask= fc  result= f8   min= 200000   vmask= 03
1111 110x   6 bytes    mask= fe  result= fc   min= 4000000  vmask= 01

10xx xxxx   cont. byte mask= c0  result= 80   vmask= 3f
*/
static int utf8_decode_string
  (const uint8_t *input, size_t ilen, uint32_t *output, size_t *olen)
{
   const uint8_t *end,*start;
   static const uint32_t bit31= (1<<31);
   size_t L;
   int have_errors;
   int i, contb;
   uint8_t C;
   uint32_t outc; uint32_t min;

   end= input+ilen;
   L= 0;
   have_errors= 0;

   if (ilen==0) goto done;

again:
   C= input[0];
   if ( (C&0x80) ==0)    { outc= C; input++; goto out; }
   if ( (C&0xe0) ==0xc0) goto seq2; 
   if ( (C&0xf0) ==0xe0) goto seq3;
   if ( (C&0xf8) ==0xf0) goto seq4;

   // Here, we don't care about the seq5 and seq6 stuff.
   // they are invalid anyway, either overlong or greater
   // then the unicode limit. We just treat them as unrecognized
   // bytes and output them.
invalid_byte:
   outc= input[0] | bit31;
   input++;
   have_errors= 1;
   goto out;

seq2: outc= C & 0x1f;  min=    0x80; contb= 1; goto do_cont;
seq3: outc= C & 0x0f;  min=   0x800; contb= 2; goto do_cont;
seq4: outc= C & 0x07;  min= 0x10000; contb= 3; goto do_cont;

do_cont:
   start= input;
   input++;
   for(i=0;i<contb;i++)
   {
     if ((input==end) || ( (input[0]&0xc0) !=0x80)) goto reject;
     outc= (outc << 6) | (input[0]&0x3f);
     input++;
   }

   if (outc<min || outc>0x10ffff) goto reject; 
   if (outc>=0xd800 && outc<=0xdfff) goto reject;
   if (outc==0xffff || outc==0xfffe) goto reject;

out:
   output[L++]= outc;
   if (input<end) goto again;
done:
   *olen= L;
   return have_errors;
reject:
   input= start;
   goto invalid_byte; 
}


static uint32_t utf8_decode_single_char(char *src)
{
  uint32_t *dst;
  size_t L;
  L= strlen(src);
  dst= alloca(sizeof(*dst)*(L+1));
  utf8_decode_string((uint8_t*) src, L, dst, &L);
  if (L==0) return ' ';
  return dst[0];
}


static void utf8_encode_single_char(uint32_t wide, char *dst)
{
  /* This assumes that dst is big enough, at least 6 bytes. */
  size_t L;
  L= 6;
  utf8_encode_string(&wide,1, (uint8_t*) dst, &L);
}

static void utf8_decode_alloc(char *str, uint32_t **Rwstr, uint32_t *Rwlen)
{
  uint32_t *S;
  size_t L,SL;
  L= strlen(str);
  S= malloc((L+1)*sizeof(uint32_t));
  utf8_decode_string((uint8_t*)str, L, S, &SL);
  *Rwstr= S;
  *Rwlen= SL;
}


static int clip_for_rect(int *start, int *amount, int max)
{
  int end, am;
  am= *amount;
  if (am<=0) return 1;
  end= *start + am;
  if (end>max) end= max;
  if (*start<0) *start= 0;
  *amount= am= end - *start;
  return am<=0;
}

static void freeNnull(void *A)
{
  if (A) free(A);
}

void *array_make1space(int pos,void **Rarray,int n, int *Rs, int eltsize)
{
  void *src, *dst;
  int cp;
  int s;

  src= *Rarray;
  s= *Rs;
  if (n<s)
  {
    dst= src;
  }
  else
  {
    if (s==0) s= 50;
         else s+= s/2;
    dst= malloc(s*eltsize);
  }

  if (dst!=src && src && pos)
    memcpy(dst, src, pos*eltsize);
  cp= n - pos;
  if (src && cp)
    memmove(dst+(pos+1)*eltsize, src+pos*eltsize, cp*eltsize);

  if (src && src!=dst) free(src);
  *Rarray= dst;
  *Rs= s;
  return dst+pos*eltsize;
}


static void enter_screen
   (int n_widgets, int *widgets,int *co)
{
  screen_t *S;

  if (screen)
  {
    widget_t *W;
    W= screen->focus_widget;
    if (W && W->focus && W->has_focus)
    {
      (*W->focus)(W,0);
      W->has_focus= 0; 
    }
  }

  S= calloc(1,sizeof(*S));
  S->next= screen;
  screen= S;

  if (co[0]<0) co[0]= 0;
  if (co[1]<0) co[1]= 0;
  if (co[2]<=0) co[2]= x_window_width;
  if (co[3]<=0) co[3]= x_window_height;

  S->x= co[0]; S->y= co[1];
  S->w= co[2]; S->h= co[3]; 

  if (S->x>=x_window_width) S->x= 0;
  if (S->y>=x_window_height) S->y= 0;
  if (S->x+S->w>x_window_width) S->w= x_window_width-S->x;
  if (S->y+S->h>x_window_height) S->h= x_window_height-S->y;

  if (S->next)
  {
    S->backstore= get_server_pix(0,0,x_window_width,x_window_height);
    S->back_w= x_window_width;
    S->back_h= x_window_height;
  }

  S->n_widgets= n_widgets;
  S->widgets= widgets;

  gfx_fill_rect(0,S->x,S->y,S->w,S->h,0xededed);
  if (S->x>0 || S->y>0)
    gfx_draw_rect(0, S->x-1,S->y-1,S->w+2,S->h+2, 0x00);
}


static int install_click_handler
        (int x,int y,int w,int h,int *enabled,
         void *arg, int (*func)(void*,gfx_event_t*),int button)
{
  click_handler_t *C;
  int R;
  if (!screen) return 0;

  if (screen->n_click_handlers==screen->s_click_handlers)
  {
    int delta;
    if (screen->s_click_handlers) delta= screen->s_click_handlers/2;
                             else delta= screen->n_widgets;
    screen->s_click_handlers+= delta;
    screen->click_handlers= realloc(screen->click_handlers, 
                                    sizeof(click_handler_t)*
                                       screen->s_click_handlers);
  }
  R= screen->n_click_handlers;
  screen->n_click_handlers++;
  C= screen->click_handlers + R;
  C->x= x;
  C->y= y;
  C->w= w;
  C->h= h;
  C->enabled= enabled;
  C->arg= arg;
  C->func= func;
  C->button= button;
  return R;
}

static void install_release_handler
        (void *arg, int (*func)(void*,gfx_event_t*))
{
  if (!screen) return ;
  screen->release_handler.func= func;
  screen->release_handler.arg= arg;
}

static void install_motion_handler(void *arg,int (*func)(void *,gfx_event_t*))
{
  if (!screen) return ;
  screen->motion_handler.func= func;
  screen->motion_handler.arg= arg;
}

static void uninstall_motion_handler()
{
  if (!screen) return ;
  screen->motion_handler.func= NULL;
  screen->motion_handler.arg= NULL;
}

/***************
Now we have yet another handler for mouse events. Sometimes, it's necessary
to grab all mouse events. For example, the dropdown widget does this. If
the user clicks outside the dropdown list, the list gets hidden.
***************/

static int handle_grabbed_event(gfx_event_t *event)
{
  if (!screen || !screen->grabber.func) return 0;
  return (*screen->grabber.func)(screen->grabber.arg, event);
}

static void grab_mouse(int (*func)(void*,gfx_event_t*), void *arg)
{
  if (!screen) return ;
  screen->grabber.func= func;
  screen->grabber.arg= arg;
}

static void ungrab_mouse()
{
  if (!screen) return ;
  screen->grabber.func= NULL;
  screen->grabber.arg= NULL;
}


static int handle_click_event(gfx_event_t *event)
{
  int i;
  click_handler_t *C;

  if (!screen || event->type!=GFXEV_BUTTON_PRESS) return 0;
  for(i=0;i<screen->n_click_handlers;i++)
  {
    C= screen->click_handlers+i;
    if (C->button!=event->button) continue;
    if (range_test(event->x,C->x, C->w) && range_test(event->y,C->y, C->h))
    {
             // if the widget was disabled, look for something else
      if ((!C->enabled || C->enabled[0])&& C->func)
           return (*C->func)(C->arg, event);
    }
  }
  return 0;
}

static void remove_click_handler(int H)
{
  int i;
  if (!screen) return;
  if (H<0 || H>=screen->n_click_handlers) return ;
  screen->click_handlers[H].func= NULL;
  for(i=H;i<screen->n_click_handlers;i++)
    if (screen->click_handlers[i].func!=NULL) return ;
  screen->n_click_handlers= H;
}


static int handle_release_event(gfx_event_t *event)
{
  void *A; int (*F)(void *,gfx_event_t*);
  if (!screen || event->type!=GFXEV_BUTTON_RELEASE || event->button!=1)
      return 0;
  if (screen->release_handler.func)
  {
    A= screen->release_handler.arg;
    F= screen->release_handler.func;
    screen->release_handler.arg= NULL;
    screen->release_handler.func= NULL;
    return (*F)(A, event);
  }
  return 0;
}

static int handle_motion_event(gfx_event_t *event)
{
  if (!screen || event->type!=GFXEV_POINTER_MOVE) return 0;
  if (screen->motion_handler.func)
     return (*screen->motion_handler.func)(screen->motion_handler.arg,event);
  return 0;
}


static void widget_destroy(widget_t* W)
{
  if (!W) return ;
  if (W->destroy) 
   { (*W->destroy)(W); widgets[W->number]= NULL; free(W); return ; }
  switch(W->klass)
  {
case GFXCLASS_BUTTON: 
case GFXCLASS_TOGGLE: gui_button_destroy((gui_button_t*)W); break;

case GFXCLASS_LABEL: gui_label_destroy((gui_label_t*) W); break;



case GFXCLASS_RADIO:
  { radio_t *R= (void*) W;
    if (R->text) free(R->text);
    remove_click_handler(R->click); break; }

case GFXCLASS_CHECKBOX:
  { checkbox_t *R= (void*) W;
    if (R->text) free(R->text);
    remove_click_handler(R->click); 
    break; }

case GFXCLASS_SCROLLBAR: scrollbar_destroy((scrollbar_t*)W); break;
 case GFXCLASS_DROPDOWN: dropdown_destroy((dropdown_t*)W); break;
 case GFXCLASS_TEXTENTRY: textentry_free((text_entry_t*)W); break;

case GFXCLASS_PIXGRID: 
{
  gui_pixgrid_t *G;
  G= (gui_pixgrid_t*) W;
  remove_click_handler(G->click_handler);
  break;
}


case GFXCLASS_CANVAS: 
  { gui_canvas_t *CC= (void*) W;
    if (CC->buffer) free(CC->buffer);
    if (CC->scrollh) { scrollbar_destroy(CC->scrollh); free(CC->scrollh); }
    if (CC->scrollv) { scrollbar_destroy(CC->scrollv); free(CC->scrollv); }
    break;
  }

case GFXCLASS_SPINNER: gui_spinner_destroy((gui_spinner_t*) W); break;

    default: break;
  }
  widgets[W->number]= NULL;
  free(W);
}

static void widget_move(widget_t *W,int x,int y,int w,int h)
{
  if (!W) return ;
  if (W->position) { (*W->position)(W,x,y,w,h); return ; }
  switch(W->klass)
  {

case GFXCLASS_BUTTON:
case GFXCLASS_TOGGLE:
  button_set_position( (gui_button_t*) W, x,y,w,h);
  break;

case GFXCLASS_LABEL: gui_label_set_position((gui_label_t*)W, x,y,w,h); break; 

case GFXCLASS_RADIO:
  { radio_t *R; R= (void *)W;
    W->x= x; W->y= y; W->w= w; W->h= h;
    if (R->click!=-1) set_click_handler(R->click, x,y,w,h);
  radio_draw((radio_t*)W);
  break; }

case GFXCLASS_CHECKBOX:
  { checkbox_t *R; R= (void *)W;
    W->x= x; W->y= y; W->w= w; W->h= h;
    if (R->click!=-1) set_click_handler(R->click, x,y,w,h);
  checkbox_draw((checkbox_t*)W);
  break; }

case GFXCLASS_SCROLLBAR: 
  scrollbar_position((scrollbar_t*)W, x,y,w,h);
  break;
case GFXCLASS_PANEL: panel_position((panel_t *)W,x,y,w,h); break;
 case GFXCLASS_DROPDOWN: dropdown_position((dropdown_t*)W,x,y,w,h); break;

 case GFXCLASS_LIST:
  { gui_list_set_position((gui_list_t*)W, x,y,w,h); break; }


  case GFXCLASS_TEXTENTRY: textentry_position((text_entry_t*)W,x,y,w,h); break;


case GFXCLASS_PIXGRID:
{
  gui_pixgrid_t *G;
  G= (gui_pixgrid_t*) W;

  W->x= x;
  W->y= y;
  W->w= w;
  W->h= h;

  set_click_handler(G->click_handler,x,y,w,h);
  break;
}

case GFXCLASS_CANVAS: 
   gui_canvas_position((gui_canvas_t*)W, x,y,w,h);
   break;

 case GFXCLASS_SPINNER:
  gui_spinner_set_position((gui_spinner_t*)W, x,y,w,h); break; 

    default: break;
  }
}

static void widget_show(widget_t *W, int show)
{
  if (!W) return ;
  if (show) show= 1;

  if (W->show)
  {
    if (W->shown==show) return ;
    W->shown= show;
    if (W->shown) { (*W->show)(W); }
             else { if (W->hide) (*W->hide)(W); }
    return ;
  }

  switch(W->klass)
  {
case GFXCLASS_BUTTON:
case GFXCLASS_TOGGLE:
{
  gui_button_show((gui_button_t*) W, show);
  break;
}

case GFXCLASS_RADIO:
  radio_show((radio_t*) W,show);
  break;

case GFXCLASS_CHECKBOX:
  checkbox_show((checkbox_t*) W,show);
  break;

case GFXCLASS_SCROLLBAR: scrollbar_show((scrollbar_t*)W, show); break;
case GFXCLASS_PANEL: panel_show((panel_t*)W,show); break;
 case GFXCLASS_DROPDOWN: dropdown_show((dropdown_t*)W,show); break;

 case GFXCLASS_LIST: gfx_list_show((gui_list_t*) W,show); break;

case GFXCLASS_PIXGRID:
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) W;
  if (B->enabled==show) break ;
  B->enabled= show;
  break;
}

case GFXCLASS_CANVAS: 
  { gui_canvas_t *CC= (void*) W;
    if (CC->enabled==show) break;
    CC->enabled= show;
    if (CC->enabled)
    {
      gui_canvas_draw_all(CC);
      gui_canvas_update_click_handlers(CC);
    }
    break;
  } 

 case GFXCLASS_SPINNER: gui_spinner_show((gui_spinner_t*) W,show); break;

    default: break;
  }
}

static void widget_set_text(widget_t *W, char *str)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_LABEL: gui_label_set_text( (gui_label_t*) W,str); break;

case GFXCLASS_TEXTENTRY: text_entry_set((text_entry_t*)W,str); break;

    default: break;
  }
}

static char* widget_get_text(widget_t *W)
{
  char *str;
  if (!W) return strdup("");
  switch(W->klass)
  {
  case GFXCLASS_TEXTENTRY: str= textentry_get_text((text_entry_t*)W); break;

  default: str= strdup("");
  }
  return str;
}

static widget_t *get_widget(int wno)
{
  if (wno<=_XX_WIDGETS_START || wno>=_XX_WIDGETS_END) return NULL;
  return widgets[wno];
}

static void widget_set_state(widget_t *W, int state)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_TOGGLE:
{
  gui_button_t *B;
  B= (gui_button_t*) W;
  if (state) state= 1;
  button_set_state(B,state);
  break;
}

case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    if (R->state==state) break;
    if (R->state) { R->state= 0; radio_draw_button(R,R->state,1,1); }
    else radio_set(R);
    break; }

case GFXCLASS_CHECKBOX:
  checkbox_set((checkbox_t *)W, state); 
  break;

  }
}

static int widget_get_state(widget_t *W)
{
  int result;
  if (!W) return 0;
  result= 0;
  switch(W->klass)
  {
case GFXCLASS_TOGGLE:
{
  gui_button_t *B;
  B= (gui_button_t*) W;
  result= B->state;
  if (result) result= 1;
  break;
}

case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    result= R->state; break; }

case GFXCLASS_CHECKBOX:
  { checkbox_t *R; R= (void*) W;
    result= R->state; break; }

  }
  return result;
}

static int widget_get_selected(widget_t *W)
{
  int result;
  if (!W) return -1;
  result= -1;
  switch(W->klass)
  {
case GFXCLASS_RADIO:
  { radio_t *R; R= (void*) W;
    if (R->group==-1) return -1;
    return radio_group_get_selected(R->group); }

case GFXCLASS_DROPDOWN: 
  {
    dropdown_t* DD;
    DD= (dropdown_t *) W;
    result= DD->selected;
    break;
  }

 case GFXCLASS_LIST: result= gfx_list_selected((gui_list_t *)W); break;

  }
  return result;
}

static void widget_set_selected(widget_t *W,int sel)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_PANEL: panel_activate((panel_t *)W,sel); break;
case GFXCLASS_DROPDOWN: gfx_dropdown_select((dropdown_t*)W, sel); break;

 case GFXCLASS_LIST: gfx_list_select((gui_list_t*)W,sel); break;

  }
}

static void widget_set_fgbg(widget_t *W,int fg,int bg)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_LABEL: label_set_fgbg((gui_label_t*) W, fg, bg); break;

  }
}

static void widget_insert
  (widget_t *W,int pos, char *text, void *user, uint32_t *icon)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: dropdown_insert((dropdown_t*)W, pos, text, user); break;

case GFXCLASS_LIST:
  gfx_list_insert((gui_list_t*) W, pos, text, user, icon);
  break;

  }
}

static void widget_remove(widget_t *W,int pos, void **Ruser)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: dropdown_remove((dropdown_t*)W,pos,Ruser); break;

 case GFXCLASS_LIST: gfx_list_delete((gui_list_t*)W,pos,Ruser); break;

  }
}

static void widget_clear(widget_t *W)
{
  if (!W) return ;
  switch(W->klass)
  {
case GFXCLASS_DROPDOWN: gui_dropdown_clear((dropdown_t*) W); break;

case GFXCLASS_LIST:
  gfx_list_clear((gui_list_t*) W);
  break;
 
  }
}


static void set_focus(widget_t *N)
{
  widget_t *W;
  if (!screen || !N) return ;
  if (!N->can_focus || N->has_focus) return ;

  W= screen->focus_widget;
  if (W && W->can_focus && W->has_focus)
  {
    if (W->focus) (*W->focus)(W, 0);
    W->has_focus= 0;
  }

  if (N->focus) (*N->focus)(N,1);
  N->has_focus= 1;
  screen->focus_widget= N;
}


static int tabs_before(widget_t *A,widget_t *B)
{
  if (A->y<B->y) return 1;
  if (A->y==B->y && A->x<B->x) return 1;
  return 0;
}

static int focusable_event(gfx_event_t *event)
{
  int i;
  widget_t *W;

  if (!screen) return 0; 
  if (event->type==GFXEV_BUTTON_PRESS) 
  { 
    // FIXME: check for modifiers
    if (event->button!=1) return 0;
    for(i=0;i<screen->n_widgets;i++)
    {
      W= widgets[screen->widgets[i]];
      if (!W) continue;
      if (W->can_focus &&
          range_test(event->x, W->x, W->w) &&
          range_test(event->y, W->y, W->h)) break;
    }
    if (i==screen->n_widgets || W==screen->focus_widget) return 0;
    screen->focus_clicked= W;
    return 1;
  }
  if (event->type==GFXEV_BUTTON_RELEASE)
  {
    // FIXME: check for modifiers
    if (event->button!=1 || !screen->focus_clicked) return 0;
    set_focus(screen->focus_clicked);
    screen->focus_clicked= NULL;
    return 1;
  }
  if (event->type==GFXEV_KEY_PRESS)
  {
    widget_t *target, *minpos,*current;

    W= screen->focus_widget;
    if (!W) return 0;
    if (W->handle_key && (*W->handle_key)(W, event)) return 1;

    // FIXME: handle shift-tab
    if (event->key!=GFX_K_TAB)  return 0;
    
    for(i=0;i<screen->n_widgets;i++)
      if (W->number==screen->widgets[i]) break;

    if (i==screen->n_widgets) return 0;
    target= NULL;
    minpos= NULL;
    current= widgets[screen->widgets[i]];
  
    for(i=0;i<screen->n_widgets;i++)
    {
      W= widgets[screen->widgets[i]];
      if (W==current || !W || !W->can_focus) continue;

                   // FIXME: check for visibility also..
      if (!minpos) minpos= W;
      else if (tabs_before(W,minpos)) minpos= W; 

      if (tabs_before(W,current)) continue;
      if (target && tabs_before(target,W)) continue;
      target= W;
    }
    if (!target) target= minpos;
    if (target)
    {
      set_focus(target);
      return 1;
    }
  }
  return 0;
}

static void focus_lost()
{
  if (!screen) return ;
  screen->focus_widget= NULL;
}

static void set_click_handler(int click,int x,int y,int w,int h)
{
  click_handler_t *C;
  if (!screen) return ;
  if (click<0 || click>=screen->n_click_handlers) return ;
  C= screen->click_handlers+click;
  C->x= x;
  C->y= y;
  C->w= w;
  C->h= h;
}


static int install_or_modify_click
  (int ch, int *enabled, int (*func)(void*,gfx_event_t*), void* arg,
   int x,int y,int w,int h,int button)
{
  if (ch==-1)
   return install_click_handler(x,y,w,h,enabled,arg, func,button);

  set_click_handler(ch, x,y,w,h);
  return ch;
}

static void widgetpos(widget_t *W,int x,int y,int w,int h)
{
  W->x= x; W->y= y; W->w= w; W->h= h;
}

static uint32_t blend_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;

  if (alpha==0xff) { pR= fR; pG= fG; pB= fB; goto OK;}

  bR= (bg>>16)&0xff; bG= (bg>>8)&0xff; bB= bg&0xff;
  if (alpha==0) { pR= bR; pG= bG; pB= bB; goto OK; }

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

OK:
  return   ((pR<<x_red_shift)&x_red_mask)
         | ((pG<<x_green_shift)&x_green_mask)
         | ((pB<<x_blue_shift)&x_blue_mask);
}

static uint32_t blend_usr_usr_usr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  if (alpha==0xff)  return fg; 
  if (alpha==0)    return bg;  

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;


  bR= (bg>>16)&0xff; bG= (bg>>8)&0xff; bB= bg&0xff;

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

  return  (pR<<16) | (pG<<8) | (pB<<0);
}

static uint32_t blend_usr_svr(uint32_t alpha, uint32_t fg, uint32_t bg)
{
  uint32_t fR, fG, fB; 
  uint32_t bR, bG, bB; 
  uint32_t pR, pG, pB; 
  double A,B;

  if (alpha==0) return bg;

  fR= (fg>>16)&0xff; fG= (fg>>8)&0xff; fB= fg&0xff;

  if (alpha==0xff) { pR= fR; pG= fG; pB= fB; goto OK;}

  bR= (bg&x_red_mask)>>x_red_shift; 
  bG= (bg&x_green_mask)>>x_green_shift;
  bB= (bg&x_blue_mask)>>x_blue_shift;

  A= (double) alpha / 255.0;
  B= 1.0-A;

  pR= A*fR + B*bR;
  pG= A*fG + B*bG;
  pB= A*fB + B*bB;

OK:
  return   ((pR<<x_red_shift)&x_red_mask)
         | ((pG<<x_green_shift)&x_green_mask)
         | ((pB<<x_blue_shift)&x_blue_mask);
}

static void blend_graymap(int flags, int fg, int bg,
                          const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          int dst_x, int dst_y, int width, int height)
{
  int x,y;
  uint32_t A;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, x_window_width);
  clip_for_rect( &dst_y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  if (flags&GFX_BACKGND) // blend with fg,bg pair
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)   
      {
        A= src[(x+src_x) + (y+src_y)*src_w];
        x_image_data[y+dst_y][x+dst_x]= blend_usr_usr(A,fg, bg);
      }
  } 
  else
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)   
      {
        A= src[(x+src_x) + (y+src_y)*src_w];
        x_image_data[y+dst_y][x+dst_x]= 
             blend_usr_svr(A,fg, x_image_data[y+dst_y][x+dst_x]);
      }
  } 

  if (flags&GFX_UPDATE)
    gfx_update(dst_x, dst_y, width, height);
}

static uint32_t color_s(uint32_t uR, uint32_t uG, uint32_t uB)
{
  return ((uR<<x_red_shift)&x_red_mask)
        |((uG<<x_green_shift)&x_green_mask)
        |((uB<<x_blue_shift)&x_blue_mask);
}

static uint32_t u_red(uint32_t C) { return (C>>16)&0xff; }
static uint32_t u_green(uint32_t C) { return (C>>8)&0xff; }
static uint32_t u_blue(uint32_t C) { return (C)&0xff; }

static uint32_t color_u_to_s(uint32_t U)
{
  return color_s(u_red(U), u_green(U), u_blue(U));
}

static unsigned int blend_chan(unsigned int F, double A, unsigned int B)
{
  return  (unsigned int) ((F&0xff)*A + (B&0xff)*(1-A));
}


static unsigned int blend(uint32_t F, double A, uint32_t B)
{
  return color_s(
            blend_chan( u_red(F), A, u_red(B)),
            blend_chan( u_green(F), A, u_green(B)),
            blend_chan( u_blue(F), A, u_blue(B))
                );
}

static void grad_fill(int x,int y, int w, int h, uint32_t start, uint32_t end)
{
  int fx, fy, fw, fh,x0,y0,dx,dy;
  fx= x; fy= y; fw= w; fh= h;

  clip_for_rect(&x, &w, x_window_width);
  clip_for_rect(&y, &h, x_window_height);
  if (w<=0 || h<=0) return;

  for(y0=0;y0<h;y0++)
    for(x0=0;x0<w;x0++)
    {
      dx= (x0+x)-fx; dy= (y0+y)-fy;
      x_image_data[y0+y][x0+x]= blend(start, 1.0-(double)(dx+dy)/(fw+fh), end);
    }
}

static void hline(int x1,int x2, int y,uint32_t color)
{
  if (y<0 || y>=x_window_height || x1>x2 || x1>=x_window_width) return ;
  if (x2>=x_window_width) x2= x_window_width-1;

  for(;x1<=x2;x1++)
    x_image_data[y][x1]= color;
}

static void vline(int x,int y1, int y2,uint32_t color)
{
  if (x<0 || x>=x_window_width || y1>y2 || y1>=x_window_height) return ;
  if (y2>=x_window_height) y2= x_window_height-1;

  for(;y1<=y2;y1++)
    x_image_data[y1][x]= color;
}




static void gfx_fill_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color)
{
  int x,y;
  uint32_t sv;
  clip_for_rect(&dst_x, &w, x_window_width);
  clip_for_rect(&dst_y, &h, x_window_height);
  if (w<=0 || h<=0) return ;
  sv= color_u_to_s(color);
  for(y=0;y<h;y++)
   for(x=0;x<w;x++)
     x_image_data[y+dst_y][x+dst_x]= sv;
  if (flags&GFX_UPDATE) gfx_update(dst_x, dst_y, w,h);
}


void gfx_draw_rect(int flags, int dst_x,int dst_y,
                   int w,int h, unsigned int color)
{
  uint32_t sv;
  sv= color_u_to_s(color);
  hline(dst_x, dst_x+w-1, dst_y, sv);
  hline(dst_x, dst_x+w-1, dst_y+h-1, sv);
  vline(dst_x, dst_y, dst_y+h-1, sv);
  vline(dst_x+w-1, dst_y, dst_y+h-1, sv);
  if (flags&GFX_UPDATE) gfx_update(dst_x, dst_y, w,h);
}

static void blend_graymap_buffer
        (unsigned int fg, const unsigned char *src, int src_w, int src_h,
                          int src_x, int src_y,
                          unsigned int *dst, int dst_w, int dst_h,
                          int dst_x, int dst_y, int width, int height)
{
  int x,y;
  uint32_t A,D;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, dst_w);
  clip_for_rect( &dst_y, &height, dst_h);
  if (width<=0 || height<=0) return ;

  for(y=0;y<height;y++)
  {
    for(x=0;x<width;x++)   
    {
       A= src[(x+src_x) + (y+src_y)*src_w];
       D= (y+dst_y)*dst_w + (x+dst_x);
       dst[D]= blend_usr_usr_usr(A,fg, dst[D]);
    }
  }
}



static void gfx_put(int flags,
             const unsigned int *buffer, int src_w, int src_h,
             int src_x, int src_y,
             int dst_x, int dst_y,
             int width, int height)
{
  int x,y;

  clip_for_rect( &src_x, &width, src_w);
  clip_for_rect( &src_y, &height, src_h);
  clip_for_rect( &dst_x, &width, x_window_width);
  clip_for_rect( &dst_y, &height, x_window_height);
  if (width<=0 || height<=0) return ;

  if (!(flags&GFX_ALPHA)) 
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)
      {
         uint32_t sR, sG, sB, sP;
         uint32_t dP;
         sP= buffer[ (x+src_x) + (y+src_y)*src_w ];
         sR= (sP >> 16)&0xff;
         sG= (sP >> 8 )&0xff;
         sB= (sP      )&0xff;

         dP= (sR << x_red_shift)&x_red_mask;
         dP|= (sG << x_green_shift)&x_green_mask;
         dP|= (sB << x_blue_shift)&x_blue_mask;

         x_image_data[y+dst_y][x+dst_x]= dP;
       }
  }
  else
  {
    for(y=0;y<height;y++)
      for(x=0;x<width;x++)
    {
        uint32_t sA, sR, sG, sB, sP;
        uint32_t     dR, dG, dB, dP;

        sP= buffer[ (x+src_x) + (y+src_y)*src_w ];
        sA= (sP >> 24)&0xff;
        if (!sA) continue;

        sR= (sP >> 16)&0xff;
        sG= (sP >> 8 )&0xff;
        sB= (sP      )&0xff;

        if (sA==0xff)
        {
           dR= sR;
           dG= sG;
           dB= sB;
        }
        else 
        {
            double R,V;

            dP= x_image_data[y+dst_y][x+dst_x];

            dR= (dP & x_red_mask)>>x_red_shift;
            dG= (dP & x_green_mask)>>x_green_shift;
            dB= (dP & x_blue_mask)>>x_blue_shift;

            V= sA/255.0; R= 1.0 - V;

            dR=  dR*R + sR*V;
            dG=  dG*R + sG*V;
            dB=  dB*R + sB*V;
         }

         dP= (dR << x_red_shift)&x_red_mask;
         dP|= (dG << x_green_shift)&x_green_mask;
         dP|= (dB << x_blue_shift)&x_blue_mask;

         x_image_data[y+dst_y][x+dst_x]= dP;
     }
  }

  if (flags & GFX_UPDATE)
      gfx_update(dst_x,dst_y,width,height);
}


static unsigned int* convert_graymap_to_color
        (unsigned int fg, unsigned int bg, const unsigned char *src)
{
  unsigned int *buffer;
  int i;
  int w,h;
  w= src[0]; 
  h= src[1];
  src+= 2;
  buffer= malloc(sizeof(*buffer)*(w*h+2));
  for(i=0;i<w*h;i++) buffer[i+2]= bg;

  blend_graymap_buffer(fg, src, w,h, 0,0, buffer+2, w,h, 0,0, w,h);
  buffer[0]= w;
  buffer[1]= h;
  return buffer;
}


static void gfx_draw_3dbox(int x,int y,int w,int h, 
                        int light, int dark, int border,
                        int start, int end)
{
  int sX,sY,eX,eY;

  light= color_u_to_s(light);
  dark= color_u_to_s(dark);
  border= color_u_to_s(border);

  sX= x; eX= x + w - 1;
  sY= y; eY= y + h - 1;

  hline(sX, eX, sY,     border);
  hline(sX, eX, eY,     border);
  vline(sX, sY+1, eY-1, border);
  vline(eX, sY+1, eY-1, border);

  hline(sX+1, eX-2, sY+1, light);
  vline(sX+1, sY+1, eY-2, light);
  hline(sX+1, eX-1, eY-1, dark);
  vline(eX-1, sY+1, eY-1, dark);

  grad_fill(sX+2, sY+2, w-4, h-4, start, end);
}


static void convert_images_to_server(uint32_t **images)
{
  int i;
  for(i=0;images[i];i++)
  {
    convert_image_to_server(images[i]);
    images[i]= NULL;
  }
}

static void convert_image_to_server(uint32_t *IMG)
{
  int W,H,i;
  W= IMG[0];
  if (W&(1<<31))
  {
    H= IMG[1];
    W&= ~(1<<31);
    IMG+= 2;
    for(i=0;i<W*H;i++)
      IMG[i]= color_u_to_s(IMG[i]);
    IMG[-2] = W;
  }
}

static void draw_icon_and_text
                 (int x,int y,int w,int h,
                  int iconpos, uint32_t *icon,
                  int space,
                  uint32_t text_fg, char *text)
{
  int iw,ih,tw,th,ix,iy,tx,ty,total_w,total_h;
  if (!icon) 
  {
    if (text) goto text_only;
    return ;
  }
  if (!text)
  {
     draw_icon_centered(x,y,w,h,icon);
     return ;
  }
  // convert_image_to_server(icon);

  iw= icon[0] & ~(1<<31);
  ih= icon[1];
  get_text_data(1, text, &tw, &th,NULL,NULL);

  switch(iconpos)
  {
  case 'L': case 'R':
     total_w= iw+tw; 
     if (total_w>w) goto text_only;
     
     if (w-total_w<space) space= w-total_w;
     total_w+= space;
     break;
  case 'T': 
  case 'B': 
  default:
     total_h= ih+th;
     if (total_h>h) goto text_only;
     if (h-total_h<space) space= h-total_h;
     total_h+= space;
     break;
  }
  switch(iconpos)
  {
   case 'L':
     ix= (w - total_w)/2;
     tx= ix+iw+space;
     goto horz_render;
   case 'R':
     tx= (w - total_w)/2;
     ix= tx+tw+space;
     goto horz_render;
   case 'T':
     iy= (h-total_h)/2;
     ty= iy+ih+space;
     break;
   default:
   case 'B':
     iy= (h-total_h)/2;
     ty= iy+ih+space;
     break;
  }
  draw_icon_centered(x, y+iy, w, ih, icon);
  txt_print_fit("C.", "L>", x, y+ty, w, th, 1,1, text_fg,0xFFffFF, text);
  return ;

text_only:
  txt_print_fit("C.","C.",x,y,w,h,1,1,text_fg, 0xffffff, text);
  return ;
horz_render:
  draw_icon_centered(x+ix, y, iw, h, icon);
  txt_print_fit("L>", "C.", x+tx, y, tw, h, 1,1,text_fg,0xffFFff,text);
  return ;
}

static void draw_icon_centered(int x,int y,int w,int h, uint32_t *icon)
{
  int iw,ih, copy_w, copy_h, src_x, src_y, dst_x, dst_y;
  iw= icon[0];
  ih= icon[1];
  iw&=~(1<<31);
  if (iw<=w)
  {
    src_x= 0;
    dst_x= (w-iw)/2;
    copy_w= iw;
  }
  else
  {
    src_x= (iw-w)/2;
    dst_x= 0;
    copy_w= w;
  }
  if (ih<=h)
  {
    src_y= 0;
    dst_y= (h-ih)/2;
    copy_h= ih;
  }
  else
  {
    src_y= (ih-h)/2;
    dst_y= 0;
    copy_h= h;
  }
  gfx_put(GFX_ALPHA, icon+2, iw, ih, src_x, src_y, x+dst_x,y+dst_y,
                                            copy_w, copy_h);
}


static void get_text_data(int font, const char *str, 
                          int *Rw, int *Rh,int *Ra,unsigned char **Rd)
{
  uint32_t *wtr;
  size_t L= strlen(str);
  wtr= alloca((L+1)*sizeof(uint32_t));
  utf8_decode_string((uint8_t*) str, L, wtr, &L);

  if (font<1) font=1;
  if (font>3) font=3;
  switch(font)
  {
  case 1: font1_render(wtr, L, Rw, Rh, Ra, Rd); break;
  case 2: font2_render(wtr, L, Rw, Rh, Ra, Rd); break;
  case 3: font3_render(wtr, L, Rw, Rh, Ra, Rd); break;
  }
}


static void gfx_text_size(int font, char *str, int *W, int *H)
{
  get_text_data(font, str, W, H, NULL, NULL);
}

void txt_print(int flags, int font, int fg, int bg, int x, int y, 
               char *str,int *Rw, int *Rh)
{
  int w,h; unsigned char *data;
  get_text_data(font, str, &w, &h, NULL, &data);

  blend_graymap(flags, fg, bg, data, w,h, 0,0, x,y,w,h);
  if (data) free(data);
  if (Rw) *Rw= w;
  if (Rh) *Rh= h;
}


static int max_text_width(int font, ...)
{
  char *str;
  va_list ap;
  int mw, tw;
  va_start(ap,font);
  mw= 0;
  while((str=va_arg(ap,char*)))
  {
    get_text_data(font,str,&tw, NULL,NULL,NULL);
    if (tw>mw) mw= tw;
  }
  va_end(ap);
  return mw;
}


static void txt_print_fit(const char *horz,const char *vert,
                   int x,int y, int w, int h,
                   int font, int alpha, int fg, int bg,
                   const char *str)
{
  int tw,th; unsigned char *data;
  int src_x, src_y, dst_x, dst_y, cp_w, cp_h;
  int flags;

  get_text_data(font, str, &tw, &th, NULL, &data);

  if (!horz) horz= "C.";
  if (!vert) vert= "C.";

  if (tw>w)
  {
    if (strchr(horz,'<'))       src_x= tw-w;
    else if (strchr(horz,'>'))  src_x= 0;
    else                        src_x= (tw-w)/2; 
    cp_w= w;
    dst_x= x;
  }
  else
  {
    src_x= 0;
    cp_w= tw;
    if (strchr(horz,'B'))       dst_x= x;
    else if (strchr(horz,'E'))  dst_x= x+w-tw;
    else                        dst_x= x+(w-tw)/2;
  }

  if (th>h)
  {
    if (strchr(vert,'<'))       src_y= th-h;
    else if (strchr(vert,'>'))  src_y= 0;
    else                        src_y= (th-h)/2;
    cp_h= h;
    dst_y= y;
  }
  else
  {
    src_y= 0;
    cp_h= th;
    if (strchr(vert,'B'))       dst_y= y;
    else if (strchr(vert,'E'))  dst_y= y+h-th;
    else                        dst_y= y+(h-th)/2;
  }

  if (alpha) flags= GFX_ALPHA;
        else flags= 0;
  blend_graymap(flags, fg, bg, data, tw,th, src_x,src_y, dst_x,dst_y,cp_w,cp_h);
  if (data) free(data);
}


static void button_set_text(gui_button_t *B, char *text)
{
  if (B->text) free(B->text);
  B->text= strdup(text);
  button_render(B);
}

static void button_render(gui_button_t *B)
{
  int x,y,w,h;

  if (!B->enabled) return ;

  x= B->widget.x; y= B->widget.y; w= B->widget.w; h= B->widget.h;

  RES_COLOR(buttonNOR_SHDlight, 0xffffff, 
                                "Button normal view shadow, light line");
  RES_COLOR(buttonNOR_SHDdark, 0xd5d5d1, "");
  RES_COLOR(buttonDPD_SHDlight, 0xd5d5d1,
                                "Button depressed view shadow, light line");
  RES_COLOR(buttonDPD_SHDdark, 0xffffff, "");
  RES_COLOR(buttonNOR_BRD, 0xaaaaa3, "Button border");
  RES_COLOR(buttonDPD_BRD, 0xaaaaa3, "");
  RES_COLOR(buttonNOR_GRDstart, 0xfcfcfb, "Button normal view, gradient start");
  RES_COLOR(buttonNOR_GRDend, 0xdbdbd7, "");
  RES_COLOR(buttonDPD_GRDstart,0xcccac9,"");
  RES_COLOR(buttonDPD_GRDend, 0xe9e8e7, "");
  RES_COLOR(button_FG, 0x000000, "");
  RES_INT(button_iconspc, 4, "Space between the icon and the text");

  gfx_draw_3dbox(x,y,w,h, 
    B->state ? buttonDPD_SHDlight : buttonNOR_SHDlight,
    B->state ? buttonDPD_SHDdark  : buttonNOR_SHDdark,
    B->state ? buttonDPD_BRD      : buttonNOR_BRD,
    B->state ? buttonDPD_GRDstart : buttonNOR_GRDstart,
    B->state ? buttonDPD_GRDend   : buttonNOR_GRDend);

  draw_icon_and_text(x,y,w,h, B->iconpos, B->icon, button_iconspc, 
                     button_FG, B->text);
  gfx_update(x,y,w,h);
}

static gui_button_t *gui_button_new
  (const char *txt, int iconpos, uint32_t* icon, int klass)
{
  // this one is for internal use only. it doesn't
  // register the click handler
  gui_button_t *B;

  B= calloc(1,sizeof(*B));
  B->state= 0;
  B->enabled= 0;
  B->iconpos= iconpos;
  B->icon= icon;

  if (txt) B->text= strdup(txt);

  B->click_handler= -1;
  B->widget.klass= klass;
  return B;
}


static widget_t* gfx_button
     (const char *txt,int iconpos, uint32_t *icon,int klass)
{
  gui_button_t *B;
  B= gui_button_new(txt,iconpos,icon,klass);
  B->click_handler= install_click_handler(0,0,0,0, &B->enabled, 
                                           B, gui_button_click,1);
  return &B->widget;
}


static void button_set_state(gui_button_t *B, int state)
{
  if (state) state= 1;
  B->state= state;
  button_render(B);
}


static int gui_button_click(void *arg, gfx_event_t *event)
{
  gui_button_t *B;
  B= arg;
  if (!B->enabled) return 0; // shouldn't happen, but you never know
  if (B->widget.klass==GFXCLASS_BUTTON)
    button_set_state(B, 1);
  else
    button_set_state(B,B->state^1);
  install_release_handler(arg, gui_button_release);
  if (B->click_func)
     return (*B->click_func)(B->click_arg,event); 
  return 1;
}

static int gui_button_release(void *arg, gfx_event_t *event)
{
  gui_button_t *B;
  B= arg;
  event->type= B->widget.number;
  if (B->widget.klass==GFXCLASS_BUTTON)
    button_set_state(B,0);
  else
    event->key= B->state;
  if (B->release_func)
    return (*B->release_func)(B->click_arg,event);
  return 0;
}


static void gui_button_destroy(gui_button_t *B)
{
  if (B->text) free(B->text);
  remove_click_handler(B->click_handler);
}


static void button_set_position( gui_button_t *B, int x,int y,int w,int h)
{
  set_click_handler(B->click_handler, x,y,w,h);
  B->widget.x= x;
  B->widget.y= y;
  B->widget.w= w;
  B->widget.h= h;
}

static void gui_button_activate(widget_t *W, int x,int y,int w,int h)
{
  gui_button_t *B;
  B= (gui_button_t *)W;
  // this is again for internal use. it sets the position,
  // installs the click handler and then shows the button
  B->widget.x= x;
  B->widget.y= y;
  B->widget.w= w;
  B->widget.h= h;
 
  B->click_handler= install_click_handler(x,y,w,h, &B->enabled, 
                                           B, gui_button_click,1);
  B->enabled= 1;
  button_render(B);
}


static void gui_button_show(gui_button_t *B,int show)
{
  if (show) show= 1;
  if (B->enabled==show) return ;
  B->enabled= show;
  if (B->enabled) button_render(B);
}


static void gui_button_init
  (gui_button_t *B,const char *txt, int iconpos, uint32_t* icon, 
   int (*click_func)(void *,gfx_event_t*), 
   int (*release_func)(void *,gfx_event_t*), void *click_arg)
{
  memset(B,0,sizeof(*B));
  B->state= 0;
  B->enabled= 0;
  if (txt) B->text= strdup(txt);
  B->iconpos= iconpos;
  B->icon= icon;

  B->click_func= click_func;
  B->release_func= release_func;
  B->click_arg= click_arg;

  B->widget.klass= GFXCLASS_BUTTON;
  
  B->click_handler= install_click_handler(0,0,0,0, &B->enabled, 
                                           B, gui_button_click,1);
}

static void label_render(gui_label_t *G)
{
  int tw, th; unsigned char *td;
  int dst_x, dst_y, copy_w, copy_h, src_x, src_y;

  int x,y,w,h;

  if (!G->widget.shown) return ;

  x= G->widget.x; y= G->widget.y; w= G->widget.w; h= G->widget.h;
  
  get_text_data(G->font, G->text, &tw, &th, NULL, &td);
  gfx_fill_rect(0, x, y, w, h, G->bg);

  if (th<=h)
  {
    src_y= 0; dst_y= y + (h-th)/2; copy_h= th;
  }
  else
  {
    src_y= (th-h)/2; dst_y= y; copy_h= h;
  }

  if (tw<w)
  {
    src_x= 0; copy_w= tw;
    if (G->just=='C')
      dst_x= x+(w-tw)/2;
    else if (G->just=='R')
      dst_x= x+w-tw;
    else
      dst_x= x;
  }
  else
  {
    dst_x= x; copy_w= w;
#if 0
    if (G->flags&GFX_CUT_LEFT)
      src_x= tw - G->h;
    else
#endif
    src_x= 0;
  }

  blend_graymap(GFX_BACKGND, G->fg, G->bg, td, tw, th,
                src_x, src_y, dst_x, dst_y, copy_w, copy_h);
  free(td);
  gfx_update(x,y,w,h);
}


static widget_t* gfx_label(int font, int fg, int bg, int just, char *str)
{
  gui_label_t *G;
  G= calloc(1,sizeof(*G));
  G->font= font;
  G->fg= fg;
  G->bg= bg;
  G->just= just;
  G->text= strdup(str ? str:"");

  G->widget.klass= GFXCLASS_LABEL;
  G->widget.show= gui_label_show;
  return &G->widget;
}


static void gui_label_show(widget_t *W)
{
  label_render((gui_label_t*) W);
}

static void gui_label_set_position(gui_label_t *L,int x,int y,int w,int h)
{
  widget_t *W;
  W= &L->widget;
  W->x= x; W->y= y; W->w= w; W->h= h;
  label_render(L);
}

static void gui_label_destroy(gui_label_t *G)
{
  if (G->text)
   free(G->text);
}


static void gui_label_set_text(gui_label_t *G,const char *str)
{
  if (G->text) free(G->text);
  G->text= str ? strdup(str) : NULL;
  label_render(G);
}


static void label_set_fgbg(gui_label_t *G, int fg,int bg)
{
  if (G->fg==fg && G->bg==bg) return ;
  G->fg= fg;
  G->bg= bg;
  label_render(G);
}


static void init_radio_images()
{
  if (radio_on) return ;
  radio_on= convert_graymap_to_color(radio_fg, radio_bg,Gradio_on);
  radio_off= convert_graymap_to_color(radio_fg, radio_bg,Gradio_off);
}

static void radio_draw_button(radio_t *R,int state,int bg, int upd)
{
  int w,h,x,y;
  unsigned int *img;

  if (!R->enabled) return ;
  init_radio_images();
  img= state ? radio_on : radio_off;
  w= img[0];
  h= img[1];

  x= R->widget.x+radio_pad_left;
  y= R->widget.y;
  if (R->widget.h>h) y+= (R->widget.h-h)/2;

  if (bg) gfx_fill_rect(0, x,y,w,h, radio_bg);
  gfx_put(upd? GFX_UPDATE :0, img+2,w,h, 0,0, x,y,w,h);
}



static void radio_show(radio_t *R, int show)
{
  if (show)
  {
    if (R->enabled) return ;
    R->enabled= 1;
    if (R->click==-1)
      R->click= install_click_handler
          (R->widget.x,R->widget.y, R->widget.w, R->widget.h,
             &R->enabled, R, radio_click, 1);
    radio_draw(R);
  }
  else
  {
    if (!R->enabled) return ;
    // disable the click handler
    R->enabled= 0;
  }
}

static void radio_set(radio_t *R)
{
  if (R->state) return ;
  R->state= 1;
  if (R->enabled) radio_draw_button(R,R->state,1,1);
  rgroup_clear_except(R->group, &R->widget);
}

static int radio_click(void *arg, gfx_event_t *event)
{
  radio_t *R;
  R= arg;
  if (!R->state)
  {
    radio_set(arg);
    R->change= 1;
  }
  else
    R->change= 0;
  install_release_handler(arg, radio_release);
  return 1;
}

static int radio_release(void *arg, gfx_event_t *event)
{
  radio_t *R;

  R= arg;
  if (!R->change) return 1;
 
  event->type= R->widget.number;
  R->change= 0;
  return 0;
}


static widget_t* radio_new(const char *text, int group)
{
  radio_t *R;
  R= calloc(1,sizeof(*R));
  R->click= -1;
  if (text) R->text= strdup(text);
  R->group= group;
  R->widget.klass= GFXCLASS_RADIO;
  if (group!=-1) register_radio_in_group(group, &R->widget);
  return &R->widget;
}


static void radio_draw_text(radio_t *R)
{
  unsigned char *td; int tw, th,cw,tx,ty;
  int x,y,w,h;
  if (!R->text || !R->text[0]) return ;

  x= R->widget.x; y= R->widget.y; w= R->widget.w; h= R->widget.h;
  
  get_text_data(1, R->text, &tw, &th, NULL, &td);
  tx= x + radio_pad_left + gfx_radio_width + radio_pad_mid;
  ty= y;
  if (h >= th)
    ty+= (h-th)/2;
  cw= (x+w)-tx;
  if (cw>tw) cw= tw;
  blend_graymap(GFX_BACKGND | GFX_UPDATE, radio_fg, radio_bg,
                td, tw, th, 0,0, tx,ty, cw, th);
  free(td);
}

static void radio_draw(radio_t *R)
{
  int x,y,w,h;
  x= R->widget.x;
  y= R->widget.y;
  w= R->widget.w;
  h= R->widget.h;
  if (!R->enabled) return ;
  gfx_fill_rect(0,x,y,w, h, radio_bg);
  radio_draw_button(R, R->state, 0,0);
  radio_draw_text(R);
  gfx_update(x,y,w, h);
}


static radio_group_t *get_rgroup(int ident)
{
  int i;
  if (!screen || ident==-1) return NULL;
  for(i=0;i<screen->n_rgroups;i++)
    if (screen->rgroups[i].ident==ident)
       return screen->rgroups+i;
  return NULL; 
}

static void rgroup_clear_except(int ident,widget_t *R)
{
  widget_t *P;
  radio_group_t *G;
  int i;

  G= get_rgroup(ident);
  if (!G) return ;
  
  for(i=0;i<G->n_widgets;i++)
  {
    P= G->widgets[i];
    if (P==R) continue;
    widget_set_state(P,0);
  }
}

static void register_radio_in_group(int ident, widget_t *W)
{
  radio_group_t *G;
  G= get_rgroup(ident);
  if (G) goto found;

  if (screen->n_rgroups==screen->s_rgroups)
  {
    screen->s_rgroups+= screen->s_rgroups/2 + 10;
    screen->rgroups= realloc(screen->rgroups, 
                              sizeof(screen->rgroups[0])*screen->s_rgroups);
  }
  G= screen->rgroups+screen->n_rgroups;
  memset(G,0,sizeof(*G));
  G->ident= ident;
  screen->n_rgroups++;
found:
  if (G->n_widgets==G->s_widgets)
  {
    G->s_widgets+= G->s_widgets/2+10;
    G->widgets= realloc(G->widgets, sizeof(G->widgets[0])*G->s_widgets);
  }
  G->widgets[G->n_widgets]= W;
  G->n_widgets++;
}

static void free_rgroups(screen_t *S)
{
  int i;
  for(i=0;i<S->n_rgroups;i++)
    if (S->rgroups[i].widgets) free(S->rgroups[i].widgets);
  if (S->rgroups) free(S->rgroups);
}

static int radio_group_get_selected(int ident)
{
  radio_group_t *G;
  int i;
  G= get_rgroup(ident);
  if (!G) return -1;
  for(i=0;i<G->n_widgets;i++)
    if (widget_get_state(G->widgets[i])) 
       return G->widgets[i]->number;
  return -1;
}


static void init_checkbox_images()
{
  if (checkbox_ok) return ;
  checkbox_ok= convert_graymap_to_color(checkbox_fg, checkbox_bg,Gcheckbox_ok);
  checkbox_nok= convert_graymap_to_color(checkbox_fg, checkbox_bg,Gcheckbox_nok);
}

static void checkbox_draw_button(checkbox_t *R,int state,int bg, int upd)
{
  int w,h,x,y;
  unsigned int *img;

  if (!R->enabled) return ;
  init_checkbox_images();
  img= state ? checkbox_ok : checkbox_nok;
  w= img[0];
  h= img[1];

  x= R->widget.x+checkbox_pad_left;
  y= R->widget.y;
  if (R->widget.h>h) y+= (R->widget.h-h)/2;

  if (bg) gfx_fill_rect(0, x,y,w,h, checkbox_bg);
  gfx_put(upd? GFX_UPDATE :0, img+2,w,h, 0,0, x,y,w,h);
}



static void checkbox_show(checkbox_t *R, int show)
{
  if (show)
  {
    if (R->enabled) return ;
    R->enabled= 1;
    if (R->click==-1)
      R->click= install_click_handler
          (R->widget.x,R->widget.y, R->widget.w, R->widget.h,
             &R->enabled, R, checkbox_click, 1);
    checkbox_draw(R);
  }
  else
  {
    if (!R->enabled) return ;
    // disable the click handler
    R->enabled= 0;
  }
}

static void checkbox_set(checkbox_t *R,int value)
{
  if (value) value= 1;
  if (R->state==value) return ;
  R->state= value;
  if (R->enabled)
    checkbox_draw_button(R,R->state,1,1);
}

static int checkbox_click(void *arg, gfx_event_t *event)
{
  checkbox_t *R;
  R= arg;
  checkbox_set(R, R->state^1);
  install_release_handler(arg, checkbox_release);
  return 1;
}

static int checkbox_release(void *arg, gfx_event_t *event)
{
  checkbox_t *R;
  R= arg;
  event->type= R->widget.number;
  event->key= R->state;
  return 0;
}


static widget_t* checkbox_new(const char *text)
{
  checkbox_t *R;
  R= calloc(1,sizeof(*R));
  R->click= -1;
  if (text) R->text= strdup(text);
  R->widget.klass= GFXCLASS_CHECKBOX;
  return &R->widget;
}


static void checkbox_draw_text(checkbox_t *R)
{
  unsigned char *td; int tw, th,cw,tx,ty;
  int x,y,w,h;
  if (!R->text || !R->text[0]) return ;

  x= R->widget.x; y= R->widget.y; w= R->widget.w; h= R->widget.h;
  
  get_text_data(1, R->text, &tw, &th, NULL, &td);
  tx= x + checkbox_pad_left + gfx_checkbox_width + checkbox_pad_mid;
  ty= y;
  if (h >= th)
    ty+= (h-th)/2;
  cw= (x+w)-tx;
  if (cw>tw) cw= tw;
  blend_graymap(GFX_BACKGND | GFX_UPDATE, checkbox_fg, checkbox_bg,
                td, tw, th, 0,0, tx,ty, cw, th);
  free(td);
}

static void checkbox_draw(checkbox_t *R)
{
  int x,y,w,h;
  x= R->widget.x;
  y= R->widget.y;
  w= R->widget.w;
  h= R->widget.h;
  if (!R->enabled) return ;
  gfx_fill_rect(0,x,y,w, h, checkbox_bg);
  checkbox_draw_button(R, R->state, 0,0);
  checkbox_draw_text(R);
  gfx_update(x,y,w, h);
}


static void scrollbar_compute_trough(scrollbar_t *SB)
{
  if (SB->orient=='V')
  {
    SB->tro_h= SB->widget.h - SB->SH[0]-SB->SH[2];

    SB->tro_c0= SB->widget.y+ SB->SH[0];
    SB->tro_c1= SB->tro_c0+SB->tro_h-1;
    SB->tro_dc= SB->tro_h-1;

    SB->tro_x= SB->widget.x;
    SB->tro_y= SB->tro_c0;
    SB->tro_w= SB->widget.w;
  }
  else
  {
    SB->tro_w= SB->widget.w - SB->SW[0]-SB->SW[2];

    SB->tro_c0= SB->widget.x + SB->SW[0];
    SB->tro_c1= SB->tro_c0 + SB->tro_w - 1;
    SB->tro_dc= SB->tro_w-1;

    SB->tro_x= SB->tro_c0;
    SB->tro_y= SB->widget.y;
    SB->tro_h= SB->widget.h;
  }
  if (SB->tro_dc<1) SB->tro_dc= 1;
}

static void scrollbar_compute_button(scrollbar_t *SB)
{
  SB->but_c0= SB->tro_dc*SB->start + SB->tro_c0;
  SB->but_c1= SB->tro_dc*SB->end   + SB->tro_c0;
}

static void fill_with_horizontal_gradient
             (int x0,int y0, int y1, unsigned int *gra)
{
  int y;
  int graW;
  graW= gra[0];
  gra+= 2;
  for(y=y0;y<=y1;y++)
    put_server_pix(gra, x0, y, graW, 1);
}

static void three_part_assembly_vertical
    (int x0,int y0, int y1, 
     uint32_t *top, uint32_t *mid, uint32_t *bot)
{
  int mid_start_y, mid_end_y;

  uint32_t *topD, topW, topH;
  uint32_t *botD, botW, botH;

  topD= top+2; topW= top[0]; topH= top[1];
  botD= bot+2; botW= bot[0]; botH= bot[1];
  
  mid_start_y= y0 + topH;
  mid_end_y=   y1 - botH;
  put_server_pix(topD, x0, y0, topW, topH);
  fill_with_horizontal_gradient(x0,mid_start_y, mid_end_y, mid);
  put_server_pix(botD, x0, mid_end_y+1, botW, botH);
}

static void fill_with_vertical_gradient
             (int x0, int x1, int y0, unsigned int *gra)
{
  int x;
  int graH;
  graH= gra[1];
  gra+= 2; // skip the W+H
  for(x=x0;x<=x1;x++)
    put_server_pix(gra, x, y0, 1, graH);
}

static void three_part_assembly_horizontal
    (int x0, int x1, int y0, 
     uint32_t *lef, uint32_t *mid, uint32_t *rig)
{
  int mid_start_x, mid_end_x;

  uint32_t *lefD, lefW, lefH,
           *rigD, rigW, rigH;

  lefW= lef[0]; lefH= lef[1]; lefD= lef+2;
  rigW= rig[0]; rigH= rig[1]; rigD= rig+2;

  mid_start_x= x0 + lefW;
  mid_end_x=   x1 - rigW;
  put_server_pix(lefD, x0, y0, lefW, lefH);
  fill_with_vertical_gradient(mid_start_x,mid_end_x, y0, mid);
  put_server_pix(rigD, mid_end_x+1, y0, rigW, rigH);
}

static void scrollbar_draw_trough(scrollbar_t *SB)
{
  static uint32_t* images[]= { 
    Hscroll_ind_left, Hscroll_ind_right, Hscroll_ind_mid, Hscroll_trough,
    Vscroll_ind_top, Vscroll_ind_bot, Vscroll_ind_mid, Vscroll_trough,
    NULL };

  int y,x;
  if (!SB->enabled) return ;
  convert_images_to_server(images);
  if (SB->orient=='V')
  {
    x= SB->widget.x;
    fill_with_horizontal_gradient
             (x, SB->tro_c0, SB->but_c0-1, Vscroll_trough);

    fill_with_horizontal_gradient
             (x, SB->but_c1+1, SB->tro_c1, Vscroll_trough);

    three_part_assembly_vertical
             (x, SB->but_c0, SB->but_c1,
              Vscroll_ind_top, Vscroll_ind_mid, Vscroll_ind_bot);
  }
  else
  {
    y= SB->widget.y;
    fill_with_vertical_gradient
             (SB->tro_c0, SB->but_c0-1, y, Hscroll_trough);

    fill_with_vertical_gradient
             (SB->but_c1+1, SB->tro_c1, y, Hscroll_trough);

    three_part_assembly_horizontal
             (SB->but_c0, SB->but_c1, y,
              Hscroll_ind_left, Hscroll_ind_mid, Hscroll_ind_right);
  }
}

static void scrollbar_draw_stepper(scrollbar_t *SB, int sno, int state)
{
  int img;
  img= sno*2 + state;
  if (!SB->enabled) return ;
  put_server_pix(SB->SD[img], SB->SX[sno], SB->SY[sno],
                              SB->SW[img], SB->SH[img]);
}

static void scrollbar_draw_all(scrollbar_t *SB)
{
  scrollbar_draw_stepper(SB, 0,0);
  scrollbar_draw_stepper(SB, 1,0);
  scrollbar_draw_trough(SB);
}

static void scrollbar_init_buttons
   (scrollbar_t *SB)
{
   int i;
   static uint32_t *images[]=
    { scroll_nor_up, scroll_dpd_up,
      scroll_nor_down, scroll_dpd_down,
      scroll_nor_left, scroll_dpd_left,
      scroll_nor_right, scroll_dpd_right, NULL };

   if (SB==NULL) { gui_scrollbar_width= scroll_nor_up[0] & ~(1<<31);
                   gui_scrollbar_height= scroll_nor_left[1];
                   return ; }

   convert_images_to_server(images);

   if (SB->orient=='V')
   {
     SB->SD[0]= scroll_nor_up+2;   SB->SD[1]= scroll_dpd_up+2;
     SB->SD[2]= scroll_nor_down+2; SB->SD[3]= scroll_dpd_down+2;
   }
   else
   {
     SB->SD[0]= scroll_nor_left+2;  SB->SD[1]= scroll_dpd_left+2;
     SB->SD[2]= scroll_nor_right+2; SB->SD[3]= scroll_dpd_right+2;
   }
   for(i=0;i<4;i++)
   {
     SB->SW[i]= SB->SD[i][-2];
     SB->SH[i]= SB->SD[i][-1];
   }
}

static void scrollbar_position_buttons(scrollbar_t *SB,int x,int y,int w,int h)
{
  if (SB->orient=='V')
  {
    SB->SX[0]= x; SB->SX[1]= x;
    SB->SY[0]= y; SB->SY[1]= y+h-SB->SH[2];
  }
  else
  {
    SB->SY[0]= y;  SB->SY[1]= y;
    SB->SX[0]= x;  SB->SX[1]= x+w-SB->SW[2];
  }
}

static widget_t* scrollbar_new
    (int orient, double start, double end, double step,
     int action, void *reportarg, void *reportfunc)
{
  scrollbar_t *SB;

  SB= calloc(1,sizeof(*SB));

  SB->start= start;
  SB->end= end;
  SB->step= step;
  SB->reportarg= reportarg;
  SB->reportfunc= reportfunc;
  SB->action= action;

  SB->orient= orient ? 'V': 'H';
  SB->enabled= 0;
  SB->widget.klass= GFXCLASS_SCROLLBAR;

  SB->ch0= SB->ch1= SB->ch2= -1;

  scrollbar_init_buttons(SB);

  return &SB->widget;
}

static void scrollbar_position(scrollbar_t *SB,int x,int y,int w,int h)
{
  SB->widget.w= w;
  SB->widget.h= h;
  SB->widget.x= x;
  SB->widget.y= y;

  scrollbar_position_buttons(SB,x,y,w,h);
  scrollbar_compute_trough(SB);
  scrollbar_compute_button(SB);
  scrollbar_draw_all(SB);

  SB->ch0= install_or_modify_click
        (SB->ch0, &SB->enabled, scrollbar_click_up, SB,
        SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0],1);

  SB->ch1= install_or_modify_click
        (SB->ch1, &SB->enabled, scrollbar_click_down, SB,
        SB->SX[1], SB->SY[1], SB->SW[2], SB->SH[2],1);
 
  SB->ch2= install_or_modify_click
        (SB->ch2, &SB->enabled, scrollbar_click_tro, SB,
         SB->tro_x, SB->tro_y, SB->tro_w, SB->tro_h,1);
}


static int scrollbar_click_up(void *A, gfx_event_t *E)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 0, 1);
  install_release_handler(A, scrollbar_release_up);
  gfx_update(SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0]);
  return 1;
}

static int scrollbar_release_up(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 0, 0);
  gfx_update(SB->SX[0], SB->SY[0], SB->SW[0], SB->SH[0]);
  if (SB->start>0.0)
  {
    double S;
    S= dmax2(0.0, SB->start - SB->step);
    return scrollbar_set(SB, S, S-SB->start+SB->end, 1, event);
  }
  return 1;
}

static void scrollbar_update(scrollbar_t *SB)
{
  scrollbar_compute_button(SB);
  scrollbar_draw_trough(SB);
  if (SB->enabled)
    gfx_update(SB->tro_x, SB->tro_y, SB->tro_w, SB->tro_h);
}

static int scrollbar_set
    (scrollbar_t *SB,double S, double E, int report, gfx_event_t* event)
{
  if (SB->start==S && SB->end==E) return 1;
  SB->start= S;
  SB->end= E;
  scrollbar_update(SB);
  if (!report) return 1;
  if (SB->action && event) 
  {
    event->type= SB->widget.number;
    event->flo0= S;
    event->flo1= E;
    return 0;
  }
  if (SB->reportfunc)
    (*SB->reportfunc)(SB->reportarg, S, E);
  return 1;
}

static int scrollbar_click_down(void *A, gfx_event_t *E)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 1, 1);
  gfx_update(SB->SX[1],SB->SY[1], SB->SW[2], SB->SH[2]);
  install_release_handler(A, scrollbar_release_down);
  return 1;
}

static int scrollbar_release_down(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  scrollbar_draw_stepper(SB, 1, 0);
  gfx_update(SB->SX[1],SB->SY[1], SB->SW[2], SB->SH[2]);
  if (SB->end<1.0)
  {
    double E;
    E= dmin2(1.0,SB->end + SB->step);
    return scrollbar_set(SB,E-SB->end+SB->start,E, 1, event);
  }
  return 1;
}

static int scrollbar_click_tro(void *A,gfx_event_t *event)
{
  scrollbar_t *SB= A;
  double L,K, S, E;
  int C;

  if (SB->orient=='V') C= event->y; else C= event->x;
  if (C>=SB->but_c0 && C<=SB->but_c1)
  {
    install_release_handler(A, scrollbar_release_tro);
    install_motion_handler(A, scrollbar_move_pointer);
    SB->last_seen_c= C;
    return 1;
  }
  if (C<SB->tro_c0 || C>SB->tro_c1) return 1;
  C -= SB->tro_c0;
  L= SB->end - SB->start;

  K= (double) C / SB->tro_dc;
  S= K-L/2;
  E= S+L;

  if (S<0.0) { S= 0.0; E= S+L; }
  if (E>1.0) { E= 1.0; S= E-L;  }

  install_release_handler(A, scrollbar_release_dummy);
  return scrollbar_set(SB,S,E,1,event);
}

static int scrollbar_release_dummy(void *A, gfx_event_t *E)
{
  // this function is used to eat up the dummy release events
  // left over from clicks into the trough area. 
  // normally, I'd do the returning stuff within this
  // release handler, but there is too much information to
  // pass around.
  return 1;
}

static int scrollbar_move_pointer(void *A, gfx_event_t *event)
{
  scrollbar_t *SB= A;
  int D;
  double L, S, E;
  int C;

  if (SB->orient=='V') C= event->y; else C= event->x;

  if (C>SB->tro_c1 || C<SB->tro_c0) return 1;

  D= C - SB->last_seen_c;
  if (D==0) return 1;

  SB->last_seen_c= C;
 
  L= SB->end - SB->start;
  if (D>0)
  {
    if (SB->end==1.0) return 1;
    E= dmin2(1.0,SB->end + (double) D / SB->tro_dc);
    S= E - L;
  } else {
    if (SB->start==0.0) return 1;
    S= dmax2(0.0, SB->start + (double) D / SB->tro_dc);
    E= S + L;
  }

  return scrollbar_set(SB, S,E, 1, event);
}

static int scrollbar_release_tro(void *A, gfx_event_t *E)
{
  uninstall_motion_handler();
  return 1;
}


static void scrollbar_relayout
   (scrollbar_t *SB, int nx, int ny, int nw,int nh,
    double start, double end, double step)
{
  SB->start= dmin2(1.0,dmax2(0.0, start));
  SB->end= dmax2(0.0,dmin2(1.0,end));
  SB->step= step;
  if (step<0.0 || step>=1.0) SB->step= 0.1;

  if (nw!=SB->widget.w || nh!=SB->widget.h 
      || nx!=SB->widget.x || ny!=SB->widget.y)
  {
    scrollbar_position(SB,nx,ny,nw,nh);
  }
  else
  {
    scrollbar_compute_trough(SB);
    scrollbar_compute_button(SB);
    scrollbar_draw_all(SB);
  }
}

static void scrollbar_destroy(scrollbar_t *SB)
{
  remove_click_handler(SB->ch0);
  remove_click_handler(SB->ch1);
  remove_click_handler(SB->ch2);
}

static void scrollbar_show(scrollbar_t *SB,int show)
{
  SB->enabled= show;
  if (SB->enabled) scrollbar_draw_all(SB);
}

static panel_t *panel_new(int nsubs)
{
  panel_t *P;
  P= calloc(1,sizeof(*P));
  P->n_subs= nsubs;
  P->subs= calloc(nsubs,sizeof(P->subs[0]));
  P->widget.klass= GFXCLASS_PANEL;
  return P;
}


static void panel_show(panel_t *P,int show)
{
  P->enabled= show;
  if (show)
    gfx_fill_rect(0, P->widget.x,P->widget.y,P->widget.w,P->widget.h, 0xededed); 
  panel_show_widgets(P,P->active,show);
}

static void panel_show_widgets(panel_t *P,int sub, int show)
{
  int i;
  subscreen_t *S; 
  if (sub<0 || sub>=P->n_subs) return ;
  S= P->subs+sub;

  for(i=0;i<S->n_widgets;i++)
  {
    widget_t *W;
    int n= S->widgets[i];
    if (n<=_XX_WIDGETS_START || n>=_XX_WIDGETS_END) continue;
    W= widgets[n];
    if (W) widget_show(W,show);
  }
}

static void panel_activate(panel_t *P,int sel)
{
  if (sel<0 || sel>=P->n_subs || sel==P->active) return ;
  if (!P->enabled) { P->active= sel; return ; }
  panel_show_widgets(P,P->active,0);
  gfx_fill_rect(0, P->widget.x,P->widget.y,P->widget.w,P->widget.h, 0xededed); 
  panel_show_widgets(P,sel,1);
  P->active= sel;
  gfx_update(P->widget.x,P->widget.y,P->widget.w,P->widget.h);
}

static void panel_position(panel_t *P,int nx,int ny,int nw,int nh)
{
  P->widget.x= nx;
  P->widget.y= ny;
  P->widget.w= nw;
  P->widget.h= nh;
}

static widget_t *dropdown_new(int action)
{
  dropdown_t *DD;
  DD= calloc(1,sizeof(*DD));
  DD->selected= -1;
  DD->click_handler= -1;
  DD->action= action;
  DD->widget.klass= GFXCLASS_DROPDOWN;
  return &DD->widget;
}


static void dropdown_show(dropdown_t *DD,int show)
{
  if (show==DD->shown) return ;
  DD->shown= show;
  if (show)
  {
    if (DD->click_handler==-1)
      DD->click_handler= install_click_handler(DD->widget.x,DD->widget.y,
                           DD->widget.w,DD->widget.h,
                           &DD->click_enabled, DD, dropdown_click, 1);
    DD->click_enabled= 1;
    dropdown_render_button(DD,0);
  }
  else
  {
    DD->click_enabled= 0;
  }
}


static void dropdown_render_button(dropdown_t *DD, int p)
{
  char *text;
  int ix,iy, tx,ty;
  int tcw, tch, tsx, tsy, tw,th;
  // int w,h; // W and H minus the border
  unsigned char *tdata;

  int W,H,X,Y;

RES_INT(dropdown_pad_left, 2, "");
RES_INT(dropdown_pad_right, 2, "");
RES_INT(dropdown_pad_mid, 2, "");
RES_COLOR(dropdown_dark1, 0xd5d5d1, "");
RES_COLOR(dropdown_light1, 0xffffff, "");
RES_COLOR(dropdown_border1, 0xaaaaa3, "");
RES_COLOR(dropdown_dark2, 0xffffff, "");
RES_COLOR(dropdown_light2, 0xd5d5d1, "");
RES_COLOR(dropdown_border2, 0xaaaaa3, "");
RES_COLOR(dropdown_gradb1, 0xfcfcfb, "");
RES_COLOR(dropdown_grade1, 0xdbdbd7, "");
RES_COLOR(dropdown_gradb2, 0xcccac9, "");
RES_COLOR(dropdown_grade2, 0xe9e8e7, "");

RES_GRAYIMG(dropd_but, "Dropdown button image")
   11, 7,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x7f,0xef,0xef,0xef,0xef,0xef,0xef,0xef,
    0x7f,0x00,0x00,0x01,0x9a,0xef,0xef,0xef,0xef,0xef,
    0x9a,0x01,0x00,0x00,0x00,0x06,0xb1,0xef,0xef,0xef,
    0xb1,0x06,0x00,0x00,0x00,0x00,0x00,0x0e,0xbb,0xef,
    0xbb,0x0e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,
    0xab,0x14,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,
RES_END

  if (!DD->shown) return ;

  tdata= NULL;

  W= DD->widget.w;
  H= DD->widget.h;
  X= DD->widget.x;
  Y= DD->widget.y;

  if (W<4 || H<4)
  {
    // even the border doesn't fit!
    gfx_fill_rect(GFX_UPDATE, DD->widget.x, DD->widget.y, W,H, 0xFFff0000);
    return ;
  }
  gfx_draw_3dbox(X,Y,W,H, 
           p ? dropdown_light2 : dropdown_light1,
           p ? dropdown_dark2  : dropdown_dark1,
           p ? dropdown_border2  : dropdown_border1,
           p ? dropdown_gradb2  : dropdown_gradb1,
           p ? dropdown_grade2  : dropdown_grade1);

  int buW,buH;
  buW= dropd_but[0];
  buH= dropd_but[1];

  ix= W -2 -dropdown_pad_right -buW;
  iy= (H - buH)/2;
    // no space for button. in fact, the text won't fit here also
    // so we simply display an empty area.
  if (ix<2 || iy<2) return ;
  
  blend_graymap(GFX_ALPHA, 0x00, 0xffFFff,
               dropd_but+2, buW, buH, 0,0,
               X+ix, Y+iy+2, buW, buH);

  if (DD->selected<0 || DD->selected>=DD->n_items) goto done;
  text= DD->items[DD->selected].str;
  if (!text || !text[0]) goto done;

  get_text_data(1,text, &tw, &th, NULL, &tdata);

  tx= 2 + dropdown_pad_left;
  tsx= 0;
  tcw= imax2(0,imin2(tw, ix-dropdown_pad_mid-tx));
  if (tcw==0) goto done;

  ty= 2 + imax2( 0, (H-th)/2 );
  tsy= imax2(0, (th-H)/2); 
  tch= imin2(th, H);

  if (tch==0) goto done;

  blend_graymap(GFX_ALPHA, 0x00, 0xffFFff, tdata, tw, th, tsx,tsy,
                             X+tx, Y+ty, tcw, tch);
done:
  if (tdata) free(tdata);
  gfx_update(X,Y,W,H);
}

static int dropdown_click(void *arg, gfx_event_t* event)
{
  dropdown_t *DD= arg;
  if (event->type!=GFXEV_BUTTON_PRESS || event->button!=1) return 0;
  dropdown_render_button(DD,1);
  install_release_handler(DD, dropdown_release);
  return 1;
}

static int dropdown_release(void *arg, gfx_event_t *event)
{
  dropdown_t *DD= arg;
  // dropdown_render_button(DD,0);
  dropdown_show_list(DD);
  return 1;
}


static void dropdown_show_list(dropdown_t *DD)
{
  if (DD->list_backup) { free(DD->list_backup); DD->list_backup= NULL; }
  DD->list_active= 1;

  DD->list_w= DD->widget.w;
  DD->list_x= DD->widget.x;

  DD->list_y= DD->widget.y + DD->widget.h;

  get_text_data(1,"M",NULL,&DD->fh,NULL,NULL);
  int ni;
  ni= imax2(DD->n_items, 1);
  DD->list_cont_h= dropdown_list_padv*2 + ni*DD->fh + (ni-1)*dropdown_list_spc;

  DD->posy= 0;
  if (DD->list_y+DD->list_cont_h+2<=x_window_height)
  {
    // no scrollbar needed
    DD->list_ph= DD->list_cont_h;
    DD->list_h= DD->list_ph+2;
    DD->list_pw= DD->list_w-2;
    DD->list_px= DD->list_x+1;
    DD->list_py= DD->list_y+1;

    if (DD->scroll) DD->scroll->enabled= 0;
    dropdown_get_list_backup(DD);
    dropdown_draw_listframe(DD,0xf);
  }
  else
  {
    DD->list_px= DD->list_x+1;
    DD->list_pw= DD->list_w - 1 - gui_scrollbar_width;
    DD->list_h= x_window_height - DD->list_y;
    if (DD->list_h<(DD->fh+dropdown_list_padv*2+2))
    {
      DD->list_y= DD->widget.y;
      DD->list_h= x_window_height - DD->list_y;
    }
    DD->list_ph= DD->list_h-2;
    DD->list_py= DD->list_y+1;
    if (DD->list_ph<=0) goto impossible;
    if (DD->selected!=-1)
    {
      DD->posy= dropdown_item_pos(DD,DD->selected) - DD->list_ph/2;
      if (DD->posy<0) DD->posy= 0;
      else if (DD->posy+DD->list_ph > DD->list_cont_h)
      {
        DD->posy= DD->list_cont_h - DD->list_ph;
        if (DD->posy<0) DD->posy= 0;
      }
    }
    dropdown_get_list_backup(DD);
     // scrollbar parameters
    int Sx, Sy, Sw, Sh;  
    double Sb, Se, Ss;

    Sx= DD->list_x+DD->list_w-gui_scrollbar_width;
    Sy= DD->list_y;
    Sw= gui_scrollbar_width;
    Sh= DD->list_h;
    Sb= (double)DD->posy/DD->list_cont_h;
    Se= (double)(DD->posy+DD->list_ph)/DD->list_cont_h;
    Ss= DD->list_ph*0.9/DD->list_cont_h;
    if (DD->scroll)
    {
      DD->scroll->enabled= 1;
      scrollbar_relayout(DD->scroll, Sx, Sy,Sw, Sh, Sb, Se, Ss);
    }
    else
    {
      DD->scroll= (scrollbar_t*)
                    scrollbar_new(1, Sb, Se, Ss, 0, DD, dropdown_scroll);
      scrollbar_position(DD->scroll, Sx, Sy,Sw, Sh);
    }
    scrollbar_show(DD->scroll,1);
    dropdown_draw_listframe(DD,0xe);
  }
  dropdown_draw_listbg(DD);
  dropdown_draw_contents(DD);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  DD->selitem= -1;
  DD->but1clicked= 0;
  grab_mouse((void*)dropdown_mouse, DD);
  DD->click_enabled= 0;

impossible:
  return ; // FIXME
}

static void dropdown_draw_listbg(dropdown_t *DD)
{
  gfx_fill_rect(0,DD->list_px,DD->list_py,DD->list_pw,DD->list_ph, 0xffffffff);
}

static void dropdown_get_list_backup(dropdown_t *DD)
{
  if (DD->list_w<=0 || DD->list_h<=0) return ;
  DD->list_backup= get_server_pix(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
}

static void dropdown_put_list_backup(dropdown_t *DD)
{
  if (!DD->list_backup || DD->list_w<=0 || DD->list_h<=0) return ;
  put_server_pix(DD->list_backup, DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  free(DD->list_backup);
  DD->list_backup= NULL;
}

static void dropdown_draw_contents(dropdown_t *DD)
{
  int i,j,k;
  if (DD->n_items==0) return ;
  i= 0; 
  j= DD->n_items-1;
  while(i<=j)
  {
    k= (i+j)/2;
    switch(dropdown_draw_item(DD,k))
    {
     case 1: j= k-1; break;
     case 0: goto found;
     case -1: i= k+1; break;
    }
  }

  return;
found:
  for(i=k-1;i>=0;i--)         if (dropdown_draw_item(DD,i)) break;
  for(j=k+1;j<DD->n_items;j++) if (dropdown_draw_item(DD,j)) break;
}

static int dropdown_draw_item(dropdown_t *DD,int idx)
{
  int P;
  P= dropdown_item_pos(DD,idx);
  if (P>=DD->posy+DD->list_ph) return 1;
  if (P+DD->fh<DD->posy) return -1;
  print_clipped(DD->list_px,DD->list_py,DD->list_pw,DD->list_ph,
           DD->list_px, P-DD->posy+DD->list_py, 1, DD->items[idx].str); 
  return 0;
}

static void print_clipped(int Cx,int Cy,int Cw,int Ch,
                          int x, int y, int font, const char* str)
{
  unsigned char *tdata;
  int tw,th;

  int sx,sy, dx,dy, ow, oh;

  if (x>=Cx+Cw || y>=Cy+Ch || Cw<=0 || Ch<=0) return ;

  get_text_data(font, (char*) str,&tw,&th,NULL,&tdata);

  sx= 0; sy=0; dx= x; dy= y; ow= tw; oh= th;
  if (dx<Cx)
  {
    sx+= (Cx-dx);
    ow-= (Cx-dx);
    dx= Cx;
  }

  if (dy<Cy)
  {
    sy+= (Cy-dy);
    oh-= (Cy-dy);
    dy= Cy;
  }

  if (ow<=0 || oh<=0) goto done;

  if (dx+ow>Cx+Cw)
  {
    ow= (Cx+Cw-dx);
  }
  if (dy+oh>Cy+Ch)
  {
    oh= (Cy+Ch-dy);
  }
  if (ow<=0 || oh<=0) goto done;

  blend_graymap(0, 0xff000000, 0xffFFFFFF, tdata, tw,th, sx, sy, dx,dy,ow,oh);
done:
  free(tdata);
}

static int dropdown_item_pos(dropdown_t *DD,int item)
{
  return item*(dropdown_list_spc+DD->fh) + dropdown_list_padv;
}

static void dropdown_draw_listframe(dropdown_t *DD,int which)
{
  int l,r,t,b;
  l= DD->list_x;
  r= DD->list_x+DD->list_w-1;
  t= DD->list_y;
  b= DD->list_y+DD->list_h-1;
  if (which&1) vline(r, t,b, dropdown_list_border);
  if (which&2) vline(l, t,b, dropdown_list_border);
  if (which&4) hline(l, r,t, dropdown_list_border);
  if (which&8) hline(l, r,b, dropdown_list_border);
}

static void dropdown_scroll(dropdown_t *DD,double S,double E)
{
  dropdown_scroll_to(DD, DD->list_cont_h*S,0);
}

static int dropdown_mouse(dropdown_t *DD, gfx_event_t *event)
{
  switch(event->type)
  {
  case GFXEV_BUTTON_PRESS:
    switch(event->button)
    {
    case 1: 
      if (!in_rect(DD->list_x,DD->list_y,DD->list_w,DD->list_h,
           event->x,event->y))
      {
        DD->but1clicked= 1;
        DD->selitem= -1;
        return 1;
      }
      if (in_rect(DD->list_px,DD->list_py,DD->list_pw,DD->list_ph,
           event->x,event->y))
      {
        DD->but1clicked= 1;
        DD->selitem= dropdown_item_at(DD,event->y);
        dropdown_hilight_item(DD, DD->selitem);
        return 1;
      }
      return 0;
    case 4:
      dropdown_scroll_to(DD, DD->posy-0.9*DD->list_ph, 1);
      return 1;
    case 5:
      dropdown_scroll_to(DD, DD->posy+0.9*DD->list_ph, 1);
      return 1;
    }
    return 0;
  case GFXEV_BUTTON_RELEASE:
    if (event->button==1 && DD->but1clicked)
    {
      DD->but1clicked= 0;
      if (DD->selitem!=-1)
        DD->selected= DD->selitem;
      dropdown_hide_list(DD);
      ungrab_mouse();
      if (DD->selitem!=-1 && DD->action)
      {
        event->type= DD->widget.number;
        event->key= DD->selitem;
        event->usr= DD->items[DD->selitem].ptr;
        DD->selitem= -1;
        return 0;
      }
      DD->selitem= -1;
      return 1;
    }
    return 0;
  }
  return 0;
}

static int in_rect(int rx,int ry,int rw,int rh, int x,int y)
{
  if (x<rx || y<ry || x>=(rx+rw) || y>=(ry+rh)) return 0;
  return 1;
}

static void dropdown_hide_list(dropdown_t *DD)
{
  if (!DD->list_active) return ;
  DD->list_active= 0;
  dropdown_put_list_backup(DD);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
  dropdown_render_button(DD,0);
  DD->click_enabled= 1;
  if (DD->scroll) DD->scroll->enabled= 0;
}

static void dropdown_scroll_to(dropdown_t *DD,int pos,int report)
{
  if (pos<0) pos= 0;
  if (pos+DD->list_ph>DD->list_cont_h) pos= DD->list_cont_h-DD->list_ph;
  if (pos<0) pos= 0;
  if (DD->posy==pos) return ;
  
  DD->posy= pos;
  dropdown_draw_listbg(DD);
  dropdown_draw_contents(DD);
  if (report && DD->scroll) 
    scrollbar_set(DD->scroll, (double) DD->posy/DD->list_cont_h, 
                              (double) (DD->posy+DD->list_ph)/DD->list_cont_h, 
                              0, NULL);
  gfx_update(DD->list_x,DD->list_y,DD->list_w,DD->list_h);
}

static int dropdown_item_at(dropdown_t *DD,int y)
{
  int K;
  if (DD->n_items<=0) return -1;
  
  y= y - DD->list_py + DD->posy;
  if (y<DD->fh+dropdown_list_padv)
     K= 0;
  else
     K= (y-dropdown_list_padv+dropdown_list_spc)/(DD->fh+dropdown_list_spc);
  if (K>=DD->n_items) return -1;
  return K;
}

static void dropdown_hilight_item(dropdown_t *DD, int item)
{
  int x,y,w,h;

  if (item<0 || item>=DD->n_items) return ;
  x= DD->list_px;
  y= dropdown_item_pos(DD,item)-dropdown_list_spc+DD->list_py-DD->posy;
  w= DD->list_pw;
  h= DD->fh+dropdown_list_spc;
  fill_clipped_rect(DD->list_px, DD->list_py, DD->list_pw, DD->list_ph,
                    x,y,w,h, dropdown_list_hcolor);
  dropdown_draw_item(DD,item);
  gfx_update(x,y,w,h);
}

static void fill_clipped_rect
               (int Cx,int Cy,int Cw, int Ch, 
                int dx,int dy,int ow, int oh, unsigned int color)
{
  if (ow<=0 || oh<=0) return ;
  if (dx>=(Cx+Cw) || dy>=(Cy+Ch) || (dx+ow<=Cx) || (dy+oh<=Cy)) return ;

  if (dx<Cx)
  {
    ow-= (Cx-dx);
    dx= Cx;
  }

  if (dy<Cy)
  {
    oh-= (Cy-dy);
    dy= Cy;
  }
  if (ow<=0 || oh<=0) return ;

  if ((dy+oh)>=(Cy+Ch))
  {
    oh= Cy+Ch-dy;
  }
  if ((dx+ow)>=(Cx+Cw))
  {
    ow= Cx+Cw-dx;
  }
  if (ow<=0 || oh<=0) return ;
  gfx_fill_rect(0,dx,dy,ow,oh,color);
}


static void dropdown_insert(dropdown_t *DD,
                            int pos, const char *str, void *usr)
{
  TUPsp_t *src, *dst;
  int i;
  
  if (pos<0 || pos>DD->n_items) pos= DD->n_items;
  src= DD->items;
  if (DD->n_items==DD->s_items)
  {
    if (DD->s_items==0) DD->s_items= 10;
    else DD->s_items+= DD->s_items/2;
    DD->items= dst= malloc(DD->s_items*sizeof(DD->items[0]));
  }
  else dst= DD->items;

  if (src)
  {
    for(i=DD->n_items;i>pos;i--) dst[i]= src[i-1];
    if (src!=dst)
      for(i=0;i<pos;i++) dst[i]= src[i];
    if (src!=dst) free(src);
  }
  dst[pos].str= strdup(str);
  dst[pos].ptr= usr;
  DD->n_items++;
  if (pos<=DD->selected) DD->selected++;
}


static void dropdown_remove(dropdown_t *DD,int pos, void **Rusr)
{
  int i;
  
  if (DD->n_items==0) return ; 
  if (pos<0 || pos>=DD->n_items) pos= DD->n_items-1;
  if (Rusr) *Rusr= DD->items[pos].ptr;

  // actually, the string is always gotten from strdup, if is unnecessary
  if (DD->items[pos].str) free(DD->items[pos].str); 
  for(i=pos;i<DD->n_items-1;i++)
    DD->items[i]= DD->items[i+1];
  if (pos==DD->selected) DD->selected= -1;
  else if (pos<DD->selected) DD->selected--;
  DD->n_items--;
}

static void gui_dropdown_clear(dropdown_t *DD)
{
  int i;
  if (DD->n_items==0) return ; 
  for(i=0;i<DD->n_items;i++)
   free(DD->items[i].str);
  DD->selected= -1;
  DD->n_items= 0;  
  if (DD->shown)
    dropdown_render_button(DD,0);
}

static void gfx_dropdown_select(dropdown_t *DD, int pos)
{
  if (pos<0 || pos>=DD->n_items) pos= -1;
  if (DD->selected==pos) return ;
  DD->selected= pos;
  if (DD->shown)
    dropdown_render_button(DD,0);
}


static void dropdown_destroy(dropdown_t *DD)
{
  int i;
  if (DD->scroll)
     scrollbar_destroy(DD->scroll);
  remove_click_handler(DD->click_handler);
  freeNnull(DD->list_backup);

  for(i=0;i<DD->n_items;i++)
    free(DD->items[i].str);
  freeNnull(DD->items);
}

static void dropdown_position(dropdown_t *DD,int x,int y,int w,int h)
{
  DD->widget.x= x;
  DD->widget.y= y;
  DD->widget.w= w;
  DD->widget.h= h;
  dropdown_render_button(DD,0);
}


static widget_t* gfx_list(int noicon,int multisel, int click_action)
{
  gui_list_t *LL;

  LL= calloc(1,sizeof(*LL));

  LL->uses_icons= !noicon;
  LL->multiselect= multisel;
  LL->click_action= click_action;

  LL->ch0= LL->ch1= LL->ch2= -1;
  LL->click_index= -1;

  LL->widget.klass= GFXCLASS_LIST;
  return &LL->widget;
}


static void gui_list_set_position(gui_list_t* LL,int x,int y,int w,int h)
{
    LL->x= x; LL->y= y; LL->w= w; LL->h= h;
    LL->port_x= LL->x+1;
    LL->port_y= LL->y+1;
    LL->widget.x= x;
    LL->widget.y= y;
    LL->widget.w= w;
    LL->widget.h= h;
}


static void gfx_list_show(gui_list_t *L, int show)
{
  int hv,hh;

  if ((L->enabled && show) || (!L->enabled && !show)) return ;

  if (!show)
  {
    L->enabled= 0;
    if (L->scrollv) L->scrollv->enabled= 0;
    if (L->scrollh) L->scrollh->enabled= 0;
    return ;
  }

  L->enabled= 1;

  L->max_icon_width= list_max_icon_width(L);
  compute_list_items(L, 0, L->n_items-1);
  compute_list_content_size(L, &L->content_w, &L->content_h);
  compute_list_port(L, &L->port_w, &L->port_h, &hh, &hv);
  list_layout_items(L,0);
  list_draw_borders(L, 0xf);
  list_arrange_scrollbars(L, hh, hv);
  list_draw_contents(L);
  gfx_update(L->x,L->y,L->w,L->h);
  list_install_click_handlers(L);
}



static void list_install_click_handlers(gui_list_t *LL)
{
  int x,y,w,h;
  if (!LL->enabled) return ;

  x= LL->port_x; y= LL->port_y;
  w= LL->port_w; h= LL->port_h;
  
  LL->ch0= install_or_modify_click
             (LL->ch0,&LL->enabled, gui_list_click, LL, x,y,w,h, 1);
  LL->ch1= install_or_modify_click
             (LL->ch1,&LL->enabled, gui_list_click4, LL, x,y,w,h, 4);

  LL->ch2= install_or_modify_click
             (LL->ch2,&LL->enabled, gui_list_click5, LL, x,y,w,h, 5);
}


static void compute_list_items
    (gui_list_t* LL, int start, int end)
{
  int tw,th;
  int i;

  start= imax2(0,start);
  end= imin2(end,LL->n_items-1);

  for(i=start;i<=end;i++)
  {
    list_item_t *item= LL->items+ i;

    get_text_data(1, item->str, &tw, &th, NULL, NULL);
    if (LL->uses_icons)
      item->text_x= gui_list_pad_horz+gui_list_icontext_sep + LL->max_icon_width;
    else
      item->text_x= gui_list_pad_horz;

    item->w= item->text_x + tw + gui_list_pad_horz;

    if (LL->uses_icons&&item->icon_data)
    {
      item->h= imax2(item->icon_height, th);
      item->icon_y= (item->h-item->icon_height)/2;
      item->icon_x= (LL->max_icon_width-item->icon_width)/2 + gui_list_pad_horz;
    }
    else
    {
      item->h= th;
    }
    item->text_y= (item->h-th)/2;

    item->text_w= tw;
    item->text_h= th;
  }
}

static void compute_list_content_size(gui_list_t *LL,int *Rw, int *Rh)
{
  int i;
  int w,h;
  w= h= 0;
  for(i=0;i<LL->n_items;i++)
  {
    h+= LL->items[i].h;
    if (i>0 && i<LL->n_items-1) h+= gui_list_spacing;
    w= imax2(w, LL->items[i].w);
  }
  h+= 2*gui_list_pad_horz;
  if (Rw) *Rw= w;
  if (Rh) *Rh= h;
}

static int list_max_icon_width(gui_list_t *LL)
{
  int i,w;
  w= 0;
  if (!LL->uses_icons) return 0;
  for(i=0;i<LL->n_items;i++)
    if (LL->items[i].icon_data)
      w= imax2(w, LL->items[i].icon_width);
  return w;
}

static void compute_list_port
  (gui_list_t* LL, int *Rportw, int *Rporth, int *Rhs, int *Rvs)
{
  int portw,porth, wA,wB, hA, hB;

  wA= LL->w - 2 ;
  wB= LL->w - 1 - gui_scrollbar_width;

  hA= LL->h - 2; 
  hB= LL->h - 1 - gui_scrollbar_height;

  portw= wA;
  porth= hA;
  if (portw<LL->content_w) porth= hB;
  if (porth<LL->content_h) portw= wB;
  if (portw<LL->content_w) porth= hB;
 
  if (Rportw) *Rportw= portw;
  if (Rporth) *Rporth= porth;
  if (Rhs)    *Rhs= (porth==hB);
  if (Rvs)    *Rvs= (portw==wB);
}

static int list_render_item(gui_list_t *LL,int ino,int bg)
{
  list_item_t *item= LL->items+ino;

  int src_x,src_y, copy_w, copy_h;
  unsigned char *tdata;
  
  int cW = item->icon_width,
      cH = item->icon_height,
      cX = item->icon_x,
      cY = item->icon_y + item->y;

  int tW= item->text_w,
      tH= item->text_h,
      tX= item->text_x,
      tY= item->text_y + item->y;

  int iY= item->y,
      iH= item->h;
      //  iX= 0, iW= item->w,

  int sY= LL->posy, 
      sX= LL->posx,
      sW= LL->port_w,
      sH= LL->port_h;

  if ((iY+iH)<=sY)  return -1;
  if (iY>=(sY+sH))  return 1;

  if (item->selected || bg)
  {
    int bY= iY-sY+LL->port_y,
        bW= LL->port_w,
        bX= LL->port_x,
        bH= iH;
    int color;

    if (bY<LL->port_y) 
    {
      bH-= LL->port_y-bY;
      if (bH<=0) goto bg_done;
      bY= LL->port_y;
    }

    if ((bY+bH)>(LL->port_y+LL->port_h))
    {
      bH= (LL->port_y+LL->port_h) - bY;
      if (bH<=0) goto bg_done;
    }
    if (item->selected) color= 0xaabbff;
             else color= 0xffffff;
    gfx_fill_rect(0, bX, bY, bW, bH, color);
  }

bg_done:
  if (!LL->uses_icons || !item->icon_data) goto icon_done;

  src_x= 0;
  src_y= 0;
  copy_w= cW;
  copy_h= cH;

  if (cX<sX)
  {
    src_x += sX-cX;
    copy_w-= sX-cX;
    cX= sX;
  }

  if (cY<sY)
  {
    src_y+= sY-cY;
    copy_h-= sY-cY;
    cY= sY;
  }

  if ((cX+copy_w)>(sX+sW))
    copy_w-= (cX+copy_w) - (sX+sW);

  if ((cY+copy_h)>(sY+sH))
    copy_h-= (cY+copy_h) - (sY+sH);

    if (copy_w<=0) goto icon_done;
    if (copy_h<=0) goto icon_done;
  if (cY>=(sY+sH)) goto icon_done;
  if (cX>=(sX+sW)) goto icon_done;

  // now, cX and cY contain the document coordinates for copy.

  gfx_put(GFX_ALPHA, item->icon_data, cW, cH, src_x, src_y,
                                      cX-sX+LL->port_x, cY-sY+LL->port_y,
                                      copy_w, copy_h);
icon_done:
  src_x= 0;
  src_y= 0;
  copy_w= tW;
  copy_h= tH;

  if (tX<sX)
  {
    src_x += sX-tX;
    copy_w-= sX-tX;
    tX= sX;
  }

  if (tY<sY)
  {
    src_y += sY-tY;
    copy_h-= sY-tY;
    tY= sY;
  }

  if ((tX+copy_w)>(sX+sW))
  {
    copy_w -= (tX+copy_w)-(sX+sW);
  }
  if ((tY+copy_h)>(sY+sH))
  {
    copy_h -= (tY+copy_h)-(sY+sH);
  }

  if (copy_h<=0) goto text_done;
  if (copy_w<=0) goto text_done;
  if (tY>=(sY+sH)) goto text_done;
  if (tX>=(sX+sW)) goto text_done;

  get_text_data(1, item->str, NULL, NULL, NULL,&tdata);
  blend_graymap(0, 0x00, 0xffffff, tdata, tW, tH, src_x, src_y,
                             tX-sX+LL->port_x, tY-sY+LL->port_y,
                             copy_w, copy_h);
  free(tdata);

text_done:
  return 0;
}


static void gui_list_scrollbar_click_horz(void *a, double S, double E)
{
  int posx;
  gui_list_t *L;
  L= a;

  posx= S*L->content_w;
  if (posx+L->port_w>L->content_w)
    posx= L->content_w - L->port_w;
  if (posx<0) posx= 0;
  if (posx!=L->posx)
  {
    L->posx= posx;
    list_draw_contents(L);
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
}

static void gui_list_scrollbar_click_vert(void *a, double S, double E)
{
  int posy;
  gui_list_t *L;
  L= a;

  posy= S*L->content_h;
  if (posy+L->port_h>L->content_h)
    posy= L->content_h - L->port_h;
  if (posy<0) posy= 0;
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
}




static void list_layout_items(gui_list_t *LL,int start)
{
  int i,y;
  start= imax2(0,start);
  if (start==0) y= gui_list_pad_vert;
           else y= LL->items[start-1].y+LL->items[start-1].h+gui_list_spacing;
 
  for(i=start;i<LL->n_items;i++)
  {
    LL->items[i].y= y;
    y+= LL->items[i].h + gui_list_spacing;
  }
}

static void list_draw_borders(gui_list_t *LL,int which)
{
  int x,y,w,h;
  unsigned int border;
  x= LL->x; y= LL->y; w= LL->w; h= LL->h;

  border= color_u_to_s(gui_list_border);
  if (which & 8) hline(x, x+w-1, y, border);
  if (which & 2) hline(x, x+w-1, y+h-1, border);
  if (which & 4) vline(x, y, y+h-1, border);
  if (which & 1) vline(x+w-1, y, y+h-1, border);
}

static void list_draw_contents(gui_list_t *L)
{
  int i,j,k;
  gfx_fill_rect(0,L->port_x,L->port_y,L->port_w,L->port_h, 0xffffff);
  if (L->n_items==0) return ;
  i= 0; 
  j= L->n_items-1;
  while(i<=j)
  {
    k= (i+j)/2;
    switch(list_render_item(L,k,0))
    {
     case 1: j= k-1; break;
     case 0: goto found;
     case -1: i= k+1; break;
    }
  }

  return;
found:
  for(i=k-1;i>=0;i--)         if (list_render_item(L,i,0)) break;
  for(j=k+1;j<L->n_items;j++) if (list_render_item(L,j,0)) break;
}

static void list_compute_scroll
    (int pos,int win,int con, double *Rstart, double *Rend, double *Rstep)
{
  if (con<=0) con= 1;
  *Rstart=  dmax2(0.0,dmin2((double)pos/con,1.0));
  *Rend=    dmin2(1.0,dmax2((double)(pos+win)/con,0.0));
  *Rstep=   dmax2(0.0,dmin2(1.0,(double)win/con*0.9));
}

static void list_arrange_scrollbars
   (gui_list_t *LL, int have_horz, int have_vert)
{
  int ver_scroll_h, hor_scroll_w;
  double start,end,step;

  hor_scroll_w= LL->w;
  if (have_vert) hor_scroll_w-= gui_scrollbar_width;
  ver_scroll_h= LL->h;
  if (have_horz) ver_scroll_h-= gui_scrollbar_height;

  switch((have_vert ? 2: 0) | (LL->has_scrollv ?1:0))
  {
  case 0: break;
  case 1: list_draw_borders(LL, 1); break;
  case 3:
  case 2: 
    list_compute_scroll(LL->posy, LL->port_h, LL->content_h,
                        &start,&end,&step);
    if (LL->scrollv)
      scrollbar_relayout(LL->scrollv, 
                   LL->scrollv->widget.x, LL->scrollv->widget.y,
                   gui_scrollbar_width, ver_scroll_h, start, end,step);
    else {
      LL->scrollv= (scrollbar_t*)
        scrollbar_new(1, start,end,step,0, LL, gui_list_scrollbar_click_vert);
      scrollbar_position(LL->scrollv, LL->x+LL->w-gui_scrollbar_width, LL->y,
                          gui_scrollbar_width, ver_scroll_h);
      scrollbar_show(LL->scrollv,1);
    }
    break;
  }

  switch( (have_horz?2:1)  | (LL->has_scrollh?1:0))
  {
  case 0: break;
  case 1: list_draw_borders(LL,2); break;
  case 3:
  case 2: 
    list_compute_scroll(LL->posx, LL->port_w, LL->content_w,
                        &start,&end,&step);
    if (LL->scrollh)
      scrollbar_relayout(LL->scrollh, 
                   LL->scrollh->widget.x, LL->scrollh->widget.y,
                   hor_scroll_w, gui_scrollbar_height, start,end,step);
    else 
    {
      LL->scrollh= (scrollbar_t*)
        scrollbar_new(0, start,end,step,0, LL, gui_list_scrollbar_click_horz);
      scrollbar_position(LL->scrollh, 
             LL->x,LL->y+LL->h-gui_scrollbar_height,
             hor_scroll_w, gui_scrollbar_height);
      scrollbar_show(LL->scrollh,1);
    }
    break;
  }

  if (!have_vert && LL->scrollv) LL->scrollv->enabled= 0;
  if (!have_horz && LL->scrollh) LL->scrollh->enabled= 0;

  if (have_vert && have_horz)
  {
    if (!LL->has_scrollv || !LL->has_scrollh)
      gfx_fill_rect(0, LL->scrollh->widget.x+ LL->scrollh->widget.w,
                       LL->scrollv->widget.y+ LL->scrollv->widget.h,
                       gui_scrollbar_width, gui_scrollbar_height, 0xdddddd);
  }

  if (have_horz)
    gfx_update(LL->x,LL->scrollh->widget.y, LL->w, gui_scrollbar_height);
  if (have_vert)
    gfx_update(LL->scrollv->widget.x, LL->y, gui_scrollbar_width, LL->h);
  LL->has_scrollh= have_horz;
  LL->has_scrollv= have_vert;
}



static int gui_list_click(void *a, gfx_event_t *ev)
{
  int i,j,k;
  gui_list_t *L;
  int upd;
  
  L= a;
  if (L->click_action==0) return 1;
  i= 0; j= L->n_items-1;

  while(i<=j)
  {
    int iY, iH;
    k= (i+j)/2;
    iY= L->items[k].y - L->posy + L->port_y; 
    iH= L->items[k].h;

    if (ev->y<iY) { j= k-1; continue; } 
    if (ev->y>=(iY+iH)) { i= k+1; continue; }
    goto found;
  }
  return 1;
found:
  upd=1;
  if (!L->multiselect)
  {
    for(i=0;i<L->n_items;i++)
      if (i!=k && L->items[i].selected)
      {
        L->items[i].selected= 0;
        upd*= list_render_item(L, i, 1);
      }
    if (!L->items[k].selected)
    {
       L->items[k].selected= 1;
       upd*= list_render_item(L,k,1);
    }
  }
  else
  {
    L->items[k].selected= L->items[k].selected ? 0:1;
    upd= list_render_item(L,k,1);
  }

  if (!upd)
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);

  if (L->click_time && ev->time>L->click_time && 
        (ev->time-L->click_time<500) && L->click_index==k)
  {
    ev->type= GFXEV(L->widget.number, DOUBLE_CLICK);
    L->click_time= 0;
    L->click_index= -1;
  }
  else
  {
    ev->type= L->widget.number;
    L->click_time= ev->time;
    L->click_index= k;
  }
  ev->key= k;
  ev->string= L->items[k].str;
  ev->usr= L->items[k].user;
  return 0;
}

 // mouse button 4: scroll up
static int gui_list_click4(void *a, gfx_event_t *ev)
{
  gui_list_t *L;
  int posy;
  L= a;

  posy= imax2(L->posy - L->port_h/2,0);
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    if (L->has_scrollv) 
       scrollbar_set( L->scrollv,
                      (double) L->posy/L->content_h, 
                      (double)(L->posy+L->port_h)/L->content_h,
                      0, NULL );
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
  return 2;
}

 // mouse button 5: scroll down
static int gui_list_click5(void *a, gfx_event_t *ev)
{
  gui_list_t *L;
  int posy;
  L= a;

  posy= imax2(0, imin2(L->posy + L->port_h/2, L->content_h - L->port_h));
  if (posy!=L->posy)
  {
    L->posy= posy;
    list_draw_contents(L);
    if (L->has_scrollv) 
       scrollbar_set( L->scrollv,
                      (double) L->posy/L->content_h, 
                      (double)(L->posy+L->port_h)/L->content_h,
                      0, NULL );
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
  }
  return 2;
}

static void list_relayout(int flags, gui_list_t *L)
{
  int hh, hv;
  compute_list_content_size(L, &L->content_w, &L->content_h);
  compute_list_port(L, &L->port_w, &L->port_h,&hh, &hv);

  L->posy= imax2(0, imin2(L->posy, L->content_h-L->port_h));
  L->posx= imax2(0, imin2(L->posx, L->content_w-L->port_w));

  list_arrange_scrollbars(L,hh,hv);

  list_install_click_handlers(L);

  list_draw_contents(L);

  if (flags&GFX_UPDATE && L->enabled)
    gfx_update(L->x,L->y,L->w,L->h);
}


static void gfx_list_insert(gui_list_t* L, int pos, char *str, void *usr
                          ,const unsigned int*icon) 
{
  list_item_t *item;
  unsigned int icon_w, icon_h;

  if (icon)
  {
  icon_w= icon[0] & ~(1<<31);
  icon_h= icon[1];
  icon= icon+2;
  }
  else icon_w= icon_h= 0;

  if (pos<0 || pos>=L->n_items) pos= L->n_items;

  item= array_make1space(pos,(void**) &L->items, L->n_items, &L->s_items,
                         sizeof(L->items[0]));
  item->str= strdup(str);
  item->user= usr;
  item->icon_data= icon;
  item->icon_width= icon_w;
  item->icon_height= icon_h;
  item->selected= 0;

  L->n_items++;
  compute_list_items(L, pos, pos);

  if (!L->enabled) return ;

  L->max_icon_width= list_max_icon_width(L);
  list_layout_items(L, pos);
  list_relayout(GFX_UPDATE,L);
}


static void gfx_list_delete(gui_list_t *L, int pos, void **Ruser)
{
  int i;

  if (Ruser) *Ruser= NULL;
  if (L->n_items==0) return ;
  if (pos<0) pos= L->n_items-1;
  if (pos>=L->n_items) return ;

  if (Ruser) *Ruser= L->items[pos].user;
  free(L->items[pos].str);

  for(i=pos;i<L->n_items-1;i++)
     L->items[i]= L->items[i+1];
  L->n_items--;

  if (L->enabled)
  {
    if (pos<L->n_items)
      list_layout_items(L, pos);
    list_relayout(GFX_UPDATE,L);
  }
}


static int gfx_list_selected(gui_list_t *L)
{
  int i;
  for(i=0;i<L->n_items;i++)
   if (L->items[i].selected) return i;
  return -1;
}


static void gfx_list_select(gui_list_t* L,int pos)
{
  int i;
  int ch;
  if (pos<0 || pos>=L->n_items) return ;
  if (L->items[pos].selected) return ;
  ch= 1;
  for(i=0;i<L->n_items;i++)
    if (L->items[i].selected)
    {
      L->items[i].selected= 0;
      if (L->enabled) ch&= list_render_item(L,i,1);
    }
  L->items[pos].selected= 1;
  if (L->enabled) 
    ch &=list_render_item(L,pos,1);
  if (L->enabled && !ch)
    gfx_update(L->port_x,L->port_y,L->port_w,L->port_h);
}

static void gfx_list_clear(gui_list_t *L)
{
  int i;
  for(i=0;i<L->n_items;i++)
  {
    free(L->items[i].str);
    L->items[i].str= NULL;
  }
  L->n_items= 0;
  L->posx= 0;
  L->posy= 0;
  if (L->enabled)
    list_relayout(GFX_UPDATE,L);
}


static widget_t *text_entry_new(char *initstr)
{
  text_entry_t *te;
  uint32_t i;
  uint32_t *wide_str, wide_str_len;
  int size;
  int x;

  te= calloc(1,sizeof(*te));

  if (!initstr) initstr= "";
  utf8_decode_alloc(initstr, &wide_str, &wide_str_len);

  size= wide_str_len + wide_str_len/2 + 2;
  if (size<50) size= 50;

  te->size= size;
  te->len= wide_str_len+1;
  te->glyphs= malloc(sizeof(te->glyphs[0])*te->size);
  
  for(i=0;i<te->len-1;i++) mk_glyph(te->glyphs+i, wide_str[i]);
  mk_glyph(te->glyphs+i, ' ');
  free(wide_str);

  x= 0;
  for(i=0;i<te->len;i++)
  {
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  
  te->fonth= font1height();
  
  te->cursor= te->len-1;
  te->left= 0;

  te->widget.can_focus= 1;
  te->widget.has_focus= 0;
  te->widget.focus= textentry_focus;
  te->widget.handle_key= textentry_key;

  te->widget.klass= GFXCLASS_TEXTENTRY;

  te->widget.show= gui_textentry_show;
  te->widget.hide= gui_textentry_hide;

  return &te->widget;
}


static void textentry_position(text_entry_t *te,int x,int y,int w,int h)
{
  widget_t *W;
  te->x= x; te->y= y; te->w= w; te->h= h;
  W= &te->widget;
  W->x= x; W->y= y; W->w= w; W->h= h;
  make_cursor_visible(te);
}

static void make_cursor_visible(text_entry_t *te)
{
  int cx, cw;
  int i;
  cx= te->glyphs[te->cursor].x;
  cw= te->glyphs[te->cursor].w;

  if (cx<te->left) te->left= cx; 
  else if (cx+cw-te->left>te->w) te->left= cx+cw-te->w; 

  if (te->widget.shown)
  {
    gfx_fill_rect(0, te->x, te->y, te->w, te->h, TE_bg);
    gfx_draw_rect(0, te->x-1, te->y-1, te->w+2, te->h+2, 0x888888);
    for(i=0;i<te->len;i++) if (draw_glyph(te, i,0)) break;
    gfx_update(te->x, te->y, te->w, te->h);
  }
}


static void mk_glyph(glyph_t *G, uint32_t chr)
{
  // We don't store the height, they all have the same height.
  font1_render(&chr, 1, (int*) &G->w, NULL, NULL, &G->d);
  G->chr= chr;
}

static int draw_glyph(text_entry_t  *te, int gn, int expose)
{
  int ws, we, sx, sy, cw, ch, dx,dy, gs,ge;
  uint32_t fg, bg;
  glyph_t *G;

  ws= te->left; 
  we= te->left+te->w;
  G= te->glyphs+gn;

  if (te->fonth>te->h)
  {
    sy= (te->fonth-te->h)/2;
    ch= te->h;
    dy= 0;
  } else { dy= (te->h-te->fonth)/2; sy=0; ch= te->fonth; }

  gs= G->x;
  ge= gs + G->w;

  if (ge<=ws) return 0;
  if (gs>=we) return 1;
    
  sx= 0; cw= te->glyphs[gn].w;
  if (gs<ws) { sx= ws-gs; cw-= ws-gs; }
  if (ge>we) { cw-= ge-we; }

  dx= sx + gs - ws;
  if (te->widget.has_focus && gn==te->cursor) { fg= TE_cfg; bg= TE_cbg; }
                                  else { fg= TE_fg;  bg= TE_bg; }

  blend_graymap( (expose ? GFX_UPDATE : 0) | GFX_BACKGND, 
                 fg, bg, G->d, G->w, te->fonth, sx, sy,
                         dx + te->x, dy + te->y, cw, ch );
  return 0;
}


static void textentry_focus(void *va, int focus)
{
  text_entry_t *te;
  te= va;
  if (!te->widget.shown) return ;
  if (te->widget.has_focus==focus) return ;
  te->widget.has_focus= focus;
  draw_glyph(te, te->cursor, 1);
}

static int textentry_key(void* va, gfx_event_t *event) 
{
  text_entry_t *te;
  te= va;
    // this will not happen, hopefully.
  if (!te->widget.shown) return 0;
  if (te->key_filter && (*te->key_filter)(te->key_arg,va,event))
    return 1;
  
  switch(event->key)
  {
   case GFX_K_LEFT:
     if (te->cursor!=0) text_entry_move_cursor(te, te->cursor-1);
     return 1;
   case GFX_K_RIGHT:
     if (te->cursor!=te->len-1) text_entry_move_cursor(te,te->cursor+1);
     return 1;
   case GFX_K_HOME: text_entry_move_cursor(te, 0); return 1;
   case GFX_K_END:  text_entry_move_cursor(te, te->len-1); return 1;
   case GFX_K_DELETE:
     if (te->cursor!=te->len-1) delete_cursor_char(te);
     return 1;
   case GFX_K_BACKSPACE:
     if (te->cursor!=0)
     {
       te->cursor--;
       delete_cursor_char(te);
     }
     return 1;
   case GFX_K_PRT:
     insert_char(te, event->wide);
     return 1;
  }
  return 0;
}


static void text_entry_move_cursor(text_entry_t *te, int newcurs)
{
  int ws, we, gs,ge;
  int C;

  if (newcurs<0 || newcurs>=te->len || newcurs==te->cursor) return ;  

  gs= te->glyphs[newcurs].x;
  ge= gs + te->glyphs[newcurs].w;

  ws= te->left; 
  we= te->left+te->w;

  if (gs<ws|| ge>we)
  {
    te->cursor= newcurs;
    make_cursor_visible(te);
    return ;
  }

  C= te->cursor;
  te->cursor= newcurs;
  draw_glyph(te, C,1);
  draw_glyph(te, te->cursor,1);
}

static void insert_char(text_entry_t *te, uint32_t chr)
{
  int i;
  if (te->len==te->size)
  {
    te->size+= te->size/2;
    te->glyphs= realloc(te->glyphs, sizeof(te->glyphs[0])*te->size);
  }
  for(i=te->len;i>te->cursor;i--)
    te->glyphs[i]= te->glyphs[i-1];
  mk_glyph(te->glyphs+ te->cursor, chr);
  
  te->cursor++;
  te->len++;
  for(i=te->cursor;i<te->len;i++)
    te->glyphs[i].x= te->glyphs[i-1].x + te->glyphs[i-1].w;

  make_cursor_visible(te);
}

static void delete_cursor_char(text_entry_t *te)
{
  int i,x;
  free(te->glyphs[te->cursor].d);
  x= te->glyphs[te->cursor].x;
  for(i=te->cursor;i<te->len-1;i++)
  {
    te->glyphs[i]= te->glyphs[i+1];
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  te->len--;
  te->glyphs[i].x= x;
  make_cursor_visible(te);
}


static char *textentry_get_text(text_entry_t *te)
{
  uint32_t *wide, widelen;
  uint8_t *str;
  int i;
  size_t slen;

  widelen= te->len;
  wide= malloc(sizeof(uint32_t)*widelen);
  for(i=0;i<te->len;i++)
    wide[i]= te->glyphs[i].chr;

  str= malloc(widelen+1);
  utf8_encode_string(wide, widelen, str, &slen);
  if (slen) str[slen-1]= 0; // eat up the space we added
  free(wide);
  return (char*) str;
}


static void textentry_free(text_entry_t *te)
{
  int i;
  for(i=0;i<te->len;i++)
   free(te->glyphs[i].d);
  free(te->glyphs);
}


static void text_entry_set(text_entry_t *te, char *str)
{
  uint32_t i;
  uint32_t *wide_str, wide_str_len;
  int x;

  if (!str) str="";
  utf8_decode_alloc(str, &wide_str, &wide_str_len);

  if (wide_str_len>te->size)
  {
    te->size= wide_str_len + wide_str_len/2 + 2;
    if (te->size<50) te->size= 50;
    te->glyphs= realloc(te->glyphs,sizeof(te->glyphs[0])*te->size);
  }

  for(i=0;i<te->len;i++) free(te->glyphs[i].d);

  te->len= wide_str_len+1;
  
  for(i=0;i<te->len-1;i++) mk_glyph(te->glyphs+i, wide_str[i]);
  mk_glyph(te->glyphs+i, ' ');

  x= 0;
  for(i=0;i<te->len;i++)
  {
    te->glyphs[i].x= x;
    x+= te->glyphs[i].w;
  }
  
  free(wide_str);
  
  te->cursor= te->len-1;
  te->left= 0;
  if (te->widget.shown)
    make_cursor_visible(te);
}




static int font1height()
{
  int h;
  // this is just to get the font height. it fails badly when
  // the init string is empty, which happens a lot. so, I'm going
  // to use a fixed string for this.
  unsigned int fixedchr;
  fixedchr= 'M';
  font1_render(&fixedchr,1, NULL, &h, NULL, NULL);
  return h;
}

static void gui_textentry_show(widget_t *arg)
{
  text_entry_t *te;
  te= (text_entry_t*) arg;
  te->widget.can_focus= 1;
  make_cursor_visible(te);
}

static void gui_textentry_hide(widget_t *arg)
{
  text_entry_t *te;
  te= (text_entry_t*) arg;
  if (te->widget.has_focus) focus_lost();
  te->widget.can_focus= 0;
  te->widget.has_focus= 0; 
}


static widget_t* gfx_pixgrid()
{
  gui_pixgrid_t *B;
  B= calloc(1,sizeof(*B));
  B->widget.klass= GFXCLASS_PIXGRID;
  B->click_handler= install_click_handler(0,0,0,0,&B->enabled,B, 
                                          gui_pixgrid_click,1);
  return &B->widget;
}



static int gui_pixgrid_click(void *arg,gfx_event_t *event)
{
  gui_pixgrid_t *B;
  B= arg;
  if (!B->enabled) return 0;
  event->type += B->widget.number;
  event->x -= B->widget.x;
  event->y -= B->widget.y;
  install_release_handler(arg,gui_pixgrid_release);
  return 0;
}

static int gui_pixgrid_release(void *arg,gfx_event_t *event)
{
  gui_pixgrid_t *B;
  B= arg;
  event->type += B->widget.number;
  event->x -= B->widget.x;
  event->y -= B->widget.y;
  return 0;
}


static void gfxask_make_buttons
  (char *butstr,int *coor,int *Rnbut, int *Rbut_h,int *Rbut_total_w)
{
  int i,x,dummy,nr;
  char **buttons; int nbuttons;
  int button_h, button_w; // , button_total_w;
  int fh1;             // font height for font 1

  RES_INT(dialog_button_padding, 6, 
         "Internal spacing for confirmation dialog buttons");
  RES_INT(dialog_button_spacing, 10, 
         "External spacing for confirmation dialog buttons");

  butstr= strdup(butstr);
  split_string_bychar_d(butstr+1,butstr[0],&buttons,&nbuttons);

  if (nbuttons>8) nbuttons= 8;

  multi_line_str_dim(1,buttons,nbuttons, &button_w, &dummy);
  button_w += dialog_button_padding;
  *Rbut_total_w= button_w*nbuttons + (nbuttons-1)*dialog_button_spacing;

  get_text_data(1,"M",NULL,&fh1,NULL,NULL);
  button_h= fh1 + dialog_button_padding;

  x= 0;
  for(i=0;i<nbuttons;i++)
  {
    nr= GUIRaskB1+i;
    if (!widgets[nr]) 
    {
      widgets[nr]= (widget_t*) gui_button_new(buttons[i], 0, NULL, 
                                               GFXCLASS_BUTTON);
      widgets[nr]->number= nr;
    }
    else
    {
      button_set_text((gui_button_t*) widgets[nr], buttons[i]);
    }
    coor[4*i+0]= x;
    coor[4*i+2]= button_w;
    coor[4*i+3]= button_h;
    x+= button_w + dialog_button_spacing;
  }
  free(buttons);
  free(butstr); 
  *Rnbut= nbuttons;
  *Rbut_h= button_h;
}

static void gfxask_show_buttons
    (int *coor_widgets, int nbuttons,int X,int Y)
{
  int i;
  for(i=0;i<nbuttons;i++)
  {
    int nr;
    nr= GUIRaskB1+i;
    coor_widgets[4*i+0] += X;
    coor_widgets[4*i+1] = Y;
    gui_button_activate(widgets[nr], 
           coor_widgets[4*i+0], coor_widgets[4*i+1],
           coor_widgets[4*i+2], coor_widgets[4*i+3]);
  }
}


static void gfxask_draw_border(int X,int Y,int W,int H)
{
  int i;
  int border;
  RES_COLOR(confirm_border_color, 0 ,"Border color for confirmation dialog");
  RES_INT(confirm_border_width, 4 , "Border width for confirmation dialog");
  border= color_u_to_s(confirm_border_color);
  for(i=1;i<=confirm_border_width;i++)
  {
    hline(X-i,    X+W-1+i, Y-i     ,border);
    hline(X-i,    X+W-1+i, Y+H-1+i ,border);
    vline(X-i,    Y-i,     Y+H-1+i ,border);
    vline(X+W-1+i,Y-i,     Y+H-1+i ,border);
  }
  gfx_fill_rect(0, X,Y,W,H, confirm_bg);
}


static void split_string_bychar_d(char *str, int chr, char ***Ra,int *Rn)
{
  int d,n;
  char *x,*k,**R;
 
  R= NULL;
retry:
  n= 0;
  d= 0;
  x= str;
  while(!d)
  {
    k= strchr(x,chr);
    if (!k)
    {
      k= x+strlen(x);
      d= 1;
    }
    if (R)
    {
      R[n]= x;
      k[0]= 0;
    }
    n++;
    if (!d) { x= k+1; }
  }

  if (!R)
  {
    R= malloc(sizeof(*R)*(n+1));
    goto retry;
  }
  R[n]= NULL;
  *Ra= R;
  *Rn= n;
}

static void format_multi_line_str(char *fmt, va_list ap, char ***Rl, int *Rn)
{
  char *all;
  all= vmprintf(fmt, ap);
  split_string_bychar_d(all,'\n',Rl, Rn);
}

static void multi_line_str_dim
  (int font,char **lines, int nlines,int *Rw,int *Rh)
{
  int fh,tw;
  int i,w,h;

  get_text_data(font, "M",NULL,&fh,NULL,NULL);
  w= 0; 
  h= 0;
  for(i=0;i<nlines;i++)
  {
    get_text_data(font, lines[i],&tw,NULL,NULL,NULL);
    if (tw>w) w= tw;
    if (i) h+= 1;
    h+= fh;
  }
  *Rw= w;
  *Rh= h;
}


static char **parse_ext_list(char *inp)
{
  char **R;
  char *K,*E,*S;
  int N;

  inp= strchr(inp, '(');
  if (!inp) return NULL;
  R= NULL;

again:
  N= 0;
  K= inp+1;
  while(K[0]!=0 && K[0]!=')')
  {
    for(S=K;S[0]!='.' && S[0]!=0 && S[0]!=')';S++)  ;
    if (S[0]!='.') { K=S; continue; }
    for(E=S+1;E[0]!=0 && E[0]!=')' && E[0]!=' ' && E[0]!=',';E++)  ;
    if (E==S+1) { K=E; continue; }
    if (R)
    {
      R[N]= malloc(E-S+1);
      memcpy(R[N],S, E-S);
      R[N][E-S]= 0;
    }
    N++;
    K= E;
  }
  if (!R)
  {
    R= malloc(sizeof(*R)*(N+1));
    goto again;
  }
  R[N]= NULL;
  return R;
}

static char **make_file_extension_list(char **inp)
{
  int i,j;
  char **R;
  int nent,ne;
  char ***L;

  if (!inp || !inp[0] || !inp[0][0]) return NULL;
  if (strchr(inp[0],'('))
  {
    R= parse_ext_list(inp[0]);
    goto done;
  }

  {
    int first_spc;
    for(i=0;inp[0][i]==' ';i++) ;
    first_spc= i;

    for(i=1;inp[i];i++)
    {
      for(j=0;inp[i][j]==' ';j++) ;
      if (j<=first_spc) break;
    }
    nent= i;
  }
  if (nent==1) return NULL;

  ne= 0;
  L= calloc(nent,sizeof(*L));
  for(i=0;i<nent;i++)
  {
   if (!strchr(inp[i],'(')) continue;
    L[i]= parse_ext_list(inp[i]);
    if (L[i])
    {
      for(j=0;L[i][j];j++) ;
      ne+= j;
    }
  }
  R= malloc(sizeof(*R)*(ne+1));
  ne= 0;
  for(i=0;i<nent;i++)
  {
    if (L[i])
    {
     for(j=0;L[i][j];j++)
       R[ne++]= L[i][j];
     free(L[i]);
    } 
  }
  R[ne]= NULL;
  free(L);

done:
  return R; // maybe sort the list, and unify it??
}

static int file_matches_ext_set(char *fn,char **ext)
{
  int i;
  int lf,le;
  if (!ext) return 1;
  lf= strlen(fn);
  for(i=0;ext[i];i++)
  {
    if (!strcmp(ext[i],".*")) return 1;
    le= strlen(ext[i]);
    if (lf<=le) continue;
    if (!strcasecmp(fn+lf-le,ext[i])) return 1;
  }
  return 0;
}


static char **list_files(char *dn)
{
  DIR *dir;
  struct dirent *de;
  char **ptr;
  char *str;
  size_t i, ptrsize, strsize, L;
  buffer_t *buffer;

  dir= opendir(dn);
  if (!dir)
  {
    ptr= malloc(sizeof(*ptr));
    ptr[0]= NULL;
    return ptr;
  }

  buffer= buffer_new(1024);
  ptrsize= strsize= 0;
  while((de=readdir(dir)))
  {
    buffer_write(buffer, "U", 1);
    L= strlen(de->d_name)+1;
    buffer_write(buffer, de->d_name, L);
    strsize+= L+1;
    ptrsize++;
  }
  closedir(dir);

  ptr= malloc( (ptrsize+1)*sizeof(char*) + strsize );
  str= (char*) ptr + (ptrsize+1)*sizeof(char*) ;

  buffer_read(buffer, str, strsize);
  buffer_free(buffer, NULL, NULL);

  for(i=0;i<ptrsize;i++)
  {
    ptr[i]= str;
    str+= strlen(str)+1;
  }
  ptr[i]= NULL;
  
  return ptr;
}

static void file_types(char *dn, char **files)
{
  size_t i;
  size_t mlen,L, dlen;
  char *path,*name;

  mlen= 0;
  for(i=0;files[i];i++)
  {
    L= strlen(files[i]);
    if (L>mlen) mlen= L;
  }

  dlen= strlen(dn);
  path= malloc(dlen+2+mlen); // slash + null
  name= path+dlen+1;
  memcpy(path, dn, dlen);
  path[dlen]= '/';

  for(i=0;files[i];i++)
  {
    struct stat sbuf;
    strcpy(name, files[i]+1);
    if (stat(path,&sbuf)) continue;
    if (S_ISDIR(sbuf.st_mode))      files[i][0]= 'D';
    else if (S_ISREG(sbuf.st_mode)) files[i][0]= 'F';
  } 

  free(path);
}


_BUFFER_PROTO buffer_t *buffer_new(size_t blksize)
{
  buffer_t *B;
  B= malloc(sizeof(*B));
  B->first= B->last= NULL;
  B->blksize= blksize;
  return B;
}


_BUFFER_PROTO void buffer_free(buffer_t *B, void **Rd, size_t *Rl)
{
  struct buffer_node *P,*N;
  if (Rd || Rl) buffer_collect(B, Rd, Rl);
  for(P=B->first;P;P=N)
  {
    N= P->next;
    free(P);
  }
  free(B);
}

_BUFFER_PROTO void buffer_collect(buffer_t *B, void **Rd, size_t *Rl)
{
  size_t S;
  struct buffer_node *P;
  unsigned char *R;

  if (!Rd && !Rl) return ;

  S= 0;
  for(P=B->first;P;P=P->next) S+= P->len;

  if (S==0) { if (Rd) *Rd= NULL; if (Rl) *Rl= 0; return ; }
  if (!Rd) { *Rl= S; return ; }

  R= malloc(S);
  S= 0;
  for(P=B->first;P;P=P->next)
  {
    memcpy(R+S, P->data+P->start, P->len);
    S+= P->len;
  }

  *Rd= (void*) R;
  if (Rl) *Rl= S;
}

_BUFFER_PROTO void buffer_write(buffer_t *B, void *d, size_t l)
{
  struct buffer_node *P;
  size_t cp;

  while(l)
  {
    P= B->last;
    if (!P || (P->start+P->len)==P->size)
    {
      P= malloc(sizeof(*P)+B->blksize-1);
      P->len= 0;
      P->next= NULL;
      P->size= B->blksize;
      P->start= 0;
      if (!B->last) { B->last= B->first= P; }
      else { B->last->next= P; B->last= P; }
    }

    cp= P->size-P->len-P->start;
    if (cp>l) cp= l; 

    memcpy(P->data+P->len+P->start, d, cp);
    P->len+= cp;
    l-= cp;
    d= (unsigned char*) d + cp;
  }
}

_BUFFER_PROTO void buffer_append(buffer_t *dst, buffer_t *src_f)
{
  if (src_f->first!=NULL)
  {
    if (dst->first==NULL)
    {
      dst->first= src_f->first;
      dst->last= src_f->last;
    }
    else
    {
      dst->last->next= src_f->first;
      dst->last= src_f->last;
    }
  }
  free(src_f);
}



_BUFFER_PROTO size_t buffer_read(buffer_t *B, void *d, size_t l)
{
  size_t total;
  struct buffer_node *P;
  size_t cp;
  total= 0;

  while(l)
  {
    P= B->first;
    if (!P) break;  
    if (P->len==0)
    {
      B->first= P->next;
      if (!B->first) B->last= NULL;
      free(P);
      continue;
    } 
    cp= P->len;
    if (cp>l) cp= l;
    memcpy(d, P->data+P->start, cp);
    P->start+= cp;
    P->len-= cp;
    total+= cp;
    d= (unsigned char*) d + cp;
  }
  return total;
}



static int filter_files_byext(int nfiles,char **files, char **suffixes)
{
  int i, last;
  char *tmp;
  if (!nfiles) return 0;
  last= nfiles-1;
  for(i=0;i<last;i++)
  {
    if (files[i][0]!='F') continue;
    if (file_matches_ext_set(files[i],suffixes)) continue;
    tmp= files[last];
    files[last]= files[i];
    files[i]= tmp;
    last--;
    i--;
  } 
  if (files[last][0]!='F' || file_matches_ext_set(files[last],suffixes))
     return last+1;
  return last;
}

static int filter_files_byhid(int nfiles,char **files,int showhid)
{
  int i, last;
  char *tmp;
  if (!nfiles) return 0;
  if (showhid) return nfiles;
  last= nfiles-1;
  for(i=0;i<last;i++)
  {
    if (files[i][1]!='.') continue;
    tmp= files[last];
    files[last]= files[i];
    files[i]= tmp;
    last--;
    i--;
  } 
  if (files[last][1]!='.') return last+1;
  return last;
}

static int comparstr(const void *a,const void* b)
{
  return strcmp(*(const char**) a, *(const char**) b);
}

static void sort_files(int nfiles, char **files)
{
  qsort(files, nfiles, sizeof(files[0]), comparstr);
}


static char *sau_getcwd()
{
  char *buf; size_t siz;

  siz= 0;
  
  while(1)
  {
    if (!siz) { siz= 256;  }
         else { siz+= siz/2; free(buf); }
    buf= malloc(siz);
    if (getcwd(buf,siz)) return buf;
    if (errno!=ERANGE)   return NULL;
  }
}

static char *sau_gethome()
{
  char *x;
  x= getenv("HOME");
  if (!x) x= "/";
  return strdup(x);
}

static char* combine_path(char *dir,char *fn)
{
  char *R;
  int Ld;
  Ld= strlen(dir);
  R= malloc(Ld+strlen(fn)+2);
  if (Ld>0 && dir[Ld-1]=='/')
    sprintf(R,"%s%s",dir,fn);
  else
    sprintf(R,"%s/%s",dir,fn);
  return R;
}

static void split_initial_fn(char *init, char **Rdir, char **Rfil)
{
  char *dir; // , *fil;
  char *pfil,*pdir;
  char *dir_pfx;

  if (!init)
  {
    if (!(dir= sau_getcwd())) dir= sau_gethome();
    *Rdir= dir;
    *Rfil= NULL;
    return ;
  }
  
  pfil= strrchr(init,'/');
  if (pfil) 
  {
    pfil++;  
    pdir= strdup(init); 
    pdir[pfil-init]= 0; 
    if (!pfil[0]) pfil= NULL;
             else pfil= strdup(pfil);
  }
  else 
  { 
    pdir= NULL; 
  }

  if (init[0]=='/')
  {
    *Rdir= pdir;
    *Rfil= pfil;
    return ;
  }

  dir_pfx= sau_getcwd();
  if (!dir_pfx)
  {
    // we can't get the current directory, the rest of the 
    // path is meaningless except for the file name, if any.
    *Rdir= sau_gethome();
    *Rfil= pfil; 
    if (pdir) free(pdir);
    return ;
  }

  if (pdir) 
  {
    dir= malloc(strlen(pdir) + strlen(dir_pfx)+1);
    sprintf(dir,"%s/%s",dir_pfx,pdir);
    free(pdir);
    free(dir_pfx);
  }
  else
  {
    dir= dir_pfx;
  }

  *Rdir= dir;
  *Rfil= pfil;
}


static void filesel_make_screen(int *RX,int *RY,int *RW,int *RH,int title_w)
{
  int W,H,X,Y;
  int coor_screen[4];
  // this list should be the same order as in the enum definition
  static int dlg_widgets[]= {
    GUIRfilD1, GUIRfilD2, GUIRfilD3, GUIRfilD4, GUIRfilD5, GUIRfilD6,
    GUIRfilD7, GUIRfilD8, GUIRfilD9, GUIRfilD10, 
    GUIRfilHOME, GUIRfilREFRESH, GUIRfilOK, GUIRfilCANCEL, GUIRfilLIST,
    GUIRfilNAME,
  };

  W= imin2(imax2(imax2(400,x_window_width *8/10),title_w+2*filesel_pad),
           x_window_width);
  H= imin2(imax2(400,x_window_height*8/10),x_window_height);
  X= (x_window_width-W)/2;
  Y= (x_window_height-H)/2;

  coor_screen[0]= X; coor_screen[1]= Y;
  coor_screen[2]= W; coor_screen[3]= H;

  enter_screen(15, dlg_widgets, coor_screen);
  *RX= X; *RY= Y; *RW= W; *RH= H;

  gfx_fill_rect(0,X,Y,W, H,filesel_bg);
}

static void file_select_dialog
  (filesel_t *fs,int mode,char *ifil)
{
  char *title;
  text_entry_t *entry;
  int i;

  int W,H,X,Y;

  int button_w, button_h;
  int title_w, title_h, title_x, title_y;
  int list_w, list_h, list_x, list_y;
  // int dirst_w, dirst_h;
  int dirst_x, dirst_y;

  int homB_x, homB_y, refB_x, refB_y, okB_x, okB_y, canB_x, canB_y, 
      tex_x, tex_y, tex_w, tex_h;

  int fh1,fh3;

  gfx_text_size(1,"M",NULL,&fh1);
  gfx_text_size(3,"M",NULL,&fh3);

  title= (char*) (mode ? filesel_lbl_save : filesel_lbl_load);
  gfx_text_size(3, title, &title_w, &title_h);

  filesel_make_screen(&X,&Y,&W,&H, title_w);

  button_w= max_text_width(1, filesel_lbl_cancel, filesel_lbl_ok,
                              filesel_lbl_refresh, filesel_lbl_home, NULL) 
           + filesel_ipad;
  button_h= fh1 + filesel_ipad;

  title_x= (W - title_w)/2;
  title_y= filesel_pad;

  dirst_y= title_y + title_h + filesel_pad;
  dirst_x= filesel_dirst_left;

  homB_x= filesel_pad;
  homB_y= dirst_y + button_h + filesel_pad;

  refB_x= W - filesel_pad - button_w;
  refB_y= homB_y;

  tex_x= homB_x + button_w + filesel_pad;
  tex_y= homB_y;
  tex_w= refB_x - filesel_pad - tex_x;
  tex_h= button_h;

  list_y= tex_y + tex_h + filesel_pad;
  list_x= filesel_pad;
  list_w= imax2(1,W-list_x-filesel_pad);

  canB_x= refB_x;
  canB_y= H - filesel_pad - button_h;
  okB_x= canB_x - filesel_pad - button_w;
  okB_y= canB_y;

  list_h= okB_y - filesel_pad - list_y;


  widgets[GUIRfilHOME]= gfx_button(filesel_lbl_home,0,NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilHOME],
          X+homB_x, Y+homB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilHOME],1);

  widgets[GUIRfilREFRESH]= gfx_button(filesel_lbl_refresh,0,NULL,
                                          GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilREFRESH],
          X+refB_x, Y+refB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilREFRESH],1);

  widgets[GUIRfilOK]= gfx_button(filesel_lbl_ok, 0, NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilOK],
          X+okB_x, Y+okB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilOK],1);

  widgets[GUIRfilCANCEL]= gfx_button(filesel_lbl_cancel,0,NULL,GFXCLASS_BUTTON);
    button_set_position((gui_button_t*)widgets[GUIRfilCANCEL],
          X+canB_x, Y+canB_y, button_w, button_h); 
    gui_button_show((gui_button_t*)widgets[GUIRfilCANCEL],1);

  widgets[GUIRfilLIST]= gfx_list(0,0,1);
    gui_list_set_position((gui_list_t*)widgets[GUIRfilLIST],
          X+list_x, Y+list_y, list_w, list_h);
  widgets[GUIRfilNAME]= text_entry_new(ifil);
    entry= (text_entry_t*) widgets[GUIRfilNAME];
    entry->key_filter= filesel_tab_complete;
    entry->key_arg= fs;
    textentry_position(entry, X+tex_x, Y+tex_y, tex_w, tex_h);
    widget_show((widget_t*)entry, 1);
    set_focus(widgets[GUIRfilNAME]);

  for(i=GUIRfilD1;i<=GUIRfilD10;i++)
  {
    widgets[i]= gfx_button("", 0, NULL, GFXCLASS_TOGGLE);
    button_set_position((gui_button_t*)widgets[i], dirst_x, dirst_y, 
                        100,button_h);
  }

  for(i=GUIRfilD1;i<=GUIRfilNAME;i++)
    widgets[i]->number= i;

  fs->dirst_y= dirst_y;
  fs->x= X;
  fs->y= Y;
  fs->w= W;
  fs->h= H;
  fs->button_h= button_h;

  txt_print(0,3,filesel_fg, filesel_bg,X+title_x, Y+title_y, title, NULL, NULL);
}

static void populate_file_list
        (filesel_t *fs)
{
  char **files;
  int nfiles,shown,i;

  static const unsigned int ICf[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffedecec,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xff484445,0xffedecec,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xff211c1d,0xff484445,0xffedecec,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xff211c1d,
    0xff211c1d,0xff484445,0xffedecec,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  static const unsigned int ICd[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xfff8f8f8,0xfff8f8f8,0xfff8f8f8,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff5d595a,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff5d595a,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff5f5b5c,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff5f5b5c,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff646161,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff646161,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  static const unsigned int ICa[]= {
  16 | (1<<31), 16,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff908d8e,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff908d8e,0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xff908d8e,0xff211c1d,0xff211c1d,0xff211c1d,0xffffffff,
    0xffffffff,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xff908d8e,0xff211c1d,0xff211c1d,0xffffffff,0xffffffff,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,
    0xff211c1d,0xff211c1d,0xff211c1d,0xff211c1d,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xff908d8e,0xff211c1d,
    0xff211c1d,0xff908d8e,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xff908d8e,0xff908d8e,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,0xffffffff,
    0xffffffff,0xffffffff,0xffffffff,0xffffffff,
  };
  static const unsigned int *icons[3]= { ICf, ICd, ICa };

  if (fs->files) free(fs->files); // the whole array is one piece.
  files= list_files(fs->dir);
  file_types(fs->dir, files);

  gfx_list_show((gui_list_t*) widgets[GUIRfilLIST],0);
  gfx_list_clear((gui_list_t*) widgets[GUIRfilLIST]);
  for(nfiles=0;files[nfiles];nfiles++) ;

  shown= filter_files_byext(nfiles, files,fs->ext);
  shown= filter_files_byhid(shown, files, 0);
  sort_files(shown, files);
  for(i=0;i<shown;i++)
  {
    int isel;
    switch(files[i][0])
    {
    case 'F': isel= 0; break;
    case 'D': isel= 1; break;
    default:  isel= 2; break;
    }
    gfx_list_insert((gui_list_t*) widgets[GUIRfilLIST], -1,
            files[i]+1, files[i], icons[isel]);
  }
  fs->files= files;
  fs->nfiles= nfiles;
  fs->shown= shown;
  gfx_list_show((gui_list_t*) widgets[GUIRfilLIST],1);
}


static int filesel_tab_complete(void *arg,void *te,gfx_event_t *event)
{
  if (event->type!=GFXEV_KEY_PRESS) return 0;
  switch(event->key)
  {
  case GFX_K_TAB:
     break;
  case GFX_K_RETURN:
     event->type= GUIRfilOK;
     break;
  case GFX_K_ESCAPE:
     event->type= GUIRfilCANCEL;
     break;
  }
  return 0; 
}



static char **sepdir(char *name)
{
  char **R;
  int N,done;
  char *k,*str;

  R= NULL;
/* 
    /home/dodo/foo   : 4 components /,home,dodo,foo
     home/dodo/foo   : 3 components home,dodo,foo
*/
again:
  N= 0;
  str= name;

  if (str[0]=='/')
  {
    if (R) R[N]= strdup("/"); 
    N++;
    while(str[0]=='/') str++;
  }

  done= 0;
  if (!str[0]) done= 1;
  while(!done)
  {
    k= strchr(str,'/');
    if (!k) { k= str+strlen(str); done= 1; }
    if (R)
    {
      R[N]= malloc(k-str+1);
      memcpy(R[N], str, k-str);
      R[N][k-str]= 0;
    }
    N++;
    str= k+1;
  }

  if (R) { R[N]= NULL; return R; }
  R= malloc(sizeof(*R)*(N+1));
  goto again;
}


static void filesel_hide_buttons()
{
  int i;
  for(i=GUIRfilD1;i<=GUIRfilD10;i++)
    gui_button_show((gui_button_t*) widgets[i], 0);
}

static void filesel_show_buttons(filesel_t *fs)
{
  int i;
  for(i=fs->dir_start;i<=fs->dir_end;i++)
    gui_button_show((gui_button_t*) widgets[i-fs->dir_start+GUIRfilD1], 1);
}

static void filesel_render_dirstack(filesel_t *fs)
{
  int i;
  char *dn;

  filesel_hide_buttons();
  dn= remove_trailing_slash(strdup(fs->dir));

again:

  for(i=0;i<fs->n_dirs;i++)
    if (!strcmp(dn,fs->dirs[i].dir)) break;
  if (i!=fs->n_dirs)
  {
    int st,en,K;
    K= i;
    st= imax2(0,K-4);
    en= imin2(K+5,fs->n_dirs-1);
    if (fs->dir_start==st && fs->dir_end==en)
    {
      filesel_activate_button(fs, K-st);
      filesel_show_buttons(fs);
      return ;
    }
    fs->dir_start= st;
    fs->dir_end= en;
    filesel_render_buttons(fs);
    filesel_activate_button(fs, K-st);
    filesel_show_buttons(fs);
    return ;
  }

  filesel_create_buttons(fs);
  fs->dir_start= fs->dir_end= -1;
  goto again;
}

static char* remove_trailing_slash(char *dn)
{
  int L;
  L= strlen(dn);
  while(L>1 && dn[L-1]=='/') { dn[L-1]= 0; L--; }
  return dn;
}

static void filesel_create_buttons(filesel_t *fs)
{
  int i;
  char *dn;
  char **comp;
  int ncomp;
  char *Z;

  dn= remove_trailing_slash(strdup(fs->dir));

  comp= sepdir(dn);
  for(ncomp=0;comp[ncomp];ncomp++) ;

  filesel_free_buttons(fs);
  fs->n_dirs= ncomp;
  fs->dirs= calloc(ncomp,sizeof(fs->dirs[0]));
  Z= NULL;
  for(i=0;i<fs->n_dirs;i++)
  {
    fs->dirs[i].dir= fs_combine(Z, comp[i]);
    fs->dirs[i].label= comp[i];
    Z= fs->dirs[i].dir;
  }
  free(comp);
  free(dn);
}

static void filesel_free_buttons(filesel_t *fs)
{
  int i;
  if (!fs->dirs) return ;
  for(i=0;i<fs->n_dirs;i++)
  {
    free(fs->dirs[i].label);
    free(fs->dirs[i].dir);
  }
  free(fs->dirs);
  fs->dirs= NULL;
  fs->n_dirs= 0;
}

static void filesel_activate_button(filesel_t *fs,int idx)
{
  int i;
  for(i=0;i<=fs->dir_end-fs->dir_start;i++)
    button_set_state((gui_button_t*)widgets[GUIRfilD1+i], i==idx);
}

static void filesel_render_buttons(filesel_t *fs)
{
  int i;
  int x,y;

  y= fs->y+fs->dirst_y;
  x= fs->x+filesel_dirst_left;

  gfx_fill_rect(1, fs->x, y, fs->w, fs->button_h, filesel_bg);
  
  for(i=fs->dir_start;i<=fs->dir_end;i++)
  {
    gui_button_t *B;
    B= (gui_button_t*) widgets[i-fs->dir_start+GUIRfilD1];
    button_set_text(B, fs->dirs[i].label);
    if (!fs->dirs[i].width)
    {
      gfx_text_size(1, fs->dirs[i].label, &fs->dirs[i].width, NULL);
      fs->dirs[i].width+= 2*filesel_dirst_ipad;
    }
    button_set_position(B, x, y, fs->dirs[i].width, fs->button_h);
    x+= filesel_dirst_pad+fs->dirs[i].width;
    button_set_state(B, 0);
  }
}

static char *com3(char *x,char *y,char *z)
{
  char *R;
  int Lx,Ly,Lz;
  Lx= strlen(x); Ly= strlen(y); Lz= strlen(z);
  R= malloc(Lx+Ly+Lz+1);
  memcpy(R, x, Lx); memcpy(R+Lx,y,Ly); memcpy(R+Lx+Ly,z,Lz);
  R[Lx+Ly+Lz]= 0;
  return R;
}

static char *com2(char *x,char *y)
{
  char *R;
  int Lx,Ly;
  Lx= strlen(x); Ly= strlen(y);
  R= malloc(Lx+Ly+1);
  memcpy(R, x, Lx); memcpy(R+Lx,y,Ly);
  R[Lx+Ly]= 0;
  return R;
}

static char *fs_combine(char *x,char *y)
{
  if (!x) return strdup(y);
  if (x[0]=='/' && x[1]==0) return com2(x,y);
  return com3(x,"/",y);
}


static void filesel_activate_dir(filesel_t *fs, int idx)
{
  filesel_activate_button(fs,idx);
  filesel_setdir(fs,fs->dirs[idx+fs->dir_start].dir);
  populate_file_list(fs);
}

static void filesel_setdir(filesel_t *fs,char *dir)
{
  if (fs->dir) free(fs->dir);
  fs->dir= strdup(dir);
}

static widget_t *gui_canvas_new()
{
  gui_canvas_t *CC;
  CC= calloc(1,sizeof(*CC));
  CC->widget.klass=GFXCLASS_CANVAS;
  CC->scrollv= (scrollbar_t*) scrollbar_new(1, 0.0,1.0,0.1,0,CC,gui_canvas_scrollv);
  CC->scrollh= (scrollbar_t*) scrollbar_new(0, 0.0,1.0,0.1,0,CC,gui_canvas_scrollh);

  CC->click1= CC->click3= -1;
  return &CC->widget;
}

static void gui_canvas_update_click_handlers(gui_canvas_t *CC)
{
  CC->click1= install_or_modify_click
       (CC->click1, &CC->enabled, gui_canvas_click, CC,
        CC->widget.x, CC->widget.y, CC->port_w, CC->port_h, 1);
  CC->click3= install_or_modify_click
       (CC->click3, &CC->enabled, gui_canvas_click, CC,
        CC->widget.x, CC->widget.y, CC->port_w, CC->port_h, 3);
}

static void gui_canvas_position(gui_canvas_t *CC,int x,int y,int w,int h)
{
  widget_t *W;
  W= &CC->widget;
  W->x= x;
  W->y= y;
  W->w= w;
  W->h= h;

  scrollbar_position(CC->scrollh, x, y+h-gui_scrollbar_height,w, 
                     gui_scrollbar_height);
  scrollbar_position(CC->scrollv, x+w-gui_scrollbar_width, y, 
                     gui_scrollbar_width, h);
  gui_canvas_arrange_scrollbars(CC);
}


static int gui_canvas_setbuffer(gui_canvas_t *CC,int new_w,int new_h)
{
  uint32_t *nb;

  if (new_w<=0) new_w= CC->buffer_w;
  if (new_h<=0) new_h= CC->buffer_h;

  if (new_w==CC->buffer_w && new_h==CC->buffer_h) return 1;

  nb= calloc(new_w*new_h, sizeof(uint32_t));
  if (CC->buffer)
  {
    int y,x;
    int cw,ch;
    cw= imin2(CC->buffer_w, new_w);
    ch= imin2(CC->buffer_h, new_h);
    for(y=0;y<ch;y++)
      for(x=0;x<cw;x++)
        nb[y*new_w + x]= CC->buffer[y*CC->buffer_w+x];
    free(CC->buffer);
  }
  CC->buffer= nb;
  CC->buffer_w= new_w;
  CC->buffer_h= new_h;

  return 0;
}

static void gui_canvas_arrange_scrollbars
   (gui_canvas_t *CC)
{
  int dw,dh,bw,bh;
  int hor,ver;
  widget_t *W;

  dw= CC->widget.w;
  dh= CC->widget.h;

  bw= CC->buffer_w;
  bh= CC->buffer_h;

  hor= 0;
  ver= 0;
  if (bw>dw) { hor= 1; dh-= gui_scrollbar_height; }
  if (bh>dh) { ver= 1; dw-= gui_scrollbar_width; }
  if (!hor && bw>dw) { hor= 1; dh-= gui_scrollbar_height; }

  if (dw<=0 || dh<=0) { CC->too_small=1; return ; }

  CC->port_w= dw;
  CC->port_h= dh;

  if (hor)
  {
    if (CC->pos_x+CC->port_w>bw)
      CC->pos_x= imax2(0,bw-CC->port_w);

    W= &CC->scrollh->widget;
    scrollbar_relayout(CC->scrollh, W->x, W->y, CC->port_w, W->h,
          (double)CC->pos_x/CC->buffer_w,
          (double)imin2(CC->pos_x+CC->port_w,CC->buffer_w)/CC->buffer_w, 0.1);
  }
  else
  {
    if (CC->have_scrollh)
      scrollbar_show(CC->scrollh, 0);
  }
  CC->have_scrollh= hor;

  if (ver)
  {
    if (CC->pos_y+CC->port_h>bh)
       CC->pos_y= imax2(0,bh-CC->port_h);
    W= &CC->scrollv->widget;
    scrollbar_relayout(CC->scrollv, W->x, W->y, W->w, CC->port_h,
          (double)CC->pos_y/CC->buffer_h,
          (double)imin2(CC->pos_y+CC->port_h,CC->buffer_h)/CC->buffer_h, 0.1);
  }
  else
  {
    if (CC->have_scrollv)
       scrollbar_show(CC->scrollv,0);
  }
  CC->have_scrollv= ver;

  gui_canvas_update_click_handlers(CC);
}

static void gui_canvas_paint_scrollbars(gui_canvas_t *CC)
{
  if (!CC->enabled) return ;
  if (CC->have_scrollv) scrollbar_show(CC->scrollv,1);
  if (CC->have_scrollh) scrollbar_show(CC->scrollh,1);
}

static void gui_canvas_paint_buffer(gui_canvas_t *CC)
{
  if (!CC->enabled) return ;
  if (!CC->buffer)
  {
//
 //   gfx_fill_rect(GFX_UPDATE,CC->widget.x,CC->widget.y,
  //                           CC->port_w, CC->port_h, 0xfF00ff);
    return ;
  }
  gfx_put(GFX_UPDATE, CC->buffer, CC->buffer_w, CC->buffer_h,
            CC->pos_x, CC->pos_y,
           CC->widget.x, CC->widget.y, CC->port_w, CC->port_h);
}

static void gui_canvas_draw_all(gui_canvas_t *CC)
{
  gui_canvas_paint_scrollbars(CC);
  gui_canvas_paint_buffer(CC);
  if (!CC->enabled) return ;
  if (CC->port_w>CC->buffer_w)
    gfx_fill_rect(GFX_UPDATE, 
        CC->widget.x+CC->buffer_w, CC->widget.y, 
                    CC->port_w-CC->buffer_w, CC->port_h,0xFFffff);
  if (CC->port_h>CC->buffer_h)
    gfx_fill_rect(GFX_UPDATE, 
        CC->widget.x, CC->widget.y+CC->buffer_h, 
                    CC->port_w, CC->port_h-CC->buffer_h,0xffFFff);
}

static void gui_canvas_update(gui_canvas_t *CC,int x,int y,int w,int h)
{
  int sx,sy,ex,ey;
  if (w<=0 || h<=0 || !CC->enabled) return ;
  sx= imax2(imax2(x, 0), CC->pos_x);
  sy= imax2(imax2(y, 0), CC->pos_y);

  ex= imin2(imin2(x+w,CC->buffer_w), CC->pos_x+CC->port_w);
  ey= imin2(imin2(y+h,CC->buffer_h), CC->pos_y+CC->port_h);

  if (ex<=sx || ey<=sy) return ;
  gfx_put(GFX_UPDATE, CC->buffer, CC->buffer_w, CC->buffer_h,
             sx, sy,
             sx-CC->pos_x+CC->widget.x, sy-CC->pos_y+CC->widget.y,
             ex-sx, ey-sy);
}


static void gui_canvas_clipped_hline
   (gui_canvas_t *CC,int color,int x1,int x2,int y)
{
  int x, bw;
  if (y<0 || y>=CC->buffer_h) return ;
  bw= CC->buffer_w;
  x1= imax2(0,x1);
  x2= imin2(x2,bw-1);
  for(x=x1;x<=x2;x++) CC->buffer[y*bw+x]= color;
}


static void gui_canvas_clipped_vline
   (gui_canvas_t *CC,int color,int x,int y1,int y2)
{
  int y, bw;
  if (x<0 || x>=CC->buffer_w) return ;
  bw= CC->buffer_w;
  y1= imax2(0,y1);
  y2= imin2(y2,CC->buffer_h-1);
  for(y=y1;y<=y2;y++) CC->buffer[y*bw+x]= color;
}



static gui_canvas_t *gui_canvas_get(int wno)
{
  widget_t *W;
  W= get_widget(wno);
  if (W && W->klass==GFXCLASS_CANVAS) return (gui_canvas_t*) W;
  return NULL;
}

static void gui_canvas_scrollv(gui_canvas_t *CC,double start,double end)
{
  CC->pos_y= start*CC->buffer_h;
  if (CC->pos_y+CC->port_h>CC->buffer_h)
   CC->pos_y=imax2(0,CC->buffer_h-CC->port_h);
  gui_canvas_paint_buffer(CC);
}
static void gui_canvas_scrollh(gui_canvas_t *CC,double start,double end)
{
  CC->pos_x= start*CC->buffer_w;
  if (CC->pos_x+CC->port_w>CC->buffer_w)
   CC->pos_x=imax2(0,CC->buffer_w-CC->port_w);
  gui_canvas_paint_buffer(CC);
}

static int gui_canvas_click(void *arg,gfx_event_t *ev)
{
  gui_canvas_t *CC;
  CC= arg;
  ev->type= GFXEV(CC->widget.number,BUTTON_PRESS);
  ev->x= ev->x - CC->widget.x + CC->pos_x;
  ev->y= ev->y - CC->widget.y + CC->pos_y;
  install_release_handler(CC, gui_canvas_release);
  return 0;
}

static int gui_canvas_release(void *arg,gfx_event_t *ev)
{
  gui_canvas_t *CC;
  CC= arg;
  ev->type= GFXEV(CC->widget.number,BUTTON_RELEASE);
  ev->x= ev->x - CC->widget.x + CC->pos_x;
  ev->y= ev->y - CC->widget.y + CC->pos_y;
  return 0;
}


static int gui_canvas_motion(void *arg, gfx_event_t *ev)
{
  gui_canvas_t *CC;
  int x,y, minx, maxx, miny, maxy;

  CC= arg;
  x= ev->x;
  y= ev->y;
  if (!range_test(x,CC->widget.x, CC->port_w) ||
      !range_test(y,CC->widget.y, CC->port_h))
    return 1;
  x= x - CC->widget.x + CC->pos_x;
  y= y - CC->widget.y + CC->pos_y;

  if (CC->rs_x0==x && CC->rs_y0==y) return 1;

  minx= imin2(imin2( CC->rs_x0, CC->rs_x1 ), x);
  maxx= imax2(imax2( CC->rs_x0, CC->rs_x1 ), x);
  miny= imin2(imin2( CC->rs_y0, CC->rs_y1 ), y);
  maxy= imax2(imax2( CC->rs_y0, CC->rs_y1 ), y);

  gui_canvas_draw_recsel(CC);
  CC->rs_x1= x;
  CC->rs_y1= y;
  gui_canvas_draw_recsel(CC);
  gui_canvas_update(CC, minx, miny, maxx-minx+1, maxy-miny+1);
  return 1;
}


static void gui_canvas_draw_recsel(gui_canvas_t *CC)
{
  int x,y,w,h,C;

  x= imin2(CC->rs_x0, CC->rs_x1);
  y= imin2(CC->rs_y0, CC->rs_y1);

  w= imax2(CC->rs_x0, CC->rs_x1) - x+1;
  h= imax2(CC->rs_y0, CC->rs_y1) - y+1;

  C=  (w<2) ? 0 : 1;
  C|= (h<2) ? 0 : 2;
  switch(C)
  {
  case 0: break ;
  case 1: gui_canvas_invert_hline(CC,x, x+w-1, y); break ;
  case 2: gui_canvas_invert_vline(CC,x, y, y+h-1); break ;
  case 3: gui_canvas_invert_hline(CC,x, x+w-1, y);
          gui_canvas_invert_hline(CC,x, x+w-1, y+h-1);
          gui_canvas_invert_vline(CC,x, y+1, y+h-2);
          gui_canvas_invert_vline(CC,x+w-1, y+1, y+h-2);
          break;
  }
}

static void gui_canvas_invert_hline(gui_canvas_t *CC, int x1, int x2, int y)
{
  int x;
  x1= imax2(0,x1);
  x2= imin2(CC->buffer_w-1, x2);
  if (range_test(y, 0, CC->buffer_h))
    for(x=x1;x<=x2;x++)
      CC->buffer[CC->buffer_w*y+x] ^= 0xFFffFF;
}

static void gui_canvas_invert_vline(gui_canvas_t *CC,int x,int y1, int y2)
{
  int y;
  y1= imax2(0,y1);
  y2= imin2(CC->buffer_h-1,y2);
  if (range_test(x, 0, CC->buffer_w))
    for(y=y1;y<=y2;y++)
      CC->buffer[CC->buffer_w*y+x] ^= 0xFFffFF;
}


static int gui_timer_schedule
  (unsigned int msecs, int (*f)(void*,gfx_event_t*), void *a)
{
  static int last_timer;
  if (!screen) return -1;

  if (screen->n_timers==screen->s_timers)
  {
    if (!screen->s_timers) 
    {
      screen->s_timers= 10;
      screen->timers= malloc(sizeof(screen->timers[0])*screen->s_timers);
    }
    else
    {
      screen->s_timers+= screen->s_timers /2; 
      screen->timers= realloc(screen->timers,
                sizeof(screen->timers[0])*screen->s_timers);
    }
  }

  gui_timer_t *tt;
  tt= screen->timers + screen->n_timers;
  screen->n_timers++;
  tt->func= f;
  tt->arg= a;
  tt->value= msecs;
  tt->ident= last_timer++;
  return tt->ident;
}

 // this function returns 0 if there are no timers
 // it returns 1 if there is a timer and the remaining
 // time for it is stored in Rmsecs
static int gui_timer_get(unsigned int *Rmsecs)
{
  int i;
  unsigned int min;
  if (!screen || !screen->n_timers) return 0;
  min= screen->timers[0].value;
  for(i=1;i<screen->n_timers;i++)
     min = min < screen->timers[i].value ? min : screen->timers[i].value;
  *Rmsecs= min;
  return 1;
}

static int gui_timer_elapsed(unsigned int elap,gfx_event_t *event)
{
  int i,R;
  int T;
  if (!screen || !screen->n_timers) return 0;
  R= 0;
  T= screen->n_timers;
  for(i=0;i<T;i++)
  {
    gui_timer_t *tt;
    tt= screen->timers+i;
    if (elap<tt->value) { tt->value-= elap; continue; }
    if (!R)
    {
      int (*F)(void *,gfx_event_t*);
      void *A;
      F= tt->func;
      A= tt->arg;
      screen->timers[i]= screen->timers[T-1];
      i--;
      screen->timers[T-1]= screen->timers[screen->n_timers-1];
      T--;
      screen->n_timers--;
      if (F)
        R= (*F)(A,event); 
      continue;
    }
    tt->value= 0;
  }
  return R;
}

static void gui_timer_cancel(int ident)
{
  int i;
  if (ident==-1 || !screen || !screen->n_timers) return ;
  for(i=0;i<screen->n_timers;i++)
   if (screen->timers[i].ident==ident)
   {
    screen->timers[i]= screen->timers[screen->n_timers-1];
    screen->n_timers--;
    break;
   }
}

static widget_t* gui_spinner(int type, int frac)
{
  gui_spinner_t *SS;

  SS= calloc(1,sizeof(*SS));
  SS->widget.klass= GFXCLASS_SPINNER;
  SS->type= type;
  SS->frac= frac;
    // FIXME: colors should be resources
  SS->label= gfx_label(1,0x00,0xffFFff,'R',"");
  gui_button_init(&SS->less,NULL,'T',RESspinLESS,
                    gui_spinner_less_click, gui_spinner_less_release, SS);
  gui_button_init(&SS->more,NULL,'T',RESspinMORE,
                    gui_spinner_more_click, gui_spinner_more_release, SS);
  spinner_lessb_width= RESspinLESS[0] & ~(1<<31);
  spinner_moreb_width= RESspinMORE[0] & ~(1<<31);
  SS->intq= 1;
  SS->floq= 1.0;
  SS->timer= -1;
  return &SS->widget;
}


static void gui_spinner_destroy(gui_spinner_t *SS)
{
  gui_button_destroy(&SS->less);
  gui_button_destroy(&SS->more);
  widget_destroy(SS->label);
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->timer= -1;
}


static void gui_spinner_set_position
   (gui_spinner_t* LL,int x,int y,int w,int h)
{
  LL->widget.x= x;
  LL->widget.y= y;
  LL->widget.w= w;
  LL->widget.h= h;
    // FIXME: paddings should be resources
  button_set_position(&LL->less, x,y, spinner_lessb_width, h);
  button_set_position(&LL->more, x+w-spinner_moreb_width,y,
                                 spinner_moreb_width, h);
  widget_move(LL->label, x+spinner_lessb_width+5, y, 
      w - 10 - spinner_lessb_width-spinner_moreb_width , h);
}


static void gui_spinner_show(gui_spinner_t *S, int show)
{
  if ((S->enabled && show) || (!S->enabled && !show)) return ;

  if (!show)
  {
    S->enabled= 0;
    gui_button_show(&S->less,0);
    gui_button_show(&S->more,0);
    widget_show(S->label, 0);
    return ;
  }

  S->enabled= 1;
  gui_button_show(&S->less,1);
  gui_button_show(&S->more,1);
  gui_spinner_render(S);
  widget_show(S->label, 1);
}

static void gui_spinner_render(gui_spinner_t *S)
{
  char buf[40];
  if (S->type=='F')
  {
    sprintf(buf,"%f",S->flov);
  }
  else
    sprintf(buf,"%d", S->intv);
  gui_label_set_text((gui_label_t*) S->label,buf);
}

static int gui_spinner_delta(gui_spinner_t *S, gfx_event_t *event, int dir)
{
  int iV; double fV;
  if (S->type=='F')
  {
    fV= S->flov;
    S->flov+= dir*S->floq;
    spinner_apply_limits(S);
    if (S->flov!=fV)
    {
       gui_spinner_render(S);
       event->type= S->widget.number;
       event->flo0= S->flov;
       return 0; 
    }
    return 1;
  }
  iV= S->intv;
  S->intv += dir*S->intq;
  spinner_apply_limits(S);  
  if (S->intv!=iV)
  {
     gui_spinner_render(S);
     event->type= S->widget.number;
     event->key= S->intv;
     return 0;
  }
  return 1;
}

static void spinner_apply_limits(gui_spinner_t* S)
{
  if (S->type=='F')
  {
     if ((S->limflags&SPINNER_MIN) && S->flov<S->flomin) S->flov= S->flomin;
     if ((S->limflags&SPINNER_MAX) && S->flov>S->flomax) S->flov= S->flomax;
  }
  else
  {
     if ((S->limflags&SPINNER_MIN) && S->intv<S->intmin) S->intv= S->intmin;
     if ((S->limflags&SPINNER_MAX) && S->intv>S->intmax) S->intv= S->intmax;
  }
}

static gui_spinner_t *get_spinner_widget(int wno)
{
  widget_t *W;
  if (!(W=get_widget(wno))) return NULL;
  return W->klass==GFXCLASS_SPINNER ? (gui_spinner_t*) W : NULL;
}


static void gui_spinner_remove_timer
  (gui_spinner_t *SS)
{
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->timer= -1;
}

static void gui_spinner_init_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*))
{
  if (SS->timer!=-1) gui_timer_cancel(SS->timer);
  SS->count= 0;
  gui_spinner_reset_timer(SS,F);
}

static void gui_spinner_reset_timer
  (gui_spinner_t *SS,int (*F)(void*,gfx_event_t*))
{
  int delay;
  SS->count++;
  if (SS->count>50) delay= 85;
  else if (SS->count>10) delay= 150;
  else delay= 200;

  SS->timer= gui_timer_schedule(delay, F, SS);
}

static int gui_spinner_less_release(void *arg,gfx_event_t *event)
{
  gui_spinner_remove_timer(arg);
  return 0;
}

static int gui_spinner_less_click(void *arg,gfx_event_t *event)
{
  gui_spinner_init_timer(arg, gui_spinner_less_timeout);
  return gui_spinner_delta(arg, event,-1);
}

static int gui_spinner_less_timeout(void *arg,gfx_event_t *event)
{
  gui_spinner_reset_timer(arg, gui_spinner_less_timeout);
  return !gui_spinner_delta(arg, event,-1);
}

static int gui_spinner_more_release(void *arg,gfx_event_t *event)
{
  gui_spinner_remove_timer(arg);
  return 0;
}

static int gui_spinner_more_click(void *arg,gfx_event_t *event)
{
  gui_spinner_init_timer(arg, gui_spinner_more_timeout);
  return gui_spinner_delta(arg, event,1);
}

static int gui_spinner_more_timeout(void *arg,gfx_event_t *event)
{
  gui_spinner_reset_timer(arg, gui_spinner_more_timeout);
  return !gui_spinner_delta(arg, event,1);
}


static widget_t *gui_logview()
{
  gui_logview_t *B;

  B= calloc(1,sizeof(*B));
  // B->click_handler= -1;

  B->widget.klass= GFXCLASS_LOGVIEW;
  B->widget.show= gui_logview_show;
  B->widget.hide= gui_logview_hide;
  B->widget.destroy= gui_logview_destroy;
  B->widget.position= gui_logview_position;
  return &B->widget;
}

static void gui_logview_destroy(widget_t *W)
{
  int i;
  gui_logview_t *L= (gui_logview_t *)W;
  if (L->lines)
  {
    for(i=0;i<L->nlines;i++) free(L->lines[i]);
    free(L->lines);
    L->lines= NULL;
  }
  // remove_click_handler(L->click_handler);
}

static void logview_scroll_up(gui_logview_t *L, int yof)
{
  int x,y;
  int cx, cy, cw, ch;
  unsigned int color;

  cx= L->px;
  cy= L->py;
  cw= L->pw;
  ch= L->ph;
  if (clip_for_rect(&cx, &cw, x_window_width)) return ;
  if (clip_for_rect(&cy, &ch, x_window_height)) return ;
  for(y=cy;y<cy+ch-yof;y++)
   for(x=cx;x<cx+cw;x++)
     x_image_data[y][x]= x_image_data[y+yof][x];

  color= color_u_to_s(logview_background);
  
  for(;y<cy+ch;y++)
   for(x=cx;x<cx+cw;x++)
     x_image_data[y][x]= color;
}

static void logview_print_line
   (gui_logview_t *L,char *line, 
    int nonl,int *Ruys,int *Ruye)
{
  unsigned char *td; int tw,th;
  int cw;
  int delta;
  get_text_data(1,line,&tw,&th,NULL, &td);
  delta= L->cy+th+2 - L->ph;
  if (delta>0)
  {
    *Ruys= 0; *Ruye= L->ph;
    logview_scroll_up(L, delta);
    L->cy-= delta;
  }
  else { *Ruys= L->cy; *Ruye= L->cy+th; }
  cw= imin2(tw, L->pw - L->cx);
  if (cw>0)
  {
    blend_graymap(GFX_BACKGND,logview_foreground, logview_background,
                   td, tw, th, 0, 0, 
                   L->cx+L->px, L->cy+L->py, cw, th);
    if (!nonl) { L->cy+= th + 2; L->cx= 0; }
    else { L->cx+= cw; }
  } 
  free(td);
}


static void logview_render(gui_logview_t *L)
{
  int i;
  int dum;

  L->cx= 0;
  L->cy= 0;

  gfx_fill_rect(0,L->widget.x,L->widget.y, L->widget.w,L->widget.h,
                  logview_background);

  for(i=0;i<L->nlines-1;i++)
   logview_print_line(L,L->lines[i],0,&dum,&dum);
  if (L->nlines) logview_print_line(L,L->lines[L->nlines-1],
                                    L->last_line_incomplete,&dum,&dum);

  gfx_update(L->widget.x, L->widget.y,L->widget.w,L->widget.h);
}


static void gui_logview_show(widget_t *W)
{
  logview_render((gui_logview_t*)W);
}

static void gui_logview_hide(widget_t *W) { }

static void gui_logview_position(widget_t *W, int x,int y,int w,int h)
{
  gui_logview_t *L= (gui_logview_t*) W;
  int nl;
  char **ll;
  int i;

  widgetpos(W,x,y,w,h);
  if (!L->fh) get_text_data(1,"M",NULL,&L->fh,NULL,NULL);
  nl= (w+L->fh-1)/L->fh;
  if (nl!=L->slines)
  {
    ll= calloc(sizeof(*ll),nl);
    if (nl>L->nlines)
      for(i=0;i<L->nlines;i++) ll[i]= L->lines[i];
    else
    {
      for(i=0;i<nl;i++)
         ll[nl-1-i]= L->lines[L->nlines-i-1];
      for(i=0;i<L->nlines-nl;i++) free(L->lines[i]);
      L->nlines= nl;
    }
    if (L->lines) free(L->lines[i]);
    L->lines= ll;
    L->slines= nl;
  }
  L->pw= w-2*logview_pad;
  L->ph= h-2*logview_pad;
  L->px= x+logview_pad;
  L->py= y+logview_pad;
  if (W->shown) logview_render(L);
}


static void logview_write(gui_logview_t *L, const char *txt, size_t len)
{
  char *E;

  while(len)
  {
    E= memchr(txt, '\n', len);
    if (!E) 
    {
       logview_put_line(L, txt, len, 1);
       len= 0;
    }
    else if (E==txt)
    {
       logview_put_line(L, " ",1, 0);
       txt= E+1;
       len--;
    }
    else
    {
       logview_put_line(L,txt,E-txt,0);
       len-= E-txt+1;
       txt= E+1;
    }
  }
}

static void logview_put_line
   (gui_logview_t *L, const char *txt, size_t len, int nonl)
{
  char *ll,*pp,*oo;
  size_t lo;
  int sy,ey;
  int i;

again:
  if (L->last_line_incomplete)
  {
    if (!L->nlines) { L->last_line_incomplete= 0; goto again; }
    oo= L->lines[L->nlines-1];
    lo= strlen(oo);
    ll= malloc(lo+len+1);
    memcpy(ll, oo, lo);
    memcpy(ll+lo, txt, len);
    ll[len+lo]= 0;
    free(oo);
    L->lines[L->nlines-1]= ll;
    pp= ll+lo;
  }
  else 
  {
    if (L->nlines==L->slines)
    {
      if (L->widget.shown && L->nlines)
      {
        free(L->lines[0]);
        for(i=0;i<L->nlines-1;i++) L->lines[i]= L->lines[i+1];
        L->nlines--;
      }
      else 
      {
        if (!L->slines) 
          { L->slines= 50; L->lines= malloc(sizeof(L->lines[0])*L->slines); }
        else
          { L->slines+= L->slines/2; L->lines= realloc(L->lines,
                                             sizeof(L->lines[0])*L->slines); }
      }
    }
    ll= malloc(len+1);
    memcpy(ll,txt,len);
    ll[len]= 0;
    L->lines[L->nlines]= ll;
    L->nlines++;
    pp= ll;
  }
  L->last_line_incomplete= nonl;
  if (L->widget.shown)
  {
    logview_print_line(L, pp, nonl,&sy,&ey);
    gfx_update(L->px, L->py+sy, L->pw, ey-sy);
  }
}


void gfx_geometry(unsigned int *W, unsigned int *H)
{
  if (W) *W= x_window_width;
  if (H) *H= x_window_height;
}

void gfx_monitor_file(int fd, int ident, int R,int W,int X)
{
  file_monitor_t *F;
  if (n_fmon==100) return ;
  if (!R && !W && !X) return ;
  F= fmon + n_fmon;
  n_fmon++;
  F->fd= fd;
  F->ident= ident;
  F->events= (R?1:0) | (W?2:0) | (X?4:0);
}

void gfx_stop_monitor_file(int fd,int ident)
{
  int i;
  for(i=0;i<n_fmon;i++)
    if ( (fd==-1 || fmon[i].fd==fd) &&
         (ident==-1 || fmon[i].ident==ident))
    {
      fmon[i]= fmon[n_fmon-1];
      n_fmon--;
      i--;
    }
}


void gfx_leave_screen()
{
  screen_t *S;
  int i;
  if (!screen) return ;
  S= screen;

  for(i=0;i<S->n_widgets;i++)
    if (widgets[S->widgets[i]])
    {
      widget_destroy(widgets[S->widgets[i]]);
      widgets[S->widgets[i]]= NULL;
    }
  if (S->click_handlers) free(S->click_handlers);
  if (S->backstore)
  {
     put_server_pix(S->backstore, 0,0,S->back_w,S->back_h);
     gfx_update(0,0,x_window_width,x_window_height);
     free(S->backstore);
  }
  free_rgroups(S);

  screen= S->next;
  free(S);

  if (screen)
  {
    widget_t *W;
    W= screen->focus_widget;
    if (W && W->focus)
    {
      (*W->focus)(W,1); 
      W->has_focus= 1;
    }
  }
}


void gfx_set_state(int wno, int state)
{
  widget_set_state(get_widget(wno),state);
}

int  gfx_get_state(int wno)
{
  return widget_get_state(get_widget(wno));
}

int  gfx_get_selected(int wno)
{
  return widget_get_selected(get_widget(wno));
}

void gfx_set_selected(int wno,int sel)
{
  widget_set_selected(get_widget(wno),sel);
}

void gfx_set_text(int wno,char *str)
{
  widget_set_text(get_widget(wno),str);
}

void gfx_set_fgbg(int wno, int fg, int bg)
{
  widget_set_fgbg(get_widget(wno),fg,bg);
}

void gfx_insert(int wno,int pos, char *text,void *user,unsigned int* icon)
{
  widget_insert(get_widget(wno),pos,text,user,icon);
}

void gfx_remove(int wno, int pos, void **Ruser)
{
  widget_remove(get_widget(wno),pos, Ruser);
}

char* gfx_get_text(int wno)
{
  return widget_get_text(get_widget(wno));
}

void gfx_clear(int wno)
{
  return widget_clear(get_widget(wno));
}


void gfx_focus(int wno)
{
  widget_t *W;
  W= widgets[wno];
  set_focus(W);
}




void gfx_text_data(int font, const char *str, 
                   int *Rw, int *Rh,int *Ra,unsigned char **Rd)
{
  get_text_data(font,str,Rw,Rh,Ra,Rd);
}


void gfx_scrollbar_set(int wno, double start, double end, double step)
{
  scrollbar_t *SB;
  SB= (scrollbar_t*) get_widget(wno);
  if (!SB|| SB->widget.klass!= GFXCLASS_SCROLLBAR) return ;
  SB->start= dmin2(1.0,dmax2(0.0, start));
  SB->end=   dmax2(SB->start+0.000001,dmin2(1.0,dmax2(0.0, end)));
  SB->step=  dmin2(1.0,dmax2(0.0,step));
  scrollbar_update(SB);
}


void gfx_pixgrid_attribs(int pg, int *Rshown, unsigned int *Rw, unsigned int *Rh)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID) 
  {
    if (Rshown) *Rshown= 0;
    if (Rw) *Rw= 1;
    if (Rh) *Rh= 1;
  }
  else
  {
    if (Rshown) *Rshown= B->enabled;
    if (Rw) *Rw= B->widget.w;
    if (Rh) *Rh= B->widget.h;
  }
}

void gfx_pixgrid_put(int pg, int x,int y,
                     unsigned int *img, unsigned int iW,unsigned int iH,
                     int src_x, int src_y, 
                     int copy_w, int copy_h)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID || !B->enabled)  return ;

  clip_for_rect(&src_x, &copy_w, iW);
  clip_for_rect(&src_y, &copy_h, iH);
  clip_for_rect(&x, &copy_w, B->widget.w);
  clip_for_rect(&y, &copy_h, B->widget.h);
  if (copy_w<=0 || copy_h<=0) return ;
  
  gfx_put(GFX_UPDATE,img,iW,iH,src_x,src_y,
                B->widget.x+x,B->widget.y+y, copy_w, copy_h);
}

void gfx_pixgrid_putsimple(int pg, unsigned int *img)
{
  gui_pixgrid_t *B;
  B= (gui_pixgrid_t*) get_widget(pg);
  if (!B || B->widget.klass!=GFXCLASS_PIXGRID || !B->enabled)  return ;

  gfx_pixgrid_put(pg, 0,0,
                  img, B->widget.w, B->widget.h,
                  0,0, B->widget.w, B->widget.h);
}
 
int gfx_ask(char *title, char *butstr, char *fmt, ...)
{
  va_list ap;
  int buttons_h, buttons_w, nbuttons;
  int titw, tith, titx, tity;
  int R;

  int W,H,X,Y; // for the whole dialog
  char **lines; int nlines, lw, lh,lx,ly;

  int i;

  static int dlg_widgets[]= 
    { GUIRaskB1, GUIRaskB2, GUIRaskB3, GUIRaskB4, GUIRaskB5,
      GUIRaskB6, GUIRaskB7, GUIRaskB8 };
  int coor_screen[4];
  int coor_widgets[4*8];

  // LAYOSCR_SCREEN_0(LL,x_window_width,x_window_height);
  gfxask_make_buttons(butstr, coor_widgets, 
                       &nbuttons, &buttons_h, &buttons_w);

  if (title)
    get_text_data(2,title,&titw,&tith,NULL,NULL);

  va_start(ap,fmt);
  format_multi_line_str(fmt, ap, &lines, &nlines);
  va_end(ap);
  multi_line_str_dim(1,lines,nlines,&lw,&lh);

  W= imax2(lw,buttons_w)+2*dialog_spacing;
  H= 3*dialog_spacing + lh + buttons_h;

  if (title) H+= dialog_spacing + tith;
  if (title) W= imax2(W, titw+2*dialog_spacing);

  if (H>x_window_height) Y= x_window_height - H;
                    else Y= (x_window_height-H)/2;
  if (W>x_window_width)  X= 0;
                    else X= (x_window_width-W)/2;

  coor_screen[0]= X; coor_screen[1]= Y;
  coor_screen[2]= W; coor_screen[3]= H;

  enter_screen(8, dlg_widgets, coor_screen);

  // FIXME: make it possible to reposition the dialog
  // when the containing window gets resized..
  // LAYOWID_SCREEN_0(x_window_width,x_window_height,LC);

  gfxask_draw_border(X,Y,W,H);
  gfxask_show_buttons(coor_widgets, nbuttons,
          X+(W - buttons_w)/2,
          Y+H - buttons_h - dialog_spacing);

  if (lw>W) lx= X+0;
       else lx= X+(W-lw)/2;
  ly= Y+ dialog_spacing;
  if (title) ly+= tith+dialog_spacing;

  for(i=0;i<nlines;i++)
  {
    int fh;
    txt_print(0, 1, confirm_fg, confirm_bg, lx,ly, lines[i], NULL,&fh);
    ly+= fh + 1;
  } 
  free(lines[0]);
  free(lines);

  if (title)
  {
    if (titw>W) titx= X+0;
           else titx= X+(W-titw)/2;
    tity= Y+dialog_spacing;
    txt_print(0, 2, confirm_fg, confirm_bg, titx,tity, title, NULL,NULL);
  }

  gfx_update_all();

  R= -1;
  while(1)
  {
    gfx_event_t event;
    if (!gfx_event(NULL,&event)) continue;
    if (event.type==GFXEV_QUIT) { R= -1; break; }
    R= event.type- GUIRaskB1;
    if (R<0 || R>=nbuttons) continue;
    break; 
  }
  gfx_leave_screen();
  return R;
}


char* gfx_select_file(int mode,char *init,char **types)
{
  char *idir, *ifil;
  char *x;
  filesel_t *fs;
  int q;
  char *result;

  if (mode) mode= 1;

  split_initial_fn(init, &idir, &ifil);
  fs= calloc(1,sizeof(*fs));
  fs->dir_start= fs->dir_end= -1;
  filesel_setdir(fs,idir);
  free(idir);
  fs->types= types;
  fs->ext= make_file_extension_list(types);
  file_select_dialog(fs,mode,ifil);
  filesel_render_dirstack(fs);
  populate_file_list(fs);
  gfx_update_all();

  if (ifil) free(ifil);
  ifil= NULL;

retry:
  q= -1;

  while(q<0)
  {
    gfx_event_t event;
    if (gfx_event(NULL,&event))
     switch(event.type)
     {
     case GUIRfilCANCEL:
     case GFXEV_QUIT:   q= 0; break;
     case GUIRfilOK: q= 1; break;
     case GUIRfilREFRESH:
       populate_file_list(fs);
       break;
     case GUIRfilHOME:
       filesel_setdir(fs, sau_gethome());
       populate_file_list(fs);
       filesel_render_dirstack(fs);
       break;
    case GUIRfilLIST:
       x= event.usr;
       if (!x) continue;
       if (x[0]=='D')
       {
         filesel_setdir(fs, combine_path(fs->dir,x+1));
         populate_file_list(fs);
         filesel_render_dirstack(fs);
         break;
       }
       if (x[0]=='F')
       {
         text_entry_set((text_entry_t*) widgets[GUIRfilNAME],x+1);
         break;
       }
       break;
     case GUIRfilD1: case GUIRfilD2: case GUIRfilD3: case GUIRfilD4:
     case GUIRfilD5: case GUIRfilD6: case GUIRfilD7: case GUIRfilD8:
     case GUIRfilD9: case GUIRfilD10:
       filesel_activate_dir(fs, event.type-GUIRfilD1);
       break;
     }
  }
  if (q)
  {
    char *fn, *path;
    int exists, isfile;
    int valid;

    struct stat sbuf;

    fn= textentry_get_text((text_entry_t*)widgets[GUIRfilNAME]);
    if (!fn[0]) { free(fn); goto retry; }
    path= combine_path(fs->dir, fn);

    if (stat(path,&sbuf))                 exists=0; else exists=1;
    if (exists && S_ISREG(sbuf.st_mode)) isfile= 1; else isfile= 0;

    valid= 1;
    if (exists & !isfile)
    {
      gfx_ask("Invalid Selection", "!OK",
              "Selected entry\n\n%s\n\nis not a regular file", path);
      valid= 0; 
    }
    else if (mode==0 && !exists)
    {
      gfx_ask("Invalid Selection", "!OK",
              "Entered path\n\n%s\n\ndoes not exist.", path); 
      valid= 0; 
    }
    else if (mode==1 && exists)
    {
       if ((!init ||strcmp(init,path)) && 
               gfx_ask("Confirm Overwrite", "!OK!Cancel",
                   "%s\n\nDo you want to overwrite this file?", path))
          valid= 0; 
    }
    if (!valid) { free(path); free(fn); goto retry; }
    result= path;
    free(fn);
  }
  else
    result= NULL;

  gfx_leave_screen();

  if (fs->ext)
  {
    int i;
    for(i=0;fs->ext[i];i++) free(fs->ext[i]);
    free(fs->ext[i]);
  }
  filesel_free_buttons(fs);
  free(fs->dir);
  free(fs->files);
  free(fs);
  
  return result;
}


void gfx_canvas_setsize(int wno, int new_w, int new_h)
{
  gui_canvas_t *CC;
  CC= (gui_canvas_t*) get_widget(wno);
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS) return ;

  if (gui_canvas_setbuffer(CC,new_w,new_h)) return ;
  CC->pos_x= 0;
  CC->pos_y= 0;
  gui_canvas_arrange_scrollbars(CC);
  gui_canvas_draw_all(CC);
}


void gfx_canvas_draw_rectangle(int wno,int color, int x,int y,int w,int h)
{
  gui_canvas_t *CC;
  if (!(CC=gui_canvas_get(wno))) return ;
  if (w<=0 || h<=0 || !CC->buffer) return ;
  color= color_u_to_s(color);

  gui_canvas_clipped_hline(CC, color, x,x+w-1, y);
  gui_canvas_clipped_hline(CC, color, x,x+w-1, y+h-1);
 
  gui_canvas_clipped_vline(CC, color, x,y,y+h-1);
  gui_canvas_clipped_vline(CC, color, x+w-1,y, y+h-1);
  gui_canvas_update(CC,x,y,w,h);
}

void gfx_canvas_fill_rectangle(int wno,int color, int x,int y,int w,int h)
{
  gui_canvas_t *CC;
  int sx,sy,ex,ey,bw;

  if (!(CC=gui_canvas_get(wno))) return ;
  if (w<=0 || h<=0 || !CC->buffer) return ;
  color= color_u_to_s(color);

  sx= imin2(imax2(0,x),CC->buffer_w-1);
  sy= imin2(imax2(0,y),CC->buffer_h-1);

  ex= imin2(imax2(0,x+w), CC->buffer_w);
  ey= imin2(imax2(0,y+h), CC->buffer_h);

  bw= CC->buffer_w;
  for(y=sy;y<ey;y++)
    for(x=sx;x<ex;x++)
      CC->buffer[y*bw+x]= color;

  gui_canvas_update(CC,sx,sy,ex-sx,ey-sy);
}


void gfx_canvas_recsel_begin(int wno, gfx_event_t *ev)
{
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;
  if (!CC->buffer) return ;
  CC->rs_x0= CC->rs_x1= ev->x;
  CC->rs_y0= CC->rs_y1= ev->y;
  CC->recsel= 1;
  install_motion_handler(CC, gui_canvas_motion);
}


void gfx_canvas_recsel_end(int wno,int *Rx1, int *Ry1, int *Rx2, int *Ry2)
{
  int minx,miny,maxx,maxy,Z;
  gui_canvas_t *CC;
  if (!(CC= gui_canvas_get(wno))) return ;

  uninstall_motion_handler();
  gui_canvas_draw_recsel(CC);
  minx= imin2( CC->rs_x0, CC->rs_x1 );
  maxx= imax2( CC->rs_x0, CC->rs_x1 );
  miny= imin2( CC->rs_y0, CC->rs_y1 );
  maxy= imax2( CC->rs_y0, CC->rs_y1 );
  gui_canvas_update(CC, minx, miny, maxx-minx+1, maxy-miny+1);

  Rx1= Rx1 ? Rx1 : &Z;
  Ry1= Ry1 ? Ry1 : &Z;
  Rx2= Rx2 ? Rx2 : &Z;
  Ry2= Ry2 ? Ry2 : &Z;

  *Rx1= CC->rs_x0;
  *Ry1= CC->rs_y0;
  *Rx2= CC->rs_x1;
  *Ry2= CC->rs_y1;
  CC->recsel= 0;
}


void gfx_canvas_print(int font, int color, int rot, int x, int y, char *str)
{
  // later ..  
}

void gfx_canvas_put_graymap
       (int wno, unsigned int color, int dx,int dy, int w, int h,
        unsigned char *source, int sw, int sh, int sx, int sy)
{
  gui_canvas_t *CC;
  int x,y;
  int bw;
  uint32_t *B; 
  int dp,sp;

  CC= (gui_canvas_t*) get_widget(wno);
  
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS || !CC->buffer ||
      clip_for_rect(&sx, &w, sw) ||
      clip_for_rect(&sy, &h, sh) ||
      clip_for_rect(&dx, &w, CC->buffer_w) ||
      clip_for_rect(&dy, &h, CC->buffer_h)) 
    return ;

  color= color_u_to_s(color);

  bw= CC->buffer_w;
  B= CC->buffer;
  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
    {
      dp= (dy+y)*bw + (dx+x);
      sp= (sy+y)*sw + (sx+x);
      B[dp]= blend_usr_svr(source[sp], color, B[dp]);
    }

  gui_canvas_update(CC, dx, dy, w,h);
}

void gfx_canvas_put
       (int wno, int dx,int dy, int w, int h,
        unsigned int *source, int sw, int sh, int sx, int sy)
{
  gui_canvas_t *CC;
  int x,y;
  int bw;
  uint32_t *B; 
  int dp,sp;

  CC= (gui_canvas_t*) get_widget(wno);
  
  if (!CC || CC->widget.klass!=GFXCLASS_CANVAS || !CC->buffer ||
      clip_for_rect(&sx, &w, sw) ||
      clip_for_rect(&sy, &h, sh) ||
      clip_for_rect(&dx, &w, CC->buffer_w) ||
      clip_for_rect(&dy, &h, CC->buffer_h)) 
    return ;


  bw= CC->buffer_w;
  B= CC->buffer;

  for(y=0;y<h;y++)
    for(x=0;x<w;x++)
    {
      dp= (dy+y)*bw + (dx+x);
      sp= (sy+y)*sw + (sx+x);
      B[dp]= source[sp];
    }

  gui_canvas_update(CC, dx, dy, w,h);
}


void gfx_spinner_set_imin(int wno, int min)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MIN;
  SS->intmin= min;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_imax(int wno, int max)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MAX;
  SS->intmax= max;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_iquant(int wno, int qua)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->intq= qua;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fmin(int wno, double min)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MIN;
  SS->flomin= min;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fmax(int wno, double max)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->limflags |= SPINNER_MAX;
  SS->flomax= max;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fquant(int wno, double qua)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  SS->floq= qua;
  spinner_apply_limits(SS);
}

void gfx_spinner_set_fvalue(int wno, double value)
{
  double V;
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  V= SS->flov;
  SS->flov= value;
  spinner_apply_limits(SS);
  if (V!=SS->flov) gui_spinner_render(SS);
}

void gfx_spinner_set_ivalue(int wno, int value)
{
  int V;
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return ;
  V= SS->intv;
  SS->intv= value;
  spinner_apply_limits(SS);
  if (V!=SS->intv) gui_spinner_render(SS);
}

int gfx_spinner_get_ivalue(int wno)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return 0;
  return SS->intv; 
}

double gfx_spinner_get_fvalue(int wno)
{
  gui_spinner_t *SS;
  if (!(SS= get_spinner_widget(wno))) return 0.0;
  return SS->flov; 
}



void gfx_logview_printf(int wno, const char *fmt, ...)
{
  widget_t *W; 
  char *txt;
  va_list ap;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  va_start(ap,fmt);
  txt= vmprintf(fmt, ap);
  va_end(ap);
  
  logview_write((gui_logview_t*) W, txt, strlen(txt));
  free(txt);
}

void gfx_logview_write(int wno, const char *txt, size_t len)
{
  widget_t *W;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  logview_write((gui_logview_t*) W, txt, len);
}


void gfx_logview_clear(int wno)
{
  widget_t *W;
  int i;
  gui_logview_t *L;
  W= get_widget(wno);
  if (!W || W->klass!=GFXCLASS_LOGVIEW) return ;
  L= (gui_logview_t*) W;
  if (L->nlines==0) return ;
  for(i=0;i<L->nlines;i++) free(L->lines[i]);
  L->nlines= 0;
  if (W->shown) logview_render(L);
}
static void LAYOWID_SCREEN_0(int WIDTH,int HEIGHT,int *L) {
 int COWfnleft_height= 28;
 int VPAD= 8;
 int COWurlleft_height= COWfnleft_height;
 int COWsaveleft_width= 90;
 int COWsaveleft_height= COWfnleft_height;
 int COWloadleft_width= COWsaveleft_width;
 int COWloadleft_height= COWfnleft_height;
 int COWtitleleft_height= COWfnleft_height;
 int COWdelleft_bottom= HEIGHT-VPAD;
 int COWdelleft_width= COWsaveleft_width;
 int COWdelleft_height= COWsaveleft_height;
 int COWupdateleft_width= COWdelleft_width;
 int COWupdateleft_height= COWdelleft_height;
 int COWputright_width= COWdelleft_width;
 int COWputright_height= COWdelleft_height;
 int COWfnright_height= COWfnleft_height;
 int COWloadright_width= COWloadleft_width;
 int COWloadright_height= COWloadleft_height;
 int COWsaveright_right= WIDTH-VPAD;
 int COWsaveright_width= COWloadleft_width;
 int COWsaveright_height= COWloadleft_height;
 int COWurlright_height= COWurlleft_height;
 int COWtitleright_height= COWtitleleft_height;
 int COWdelright_right= WIDTH-VPAD;
 int COWdelright_width= COWputright_width;
 int COWdelright_height= COWputright_height;
 int COWupdateright_width= COWputright_width;
 int COWdnleft_width= 45;
 int COWupdateright_height= COWputright_height;
 int COWputleft_width= COWputright_width;
 int COWputleft_height= COWputright_height;
 int COWparentleft_left= VPAD;
 int COWparentleft_width= COWputright_width;
 int COWupleft_width= COWdnleft_width;
 int COWparentleft_height= COWputright_height;
 int COWmkdirleft_width= COWparentleft_width;
 int COWmkdirleft_height= COWparentleft_height;
 int COWleft_left= VPAD;
 int COWleft_width= (WIDTH-3*VPAD)/2;
 int COWfnleft_left= COWleft_left;
 int COWfnleft_top= VPAD;
 int COWfnleft_bottom= COWfnleft_top+COWfnleft_height;
 int COWfnleft_width= COWleft_width;
 int COWparentright_height= COWparentleft_height;
 int COWurlleft_left= COWleft_left;
 int COWurlleft_width= COWleft_width;
 int COWparentright_width= COWparentleft_width;
 int COWsaveleft_left= COWleft_left;
 int COWparentleft_right= COWparentleft_left+COWparentleft_width;
 int COWupleft_height= COWparentleft_height;
 int COWsaveleft_right= COWsaveleft_left+COWsaveleft_width;
 int COWsaveleft_top= COWfnleft_bottom+VPAD;
 int COWsaveleft_bottom= COWsaveleft_top+COWsaveleft_height;
 int COWloadleft_left= COWsaveleft_right+VPAD;
 int COWloadleft_right= COWloadleft_left+COWloadleft_width;
 int COWloadleft_top= COWsaveleft_top;
 int COWloadleft_bottom= COWloadleft_top+COWloadleft_height;
 int COWtitleleft_left= COWleft_left;
 int COWtitleleft_width= COWleft_width;
 int COWmkdirright_height= COWparentleft_height;
 int COWdelleft_left= COWurlleft_left;
 int COWdelleft_right= COWdelleft_left+COWdelleft_width;
 int COWdnleft_height= COWparentleft_height;
 int COWdelleft_top= COWdelleft_bottom-COWdelleft_height;
 int COWmkdirright_width= COWparentleft_width;
 int COWupdateleft_left= COWdelleft_right+VPAD;
 int COWupdateleft_right= COWupdateleft_left+COWupdateleft_width;
 int COWdelright_left= COWdelright_right-COWdelright_width;
 int COWupdateleft_top= COWdelleft_top;
 int COWtitleright_width= COWtitleleft_width;
 int COWupdateleft_bottom= COWupdateleft_top+COWupdateleft_height;
 int COWputright_left= COWupdateleft_right+VPAD;
 int COWputright_right= COWputright_left+COWputright_width;
 int COWputright_top= COWdelleft_top;
 int COWputright_bottom= COWputright_top+COWputright_height;
 int COWurlright_width= COWurlleft_width;
 int COWupright_height= COWupleft_height;
 int COWupright_width= COWupleft_width;
 int COWfnright_top= COWfnleft_top;
 int COWfnright_bottom= COWfnright_top+COWfnright_height;
 int COWfnright_width= COWfnleft_width;
 int COWright_width= COWleft_width;
 int COWsaveright_left= COWsaveright_right-COWsaveright_width;
 int COWsaveright_top= COWfnright_bottom+VPAD;
 int COWsaveright_bottom= COWsaveright_top+COWsaveright_height;
 int COWdnright_height= COWupleft_height;
 int COWdnright_width= COWupleft_width;
 int COWleft_right= COWleft_left+COWleft_width;
 int COWright_left= COWleft_right+VPAD;
 int COWright_right= COWright_left+COWright_width;
 int COWleft_top= COWsaveleft_bottom+VPAD;
 int COWright_top= COWleft_top;
 int COWfnleft_right= COWfnleft_left+COWfnleft_width;
 int COWmkdirleft_left= COWparentleft_right+VPAD;
 int COWurlleft_right= COWurlleft_left+COWurlleft_width;
 int COWloadright_top= COWsaveright_top;
 int COWloadright_right= COWsaveright_left-VPAD;
 int COWloadright_left= COWloadright_right-COWloadright_width;
 int COWdnleft_right= COWleft_right;
 int COWputleft_top= COWputright_top;
 int COWparentright_right= COWright_right;
 int COWurlright_left= COWurlleft_right+VPAD;
 int COWparentright_left= COWparentright_right-COWparentright_width;
 int COWfnright_left= COWfnleft_right+VPAD;
 int COWurlright_right= COWurlright_left+COWurlright_width;
 int COWtitleleft_right= COWtitleleft_left+COWtitleleft_width;
 int COWtitleleft_bottom= COWdelleft_top-VPAD;
 int COWupdateright_top= COWputright_top;
 int COWtitleright_left= COWtitleleft_right+VPAD;
 int COWtitleright_right= COWtitleright_left+COWtitleright_width;
 int COWupdateright_right= COWdelright_left-VPAD;
 int COWmkdirright_right= COWparentright_left-VPAD;
 int COWupdateright_left= COWupdateright_right-COWupdateright_width;
 int COWdnright_left= COWright_left;
 int COWdelright_top= COWputright_top;
 int COWdnright_right= COWdnright_left+COWdnright_width;
 int COWupright_left= COWdnright_right+VPAD;
 int COWupright_right= COWupright_left+COWupright_width;
 int COWmkdirleft_right= COWmkdirleft_left+COWmkdirleft_width;
 int COWdelright_bottom= COWdelright_top+COWdelright_height;
 int COWloadright_bottom= COWloadright_top+COWloadright_height;
 int COWdnleft_left= COWdnleft_right-COWdnleft_width;
 int COWputleft_bottom= COWputleft_top+COWputleft_height;
 int COWmkdirright_left= COWmkdirright_right-COWmkdirright_width;
 int COWputleft_right= COWupdateright_left-VPAD;
 int COWtitleleft_top= COWtitleleft_bottom-COWtitleleft_height;
 int COWputleft_left= COWputleft_right-COWputleft_width;
 int COWupdateright_bottom= COWupdateright_top+COWupdateright_height;
 int COWfnright_right= COWfnright_left+COWfnright_width;
 int COWupleft_right= COWdnleft_left-VPAD;
 int COWurlleft_bottom= COWtitleleft_top-VPAD;
 int COWtitleright_top= COWtitleleft_top;
 int COWupleft_left= COWupleft_right-COWupleft_width;
 int COWtitleright_bottom= COWtitleright_top+COWtitleright_height;
 int COWurlleft_top= COWurlleft_bottom-COWurlleft_height;
 int COWparentleft_bottom= COWurlleft_top-VPAD;
 int COWparentleft_top= COWparentleft_bottom-COWparentleft_height;
 int COWurlright_top= COWurlleft_top;
 int COWurlright_bottom= COWurlright_top+COWurlright_height;
 int COWmkdirright_top= COWparentleft_top;
 int COWleft_bottom= COWparentleft_top-VPAD;
 int COWleft_height= COWleft_bottom-COWleft_top;
 int COWdnleft_top= COWparentleft_top;
 int COWupright_top= COWparentleft_top;
 int COWupright_bottom= COWupright_top+COWupright_height;
 int COWmkdirleft_top= COWparentleft_top;
 int COWupleft_top= COWparentleft_top;
 int COWparentright_top= COWparentleft_top;
 int COWdnright_top= COWparentleft_top;
 int COWmkdirright_bottom= COWmkdirright_top+COWmkdirright_height;
 int COWupleft_bottom= COWupleft_top+COWupleft_height;
 int COWmkdirleft_bottom= COWmkdirleft_top+COWmkdirleft_height;
 int COWparentright_bottom= COWparentright_top+COWparentright_height;
 int COWdnleft_bottom= COWdnleft_top+COWdnleft_height;
 int COWright_height= COWleft_height;
 int COWdnright_bottom= COWdnright_top+COWdnright_height;
 int COWright_bottom= COWright_top+COWright_height;
  L[0]= COWleft_left; L[1]= COWleft_top;
  L[2]= COWleft_width; L[3]= COWleft_height;
  L[4]= COWfnleft_left; L[5]= COWfnleft_top;
  L[6]= COWfnleft_width; L[7]= COWfnleft_height;
  L[8]= COWurlleft_left; L[9]= COWurlleft_top;
  L[10]= COWurlleft_width; L[11]= COWurlleft_height;
  L[12]= COWsaveleft_left; L[13]= COWsaveleft_top;
  L[14]= COWsaveleft_width; L[15]= COWsaveleft_height;
  L[16]= COWloadleft_left; L[17]= COWloadleft_top;
  L[18]= COWloadleft_width; L[19]= COWloadleft_height;
  L[20]= COWtitleleft_left; L[21]= COWtitleleft_top;
  L[22]= COWtitleleft_width; L[23]= COWtitleleft_height;
  L[24]= COWdelleft_left; L[25]= COWdelleft_top;
  L[26]= COWdelleft_width; L[27]= COWdelleft_height;
  L[28]= COWupdateleft_left; L[29]= COWupdateleft_top;
  L[30]= COWupdateleft_width; L[31]= COWupdateleft_height;
  L[32]= COWputright_left; L[33]= COWputright_top;
  L[34]= COWputright_width; L[35]= COWputright_height;
  L[36]= COWfnright_left; L[37]= COWfnright_top;
  L[38]= COWfnright_width; L[39]= COWfnright_height;
  L[40]= COWloadright_left; L[41]= COWloadright_top;
  L[42]= COWloadright_width; L[43]= COWloadright_height;
  L[44]= COWsaveright_left; L[45]= COWsaveright_top;
  L[46]= COWsaveright_width; L[47]= COWsaveright_height;
  L[48]= COWright_left; L[49]= COWright_top;
  L[50]= COWright_width; L[51]= COWright_height;
  L[52]= COWurlright_left; L[53]= COWurlright_top;
  L[54]= COWurlright_width; L[55]= COWurlright_height;
  L[56]= COWtitleright_left; L[57]= COWtitleright_top;
  L[58]= COWtitleright_width; L[59]= COWtitleright_height;
  L[60]= COWdelright_left; L[61]= COWdelright_top;
  L[62]= COWdelright_width; L[63]= COWdelright_height;
  L[64]= COWupdateright_left; L[65]= COWupdateright_top;
  L[66]= COWupdateright_width; L[67]= COWupdateright_height;
  L[68]= COWputleft_left; L[69]= COWputleft_top;
  L[70]= COWputleft_width; L[71]= COWputleft_height;
  L[72]= COWparentleft_left; L[73]= COWparentleft_top;
  L[74]= COWparentleft_width; L[75]= COWparentleft_height;
  L[76]= COWmkdirleft_left; L[77]= COWmkdirleft_top;
  L[78]= COWmkdirleft_width; L[79]= COWmkdirleft_height;
  L[80]= COWupleft_left; L[81]= COWupleft_top;
  L[82]= COWupleft_width; L[83]= COWupleft_height;
  L[84]= COWdnleft_left; L[85]= COWdnleft_top;
  L[86]= COWdnleft_width; L[87]= COWdnleft_height;
  L[88]= COWdnright_left; L[89]= COWdnright_top;
  L[90]= COWdnright_width; L[91]= COWdnright_height;
  L[92]= COWupright_left; L[93]= COWupright_top;
  L[94]= COWupright_width; L[95]= COWupright_height;
  L[96]= COWmkdirright_left; L[97]= COWmkdirright_top;
  L[98]= COWmkdirright_width; L[99]= COWmkdirright_height;
  L[100]= COWparentright_left; L[101]= COWparentright_top;
  L[102]= COWparentright_width; L[103]= COWparentright_height;
}
static void LAYOSCR_SCREEN_0(int *L,int WIDTH,int HEIGHT) {
int COleft= -1;
int COright= -1;
int COtop= -1;
int CObottom= -1;
int COwidth= -1;
int COheight= -1;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCREEN_0(){
 static int SWID[]= {     Wleft,
    Wfnleft,
    Wurlleft,
    Wsaveleft,
    Wloadleft,
    Wtitleleft,
    Wdelleft,
    Wupdateleft,
    Wputright,
    Wfnright,
    Wloadright,
    Wsaveright,
    Wright,
    Wurlright,
    Wtitleright,
    Wdelright,
    Wupdateright,
    Wputleft,
    Wparentleft,
    Wmkdirleft,
    Wupleft,
    Wdnleft,
    Wdnright,
    Wupright,
    Wmkdirright,
    Wparentright,
};
  int i;
  int LC[104]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCREEN_0(LL,x_window_width,x_window_height);
  enter_screen(26, SWID,LL);
  widgets[Wleft]= gfx_list(0,0,1);
  widgets[Wleft]->number= Wleft;
  widgets[Wfnleft]= gfx_label(1,0x000000,0xededed,'L',"");
  widgets[Wfnleft]->number= Wfnleft;
  widgets[Wurlleft]= gfx_label(1,0x000000,0xededed,'L',"");
  widgets[Wurlleft]->number= Wurlleft;
  widgets[Wsaveleft]= gfx_button("Save", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wsaveleft]->number= Wsaveleft;
  widgets[Wloadleft]= gfx_button("Load", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wloadleft]->number= Wloadleft;
  widgets[Wtitleleft]= text_entry_new("");
  widgets[Wtitleleft]->number= Wtitleleft;
  widgets[Wdelleft]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wdelleft]->number= Wdelleft;
  widgets[Wupdateleft]= gfx_button("Update", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wupdateleft]->number= Wupdateleft;
  widgets[Wputright]= gfx_button("Put ->", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wputright]->number= Wputright;
  widgets[Wfnright]= gfx_label(1,0x000000,0xededed,'L',"");
  widgets[Wfnright]->number= Wfnright;
  widgets[Wloadright]= gfx_button("Load", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wloadright]->number= Wloadright;
  widgets[Wsaveright]= gfx_button("Save", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wsaveright]->number= Wsaveright;
  widgets[Wright]= gfx_list(0,0,1);
  widgets[Wright]->number= Wright;
  widgets[Wurlright]= gfx_label(1,0x000000,0xededed,'L',"");
  widgets[Wurlright]->number= Wurlright;
  widgets[Wtitleright]= text_entry_new("");
  widgets[Wtitleright]->number= Wtitleright;
  widgets[Wdelright]= gfx_button("Delete", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wdelright]->number= Wdelright;
  widgets[Wupdateright]= gfx_button("Update", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wupdateright]->number= Wupdateright;
  widgets[Wputleft]= gfx_button("<- Put", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wputleft]->number= Wputleft;
  widgets[Wparentleft]= gfx_button("Parent", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wparentleft]->number= Wparentleft;
  widgets[Wmkdirleft]= gfx_button("MkFolder", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wmkdirleft]->number= Wmkdirleft;
  widgets[Wupleft]= gfx_button("Up", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wupleft]->number= Wupleft;
  widgets[Wdnleft]= gfx_button("Dn", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wdnleft]->number= Wdnleft;
  widgets[Wdnright]= gfx_button("Dn", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wdnright]->number= Wdnright;
  widgets[Wupright]= gfx_button("Up", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wupright]->number= Wupright;
  widgets[Wmkdirright]= gfx_button("MkFolder", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wmkdirright]->number= Wmkdirright;
  widgets[Wparentright]= gfx_button("Parent", 'T', NULL,GFXCLASS_BUTTON);
  widgets[Wparentright]->number= Wparentright;
  LAYOWID_SCREEN_0(LL[2],LL[3],LC);
  for(i=0;i<26;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[Wleft], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[Wfnleft], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[Wurlleft], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[Wsaveleft], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[Wloadleft], LC[16], LC[17],LC[18],LC[19]);
  widget_move(widgets[Wtitleleft], LC[20], LC[21],LC[22],LC[23]);
  widget_move(widgets[Wdelleft], LC[24], LC[25],LC[26],LC[27]);
  widget_move(widgets[Wupdateleft], LC[28], LC[29],LC[30],LC[31]);
  widget_move(widgets[Wputright], LC[32], LC[33],LC[34],LC[35]);
  widget_move(widgets[Wfnright], LC[36], LC[37],LC[38],LC[39]);
  widget_move(widgets[Wloadright], LC[40], LC[41],LC[42],LC[43]);
  widget_move(widgets[Wsaveright], LC[44], LC[45],LC[46],LC[47]);
  widget_move(widgets[Wright], LC[48], LC[49],LC[50],LC[51]);
  widget_move(widgets[Wurlright], LC[52], LC[53],LC[54],LC[55]);
  widget_move(widgets[Wtitleright], LC[56], LC[57],LC[58],LC[59]);
  widget_move(widgets[Wdelright], LC[60], LC[61],LC[62],LC[63]);
  widget_move(widgets[Wupdateright], LC[64], LC[65],LC[66],LC[67]);
  widget_move(widgets[Wputleft], LC[68], LC[69],LC[70],LC[71]);
  widget_move(widgets[Wparentleft], LC[72], LC[73],LC[74],LC[75]);
  widget_move(widgets[Wmkdirleft], LC[76], LC[77],LC[78],LC[79]);
  widget_move(widgets[Wupleft], LC[80], LC[81],LC[82],LC[83]);
  widget_move(widgets[Wdnleft], LC[84], LC[85],LC[86],LC[87]);
  widget_move(widgets[Wdnright], LC[88], LC[89],LC[90],LC[91]);
  widget_move(widgets[Wupright], LC[92], LC[93],LC[94],LC[95]);
  widget_move(widgets[Wmkdirright], LC[96], LC[97],LC[98],LC[99]);
  widget_move(widgets[Wparentright], LC[100], LC[101],LC[102],LC[103]);
  widget_show(widgets[Wleft], 1);
  widget_show(widgets[Wfnleft], 1);
  widget_show(widgets[Wurlleft], 1);
  widget_show(widgets[Wsaveleft], 1);
  widget_show(widgets[Wloadleft], 1);
  widget_show(widgets[Wtitleleft], 1);
  widget_show(widgets[Wdelleft], 1);
  widget_show(widgets[Wupdateleft], 1);
  widget_show(widgets[Wputright], 1);
  widget_show(widgets[Wfnright], 1);
  widget_show(widgets[Wloadright], 1);
  widget_show(widgets[Wsaveright], 1);
  widget_show(widgets[Wright], 1);
  widget_show(widgets[Wurlright], 1);
  widget_show(widgets[Wtitleright], 1);
  widget_show(widgets[Wdelright], 1);
  widget_show(widgets[Wupdateright], 1);
  widget_show(widgets[Wputleft], 1);
  widget_show(widgets[Wparentleft], 1);
  widget_show(widgets[Wmkdirleft], 1);
  widget_show(widgets[Wupleft], 1);
  widget_show(widgets[Wdnleft], 1);
  widget_show(widgets[Wdnright], 1);
  widget_show(widgets[Wupright], 1);
  widget_show(widgets[Wmkdirright], 1);
  widget_show(widgets[Wparentright], 1);
  gfx_update_all();
}
static void LAYOWID_SCRmkfolder(int WIDTH,int HEIGHT,int *L) {
 int COWfolTITLE_left= 0;
 int VPAD= 8;
 int COWfolTITLE_top= 0;
 int COWfolTITLE_width= WIDTH;
 int COWfolTITLE_height= 45;
 int COWfolLAB0_left= VPAD;
 int COWfolLAB0_width= 80;
 int COWfolLAB0_height= 28;
 int COWfolOK_height= 30;
 int COWfolOK_width= 90;
 int COWfolOK_bottom= HEIGHT-VPAD;
 int COWfolOK_top= COWfolOK_bottom-COWfolOK_height;
 int COWfolNAME_right= WIDTH-VPAD;
 int COWfolOK_left= (WIDTH-2*90-VPAD)/2;
 int COWfolNAME_height= COWfolLAB0_height;
 int COWfolCANCEL_height= COWfolOK_height;
 int COWfolTITLE_right= COWfolTITLE_left+COWfolTITLE_width;
 int COWfolCANCEL_width= COWfolOK_width;
 int COWfolTITLE_bottom= COWfolTITLE_top+COWfolTITLE_height;
 int COWfolCANCEL_top= COWfolOK_top;
 int COWfolOK_right= COWfolOK_left+COWfolOK_width;
 int COWfolCANCEL_left= COWfolOK_right+VPAD;
 int COWfolCANCEL_right= COWfolCANCEL_left+COWfolCANCEL_width;
 int COWfolLAB0_top= COWfolTITLE_bottom+VPAD;
 int COWfolLAB0_right= COWfolLAB0_left+COWfolLAB0_width;
 int COWfolNAME_top= COWfolLAB0_top;
 int COWfolLAB0_bottom= COWfolLAB0_top+COWfolLAB0_height;
 int COWfolCANCEL_bottom= COWfolCANCEL_top+COWfolCANCEL_height;
 int COWfolNAME_left= COWfolLAB0_right+VPAD;
 int COWfolNAME_width= COWfolNAME_right-COWfolNAME_left;
 int COWfolNAME_bottom= COWfolNAME_top+COWfolNAME_height;
  L[0]= COWfolTITLE_left; L[1]= COWfolTITLE_top;
  L[2]= COWfolTITLE_width; L[3]= COWfolTITLE_height;
  L[4]= COWfolLAB0_left; L[5]= COWfolLAB0_top;
  L[6]= COWfolLAB0_width; L[7]= COWfolLAB0_height;
  L[8]= COWfolNAME_left; L[9]= COWfolNAME_top;
  L[10]= COWfolNAME_width; L[11]= COWfolNAME_height;
  L[12]= COWfolOK_left; L[13]= COWfolOK_top;
  L[14]= COWfolOK_width; L[15]= COWfolOK_height;
  L[16]= COWfolCANCEL_left; L[17]= COWfolCANCEL_top;
  L[18]= COWfolCANCEL_width; L[19]= COWfolCANCEL_height;
}
static void LAYOSCR_SCRmkfolder(int *L,int WIDTH,int HEIGHT) {
 int COleft= (WIDTH-400)/2;
 int COheight= 300;
 int COwidth= 400;
 int COright= COleft+COwidth;
 int COtop= (HEIGHT-300)/2;
 int CObottom= COtop+COheight;
  L[0]= COleft;
  L[1]= COtop;
  L[2]= COwidth;
  L[3]= COheight;
}
void gfx_SCRmkfolder(){
 static int SWID[]= {     WfolTITLE,
    WfolLAB0,
    WfolNAME,
    WfolOK,
    WfolCANCEL,
};
  int i;
  int LC[20]; /*widget coords */
  int LL[4]; /* screen coords */
  LAYOSCR_SCRmkfolder(LL,x_window_width,x_window_height);
  enter_screen(5, SWID,LL);
  widgets[WfolTITLE]= gfx_label(3,0x000000,0xcccccc,'C',"Create Folder");
  widgets[WfolTITLE]->number= WfolTITLE;
  widgets[WfolLAB0]= gfx_label(1,0x000000,0xededed,'L',"Name");
  widgets[WfolLAB0]->number= WfolLAB0;
  widgets[WfolNAME]= text_entry_new("");
  widgets[WfolNAME]->number= WfolNAME;
  widgets[WfolOK]= gfx_button("OK", 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfolOK]->number= WfolOK;
  widgets[WfolCANCEL]= gfx_button(NULL, 'T', NULL,GFXCLASS_BUTTON);
  widgets[WfolCANCEL]->number= WfolCANCEL;
  LAYOWID_SCRmkfolder(LL[2],LL[3],LC);
  for(i=0;i<5;i++) { LC[4*i]+= LL[0]; LC[4*i+1]+= LL[1]; }
  widget_move(widgets[WfolTITLE], LC[0], LC[1],LC[2],LC[3]);
  widget_move(widgets[WfolLAB0], LC[4], LC[5],LC[6],LC[7]);
  widget_move(widgets[WfolNAME], LC[8], LC[9],LC[10],LC[11]);
  widget_move(widgets[WfolOK], LC[12], LC[13],LC[14],LC[15]);
  widget_move(widgets[WfolCANCEL], LC[16], LC[17],LC[18],LC[19]);
  widget_show(widgets[WfolTITLE], 1);
  widget_show(widgets[WfolLAB0], 1);
  widget_show(widgets[WfolNAME], 1);
  widget_show(widgets[WfolOK], 1);
  widget_show(widgets[WfolCANCEL], 1);
  gfx_update_all();
}
